@@ -20,6 +20,11 @@
 
 #if defined(__linux__)
 
+typedef struct {
+	const char	*name;		/* cache type name */
+	const uint32_t	value;		/* cache type ID */
+} generic_map_t;
+
 #include <glob.h>
 
 #if defined(__linux__)
@@ -36,7 +41,7 @@
 	memset((path) + len, '\0', sizeof(path) - len);	\
 	strncpy((path) + len, element, strlen(element))
 
-static const struct generic_map cache_type_map[] = {
+static const generic_map_t cache_type_map[] = {
 	{"data"        , CACHE_TYPE_DATA},
 	{"instruction" , CACHE_TYPE_INSTRUCTION},
 	{"unified"     , CACHE_TYPE_UNIFIED},
@@ -70,7 +75,7 @@ static int file_exists(const char *path)
 	struct stat st;
 
 	if (!path) {
-		pr_dbg(stderr, "%s: empty path specified\n", __func__);
+		pr_dbg("%s: empty path specified\n", __func__);
 		return 0;
 	}
 
@@ -96,7 +101,7 @@ static char *get_contents(const char *path)
 	size_t        size;
 
 	if (!path) {
-		pr_dbg(stderr, "%s: empty path specified\n", __func__);
+		pr_dbg("%s: empty path specified\n", __func__);
 		return NULL;
 	}
 
@@ -170,13 +175,13 @@ static uint64_t size_to_bytes(const char *str)
 	char               *s;
 
 	if (!str) {
-		pr_dbg(stderr, "%s: empty string specified\n", __func__);
+		pr_dbg("%s: empty string specified\n", __func__);
 		return 0;
 	}
 
 	ret = sscanf(str, "%lu%ms", &value, &s);
 	if (ret != 2 || !s) {
-		pr_dbg(stderr, "%s: failed to parse suffix from \"%s\"\n",
+		pr_dbg("%s: failed to parse suffix from \"%s\"\n",
 			__func__, str);
 		return 0;
 	}
@@ -192,7 +197,7 @@ static uint64_t size_to_bytes(const char *str)
 		multiplier = (1024 * 1024);
 		break;
 	default:
-		pr_err(stderr, "unable to convert string to bytes: %s\n", str);
+		pr_err("unable to convert string to bytes: %s\n", str);
 		bytes = 0;
 		goto out;
 	}
@@ -212,10 +217,10 @@ out:
  */
 static cache_type_t get_cache_type(const char *name)
 {
-	const struct generic_map *p;
+	const generic_map_t *p;
 
 	if (!name) {
-		pr_dbg(stderr, "%s: no cache type specified\n", __func__);
+		pr_dbg("%s: no cache type specified\n", __func__);
 		goto out;
 	}
 
@@ -235,9 +240,9 @@ out:
  *
  * Returns: read-only string representation, or NULL on error.
  */
-static const char * get_cache_name(cache_type_t type)
+static const char * get_cache_name(const cache_type_t type)
 {
-	const struct generic_map *p;
+	const generic_map_t *p;
 
 	for (p = cache_type_map; p && p->name; p++) {
 		if (p->value == type)
@@ -263,12 +268,12 @@ static int add_cpu_cache_detail(cpu_cache_t *cache, const char *index_path)
 	int      ret = EXIT_FAILURE;
 
 	if (!cache) {
-		pr_dbg(stderr, "%s: invalid cache specified\n", __func__);
+		pr_dbg("%s: invalid cache specified\n", __func__);
 		goto out;
 	}
 
 	if (!index_path) {
-		pr_dbg(stderr, "%s: invalid index specified\n", __func__);
+		pr_dbg("%s: invalid index specified\n", __func__);
 		goto out;
 	}
 
@@ -372,7 +377,7 @@ uint16_t get_max_cache_level(const cpus_t *cpus)
 	uint16_t  max = 0;
 
 	if (!cpus) {
-		pr_dbg(stderr, "%s: invalid cpus parameter\n", __func__);
+		pr_dbg("%s: invalid cpus parameter\n", __func__);
 		return 0;
 	}
 
@@ -401,12 +406,12 @@ cpu_cache_t * get_cpu_cache(const cpus_t *cpus, const uint16_t cache_level)
 	cpu_t *cpu;
 
 	if (!cpus) {
-		pr_dbg(stderr, "%s: invalid cpus parameter\n", __func__);
+		pr_dbg("%s: invalid cpus parameter\n", __func__);
 		return NULL;
 	}
 
 	if (!cache_level) {
-		pr_dbg(stderr, "%s: invalid cache_level: %d\n",
+		pr_dbg("%s: invalid cache_level: %d\n",
 			__func__, cache_level);
 		return NULL;
 	}
@@ -436,12 +441,12 @@ static int get_cpu_cache_details(cpu_t *cpu, const char *cpu_path)
 
 	memset(&globbuf, 0, sizeof(globbuf));
 	if (!cpu) {
-		pr_dbg(stderr, "%s: invalid cpu parameter\n", __func__);
+		pr_dbg("%s: invalid cpu parameter\n", __func__);
 		return ret;
 	}
 
 	if (!cpu_path) {
-		pr_dbg(stderr, "%s: invalid cpu path parameter\n", __func__);
+		pr_dbg("%s: invalid cpu path parameter\n", __func__);
 		return ret;
 	}
 
@@ -459,13 +464,13 @@ static int get_cpu_cache_details(cpu_t *cpu, const char *cpu_path)
 		 * details * via /sys (ARM).
 		 */
 		if (warn_once(WARN_ONCE_NO_CACHE))
-			pr_dbg(stderr, "%s does not exist\n", glob_path);
+			pr_dbg("%s does not exist\n", glob_path);
 		return ret;
 	}
 
 	if (ret2 != S_IFDIR) {
 		if (warn_once(WARN_ONCE_NO_CACHE))
-			pr_err(stderr, "file %s is not a directory\n",
+			pr_err("file %s is not a directory\n",
 				glob_path);
 		return ret;
 	}
@@ -476,7 +481,7 @@ static int get_cpu_cache_details(cpu_t *cpu, const char *cpu_path)
 
 	if (ret2 != 0) {
 		if (warn_once(WARN_ONCE_NO_CACHE))
-			pr_err(stderr, "glob on regex \"%s\" failed: %d\n",
+			pr_err("glob on regex \"%s\" failed: %d\n",
 				glob_path, ret);
 		return ret;
 	}
@@ -486,7 +491,7 @@ static int get_cpu_cache_details(cpu_t *cpu, const char *cpu_path)
 
 	if (!cpu->cache_count) {
 		if (warn_once(WARN_ONCE_NO_CACHE))
-			pr_err(stderr, "no CPU caches found\n");
+			pr_err("no CPU caches found\n");
 		goto err;
 	}
 
@@ -494,7 +499,7 @@ static int get_cpu_cache_details(cpu_t *cpu, const char *cpu_path)
 	if (!cpu->caches) {
 		size_t cache_bytes = cpu->cache_count * sizeof(cpu_cache_t);
 
-		pr_err(stderr, "failed to allocate %zu bytes for cpu caches\n",
+		pr_err("failed to allocate %zu bytes for cpu caches\n",
 			cache_bytes);
 		goto err;
 	}
@@ -537,19 +542,19 @@ cpus_t * get_all_cpu_cache_details(void)
 
 	ret = file_exists(SYS_CPU_PREFIX);
 	if (!ret) {
-		pr_err(stderr, "%s does not exist\n", SYS_CPU_PREFIX);
+		pr_err("%s does not exist\n", SYS_CPU_PREFIX);
 		return NULL;
 	}
 
 	if (ret != S_IFDIR) {
-		pr_err(stderr, "file %s is not a directory\n", SYS_CPU_PREFIX);
+		pr_err("file %s is not a directory\n", SYS_CPU_PREFIX);
 		return NULL;
 	}
 
 	ret = glob(GLOB_PATTERN, GLOB_ONLYDIR, NULL, &globbuf);
 
 	if (ret != 0) {
-		pr_err(stderr, "glob on regex \"%s\" failed: %d\n",
+		pr_err("glob on regex \"%s\" failed: %d\n",
 			GLOB_PATTERN, ret);
 		return NULL;
 	}
@@ -559,7 +564,7 @@ cpus_t * get_all_cpu_cache_details(void)
 
 	if (!cpu_count) {
 		/* Maybe we should check this? */
-		pr_err(stderr, "no CPUs found - is /sys mounted?\n");
+		pr_err("no CPUs found - is /sys mounted?\n");
 		goto out;
 	}
 
@@ -635,4 +640,4 @@ void free_cpu_caches(cpus_t *cpus)
 	free(cpus);
 }
 
-#endif /* __linux__ */
+#endif
