@@ -34,6 +34,7 @@
 #if !defined(__NetBSD__) && !defined(__OpenBSD__) && !defined(__FreeBSD__)
 #include <sys/utsname.h>
 #endif
+#include <sys/statvfs.h>
 
 #if !defined(PR_SET_DISABLE)
 #define SUID_DUMP_DISABLE	(0)       /* No setuid dumping */
@@ -162,13 +163,72 @@ void stress_get_memlimits(
 		return;
 
 	if (fscanf(fp, "%zu", shmall) != 1) {
-		fclose(fp);
+		(void)fclose(fp);
 		return;
 	}
-	fclose(fp);
+	(void)fclose(fp);
 #endif
 }
 
+#if defined(_SC_AVPHYS_PAGES)
+#define STRESS_SC_PAGES	_SC_AVPHYS_PAGES
+#elif defined(_SC_PHYS_PAGES)
+#define STRESS_SC_PAGES	_SC_PHYS_PAGES
+#endif
+
+/*
+ *  stress_get_phys_mem_size()
+ *	get size of physical memory still available, 0 if failed
+ */
+uint64_t stress_get_phys_mem_size(void)
+{
+#if defined(STRESS_SC_PAGES)
+	uint64_t phys_pages = 0;
+	const size_t page_size = stress_get_pagesize();
+	const uint64_t max_pages = ~0ULL / page_size;
+
+	phys_pages = sysconf(STRESS_SC_PAGES);
+	/* Avoid overflow */
+	if (phys_pages > max_pages)
+		phys_pages = max_pages;
+	return phys_pages * page_size;
+#else
+	return 0ULL;
+#endif
+}
+
+/*
+ *  stress_get_filesystem_size()
+ *	get size of free space still available on the
+ *	file system where stress temporary path is located,
+ *	return 0 if failed
+ */
+uint64_t stress_get_filesystem_size(void)
+{
+	int rc;
+	struct statvfs buf;
+	fsblkcnt_t blocks, max_blocks;
+
+	if (!stress_temp_path)
+		return 0;
+
+	rc = statvfs(stress_temp_path, &buf);
+	if (rc < 0)
+		return 0;
+
+	max_blocks = (~(fsblkcnt_t)0) / buf.f_bsize;
+	blocks = buf.f_bavail;
+
+	if (blocks > max_blocks)
+		blocks = max_blocks;
+
+	(void)printf("stress_get_filesystem_size: %" PRIu64 " %" PRIu64 " %" PRIu64 "\n",
+		(uint64_t)buf.f_bsize, (uint64_t)blocks,
+		(uint64_t)buf.f_bsize * blocks);
+
+	return (uint64_t)buf.f_bsize * blocks;
+}
+
 /*
  *  stress_set_nonblock()
  *	try to make fd non-blocking
@@ -281,12 +341,12 @@ int stress_process_dumpable(const bool dumpable)
  *  stress_set_timer_slackigned_longns()
  *	set timer slack in nanoseconds
  */
-void stress_set_timer_slack_ns(const char *optarg)
+void stress_set_timer_slack_ns(const char *opt)
 {
 #if defined(__linux__) && defined(PRCTL_TIMER_SLACK)
-	timer_slack = get_uint32(optarg);
+	timer_slack = get_uint32(opt);
 #else
-	(void)optarg;
+	(void)opt;
 #endif
 }
 
@@ -308,7 +368,7 @@ void stress_set_timer_slack(void)
 void set_proc_name(const char *name)
 {
 #if defined(__linux__) && defined(PR_SET_NAME)
-	if (!(opt_flags & OPT_FLAGS_KEEP_NAME))
+	if (!(g_opt_flags & OPT_FLAGS_KEEP_NAME))
 		(void)prctl(PR_SET_NAME, name);
 #else
 	(void)name;	/* No-op */
@@ -335,6 +395,10 @@ char *munge_underscore(const char *str)
 	return munged;
 }
 
+/*
+ *  __stress_get_stack_direction()
+ *	helper to determine direction of stack
+ */
 static ssize_t __stress_get_stack_direction(const uint8_t *val1)
 {
 	const uint8_t val2;
@@ -378,12 +442,12 @@ uint64_t uint64_zero(void)
  *	set temporary file path, default
  *	is . - current dir
  */
-int stress_set_temp_path(char *path)
+int stress_set_temp_path(const char *path)
 {
 	stress_temp_path = path;
 
 	if (access(path, R_OK | W_OK) < 0) {
-		fprintf(stderr, "temp-path '%s' must be readable "
+		(void)fprintf(stderr, "temp-path '%s' must be readable "
 			"and writeable\n", path);
 		return -1;
 	}
@@ -411,6 +475,20 @@ int stress_temp_filename(
 		name, (int)pid, instance, magic);
 }
 
+/*
+ *  stress_temp_filename_args()
+ *      construct a temp filename using info from args
+ */
+int stress_temp_filename_args(
+	const args_t *args,
+	char *path,
+	const size_t len,
+	const uint64_t magic)
+{
+	return stress_temp_filename(path, len, args->name,
+		args->pid, args->instance, magic);
+}
+
 /*
  *  stress_temp_dir()
  *	create a temporary directory name
@@ -426,6 +504,19 @@ int stress_temp_dir(
 		stress_temp_path, name, (int)pid, instance);
 }
 
+/*
+ *  stress_temp_dir_args()
+ *	create a temporary directory name using info from args
+ */
+int stress_temp_dir_args(
+	const args_t *args,
+	char *path,
+	const size_t len)
+{
+	return stress_temp_dir(path, len,
+		args->name, args->pid, args->instance);
+}
+
 /*
  *   stress_temp_dir_mk()
  *	create a temporary directory
@@ -442,12 +533,22 @@ int stress_temp_dir_mk(
 	ret = mkdir(tmp, S_IRWXU);
 	if (ret < 0) {
 		ret = -errno;
-		pr_fail_err(name, "mkdir");
+		pr_fail("%s: mkdir failed, errno=%d (%s)\n",
+			name, errno, strerror(errno));
 	}
 
 	return ret;
 }
 
+/*
+ *   stress_temp_dir_mk_args()
+ *	create a temporary director using info from args
+ */
+int stress_temp_dir_mk_args(const args_t *args)
+{
+	return stress_temp_dir_mk(args->name, args->pid, args->instance);
+}
+
 /*
  *  stress_temp_dir_rm()
  *	remove a temporary directory
@@ -464,12 +565,22 @@ int stress_temp_dir_rm(
 	ret = rmdir(tmp);
 	if (ret < 0) {
 		ret = -errno;
-		pr_fail_err(name, "rmdir");
+		pr_fail("%s: rmdir failed, errno=%d (%s)\n",
+			name, errno, strerror(errno));
 	}
 
 	return ret;
 }
 
+/*
+ *  stress_temp_dir_rm_args()
+ *	remove a temporary directory using info from args
+ */
+int stress_temp_dir_rm_args(const args_t *args)
+{
+	return stress_temp_dir_rm(args->name, args->pid, args->instance);
+}
+
 /*
  *  stress_cwd_readwriteable()
  *	check if cwd is read/writeable
@@ -479,11 +590,11 @@ void stress_cwd_readwriteable(void)
 	char path[PATH_MAX];
 
 	if (getcwd(path, sizeof(path)) == NULL) {
-		pr_dbg(stderr, "Cannot determine current working directory\n");
+		pr_dbg("Cannot determine current working directory\n");
 		return;
 	}
 	if (access(path, R_OK | W_OK)) {
-		pr_inf(stdout, "Working directory %s is not read/writeable, "
+		pr_inf("Working directory %s is not read/writeable, "
 			"some I/O tests may fail\n", path);
 		return;
 	}
@@ -506,10 +617,10 @@ const char *stress_strsignal(const int signum)
 		str = strsignal(signum);
 #endif
 	if (str) {
-		snprintf(buffer, sizeof(buffer), "signal %d (%s)",
+		(void)snprintf(buffer, sizeof(buffer), "signal %d (%s)",
 			signum, str);
 	} else {
-		snprintf(buffer, sizeof(buffer), "signal %d",
+		(void)snprintf(buffer, sizeof(buffer), "signal %d",
 			signum);
 	}
 	return buffer;
@@ -599,74 +710,74 @@ int stress_cache_alloc(const char *name)
 #endif
 
 #if !defined(__linux__)
-	shared->mem_cache_size = MEM_CACHE_SIZE;
+	g_shared->mem_cache_size = MEM_CACHE_SIZE;
 #else
 	cpu_caches = get_all_cpu_cache_details();
 	if (!cpu_caches) {
 		if (warn_once(WARN_ONCE_CACHE_DEFAULT))
-			pr_inf(stdout, "%s: using built-in defaults as unable to "
+			pr_inf("%s: using built-in defaults as unable to "
 				"determine cache details\n", name);
-		shared->mem_cache_size = MEM_CACHE_SIZE;
+		g_shared->mem_cache_size = MEM_CACHE_SIZE;
 		goto init_done;
 	}
 
 	max_cache_level = get_max_cache_level(cpu_caches);
 
-	if (shared->mem_cache_level > max_cache_level) {
+	if (g_shared->mem_cache_level > max_cache_level) {
 		if (warn_once(WARN_ONCE_CACHE_REDUCED))
-			pr_dbg(stderr, "%s: reducing cache level from L%d (too high) "
+			pr_dbg("%s: reducing cache level from L%d (too high) "
 				"to L%d\n", name,
-				shared->mem_cache_level, max_cache_level);
-		shared->mem_cache_level = max_cache_level;
+				g_shared->mem_cache_level, max_cache_level);
+		g_shared->mem_cache_level = max_cache_level;
 	}
 
-	cache = get_cpu_cache(cpu_caches, shared->mem_cache_level);
+	cache = get_cpu_cache(cpu_caches, g_shared->mem_cache_level);
 	if (!cache) {
 		if (warn_once(WARN_ONCE_CACHE_NONE))
-			pr_inf(stdout, "%s: using built-in defaults as no suitable "
+			pr_inf("%s: using built-in defaults as no suitable "
 				"cache found\n", name);
-		shared->mem_cache_size = MEM_CACHE_SIZE;
+		g_shared->mem_cache_size = MEM_CACHE_SIZE;
 		goto init_done;
 	}
 
-	if (shared->mem_cache_ways > 0) {
+	if (g_shared->mem_cache_ways > 0) {
 		uint64_t way_size;
 
-		if (shared->mem_cache_ways > cache->ways) {
+		if (g_shared->mem_cache_ways > cache->ways) {
 			if (warn_once(WARN_ONCE_CACHE_WAY))
-				pr_inf(stdout, "%s: cache way value too high - "
+				pr_inf("%s: cache way value too high - "
 					"defaulting to %d (the maximum)\n",
 					name, cache->ways);
-			shared->mem_cache_ways = cache->ways;
+			g_shared->mem_cache_ways = cache->ways;
 		}
 
 		way_size = cache->size / cache->ways;
 
 		/* only fill the specified number of cache ways */
-		shared->mem_cache_size = way_size * shared->mem_cache_ways;
+		g_shared->mem_cache_size = way_size * g_shared->mem_cache_ways;
 	} else {
 		/* fill the entire cache */
-		shared->mem_cache_size = cache->size;
+		g_shared->mem_cache_size = cache->size;
 	}
 
-	if (!shared->mem_cache_size) {
+	if (!g_shared->mem_cache_size) {
 		if (warn_once(WARN_ONCE_CACHE_DEFAULT))
-			pr_inf(stdout, "%s: using built-in defaults as "
+			pr_inf("%s: using built-in defaults as "
 				"unable to determine cache size\n", name);
-		shared->mem_cache_size = MEM_CACHE_SIZE;
+		g_shared->mem_cache_size = MEM_CACHE_SIZE;
 	}
 init_done:
 	free_cpu_caches(cpu_caches);
 #endif
-	shared->mem_cache = calloc(shared->mem_cache_size, 1);
-	if (!shared->mem_cache) {
-		pr_err(stderr, "%s: failed to allocate shared cache buffer\n",
+	g_shared->mem_cache = calloc(g_shared->mem_cache_size, 1);
+	if (!g_shared->mem_cache) {
+		pr_err("%s: failed to allocate shared cache buffer\n",
 			name);
 		return -1;
 	}
 	if (warn_once(WARN_ONCE_CACHE_SIZE))
-		pr_inf(stdout, "%s: default cache size: %" PRIu64 "K\n",
-			name, shared->mem_cache_size / 1024);
+		pr_dbg("%s: default cache size: %" PRIu64 "K\n",
+			name, g_shared->mem_cache_size / 1024);
 
 	return 0;
 }
@@ -677,7 +788,7 @@ init_done:
  */
 void stress_cache_free(void)
 {
-	free(shared->mem_cache);
+	free(g_shared->mem_cache);
 }
 
 /*
@@ -734,7 +845,7 @@ int system_read(
  *      return true if 64 bit value n is prime
  *      http://en.wikipedia.org/wiki/Primality_test
  */
-static inline bool stress_is_prime64(uint64_t n)
+static inline bool stress_is_prime64(const uint64_t n)
 {
 	register uint64_t i, max;
 
@@ -791,6 +902,37 @@ size_t stress_get_file_limit(void)
 	return max - opened;
 }
 
+/*
+ *  stress_sigaltstack()
+ *	attempt to set up an alternative signal stack
+ *	  stack - must be at least 4K
+ *	  size  - size of stack (- STACK_ALIGNMENT)
+ */
+int stress_sigaltstack(const void *stack, const size_t size)
+{
+#if defined(__minix__)
+	(void)stack;
+	(void)size;
+#else
+	stack_t ss;
+
+	if (size < (KB * 4)) {
+		pr_err("sigaltstack stack size %zu must be more than 4K\n",
+			size);
+		return -1;
+	}
+	ss.ss_sp = align_address(stack, STACK_ALIGNMENT);
+	ss.ss_size = size;
+	ss.ss_flags = 0;
+	if (sigaltstack(&ss, NULL) < 0) {
+		pr_fail("sigaltstack failed: errno=%d (%s)\n",
+			errno, strerror(errno));
+		return -1;
+	}
+#endif
+	return 0;
+}
+
 /*
  *  stress_sighandler()
  *	set signal handler in generic way
@@ -802,14 +944,33 @@ int stress_sighandler(
 	struct sigaction *orig_action)
 {
 	struct sigaction new_action;
+#if !defined(__gnu_hurd__) && !defined(__minix__)
+	static bool set_altstack = false;
+
+	/*
+	 *  Signal handlers should really be using an alternative
+	 *  signal stack to be totally safe.  For any new instance we
+	 *  should set this alternative signal stack before setting
+	 *  up any signal handler. We only need to do this once
+	 *  per process instance, so just do it on the first
+	 *  call to stress_sighandler.
+	 */
+	if (!set_altstack) {
+		static uint8_t MLOCKED stack[SIGSTKSZ + STACK_ALIGNMENT];
+
+		if (stress_sigaltstack(stack, SIGSTKSZ) < 0)
+			return -1;
+		set_altstack = true;
+	}
+#endif
 
 	memset(&new_action, 0, sizeof new_action);
 	new_action.sa_handler = handler;
 	sigemptyset(&new_action.sa_mask);
-	new_action.sa_flags = 0;
+	new_action.sa_flags = SA_ONSTACK;
 
 	if (sigaction(signum, &new_action, orig_action) < 0) {
-		pr_fail(stderr, "%s: sigaction %s: errno=%d (%s)\n",
+		pr_fail("%s: sigaction %s: errno=%d (%s)\n",
 			name, stress_strsignal(signum), errno, strerror(errno));
 		return -1;
 	}
@@ -826,7 +987,7 @@ int stress_sigrestore(
 	struct sigaction *orig_action)
 {
 	if (sigaction(signum, orig_action, NULL) < 0) {
-		pr_fail(stderr, "%s: sigaction %s restore: errno=%d (%s)\n",
+		pr_fail("%s: sigaction %s restore: errno=%d (%s)\n",
 			name, stress_strsignal(signum), errno, strerror(errno));
 		return -1;
 	}
@@ -839,7 +1000,7 @@ int stress_sigrestore(
  */
 unsigned int stress_get_cpu(void)
 {
-#if defined(__linux__)
+#if defined(__linux__) && !defined(__PPC64__)
 	int cpu;
 
 	cpu = sched_getcpu();
@@ -854,27 +1015,19 @@ unsigned int stress_get_cpu(void)
  *	report that a stressor is not implemented
  *	on a particular arch or kernel
  */
-int stress_not_implemented(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_not_implemented(const args_t *args)
 {
-	(void)counter;
-	(void)instance;
-	(void)max_ops;
-
 #if !defined(__NetBSD__) && !defined(__OpenBSD__) && !defined(__FreeBSD__)
 	struct utsname buf;
 
 	if (!uname(&buf)) {
-		pr_inf(stdout, "%s: this stressor is not implemented on this system: %s %s %s\n",
-			name, buf.machine, buf.sysname, buf.release);
+		pr_inf("%s: this stressor is not implemented on this system: %s %s %s\n",
+			args->name, buf.machine, buf.sysname, buf.release);
 		return EXIT_NOT_IMPLEMENTED;
 	}
 #endif
-	pr_inf(stdout, "%s: this stressor is not implemented on this system\n",
-		name);
+	pr_inf("%s: this stressor is not implemented on this system\n",
+		args->name);
 	return EXIT_NOT_IMPLEMENTED;
 }
 
@@ -971,3 +1124,51 @@ void *align_address(const void *addr, const size_t alignment)
 
 	return (void *)uintptr;
 }
+
+/*
+ *  keep_stressing()
+ *	returns true if we can keep on running a stressor
+ */
+bool HOT OPTIMIZE3 __keep_stressing(const args_t *args)
+{
+	return (LIKELY(g_keep_stressing_flag) &&
+	        LIKELY(!args->max_ops || (*args->counter < args->max_ops)));
+}
+
+/*
+ *  stress_uint64_to_str()
+ *	turn 64 bit size to human readable string
+ */
+char *stress_uint64_to_str(char *str, size_t len, const uint64_t val)
+{
+	typedef struct {
+		uint64_t size;
+		char *suffix;
+	} size_info_t;
+
+	static const size_info_t size_info[] = {
+		{ EB, "E" },
+		{ PB, "P" },
+		{ TB, "T" },
+		{ GB, "G" },
+		{ MB, "M" },
+		{ KB, "K" },
+	};
+	size_t i;
+	char *suffix = "";
+	uint64_t scale = 1;
+
+	for (i = 0; i < SIZEOF_ARRAY(size_info); i++) {
+		uint64_t scaled = val / size_info[i].size;
+
+		if ((scaled >= 1) && (scaled < 1024)) {
+			suffix = size_info[i].suffix;
+			scale = size_info[i].size;
+			break;
+		}
+	}
+
+	(void)snprintf(str, len, "%.1f%s", (double)val / scale, suffix);
+
+	return str;
+}
