@@ -33,13 +33,13 @@ typedef struct {
 	bool ignore;			/* true to ignore using this */
 } settings_t;
 
-static pid_t pid;
-static bool enabled;
+static pid_t pid;			/* PID of ignite process */
+static bool enabled;			/* true if ignite process running */
 
 #define SETTING(path, default_setting)	\
 	{ path, default_setting, 0, NULL, 0, false }
 
-settings_t settings[] = {
+static settings_t settings[] = {
 #if defined(__linux__) && defined(STRESS_X86)
 	/* x86 Intel P-State maximizing settings */
 	SETTING("/sys/devices/system/cpu/intel_pstate/max_perf_pct", "100"),
@@ -82,7 +82,7 @@ void ignite_cpu_start(void)
 			settings[i].default_setting,
 			settings[i].default_setting_len);
 		if (ret < 0) {
-			pr_dbg(stderr, "ignite-cpu: cannot set %s to %s, "
+			pr_dbg("ignite-cpu: cannot set %s to %s, "
 				"errno=%d (%s)\n",
 				settings[i].path, settings[i].default_setting,
 				-ret, strerror(-ret));
@@ -106,12 +106,12 @@ void ignite_cpu_start(void)
 
 	pid = fork();
 	if (pid < 0) {
-		pr_dbg(stderr, "failed to start ignite cpu daemon, "
+		pr_dbg("failed to start ignite cpu daemon, "
 			"errno=%d (%s)\n", errno, strerror(errno));
 		return;
 	} else if (pid == 0) {
 		/* Child */
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
 
 		for (;;) {
@@ -126,7 +126,7 @@ void ignite_cpu_start(void)
 		}
 	} else {
 		/* Parent */
-		(void)setpgid(pid, pgrp);
+		(void)setpgid(pid, g_pgrp);
 	}
 }
 
