@@ -51,12 +51,12 @@ static const domain_t domains[] = {
  */
 void stress_set_net_port(
 	const char *optname,
-	const char *optarg,
+	const char *opt,
 	const int min_port,
 	const int max_port,
 	int *port)
 {
-	*port = get_uint64(optarg);
+	*port = get_uint64(opt);
 	check_range(optname, *port,
 		min_port, max_port - STRESS_PROCS_MAX);
 }
@@ -80,11 +80,11 @@ int stress_set_net_domain(
 			return 0;
 		}
 	}
-	fprintf(stderr, "%s: domain must be one of:", name);
+	(void)fprintf(stderr, "%s: domain must be one of:", name);
 	for (i = 0; i < SIZEOF_ARRAY(domains); i++)
 		if (domain_mask & domains[i].domain_flags)
-			fprintf(stderr, " %s", domains[i].name);
-	fprintf(stderr, "\n");
+			(void)fprintf(stderr, " %s", domains[i].name);
+	(void)fprintf(stderr, "\n");
 	*domain = 0;
 	return -1;
 }
@@ -100,7 +100,7 @@ void stress_set_sockaddr(
 	const int port,
 	struct sockaddr **sockaddr,
 	socklen_t *len,
-	int net_addr)
+	const int net_addr)
 {
 	switch (domain) {
 #if defined(AF_INET)
@@ -154,7 +154,7 @@ void stress_set_sockaddr(
 
 		memset(&addr, 0, sizeof(addr));
 		addr.sun_family = AF_UNIX;
-		snprintf(addr.sun_path, sizeof(addr.sun_path),
+		(void)snprintf(addr.sun_path, sizeof(addr.sun_path),
 			"/tmp/stress-ng-%d-%" PRIu32,
 			(int)ppid, instance);
 		*sockaddr = (struct sockaddr *)&addr;
@@ -163,7 +163,7 @@ void stress_set_sockaddr(
 	}
 #endif
 	default:
-		pr_fail_dbg(name, "unknown domain");
+		pr_fail("%s: unknown domain %d\n", name, domain);
 		(void)kill(getppid(), SIGALRM);
 		exit(EXIT_FAILURE);
 	}
