@@ -31,13 +31,12 @@
 #include <locale.h>
 #include <linux/perf_event.h>
 
-#define THOUSAND	(1000.0)
-#define MILLION		(THOUSAND * THOUSAND)
-#define BILLION		(THOUSAND * MILLION)
-#define TRILLION	(THOUSAND * BILLION)
-#define QUADRILLION	(THOUSAND * TRILLION)
-#define QUINTILLION	(THOUSAND * QUADRILLION)
-
+#define THOUSAND	(1.0E3)
+#define MILLION		(1.0E6)
+#define BILLION		(1.0E9)
+#define TRILLION	(1.0E12)
+#define QUADRILLION	(1.0E15)
+#define QUINTILLION	(1.0E18)
 
 /* used for table of perf events to gather */
 typedef struct {
@@ -223,15 +222,15 @@ static unsigned long perf_type_tracepoint_resolve_config(const int id)
 	if (not_found)
 		return UNRESOLVED;
 
-	snprintf(path, sizeof(path), "/sys/kernel/debug/tracing/events/%s/id",
+	(void)snprintf(path, sizeof(path), "/sys/kernel/debug/tracing/events/%s/id",
 		perf_tp_info[i].path);
 	if ((fp = fopen(path, "r")) == NULL)
 		return UNRESOLVED;
 	if (fscanf(fp, "%lu", &config) != 1) {
-		fclose(fp);
+		(void)fclose(fp);
 		return UNRESOLVED;
 	}
-	fclose(fp);
+	(void)fclose(fp);
 
 	return config;
 }
@@ -297,7 +296,7 @@ int perf_open(stress_perf_t *sp)
 
 	if (!sp)
 		return -1;
-	if (shared->perf.no_perf)
+	if (g_shared->perf.no_perf)
 		return -1;
 
 	memset(sp, 0, sizeof(stress_perf_t));
@@ -327,13 +326,13 @@ int perf_open(stress_perf_t *sp)
 		}
 	}
 	if (!sp->perf_opened) {
-		pthread_spin_lock(&shared->perf.lock);
-		if (!shared->perf.no_perf) {
-			pr_dbg(stderr, "perf_event_open failed, no "
+		pthread_spin_lock(&g_shared->perf.lock);
+		if (!g_shared->perf.no_perf) {
+			pr_dbg("perf_event_open failed, no "
 				"perf events [%u]\n", getpid());
-			shared->perf.no_perf = true;
+			g_shared->perf.no_perf = true;
 		}
-		pthread_spin_unlock(&shared->perf.lock);
+		pthread_spin_unlock(&g_shared->perf.lock);
 		return -1;
 	}
 
@@ -564,7 +563,7 @@ const char *perf_stat_scale(const uint64_t counter, const double duration)
 	}
 	scaled /= scale;
 
-	snprintf(buffer, sizeof(buffer), "%11.2f %-5s",
+	(void)snprintf(buffer, sizeof(buffer), "%11.2f %-5s",
 		scaled, suffix);
 
 	return buffer;
@@ -599,7 +598,7 @@ void perf_stat_dump(
 		/* Sum totals across all instances of the stressor */
 		for (p = 0; p < STRESS_PERF_MAX; p++) {
 			int32_t j, n = (i * max_procs);
-			stress_perf_t *sp = &shared->stats[n].sp;
+			stress_perf_t *sp = &g_shared->stats[n].sp;
 
 			if (!perf_stat_succeeded(sp))
 				continue;
@@ -630,7 +629,7 @@ void perf_stat_dump(
 			continue;
 
 		munged = munge_underscore(stressors[i].name);
-		pr_inf(stdout, "%s:\n", munged);
+		pr_inf("%s:\n", munged);
 		pr_yaml(yaml, "    - stressor: %s\n", munged);
 		pr_yaml(yaml, "      duration: %f\n", duration);
 
@@ -647,21 +646,21 @@ void perf_stat_dump(
 
 				if ((ids[p] == STRESS_PERF_HW_INSTRUCTIONS) &&
 				    (total_cpu_cycles > 0))
-					snprintf(extra, sizeof(extra),
+					(void)snprintf(extra, sizeof(extra),
 						" (%.3f instr. per cycle)",
 						(double)ct / (double)total_cpu_cycles);
 				if ((ids[p] == STRESS_PERF_HW_CACHE_MISSES) &&
 				     (total_cache_refs > 0))
-					snprintf(extra, sizeof(extra),
+					(void)snprintf(extra, sizeof(extra),
 						" (%5.2f%%)",
 						100.0 * (double)ct / (double)total_cache_refs);
 				if ((ids[p] == STRESS_PERF_HW_BRANCH_MISSES) &&
 				    (total_branches > 0))
-					snprintf(extra, sizeof(extra),
+					(void)snprintf(extra, sizeof(extra),
 						" (%5.2f%%)",
 						100.0 * (double)ct / (double)total_branches);
 
-				pr_inf(stdout, "%'26" PRIu64 " %-23s %s%s\n",
+				pr_inf("%'26" PRIu64 " %-23s %s%s\n",
 					ct, l, perf_stat_scale(ct, duration),
 					extra);
 
@@ -688,13 +687,13 @@ void perf_stat_dump(
 					paranoid = true;
 			}
 			if (paranoid & (level > 1)) {
-				pr_inf(stdout, "Cannot read perf counters, "
+				pr_inf("Cannot read perf counters, "
 					"do not have CAP_SYS_ADMIN capability "
 					"or %s is set too high (%d)\n",
 					path, level);
 			}
 		} else {
-			pr_inf(stdout, "perf counters are not available "
+			pr_inf("perf counters are not available "
 				"on this device\n");
 		}
 	}
