@@ -31,6 +31,10 @@
  *  kernels or versions of different C libraries.
  */
 
+/*
+ *  shim_sched_yield()
+ *  	wrapper for sched_yield(2) - yield the processor
+ */
 int shim_sched_yield(void)
 {
 #if defined(_POSIX_PRIORITY_SCHEDULING) && !defined(__minix__)
@@ -40,6 +44,11 @@ int shim_sched_yield(void)
 #endif
 }
 
+/*
+ *  shim_cacheflush()
+ *	wrapper for cacheflush(2), flush contents of
+ *	instruction and/or data cache
+ */
 int shim_cacheflush(char *addr, int nbytes, int cache)
 {
 #if defined(__linux__) && defined(__NR_cacheflush)
@@ -54,6 +63,11 @@ int shim_cacheflush(char *addr, int nbytes, int cache)
 #endif
 }
 
+/*
+ * shim_copy_file_range()
+ *	wrapper for copy_file_range(2), copy range of data
+ *	from one file to another
+ */
 ssize_t shim_copy_file_range(
 	int fd_in,
 	shim_loff_t *off_in,
@@ -79,25 +93,14 @@ ssize_t shim_copy_file_range(
 }
 
 /*
- * shim_fallocate()
- *	shim wrapper for fallocate system call
- *	- falls back to posix_fallocate w/o mode
- * 	- falls back to direct writes
+ * shim_emulate_fallocate()
+ *	emulate fallocate (very slow!)
  */
-int shim_fallocate(int fd, int mode, off_t offset, off_t len)
+static int shim_emulate_fallocate(int fd, off_t offset, off_t len)
 {
-#if defined(__linux__) && defined(__NR_fallocate)
-	return fallocate(fd, mode, offset, len);
-#elif _POSIX_C_SOURCE >= 200112L
-	(void)mode;
-
-	return posix_fallocate(fd, offset, len);
-#else
-	const off_t buf_sz = 4096;
-	off_t n;
+	const off_t buf_sz = 65536;
 	char buffer[buf_sz];
-
-	(void)mode;
+	off_t n;
 
 	n = lseek(fd, offset, SEEK_SET);
 	if (n == (off_t)-1)
@@ -106,7 +109,7 @@ int shim_fallocate(int fd, int mode, off_t offset, off_t len)
 	memset(buffer, 0, buf_sz);
 	n = len;
 
-	while (opt_do_run && (n > 0)) {
+	while (g_keep_stressing_flag && (n > 0)) {
 		ssize_t ret;
 		size_t count = (size_t)STRESS_MINIMUM(n, buf_sz);
 
@@ -117,11 +120,50 @@ int shim_fallocate(int fd, int mode, off_t offset, off_t len)
 			return -1;
 		}
 	}
-
 	return 0;
+}
+
+/*
+ * shim_fallocate()
+ *	shim wrapper for fallocate system call
+ *	- falls back to posix_fallocate w/o mode
+ * 	- falls back to direct writes
+ */
+int shim_fallocate(int fd, int mode, off_t offset, off_t len)
+{
+#if defined(__linux__) && defined(__NR_fallocate)
+	int ret;
+
+	ret = fallocate(fd, mode, offset, len);
+	/* mode not supported? try with zero mode (dirty hack) */
+	if ((ret < 0) && (errno == EOPNOTSUPP)) {
+		ret = fallocate(fd, 0, offset, len);
+		/* fallocate failed, try emulation mode */
+		if ((ret < 0) && (errno == EOPNOTSUPP)) {
+			ret = shim_emulate_fallocate(fd, offset, len);
+		}
+	}
+	return ret;
+#elif _POSIX_C_SOURCE >= 200112L
+	int ret;
+
+	(void)mode;
+
+	ret = posix_fallocate(fd, offset, len);
+	if ((ret < 0) && (errno == ENOSYS))
+		ret = shim_emulate_fallocate(fd, offset, len);
+	return ret;
+#else
+	(void)mode;
+
+	return shim_emulate_fallocate(fd, offset, len);
 #endif
 }
 
+/*
+ *  shim_gettid()
+ *	wrapper for gettid(2), get thread identification
+ */
 int shim_gettid(void)
 {
 #if defined(__linux__) && defined(__NR_gettid)
@@ -132,6 +174,11 @@ int shim_gettid(void)
 #endif
 }
 
+/*
+ *  shim_getcpu()
+ *	wrapper for getcpu(2) - get CPU and NUMA node of
+ *	calling thread
+ */
 long shim_getcpu(
 	unsigned *cpu,
 	unsigned *node,
@@ -149,6 +196,10 @@ long shim_getcpu(
 #endif
 }
 
+/*
+ *  shim_getdents()
+ *	wrapper for getdents(2) - get directory entries
+ */
 int shim_getdents(
 	unsigned int fd,
 	struct shim_linux_dirent *dirp,
@@ -166,6 +217,10 @@ int shim_getdents(
 #endif
 }
 
+/*
+ *  shim_getdent6s()
+ *	wrapper for getdents64(2) - get directory entries
+ */
 int shim_getdents64(
 	unsigned int fd,
 	struct shim_linux_dirent64 *dirp,
@@ -183,6 +238,10 @@ int shim_getdents64(
 #endif
 }
 
+/*
+ *  shim_getrandom()
+ *	wrapper for Linux getrandom(2) and BSD getentropy(2)
+ */
 int shim_getrandom(void *buff, size_t buflen, unsigned int flags)
 {
 #if defined(__linux__) && defined(__NR_getrandom)
@@ -201,6 +260,10 @@ int shim_getrandom(void *buff, size_t buflen, unsigned int flags)
 #endif
 }
 
+/*
+ *  shim_clear_cache()
+ *	wrapper for ARM GNUC clear cache intrinsic
+ */
 void shim_clear_cache(char* begin, char *end)
 {
 #if defined(__GNUC__) && defined(STRESS_ARM)
@@ -211,6 +274,11 @@ void shim_clear_cache(char* begin, char *end)
 #endif
 }
 
+/*
+ *  shim_kcmp()
+ *	wrapper for Linux kcmp(2) - compre two processes to
+ *	see if they share a kernel resource.
+ */
 long shim_kcmp(int pid1, int pid2, int type, int fd1, int fd2)
 {
 #if defined(__linux__) && defined(__NR_kcmp)
@@ -228,6 +296,10 @@ long shim_kcmp(int pid1, int pid2, int type, int fd1, int fd2)
 #endif
 }
 
+/*
+ *  shim_syslog()
+ *	wrapper for syslog(2) (NOT syslog(3))
+ */
 int shim_syslog(int type, char *bufp, int len)
 {
 #if defined(__linux__) && defined(__NR_syslog)
@@ -242,6 +314,10 @@ int shim_syslog(int type, char *bufp, int len)
 #endif
 }
 
+/*
+ *  shim_membarrier()
+ *	wrapper for membarrier(2) - issue memory barriers
+ */
 int shim_membarrier(int cmd, int flags)
 {
 #if defined(__linux__) && defined(__NR_membarrier)
@@ -255,6 +331,10 @@ int shim_membarrier(int cmd, int flags)
 #endif
 }
 
+/*
+ *  shim_memfd_create()
+ *	wrapper for memfd_create(2)
+ */
 int shim_memfd_create(const char *name, unsigned int flags)
 {
 #if defined(__linux__) && defined(__NR_memfd_create)
@@ -268,6 +348,10 @@ int shim_memfd_create(const char *name, unsigned int flags)
 #endif
 }
 
+/*
+ *  shim_get_mempolicy()
+ *	wrapper for get_mempolicy(2) - get NUMA memory policy
+ */
 int shim_get_mempolicy(
 	int *mode,
 	unsigned long *nodemask,
@@ -290,6 +374,10 @@ int shim_get_mempolicy(
 #endif
 }
 
+/*
+ *  shim_set_mempolicy()
+ *	wrapper for set_mempolicy(2) - set NUMA memory policy
+ */
 int shim_set_mempolicy(
 	int mode,
 	unsigned long *nodemask,
@@ -308,6 +396,10 @@ int shim_set_mempolicy(
 #endif
 }
 
+/*
+ *  shim_mbind()
+ *	wrapper for mbind(2) - set memory policy for a memory range
+ */
 long shim_mbind(
 	void *addr,
 	unsigned long len,
@@ -332,6 +424,10 @@ long shim_mbind(
 #endif
 }
 
+/*
+ *  shim_migrate_pages()
+ *	wrapper for migrate_pages(2) - move all pages in a process to other nodes
+ */
 long shim_migrate_pages(
 	int pid,
 	unsigned long maxnode,
@@ -352,6 +448,10 @@ long shim_migrate_pages(
 #endif
 }
 
+/*
+ *  shim_move_pages()
+ *	wrapper for move_pages(2) - move pages in a process to other nodes
+ */
 long shim_move_pages(
 	int pid,
 	unsigned long count,
@@ -377,6 +477,10 @@ long shim_move_pages(
 #endif
 }
 
+/*
+ *  shim_userfaultfd()
+ *	wrapper for userfaultfd(2)
+ */
 int shim_userfaultfd(int flags)
 {
 #if defined(__linux__) && defined(__NR_userfaultfd)
@@ -389,6 +493,10 @@ int shim_userfaultfd(int flags)
 #endif
 }
 
+/*
+ *  shim_seccomp()
+ *	wrapper for seccomp(2) - operate on Secure Computing state of process
+ */
 int shim_seccomp(unsigned int operation, unsigned int flags, void *args)
 {
 #if defined(__linux__) && defined(__NR_seccomp)
@@ -403,6 +511,10 @@ int shim_seccomp(unsigned int operation, unsigned int flags, void *args)
 #endif
 }
 
+/*
+ *  shim_unshare()
+ *	wrapper for unshare(2)
+ */
 int shim_unshare(int flags)
 {
 #if defined(__linux__) && defined(__NR_unshare)
@@ -419,6 +531,10 @@ int shim_unshare(int flags)
 #endif
 }
 
+/*
+ *  shim_shed_getattr()
+ *	wrapper for shed_getattr(2)
+ */
 int shim_sched_getattr(
 	pid_t pid,
 	struct shim_sched_attr *attr,
@@ -438,6 +554,10 @@ int shim_sched_getattr(
 #endif
 }
 
+/*
+ *  shim_shed_setattr()
+ *	wrapper for shed_setattr(2)
+ */
 int shim_sched_setattr(
 	pid_t pid,
 	struct shim_sched_attr *attr,
@@ -455,6 +575,10 @@ int shim_sched_setattr(
 #endif
 }
 
+/*
+ *  shim_mlock2()
+ *	wrapper for mlock2(2) - lock memory
+ */
 int shim_mlock2(const void *addr, size_t len, int flags)
 {
 #if defined(__linux__) && defined(__NR_mlock2)
@@ -469,6 +593,36 @@ int shim_mlock2(const void *addr, size_t len, int flags)
 #endif
 }
 
+/*
+ *  shim_mlockall()
+ * 	wrapper for mlockall() - lock all memmory
+ */
+int shim_mlockall(int flags)
+{
+#if !defined(__gnu_hurd__) && !defined(__minix__)
+	return mlockall(flags);
+#else
+	(void)flags;
+
+	errno = ENOSYS;
+	return -1;
+#endif
+}
+
+/*
+ *  shim_munlockall()
+ * 	wrapper for munlockall() - unlock all memmory
+ */
+int shim_munlockall(void)
+{
+#if !defined(__gnu_hurd__) && !defined(__minix__)
+	return munlockall();
+#else
+	errno = ENOSYS;
+	return -1;
+#endif
+}
+
 /*
  *  shim_usleep()
  *	usleep is now deprecated, so
@@ -487,7 +641,7 @@ int shim_usleep(uint64_t usec)
 		if (nanosleep(&t, &trem) < 0) {
 			if (errno == EINTR) {
 				t = trem;
-				if (opt_do_run)
+				if (g_keep_stressing_flag)
 					continue;
 			} else {
 				return -1;
@@ -528,7 +682,10 @@ char *shim_getlogin(void)
 	return pw_name;
 }
 
-
+/*
+ *  shim_msync()
+ *	wrapper for msync(2) - synchronize a file with a memory map
+ */
 int shim_msync(void *addr, size_t length, int flags)
 {
 #if !defined(__gnu_hurd__) && !defined(__minix__)
@@ -542,9 +699,12 @@ int shim_msync(void *addr, size_t length, int flags)
 #endif
 }
 
+/*
+ *  shim_sysfs()
+ *	wrapper for sysfs(2) - get filesystem type information
+ */
 int shim_sysfs(int option, ...)
 {
-
 #if defined(__linux__) && defined(__NR_sysfs)
 	int ret;
 	va_list ap;
@@ -582,3 +742,78 @@ int shim_sysfs(int option, ...)
 	return -1;
 #endif
 }
+
+/*
+ *  shim_madvise()
+ *	wrapper for madvise(2) - get filesystem type information
+ */
+int shim_madvise(void *addr, size_t length, int advice)
+{
+#if !defined(__gnu_hurd__) && NEED_GLIBC(2,19,0)
+	return madvise(addr, length, advice);
+#elif (_POSIX_C_SOURCE >= 200112L)
+	int posix_advice;
+
+	switch (advice) {
+#if defined(POSIX_MADV_NORMAL) && defined(MADV_NORMAL)
+	case MADV_NORMAL:
+		posix_advice = POSIX_MADV_NORMAL;
+		break;
+#endif
+#if defined(POSIX_MADV_SEQUENTIAL) && defined(MADV_SEQUENTIAL)
+	case MADV_SEQUENTIAL:
+		posix_advice = POSIX_MADV_SEQUENTIAL;
+		break;
+#endif
+#if defined(POSIX_MADV_RANDOM) && defined(MADV_RANDOM)
+	case MADV_RANDOM:
+		posix_advice = POSIX_MADV_RANDOM;
+		break;
+#endif
+#if defined(POSIX_MADV_WILLNEED) && defined(MADV_WILLNEED)
+	case MADV_WILLNEED:
+		posix_advice = POSIX_MADV_WILLNEED;
+		break;
+#endif
+#if defined(POSIX_MADV_DONTNEED) && defined(MADV_DONTNEED)
+	case MADV_DONTNEED:
+		posix_advice = POSIX_MADV_DONTNEED;
+		break;
+#endif
+	default:
+		posix_advice = POSIX_MADV_NORMAL;
+		break;
+	}
+	return posix_madvise(addr, length, posix_advice);
+#else
+	(void)addr;
+	(void)length;
+	(void)advice;
+
+	errno = ENOSYS;
+	return -1;
+#endif
+}
+
+/*
+ *  shim_mincore()
+ *	wrapper for mincore(2) -  determine whether pages are resident in memory
+ */
+int shim_mincore(void *addr, size_t length, unsigned char *vec)
+{
+#if !defined(__gnu_hurd__) && NEED_GLIBC(2,2,0)
+#if defined(__FreeBSD__) || defined(__OpenBSD__) || \
+    defined(__NetBSD__) || defined(__sun__)
+	return mincore(addr, length, (char *)vec);
+#else
+	return mincore(addr, length, vec);
+#endif
+#else
+	(void)addr;
+	(void)length;
+	(void)vec;
+
+	errno = ENOSYS;
+	return -1;
+#endif
+}
