@@ -87,7 +87,7 @@ typedef struct {
 	const char *name;
 } alg_rng_info_t;
 
-static alg_hash_info_t algo_hash_info[] = {
+static const alg_hash_info_t algo_hash_info[] = {
 	{ "sha1",	SHA1_DIGEST_SIZE },
 	{ "sha224",	SHA224_DIGEST_SIZE },
 	{ "sha256",	SHA256_DIGEST_SIZE },
@@ -107,7 +107,7 @@ static alg_hash_info_t algo_hash_info[] = {
 	{ "tgr192",	TGR192_DIGEST_SIZE }
 };
 
-static alg_cipher_info_t algo_cipher_info[] = {
+static const alg_cipher_info_t algo_cipher_info[] = {
 	{ "cbc(aes)",		AES_BLOCK_SIZE,		AES_MAX_KEY_SIZE },
 	{ "lrw(aes)",		AES_BLOCK_SIZE,		AES_MAX_KEY_SIZE },
 	{ "ofb(aes)",		AES_BLOCK_SIZE,		AES_MAX_KEY_SIZE },
@@ -122,14 +122,12 @@ static alg_cipher_info_t algo_cipher_info[] = {
 	{ "salsa20",		SALSA20_BLOCK_SIZE,	SALSA20_MAX_KEY_SIZE },
 };
 
-static alg_rng_info_t algo_rng_info[] = {
+static const alg_rng_info_t algo_rng_info[] = {
 	{ "jitterentropy_rng" }
 };
 
 static int stress_af_alg_hash(
-	uint64_t *const counter,
-	const uint64_t max_ops,
-	const char *name,
+	const args_t *args,
 	const int sockfd,
 	uint64_t *hashfails)
 {
@@ -153,14 +151,14 @@ static int stress_af_alg_hash(
 			/* Perhaps the hash does not exist with this kernel */
 			if (errno == ENOENT)
 				continue;
-			pr_fail_err(name, "bind");
+			pr_fail_err("bind");
 			return EXIT_FAILURE;
 		}
 		bind_ok = true;
 
 		fd = accept(sockfd, NULL, 0);
 		if (fd < 0) {
-			pr_fail_err(name, "accept");
+			pr_fail_err("accept");
 			return EXIT_FAILURE;
 		}
 
@@ -168,17 +166,17 @@ static int stress_af_alg_hash(
 
 		for (j = 32; j < (ssize_t)sizeof(input); j += 32) {
 			if (send(fd, input, j, 0) != j) {
-				pr_fail_err(name, "send");
+				pr_fail_err("send");
 				(void)close(fd);
 				return EXIT_FAILURE;
 			}
 			if (recv(fd, digest, digest_size, MSG_WAITALL) != digest_size) {
-				pr_fail_err(name, "recv");
+				pr_fail_err("recv");
 				(void)close(fd);
 				return EXIT_FAILURE;
 			}
-			(*counter)++;
-			if (max_ops && (*counter >= max_ops)) {
+			inc_counter(args);
+			if (args->max_ops && (*args->counter >= args->max_ops)) {
 				(void)close(fd);
 				return EXIT_SUCCESS;
 			}
@@ -192,9 +190,7 @@ static int stress_af_alg_hash(
 }
 
 static int stress_af_alg_cipher(
-	uint64_t *const counter,
-	const uint64_t max_ops,
-	const char *name,
+	const args_t *args,
 	const int sockfd,
 	uint64_t *cipherfails)
 {
@@ -221,20 +217,20 @@ static int stress_af_alg_cipher(
 			/* Perhaps the cipher does not exist with this kernel */
 			if (errno == ENOENT)
 				continue;
-			pr_fail_err(name, "bind");
+			pr_fail_err("bind");
 			return EXIT_FAILURE;
 		}
 		bind_ok = true;
 
 		stress_strnrnd(key, sizeof(key));
 		if (setsockopt(sockfd, SOL_ALG, ALG_SET_KEY, key, sizeof(key)) < 0) {
-			pr_fail_err(name, "setsockopt");
+			pr_fail_err("setsockopt");
 			return EXIT_FAILURE;
 		}
 
 		fd = accept(sockfd, NULL, 0);
 		if (fd < 0) {
-			pr_fail_err(name, "accept");
+			pr_fail_err("accept");
 			return EXIT_FAILURE;
 		}
 
@@ -255,6 +251,12 @@ static int stress_af_alg_cipher(
 
 			/* Chosen operation - ENCRYPT */
 			cmsg = CMSG_FIRSTHDR(&msg);
+			/* Keep static analysis happy */
+			if (!cmsg) {
+				(void)close(fd);
+				pr_fail_err("null cmsg");
+				return EXIT_FAILURE;
+			}
 			cmsg->cmsg_level = SOL_ALG;
 			cmsg->cmsg_type = ALG_SET_OP;
 			cmsg->cmsg_len = CMSG_LEN(4);
@@ -280,12 +282,12 @@ static int stress_af_alg_cipher(
 			msg.msg_iovlen = 1;
 
 			if (sendmsg(fd, &msg, 0) < 0) {
-				pr_fail_err(name, "sendmsg");
+				pr_fail_err("sendmsg");
 				(void)close(fd);
 				return EXIT_FAILURE;
 			}
 			if (read(fd, output, sizeof(output)) != sizeof(output)) {
-				pr_fail_err(name, "read");
+				pr_fail_err("read");
 				(void)close(fd);
 				return EXIT_FAILURE;
 			}
@@ -313,27 +315,27 @@ static int stress_af_alg_cipher(
 			msg.msg_iovlen = 1;
 
 			if (sendmsg(fd, &msg, 0) < 0) {
-				pr_fail_err(name, "sendmsg");
+				pr_fail_err("sendmsg");
 				(void)close(fd);
 				return EXIT_FAILURE;
 			}
 			if (read(fd, output, sizeof(output)) != sizeof(output)) {
-				pr_fail_err(name, "read");
+				pr_fail_err("read");
 				(void)close(fd);
 				return EXIT_FAILURE;
 			} else {
 				if (memcmp(input, output, sizeof(input))) {
-					pr_err(stderr, "%s: decrypted data "
+					pr_err("%s: decrypted data "
 						"different from original data "
 						"using %s\n",
-						name,  algo_hash_info[i].name);
+						args->name,  algo_hash_info[i].name);
 				}
 			}
 		}
 
 		(void)close(fd);
-		(*counter)++;
-		if (max_ops && (*counter >= max_ops))
+		inc_counter(args);
+		if (args->max_ops && (*args->counter >= args->max_ops))
 			return EXIT_SUCCESS;
 	}
 	if (!bind_ok)
@@ -343,9 +345,7 @@ static int stress_af_alg_cipher(
 }
 
 static int stress_af_alg_rng(
-	uint64_t *const counter,
-	const uint64_t max_ops,
-	const char *name,
+	const args_t *args,
 	const int sockfd,
 	uint64_t *rngfails)
 {
@@ -367,14 +367,14 @@ static int stress_af_alg_rng(
 			/* Perhaps the rng does not exist with this kernel */
 			if (errno == ENOENT)
 				continue;
-			pr_fail_err(name, "bind");
+			pr_fail_err("bind");
 			return EXIT_FAILURE;
 		}
 		bind_ok = true;
 
 		fd = accept(sockfd, NULL, 0);
 		if (fd < 0) {
-			pr_fail_err(name, "accept");
+			pr_fail_err("accept");
 			return EXIT_FAILURE;
 		}
 
@@ -382,12 +382,12 @@ static int stress_af_alg_rng(
 			char output[16];
 
 			if (read(fd, output, sizeof(output)) != sizeof(output)) {
-				pr_fail_err(name, "read");
+				pr_fail_err("read");
 				(void)close(fd);
 				return EXIT_FAILURE;
 			}
-			(*counter)++;
-			if (max_ops && (*counter >= max_ops)) {
+			inc_counter(args);
+			if (args->max_ops && (*args->counter >= args->max_ops)) {
 				(void)close(fd);
 				return EXIT_SUCCESS;
 			}
@@ -404,26 +404,20 @@ static int stress_af_alg_rng(
  *  stress_af_alg()
  *	stress socket AF_ALG domain
  */
-int stress_af_alg(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_af_alg(const args_t *args)
 {
 	int sockfd = -1, rc = EXIT_FAILURE;
 	int retries = MAX_AF_ALG_RETRIES;
 	uint64_t hashfails = 0, cipherfails = 0, rngfails = 0;
 
-	(void)instance;
-
 	for (;;) {
 		sockfd = socket(AF_ALG, SOCK_SEQPACKET, 0);
 		if (sockfd >= 0)
 			break;
 
 		retries--;
-		if ((!opt_do_run) || (retries < 0) || (errno != EAFNOSUPPORT)) {
-			pr_fail_err(name, "socket");
+		if ((!g_keep_stressing_flag) || (retries < 0) || (errno != EAFNOSUPPORT)) {
+			pr_fail_err("socket");
 			return rc;
 		}
 		/*
@@ -436,25 +430,22 @@ int stress_af_alg(
 	}
 
 	do {
-		rc = stress_af_alg_hash(counter, max_ops,
-			name, sockfd, &hashfails);
+		rc = stress_af_alg_hash(args, sockfd, &hashfails);
 		if (rc == EXIT_FAILURE)
 			goto tidy;
-		rc = stress_af_alg_cipher(counter, max_ops,
-			name, sockfd, &cipherfails);
+		rc = stress_af_alg_cipher(args, sockfd, &cipherfails);
 		if (rc == EXIT_FAILURE)
 			goto tidy;
-		rc = stress_af_alg_rng(counter, max_ops,
-			name, sockfd, &rngfails);
+		rc = stress_af_alg_rng(args, sockfd, &rngfails);
 		if (rc == EXIT_FAILURE)
 			goto tidy;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (keep_stressing());
 
 	if (hashfails | cipherfails | rngfails)
-		pr_dbg(stderr, "%s: bind failed with ENOENT on all hashes (%"
+		pr_dbg("%s: bind failed with ENOENT on all hashes (%"
 			PRIu64 " times), ciphers (%" PRIu64 " times), "
 			"prngs (%" PRIu64 " times\n",
-			name, hashfails, cipherfails, rngfails);
+			args->name, hashfails, cipherfails, rngfails);
 	rc = EXIT_SUCCESS;
 tidy:
 	(void)close(sockfd);
@@ -462,12 +453,8 @@ tidy:
 	return rc;
 }
 #else
-int stress_af_alg(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_af_alg(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
