@@ -30,18 +30,14 @@
  *  stress on sched_affinity()
  *	stress system by changing CPU affinity periodically
  */
-int stress_affinity(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_affinity(const args_t *args)
 {
-	uint32_t cpu = instance;
+	uint32_t cpu = args->instance;
 	const uint32_t cpus = stress_get_processors_configured();
 	cpu_set_t mask;
 
 	do {
-		cpu = (opt_flags & OPT_FLAGS_AFFINITY_RAND) ?
+		cpu = (g_opt_flags & OPT_FLAGS_AFFINITY_RAND) ?
 			(mwc32() >> 4) : cpu + 1;
 		cpu %= cpus;
 		CPU_ZERO(&mask);
@@ -55,34 +51,30 @@ int stress_affinity(
 				 */
 				continue;
 			}
-			pr_fail(stderr, "%s: failed to move to CPU %" PRIu32
+			pr_fail("%s: failed to move to CPU %" PRIu32
 				", errno=%d (%s)\n",
-				name, cpu, errno, strerror(errno));
+				args->name, cpu, errno, strerror(errno));
 			(void)shim_sched_yield();
 		} else {
 			/* Now get and check */
 			CPU_ZERO(&mask);
 			CPU_SET(cpu, &mask);
 			if (sched_getaffinity(0, sizeof(mask), &mask) == 0) {
-				if ((opt_flags & OPT_FLAGS_VERIFY) &&
+				if ((g_opt_flags & OPT_FLAGS_VERIFY) &&
 				    (!CPU_ISSET(cpu, &mask)))
-					pr_fail(stderr, "%s: failed to move "
+					pr_fail("%s: failed to move "
 						"to CPU %" PRIu32 "\n",
-						name, cpu);
+						args->name, cpu);
 			}
 		}
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
 	return EXIT_SUCCESS;
 }
 #else
-int stress_affinity(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_affinity(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
