@@ -45,12 +45,12 @@ static volatile bool do_accounting = true;
 static int opt_aio_requests = DEFAULT_AIO_REQUESTS;
 static bool set_aio_requests = false;
 
-void stress_set_aio_requests(const char *optarg)
+void stress_set_aio_requests(const char *opt)
 {
 	uint64_t aio_requests;
 
 	set_aio_requests = true;
-	aio_requests = get_uint64(optarg);
+	aio_requests = get_uint64(opt);
 	check_range("aio-requests", aio_requests,
 		MIN_AIO_REQUESTS, MAX_AIO_REQUESTS);
 	opt_aio_requests = (int)aio_requests;
@@ -106,11 +106,11 @@ static void aio_issue_cancel(const char *name, io_req_t *io_req)
 	case AIO_ALLDONE:
 		break;
 	case AIO_NOTCANCELED:
-		pr_dbg(stderr, "%s: async I/O request %d not cancelled\n",
+		pr_dbg("%s: async I/O request %d not cancelled\n",
 			name, io_req->request);
 		break;
 	default:
-		pr_err(stderr, "%s: %d error: %d %s\n",
+		pr_err("%s: %d error: %d %s\n",
 			name, io_req->request,
 			errno, strerror(errno));
 	}
@@ -128,7 +128,7 @@ static int issue_aio_request(
 	const int request,
 	int (*aio_func)(struct aiocb *aiocbp) )
 {
-	while (opt_do_run) {
+	while (g_keep_stressing_flag) {
 		int ret;
 
 		io_req->request = request;
@@ -146,7 +146,7 @@ static int issue_aio_request(
 		if (ret < 0) {
 			if ((errno == EAGAIN) || (errno == EINTR))
 				continue;
-			pr_err(stderr, "%s: failed to issue aio request: %d (%s)\n",
+			pr_err("%s: failed to issue aio request: %d (%s)\n",
 				name, errno, strerror(errno));
 		}
 		return ret;
@@ -159,11 +159,7 @@ static int issue_aio_request(
  *  stress_aio
  *	stress asynchronous I/O
  */
-int stress_aio(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_aio(const args_t *args)
 {
 	int ret, fd, rc = EXIT_FAILURE;
 	io_req_t *io_reqs;
@@ -171,33 +167,32 @@ int stress_aio(
 	int i;
 	uint64_t total = 0;
 	char filename[PATH_MAX];
-	const pid_t pid = getpid();
 
 	if (!set_aio_requests) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_aio_requests = MAX_AIO_REQUESTS;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_aio_requests = MIN_AIO_REQUESTS;
 	}
 
 	if ((io_reqs = calloc(opt_aio_requests, sizeof(io_req_t))) == NULL) {
-		pr_err(stderr, "%s: cannot allocate io request structures\n", name);
+		pr_err("%s: cannot allocate io request structures\n", args->name);
 		return EXIT_NO_RESOURCE;
 	}
 
-	ret = stress_temp_dir_mk(name, pid, instance);
+	ret = stress_temp_dir_mk_args(args);
 	if (ret < 0) {
 		free(io_reqs);
 		return exit_status(-ret);
 	}
 
-	(void)stress_temp_filename(filename, sizeof(filename),
-		name, pid, instance, mwc32());
+	(void)stress_temp_filename_args(args,
+		filename, sizeof(filename), mwc32());
 
 	(void)umask(0077);
 	if ((fd = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
 		rc = exit_status(errno);
-		pr_fail_err(name, "open");
+		pr_fail_err("open");
 		goto finish;
 	}
 	(void)unlink(filename);
@@ -206,12 +201,12 @@ int stress_aio(
 	sa.sa_flags = SA_RESTART | SA_SIGINFO;
 	sa.sa_sigaction = aio_signal_handler;
 	if (sigaction(SIGUSR1, &sa, &sa_old) < 0)
-		pr_fail_err(name, "sigaction");
+		pr_fail_err("sigaction");
 
 	/* Kick off requests */
 	for (i = 0; i < opt_aio_requests; i++) {
 		aio_fill_buffer(i, io_reqs[i].buffer, BUFFER_SZ);
-		ret = issue_aio_request(name, fd, (off_t)i * BUFFER_SZ,
+		ret = issue_aio_request(args->name, fd, (off_t)i * BUFFER_SZ,
 			&io_reqs[i], i, aio_write);
 		if (ret < 0)
 			goto cancel;
@@ -224,7 +219,7 @@ int stress_aio(
 	do {
 		(void)shim_usleep(250000); /* wait until a signal occurs */
 
-		for (i = 0; opt_do_run && (i < opt_aio_requests); i++) {
+		for (i = 0; g_keep_stressing_flag && (i < opt_aio_requests); i++) {
 			if (io_reqs[i].status != EINPROGRESS)
 				continue;
 
@@ -233,8 +228,8 @@ int stress_aio(
 			case ECANCELED:
 			case 0:
 				/* Succeeded or cancelled, so redo another */
-				(*counter)++;
-				if (issue_aio_request(name, fd,
+				inc_counter(args);
+				if (issue_aio_request(args->name, fd,
 					(off_t)i * BUFFER_SZ, &io_reqs[i], i,
 					(mwc32() & 0x8) ? aio_read : aio_write) < 0)
 					goto cancel;
@@ -243,12 +238,12 @@ int stress_aio(
 				break;
 			default:
 				/* Something went wrong */
-				pr_fail_errno(name, "aio_error",
+				pr_fail_errno("aio_error",
 					io_reqs[i].status);
 				goto cancel;
 			}
 		}
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (keep_stressing());
 
 	rc = EXIT_SUCCESS;
 
@@ -257,26 +252,22 @@ cancel:
 	do_accounting = false;
 	/* Cancel pending AIO requests */
 	for (i = 0; i < opt_aio_requests; i++) {
-		aio_issue_cancel(name, &io_reqs[i]);
+		aio_issue_cancel(args->name, &io_reqs[i]);
 		total += io_reqs[i].count;
 	}
 	(void)close(fd);
 finish:
 	free(io_reqs);
 
-	pr_dbg(stderr, "%s: total of %" PRIu64 " async I/O signals "
+	pr_dbg("%s: total of %" PRIu64 " async I/O signals "
 		"caught (instance %d)\n",
-		name, total, instance);
-	(void)stress_temp_dir_rm(name, pid, instance);
+		args->name, total, args->instance);
+	(void)stress_temp_dir_rm_args(args);
 	return rc;
 }
 #else
-int stress_aio(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_aio(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
