@@ -37,8 +37,8 @@ typedef int (*apparmor_func)(const char *name,
 static volatile bool apparmor_run = true;
 static char *apparmor_path = NULL;
 
-extern char apparmor_data[];
-extern const size_t apparmor_data_len;
+extern char g_apparmor_data[];
+extern const size_t g_apparmor_data_len;
 
 /*
  *  stress_apparmor_supported()
@@ -51,31 +51,31 @@ int stress_apparmor_supported(void)
 
 	/* Initial sanity checks for AppArmor */
 	if (!aa_is_enabled()) {
-		pr_inf(stdout, "apparmor stressor will be skipped, "
+		pr_inf("apparmor stressor will be skipped, "
 			"AppArmor is not enabled\n");
 		return -1;
 	}
 	if (aa_find_mountpoint(&apparmor_path) < 0) {
-		pr_inf(stdout, "apparmor stressor will be skipped, "
+		pr_inf("apparmor stressor will be skipped, "
 			"cannot get AppArmor path, errno=%d (%s)\n",
 			errno, strerror(errno));
 		return -1;
 	}
 	/* ..and see if profiles are accessible */
-	snprintf(path, sizeof(path), "%s/%s", apparmor_path, "profiles");
+	(void)snprintf(path, sizeof(path), "%s/%s", apparmor_path, "profiles");
 	if ((fd = open(path, O_RDONLY)) < 0) {
 		switch (errno) {
 		case EACCES:
-			pr_inf(stdout, "apparmor stressor will be skipped, "
+			pr_inf("apparmor stressor will be skipped, "
 				"stress-ng needs to be run with root "
 				"privilege to access AppArmor /sys files.\n");
 			break;
 		case ENOENT:
-			pr_inf(stdout, "apparmor stressor will be skipped, "
+			pr_inf("apparmor stressor will be skipped, "
 				"AppArmor /sys files do not exist\n");
 			break;
 		default:
-			pr_inf(stdout, "apparmor stressor will be skipped, "
+			pr_inf("apparmor stressor will be skipped, "
 				"cannot access AppArmor /sys files: "
 				"errno=%d (%s)\n", errno, strerror(errno));
 			break;
@@ -119,7 +119,7 @@ static void stress_apparmor_read(const char *path)
 	while (apparmor_run && (i < (4096 * APPARMOR_BUF_SZ))) {
 		ssize_t ret, sz = 1 + (mwc32() % sizeof(buffer));
 redo:
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 		ret = read(fd, buffer, sz);
 		if (ret < 0) {
@@ -146,7 +146,7 @@ static void stress_apparmor_dir(
 	DIR *dp;
 	struct dirent *d;
 
-	if (!opt_do_run)
+	if (!g_keep_stressing_flag)
 		return;
 
 	/* Don't want to go too deep */
@@ -160,7 +160,7 @@ static void stress_apparmor_dir(
 	while ((d = readdir(dp)) != NULL) {
 		char name[PATH_MAX];
 
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 		if (!strcmp(d->d_name, ".") ||
 		    !strcmp(d->d_name, ".."))
@@ -168,13 +168,13 @@ static void stress_apparmor_dir(
 		switch (d->d_type) {
 		case DT_DIR:
 			if (recurse) {
-				snprintf(name, sizeof(name),
+				(void)snprintf(name, sizeof(name),
 					"%s/%s", path, d->d_name);
 				stress_apparmor_dir(name, recurse, depth + 1);
 			}
 			break;
 		case DT_REG:
-			snprintf(name, sizeof(name),
+			(void)snprintf(name, sizeof(name),
 				"%s/%s", path, d->d_name);
 			stress_apparmor_read(name);
 			break;
@@ -201,7 +201,7 @@ static pid_t apparmor_spawn(
 again:
 	pid = fork();
 	if (pid < 0) {
-		if (opt_do_run && (errno == EAGAIN))
+		if (g_keep_stressing_flag && (errno == EAGAIN))
 			goto again;
 		return -1;
 	}
@@ -211,14 +211,14 @@ again:
 		if (stress_sighandler(name, SIGALRM,
 				stress_apparmor_handler, NULL) < 0)
 			exit(EXIT_FAILURE);
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
 
 		ret = func(name, max_ops, counter);
 		free(apparmor_path);
 		exit(ret);
 	}
-	(void)setpgid(pid, pgrp);
+	(void)setpgid(pid, g_pgrp);
 	return pid;
 }
 
@@ -235,7 +235,7 @@ static int apparmor_stress_profiles(
 	char path[PATH_MAX];
 
 	(void)name;
-	snprintf(path, sizeof(path), "%s/%s", apparmor_path, "profiles");
+	(void)snprintf(path, sizeof(path), "%s/%s", apparmor_path, "profiles");
 
 	do {
 		stress_apparmor_read(path);
@@ -257,7 +257,7 @@ static int apparmor_stress_features(
 	char path[PATH_MAX];
 
 	(void)name;
-	snprintf(path, sizeof(path), "%s/%s", apparmor_path, "features");
+	(void)snprintf(path, sizeof(path), "%s/%s", apparmor_path, "features");
 
 	do {
 		stress_apparmor_dir(path, true, 0);
@@ -285,7 +285,7 @@ static int apparmor_stress_kernel_interface(
 	do {
 		int ret = aa_kernel_interface_new(&kern_if, NULL, NULL);
 		if (ret < 0) {
-			pr_fail(stderr, "%s: aa_kernel_interface_new() failed, "
+			pr_fail("%s: aa_kernel_interface_new() failed, "
 				"errno=%d (%s)\n", name,
 				errno, strerror(errno));
 			rc = EXIT_FAILURE;
@@ -297,10 +297,10 @@ static int apparmor_stress_kernel_interface(
 		 *  already loaded the same policy, so we may get EEXIST
 		 */
 		ret = aa_kernel_interface_load_policy(kern_if,
-			apparmor_data, apparmor_data_len);
+			g_apparmor_data, g_apparmor_data_len);
 		if (ret < 0) {
 			if (errno != EEXIST) {
-				pr_fail(stderr, "%s: aa_kernel_interface_load_policy() failed, "
+				pr_fail("%s: aa_kernel_interface_load_policy() failed, "
 					"errno=%d (%s)\n", name, errno, strerror(errno));
 				rc = EXIT_FAILURE;
 			}
@@ -312,11 +312,11 @@ static int apparmor_stress_kernel_interface(
 		 *  interface correctly.
 		 */
 		ret = aa_kernel_interface_replace_policy(kern_if,
-			apparmor_data, apparmor_data_len);
+			g_apparmor_data, g_apparmor_data_len);
 		if (ret < 0) {
 			aa_kernel_interface_unref(kern_if);
 
-			pr_fail(stderr, "%s: aa_kernel_interface_replace_policy() failed, "
+			pr_fail("%s: aa_kernel_interface_replace_policy() failed, "
 				"errno=%d (%s)\n", name, errno,
 				strerror(errno));
 			rc = EXIT_FAILURE;
@@ -330,7 +330,7 @@ static int apparmor_stress_kernel_interface(
 			"/usr/bin/pulseaudio-eg");
 		if (ret < 0) {
 			if (errno != ENOENT) {
-				pr_fail(stderr, "%s: aa_kernel_interface_remove_policy() failed, "
+				pr_fail("%s: aa_kernel_interface_remove_policy() failed, "
 					"errno=%d (%s)\n", name, errno,
 					strerror(errno));
 				rc = EXIT_FAILURE;
@@ -339,7 +339,7 @@ static int apparmor_stress_kernel_interface(
 		aa_kernel_interface_unref(kern_if);
 
 		(*counter)++;
-	} while (opt_do_run && apparmor_run && (!max_ops || *counter < max_ops));
+	} while (g_keep_stressing_flag && apparmor_run && (!max_ops || *counter < max_ops));
 
 	return rc;
 }
@@ -504,7 +504,7 @@ static int apparmor_stress_corruption(
 	const uint64_t max_ops,
 	uint64_t *counter)
 {
-	char copy[apparmor_data_len];
+	char copy[g_apparmor_data_len];
 
 	int rc = EXIT_SUCCESS;
 	aa_kernel_interface *kern_if;
@@ -516,47 +516,47 @@ static int apparmor_stress_corruption(
 	do {
 		int ret;
 
-		memcpy(copy, apparmor_data, apparmor_data_len);
+		memcpy(copy, g_apparmor_data, g_apparmor_data_len);
 		/*
 		 *  Apply various corruption methods
 		 */
 		switch ((*counter) % 10) {
 		case 0:
-			apparmor_corrupt_flip_seq(copy, apparmor_data_len);
+			apparmor_corrupt_flip_seq(copy, g_apparmor_data_len);
 			break;
 		case 1:
-			apparmor_corrupt_clr_seq(copy, apparmor_data_len);
+			apparmor_corrupt_clr_seq(copy, g_apparmor_data_len);
 			break;
 		case 2:
-			apparmor_corrupt_set_seq(copy, apparmor_data_len);
+			apparmor_corrupt_set_seq(copy, g_apparmor_data_len);
 			break;
 		case 3:
 			apparmor_corrupt_flip_bits_random(copy,
-				apparmor_data_len);
+				g_apparmor_data_len);
 			break;
 		case 4:
 			apparmor_corrupt_flip_byte_random(copy,
-				apparmor_data_len);
+				g_apparmor_data_len);
 			break;
 		case 5:
 			apparmor_corrupt_clr_bits_random(copy,
-				apparmor_data_len);
+				g_apparmor_data_len);
 			break;
 		case 6:
 			apparmor_corrupt_set_bits_random(copy,
-				apparmor_data_len);
+				g_apparmor_data_len);
 			break;
 		case 7:
 			apparmor_corrupt_clr_byte_random(copy,
-				apparmor_data_len);
+				g_apparmor_data_len);
 			break;
 		case 8:
 			apparmor_corrupt_set_byte_random(copy,
-				apparmor_data_len);
+				g_apparmor_data_len);
 			break;
 		case 9:
 			apparmor_corrupt_flip_bits_random_burst(copy,
-				apparmor_data_len);
+				g_apparmor_data_len);
 			break;
 		default:
 			/* Should not happen */
@@ -565,7 +565,7 @@ static int apparmor_stress_corruption(
 
 		ret = aa_kernel_interface_new(&kern_if, NULL, NULL);
 		if (ret < 0) {
-			pr_fail(stderr, "%s: aa_kernel_interface_new() failed, "
+			pr_fail("%s: aa_kernel_interface_new() failed, "
 				"errno=%d (%s)\n", name, errno,
 				strerror(errno));
 			return EXIT_FAILURE;
@@ -574,11 +574,11 @@ static int apparmor_stress_corruption(
 		 *  Expect EPROTO failures
 		 */
 		ret = aa_kernel_interface_replace_policy(kern_if,
-			copy, apparmor_data_len);
+			copy, g_apparmor_data_len);
 		if (ret < 0) {
 			if ((errno != EPROTO) &&
 			    (errno != EPROTONOSUPPORT)) {
-				pr_fail(stderr, "%s: aa_kernel_interface_replace_policy() failed, "
+				pr_fail("%s: aa_kernel_interface_replace_policy() failed, "
 					"errno=%d (%s)\n", name, errno,
 					strerror(errno));
 				rc = EXIT_FAILURE;
@@ -586,7 +586,7 @@ static int apparmor_stress_corruption(
 		}
 		aa_kernel_interface_unref(kern_if);
 		(*counter)++;
-	} while (opt_do_run && apparmor_run &&
+	} while (g_keep_stressing_flag && apparmor_run &&
 		 (!max_ops || *counter < max_ops));
 
 	return rc;
@@ -605,11 +605,7 @@ static const apparmor_func apparmor_funcs[] = {
  *  stress_apparmor()
  *	stress AppArmor
  */
-int stress_apparmor(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_apparmor(const args_t *args)
 {
 	const size_t n = SIZEOF_ARRAY(apparmor_funcs);
 	const size_t counters_sz = n * sizeof(uint64_t);
@@ -617,31 +613,29 @@ int stress_apparmor(
 	size_t i;
 	uint64_t *counters, tmp_counter = 0, ops;
 
-	(void)instance;
-
 	counters = mmap(NULL, counters_sz, PROT_READ | PROT_WRITE,
 		MAP_SHARED | MAP_ANONYMOUS, -1, 0);
 	if (counters == MAP_FAILED) {
-		pr_err(stderr, "%s: mmap failed: errno=%d (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: mmap failed: errno=%d (%s)\n",
+			args->name, errno, strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 	memset(counters, 0, counters_sz);
 
-	if ((max_ops > 0) && (max_ops < n))
+	if ((args->max_ops > 0) && (args->max_ops < n))
 		ops = n;
 	else
-		ops = max_ops / n;
+		ops = args->max_ops / n;
 
 	for (i = 0; i < n; i++) {
-		pids[i] = apparmor_spawn(name, ops,
+		pids[i] = apparmor_spawn(args->name, ops,
 			&counters[i], apparmor_funcs[i]);
 	}
 	do {
 		(void)select(0, NULL, NULL, NULL, NULL);
 		for (i = 0; i < n; i++)
 			tmp_counter += counters[i];
-	} while (opt_do_run && (!max_ops || tmp_counter < max_ops));
+	} while (keep_stressing());
 
 	for (i = 0; i < n; i++) {
 		int status;
@@ -649,7 +643,7 @@ int stress_apparmor(
 		if (pids[i] >= 0) {
 			(void)kill(pids[i], SIGALRM);
 			(void)waitpid(pids[i], &status, 0);
-			*counter += counters[i];
+			*(args->counter) += counters[i];
 		}
 	}
 	munmap(counters, counters_sz);
@@ -662,18 +656,14 @@ int stress_apparmor(
 #else
 int stress_apparmor_supported(void)
 {
-	pr_inf(stdout, "apparmor stressor will be skipped, "
+	pr_inf("apparmor stressor will be skipped, "
 		"AppArmor is not available\n");
 	return -1;
 }
 
-int stress_apparmor(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_apparmor(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 
 }
 #endif
