@@ -31,11 +31,11 @@ static bool set_bigheap_growth = false;
  *  stress_set_bigheap_growth()
  *  	Set bigheap growth from given opt arg string
  */
-void stress_set_bigheap_growth(const char *optarg)
+void stress_set_bigheap_growth(const char *opt)
 {
 	set_bigheap_growth = true;
-	opt_bigheap_growth = get_uint64_byte(optarg);
-	check_range("bigheap-growth", opt_bigheap_growth,
+	opt_bigheap_growth = get_uint64_byte(opt);
+	check_range_bytes("bigheap-growth", opt_bigheap_growth,
 		MIN_BIGHEAP_GROWTH, MAX_BIGHEAP_GROWTH);
 }
 
@@ -43,14 +43,10 @@ void stress_set_bigheap_growth(const char *optarg)
  *  stress_bigheap()
  *	stress heap allocation
  */
-int stress_bigheap(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_bigheap(const args_t *args)
 {
 	void *ptr = NULL, *last_ptr = NULL;
-	const size_t page_size = stress_get_pagesize();
+	const size_t page_size = args->page_size;
 	const size_t stride = page_size;
 	size_t size = 0;
 	uint32_t ooms = 0, segvs = 0, nomems = 0;
@@ -58,63 +54,66 @@ int stress_bigheap(
 	uint8_t *last_ptr_end = NULL;
 
 	if (!set_bigheap_growth) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_bigheap_growth = MAX_BIGHEAP_GROWTH;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_bigheap_growth = MIN_BIGHEAP_GROWTH;
 	}
+
+	/* Round growth size to nearest page size */
+	opt_bigheap_growth &= ~(page_size - 1);
 again:
-	if (!opt_do_run)
+	if (!g_keep_stressing_flag)
 		return EXIT_SUCCESS;
 	pid = fork();
 	if (pid < 0) {
 		if (errno == EAGAIN)
 			goto again;
-		pr_err(stderr, "%s: fork failed: errno=%d: (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: fork failed: errno=%d: (%s)\n",
+			args->name, errno, strerror(errno));
 	} else if (pid > 0) {
 		int status, ret;
 
-		(void)setpgid(pid, pgrp);
+		(void)setpgid(pid, g_pgrp);
 		/* Parent, wait for child */
 		ret = waitpid(pid, &status, 0);
 		if (ret < 0) {
 			if (errno != EINTR)
-				pr_dbg(stderr, "%s: waitpid(): errno=%d (%s)\n",
-					name, errno, strerror(errno));
+				pr_dbg("%s: waitpid(): errno=%d (%s)\n",
+					args->name, errno, strerror(errno));
 			(void)kill(pid, SIGTERM);
 			(void)kill(pid, SIGKILL);
 			(void)waitpid(pid, &status, 0);
 		} else if (WIFSIGNALED(status)) {
-			pr_dbg(stderr, "%s: child died: %s (instance %d)\n",
-				name, stress_strsignal(WTERMSIG(status)),
-				instance);
+			pr_dbg("%s: child died: %s (instance %d)\n",
+				args->name, stress_strsignal(WTERMSIG(status)),
+				args->instance);
 			/* If we got killed by OOM killer, re-start */
 			if (WTERMSIG(status) == SIGKILL) {
 				log_system_mem_info();
-				pr_dbg(stderr, "%s: assuming killed by OOM "
+				pr_dbg("%s: assuming killed by OOM "
 					"killer, restarting again "
 					"(instance %d)\n",
-					name, instance);
+					args->name, args->instance);
 				ooms++;
 				goto again;
 			}
 			/* If we got killed by sigsegv, re-start */
 			if (WTERMSIG(status) == SIGSEGV) {
-				pr_dbg(stderr, "%s: killed by SIGSEGV, "
+				pr_dbg("%s: killed by SIGSEGV, "
 					"restarting again "
 					"(instance %d)\n",
-					name, instance);
+					args->name, args->instance);
 				segvs++;
 				goto again;
 			}
 		}
 	} else if (pid == 0) {
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
 
 		/* Make sure this is killable by OOM killer */
-		set_oom_adjustment(name, true);
+		set_oom_adjustment(args->name, true);
 
 		do {
 			void *old_ptr = ptr;
@@ -127,15 +126,15 @@ again:
 			 * some time and we should bail out before
 			 * exerting any more memory pressure
 			 */
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				goto abort;
 
 			ptr = realloc(old_ptr, size);
 			if (ptr == NULL) {
-				pr_dbg(stderr, "%s: out of memory at %" PRIu64
+				pr_dbg("%s: out of memory at %" PRIu64
 					" MB (instance %d)\n",
-					name, (uint64_t)(4096ULL * size) >> 20,
-					instance);
+					args->name, (uint64_t)(4096ULL * size) >> 20,
+					args->instance);
 				free(old_ptr);
 				size = 0;
 				nomems++;
@@ -159,34 +158,34 @@ again:
 				}
 
 				for (i = 0; i < n; i+= stride, u8ptr += stride) {
-					if (!opt_do_run)
+					if (!g_keep_stressing_flag)
 						goto abort;
 					*u8ptr = (uint8_t)i;
 				}
 
-				if (opt_flags & OPT_FLAGS_VERIFY) {
+				if (g_opt_flags & OPT_FLAGS_VERIFY) {
 					for (i = 0; i < n; i+= stride, tmp += stride) {
-						if (!opt_do_run)
+						if (!g_keep_stressing_flag)
 							goto abort;
 						if (*tmp != (uint8_t)i)
-							pr_fail(stderr, "%s: byte at location %p was 0x%" PRIx8
+							pr_fail("%s: byte at location %p was 0x%" PRIx8
 								" instead of 0x%" PRIx8 "\n",
-								name, u8ptr, *tmp, (uint8_t)i);
+								args->name, u8ptr, *tmp, (uint8_t)i);
 					}
 				}
 				last_ptr = ptr;
 				last_ptr_end = u8ptr;
 			}
-			(*counter)++;
-		} while (opt_do_run && (!max_ops || *counter < max_ops));
+			inc_counter(args);
+		} while (keep_stressing());
 abort:
 		free(ptr);
 	}
 	if (ooms + segvs + nomems > 0)
-		pr_dbg(stderr, "%s: OOM restarts: %" PRIu32
+		pr_dbg("%s: OOM restarts: %" PRIu32
 			", SEGV restarts: %" PRIu32
 			", out of memory restarts: %" PRIu32 ".\n",
-			name, ooms, segvs, nomems);
+			args->name, ooms, segvs, nomems);
 
 	return EXIT_SUCCESS;
 }
