@@ -28,29 +28,22 @@
 
 #define CLONE_STACK_SIZE	(64*1024)
 
-/* Context for clone */
-typedef struct {
-	uint64_t max_ops;
-	uint64_t *counter;
-	const char *name;
-} context_t;
-
 /*
  *  stress_bind_mount_child()
  *	aggressively perform bind mounts, this can force out of memory
  *	situations
  */
-static int stress_bind_mount_child(void *arg)
+static int stress_bind_mount_child(void *parg)
 {
-	context_t *context = (context_t *)arg;
-	uint64_t *counter = context->counter;
+	const args_t *args = ((pthread_args_t *)parg)->args;
+	uint64_t *counter = args->counter;
 
-	(void)setpgid(0, pgrp);
+	(void)setpgid(0, g_pgrp);
 	stress_parent_died_alarm();
 
 	do {
 		if (mount("/", "/", "", MS_BIND | MS_REC, 0) < 0) {
-			pr_fail_err(context->name, "mount");
+			pr_fail_err("mount");
 			break;
 		}
 		/*
@@ -58,9 +51,9 @@ static int stress_bind_mount_child(void *arg)
 	`	 *  just to make the kernel work harder
 		 */
 		(void)umount("/");
-		(*counter)++;
-	} while (opt_do_run &&
-		 (!context->max_ops || *counter < context->max_ops));
+		inc_counter(args);
+	} while (g_keep_stressing_flag &&
+		 (!args->max_ops || *counter < args->max_ops));
 
 	return 0;
 }
@@ -69,41 +62,31 @@ static int stress_bind_mount_child(void *arg)
  *  stress_bind_mount()
  *      stress bind mounting
  */
-int stress_bind_mount(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_bind_mount(const args_t *args)
 {
 	int pid = 0, status;
-	context_t context;
 	const ssize_t stack_offset =
 		stress_get_stack_direction() *
 		(CLONE_STACK_SIZE - 64);
 	char stack[CLONE_STACK_SIZE];
 	char *stack_top = stack + stack_offset;
-
-	(void)instance;
-
-	context.name = name;
-	context.max_ops = max_ops;
-	context.counter = counter;
+	pthread_args_t pargs = { args };
 
 	pid = clone(stress_bind_mount_child,
 		align_stack(stack_top),
 		CLONE_NEWUSER | CLONE_NEWNS | CLONE_NEWPID | CLONE_VM,
-		&context, 0);
+		(void *)&pargs, 0);
 	if (pid < 0) {
 		int rc = exit_status(errno);
 
-		pr_fail_err(name, "clone");
+		pr_fail_err("clone");
 		return rc;
 	}
 
 	do {
 		/* Twiddle thumbs */
 		(void)shim_usleep(10000);
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (keep_stressing());
 
 	(void)kill(pid, SIGKILL);
 	(void)waitpid(pid, &status, 0);
@@ -111,13 +94,8 @@ int stress_bind_mount(
 	return EXIT_SUCCESS;
 }
 #else
-int stress_bind_mount(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_bind_mount(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
-
 #endif
