@@ -28,76 +28,72 @@
  *  stress_brk()
  *	stress brk and sbrk
  */
-int stress_brk(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_brk(const args_t *args)
 {
 	pid_t pid;
 	uint32_t ooms = 0, segvs = 0, nomems = 0;
-	const size_t page_size = stress_get_pagesize();
+	const size_t page_size = args->page_size;
 
 again:
-	if (!opt_do_run)
+	if (!g_keep_stressing_flag)
 		return EXIT_SUCCESS;
 	pid = fork();
 	if (pid < 0) {
 		if (errno == EAGAIN)
 			goto again;
-		pr_err(stderr, "%s: fork failed: errno=%d: (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: fork failed: errno=%d: (%s)\n",
+			args->name, errno, strerror(errno));
 	} else if (pid > 0) {
 		int status, ret;
 
-		(void)setpgid(pid, pgrp);
+		(void)setpgid(pid, g_pgrp);
 		/* Parent, wait for child */
 		ret = waitpid(pid, &status, 0);
 		if (ret < 0) {
 			if (errno != EINTR)
-				pr_dbg(stderr, "%s: waitpid(): errno=%d (%s)\n",
-					name, errno, strerror(errno));
+				pr_dbg("%s: waitpid(): errno=%d (%s)\n",
+					args->name, errno, strerror(errno));
 			(void)kill(pid, SIGTERM);
 			(void)kill(pid, SIGKILL);
 			(void)waitpid(pid, &status, 0);
 		} else if (WIFSIGNALED(status)) {
-			pr_dbg(stderr, "%s: child died: %s (instance %d)\n",
-				name, stress_strsignal(WTERMSIG(status)),
-				instance);
+			pr_dbg("%s: child died: %s (instance %d)\n",
+				args->name, stress_strsignal(WTERMSIG(status)),
+				args->instance);
 			/* If we got killed by OOM killer, re-start */
 			if (WTERMSIG(status) == SIGKILL) {
 				log_system_mem_info();
-				pr_dbg(stderr, "%s: assuming killed by OOM "
+				pr_dbg("%s: assuming killed by OOM "
 					"killer, restarting again "
 					"(instance %d)\n",
-					name, instance);
+					args->name, args->instance);
 				ooms++;
 				goto again;
 			}
 			/* If we got killed by sigsegv, re-start */
 			if (WTERMSIG(status) == SIGSEGV) {
-				pr_dbg(stderr, "%s: killed by SIGSEGV, "
+				pr_dbg("%s: killed by SIGSEGV, "
 					"restarting again "
 					"(instance %d)\n",
-					name, instance);
+					args->name, args->instance);
 				segvs++;
 				goto again;
 			}
 		}
 	} else if (pid == 0) {
 		uint8_t *start_ptr;
-		bool touch = !(opt_flags & OPT_FLAGS_BRK_NOTOUCH);
+		bool touch = !(g_opt_flags & OPT_FLAGS_BRK_NOTOUCH);
 		int i = 0;
 
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
 
 		/* Make sure this is killable by OOM killer */
-		set_oom_adjustment(name, true);
+		set_oom_adjustment(args->name, true);
 
 		start_ptr = sbrk(0);
 		if (start_ptr == (void *) -1) {
-			pr_fail_err(name, "sbrk(0)");
+			pr_fail_err("sbrk(0)");
 			exit(EXIT_FAILURE);
 		}
 
@@ -118,14 +114,14 @@ again:
 				if ((errno == ENOMEM) || (errno == EAGAIN)) {
 					nomems++;
 					if (brk(start_ptr) < 0) {
-						pr_err(stderr, "%s: brk(%p) failed: errno=%d (%s)\n",
-							name, start_ptr, errno,
+						pr_err("%s: brk(%p) failed: errno=%d (%s)\n",
+							args->name, start_ptr, errno,
 							strerror(errno));
 						exit(EXIT_FAILURE);
 					}
 				} else {
-					pr_err(stderr, "%s: sbrk(%d) failed: errno=%d (%s)\n",
-						name, (int)page_size, errno,
+					pr_err("%s: sbrk(%d) failed: errno=%d (%s)\n",
+						args->name, (int)page_size, errno,
 						strerror(errno));
 					exit(EXIT_FAILURE);
 				}
@@ -134,14 +130,14 @@ again:
 				if (touch)
 					*(ptr - 1) = 0;
 			}
-			(*counter)++;
-		} while (opt_do_run && (!max_ops || *counter < max_ops));
+			inc_counter(args);
+		} while (keep_stressing());
 	}
 	if (ooms + segvs + nomems > 0)
-		pr_dbg(stderr, "%s: OOM restarts: %" PRIu32
+		pr_dbg("%s: OOM restarts: %" PRIu32
 			", SEGV restarts: %" PRIu32
 			", out of memory restarts: %" PRIu32 ".\n",
-			name, ooms, segvs, nomems);
+			args->name, ooms, segvs, nomems);
 
 	return EXIT_SUCCESS;
 }
