@@ -45,7 +45,7 @@
 			mfence();					\
 		}							\
 		i = (i + 32769) & (mem_cache_size - 1);			\
-		if (!opt_do_run)					\
+		if (!g_keep_stressing_flag)				\
 			break;						\
 	}
 
@@ -55,11 +55,7 @@
  *	if possible change CPU affinity to try to cause
  *	poor cache behaviour
  */
-int stress_cache(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_cache(const args_t *args)
 {
 #if defined(__linux__)
 	cpu_set_t mask;
@@ -70,12 +66,12 @@ int stress_cache(
 #endif
 	uint32_t total = 0;
 	int ret = EXIT_SUCCESS;
-	uint8_t *const mem_cache = shared->mem_cache;
-	const uint64_t mem_cache_size = shared->mem_cache_size;
+	uint8_t *const mem_cache = g_shared->mem_cache;
+	const uint64_t mem_cache_size = g_shared->mem_cache_size;
 
-	if (instance == 0)
-		pr_dbg(stderr, "%s: using cache buffer size of %" PRIu64 "K\n",
-			name, mem_cache_size / 1024);
+	if (args->instance == 0)
+		pr_dbg("%s: using cache buffer size of %" PRIu64 "K\n",
+			args->name, mem_cache_size / 1024);
 
 #if defined(__linux__)
 	if (sched_getaffinity(0, sizeof(proc_mask), &proc_mask) < 0)
@@ -85,9 +81,9 @@ int stress_cache(
 			pinned = true;
 
 	if (pinned) {
-		pr_inf(stdout, "%s: can't get sched affinity, pinning to "
+		pr_inf("%s: can't get sched affinity, pinning to "
 			"CPU %d (instance %" PRIu32 ")\n",
-			name, sched_getcpu(), pinned);
+			args->name, sched_getcpu(), pinned);
 	}
 #endif
 
@@ -97,7 +93,7 @@ int stress_cache(
 		register uint64_t j;
 
 		if ((r >> 13) & 1) {
-			switch (opt_flags & OPT_FLAGS_CACHE_MASK) {
+			switch (g_opt_flags & OPT_FLAGS_CACHE_MASK) {
 			case OPT_FLAGS_CACHE_FLUSH:
 				CACHE_WRITE(OPT_FLAGS_CACHE_FLUSH);
 				break;
@@ -134,12 +130,12 @@ int stress_cache(
 				total += mem_cache[i] +
 					mem_cache[(mem_cache_size - 1) - i];
 				i = (i + 32769) % mem_cache_size;
-				if (!opt_do_run)
+				if (!g_keep_stressing_flag)
 					break;
 			}
 		}
 #if defined(__linux__)
-		if ((opt_flags & OPT_FLAGS_CACHE_NOAFF) && !pinned) {
+		if ((g_opt_flags & OPT_FLAGS_CACHE_NOAFF) && !pinned) {
 			int current;
 
 			/* Pin to the current CPU */
@@ -150,18 +146,18 @@ int stress_cache(
 			cpu = (int32_t)current;
 		} else {
 			do {
-				cpu = (opt_flags & OPT_FLAGS_AFFINITY_RAND) ?
+				cpu = (g_opt_flags & OPT_FLAGS_AFFINITY_RAND) ?
 					(mwc32() >> 4) : cpu + 1;
 				cpu %= cpus;
 			} while (!(CPU_ISSET(cpu, &proc_mask)));
 		}
 
-		if (!(opt_flags & OPT_FLAGS_CACHE_NOAFF) || !pinned) {
+		if (!(g_opt_flags & OPT_FLAGS_CACHE_NOAFF) || !pinned) {
 			CPU_ZERO(&mask);
 			CPU_SET(cpu, &mask);
 			(void)sched_setaffinity(0, sizeof(mask), &mask);
 
-			if ((opt_flags & OPT_FLAGS_CACHE_NOAFF)) {
+			if ((g_opt_flags & OPT_FLAGS_CACHE_NOAFF)) {
 				/* Don't continually set the affinity */
 				pinned = true;
 			}
@@ -170,9 +166,9 @@ int stress_cache(
 #endif
 		shim_cacheflush((char *)stress_cache, 8192, ICACHE);
 		shim_cacheflush((char *)mem_cache, (int)mem_cache_size, DCACHE);
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
-	pr_dbg(stderr, "%s: total [%" PRIu32 "]\n", name, total);
+	pr_dbg("%s: total [%" PRIu32 "]\n", args->name, total);
 	return ret;
 }
