@@ -29,10 +29,9 @@
 #include <sys/capability.h>
 
 static int stress_capgetset_pid(
-	const char *name,
+	const args_t *args,
 	const pid_t pid,
 	const bool do_set,
-	uint64_t *counter,
 	const bool exists)
 {
 	int ret;
@@ -49,9 +48,9 @@ static int stress_capgetset_pid(
 	if (ret < 0) {
 		if (((errno == ESRCH) && exists) ||
 		    (errno != ESRCH)) {
-			pr_fail(stderr, "%s: capget on pid %d failed: "
+			pr_fail("%s: capget on pid %d failed: "
 				"errno=%d (%s)\n",
-				name, pid, errno, strerror(errno));
+				args->name, pid, errno, strerror(errno));
 		}
 	}
 
@@ -60,14 +59,14 @@ static int stress_capgetset_pid(
 		if (ret < 0) {
 			if (((errno == ESRCH) && exists) ||
 			    (errno != ESRCH)) {
-				pr_fail(stderr, "%s: capget on pid %d failed: "
+				pr_fail("%s: capget on pid %d failed: "
 					"errno=%d (%s)\n",
-					name, pid, errno, strerror(errno));
+					args->name, pid, errno, strerror(errno));
 			}
 		}
 	}
 
-	(*counter)++;
+	inc_counter(args);
 
 	return ret;
 }
@@ -76,28 +75,19 @@ static int stress_capgetset_pid(
  *  stress_cap
  *	stress capabilities (trivial)
  */
-int stress_cap(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_cap(const args_t *args)
 {
-	const pid_t pid = getpid();
-	const pid_t ppid = getppid();
-
-	(void)instance;
-
 	do {
 		DIR *dir;
 
-		stress_capgetset_pid(name, 1, false, counter, true);
-		if (!opt_do_run || (max_ops && *counter >= max_ops))
+		stress_capgetset_pid(args, 1, false, true);
+		if (!keep_stressing())
 			break;
-		stress_capgetset_pid(name, pid, true, counter, true);
-		if (!opt_do_run || (max_ops && *counter >= max_ops))
+		stress_capgetset_pid(args, args->pid, true, true);
+		if (!keep_stressing())
 			break;
-		stress_capgetset_pid(name, ppid, false, counter, false);
-		if (!opt_do_run || (max_ops && *counter >= max_ops))
+		stress_capgetset_pid(args, args->ppid, false, false);
+		if (!keep_stressing())
 			break;
 
 		dir = opendir("/proc");
@@ -111,24 +101,19 @@ int stress_cap(
 					continue;
 				if (sscanf(d->d_name, "%d", &p) != 1)
 					continue;
-				stress_capgetset_pid(name, p, false,
-					counter, false);
-				if (!opt_do_run || (max_ops && *counter >= max_ops))
+				stress_capgetset_pid(args, p, false, false);
+				if (!keep_stressing())
 					break;
 			}
 			(void)closedir(dir);
 		}
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (keep_stressing());
 
 	return EXIT_SUCCESS;
 }
 #else
-int stress_cap(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_cap(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
