@@ -24,91 +24,99 @@
  */
 #include "stress-ng.h"
 
+static uint64_t opt_chdir_dirs = DEFAULT_CHDIR_DIRS;
+
+/*
+ *  stress_set_chdir_dirs()
+ *	set number of chdir directories from given option string
+ */
+void stress_set_chdir_dirs(const char *opt)
+{
+	opt_chdir_dirs = get_uint64_byte(opt);
+	check_range("chdir-dirs", opt_chdir_dirs,
+		MIN_CHDIR_DIRS, MAX_CHDIR_DIRS);
+}
+
 /*
  *  stress_chdir
  *	stress chdir calls
  */
-int stress_chdir(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_chdir(const args_t *args)
 {
-	const pid_t pid = getpid();
 	uint64_t i;
 	char path[PATH_MAX], cwd[PATH_MAX];
 	int rc, ret = EXIT_FAILURE;
-	char *paths[DEFAULT_DIRS];
+	char *paths[opt_chdir_dirs];
 
 	memset(paths, 0, sizeof(paths));
 
 	if (getcwd(cwd, sizeof(cwd)) == NULL) {
-		pr_fail_err(name, "getcwd");
+		pr_fail_err("getcwd");
 		return ret;
 	}
 
-	rc = stress_temp_dir_mk(name, pid, instance);
+	rc = stress_temp_dir_mk_args(args);
 	if (rc < 0)
 		return exit_status(-rc);
 
 	/* Populate */
-	for (i = 0; i < DEFAULT_DIRS; i++) {
+	for (i = 0; i < opt_chdir_dirs; i++) {
 		uint64_t gray_code = (i >> 1) ^ i;
 
-		(void)stress_temp_filename(path, sizeof(path),
-			name, pid, instance, gray_code);
+		(void)stress_temp_filename_args(args,
+			path, sizeof(path), gray_code);
 		paths[i] = strdup(path);
 		if (paths[i] == NULL)
 			goto abort;
 		rc = mkdir(path, S_IRUSR | S_IWUSR | S_IXUSR);
 		if (rc < 0) {
 			ret = exit_status(errno);
-			pr_fail_err(name, "mkdir");
+			pr_fail_err("mkdir");
 			goto abort;
 		}
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			goto done;
 	}
 
 	do {
-		for (i = 0; i < DEFAULT_DIRS; i++) {
-			if (!opt_do_run || (max_ops && *counter >= max_ops))
+		for (i = 0; i < opt_chdir_dirs; i++) {
+			if (!keep_stressing())
 				goto done;
 			if (chdir(paths[i]) < 0) {
 				if (errno != ENOMEM) {
-					pr_fail_err(name, "chdir");
+					pr_fail_err("chdir");
 					goto abort;
 				}
 			}
 redo:
-			if (!opt_do_run || (max_ops && *counter >= max_ops))
+			if (!keep_stressing())
 				goto done;
 			/* We need chdir to cwd to always succeed */
 			if (chdir(cwd) < 0) {
 				/* Maybe low memory, force retry */
 				if (errno == ENOMEM)
 					goto redo;
-				pr_fail_err(name, "chdir");
+				pr_fail_err("chdir");
 				goto abort;
 			}
 		}
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 done:
 	ret = EXIT_SUCCESS;
 abort:
 	if (chdir(cwd) < 0)
-		pr_fail_err(name, "chdir");
+		pr_fail_err("chdir");
 
 	/* force unlink of all files */
-	pr_tidy(stderr, "%s: removing %" PRIu32 " directories\n",
-		name, DEFAULT_DIRS);
+	pr_tidy("%s: removing %" PRIu64 " directories\n",
+		args->name, opt_chdir_dirs);
 
-	for (i = 0; (i < DEFAULT_DIRS) && paths[i] ; i++) {
+	for (i = 0; (i < opt_chdir_dirs) && paths[i] ; i++) {
 		(void)rmdir(paths[i]);
 		free(paths[i]);
 	}
-	(void)stress_temp_dir_rm(name, pid, instance);
+	(void)stress_temp_dir_rm_args(args);
 
 	return ret;
 }
