@@ -98,14 +98,8 @@ static char *stress_clock_name(int id)
  *  stress_clock()
  *	stress system by rapid clocking system calls
  */
-int stress_clock(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_clock(const args_t *args)
 {
-	(void)instance;
-
 	do {
 		size_t i;
 		struct timespec t;
@@ -116,15 +110,15 @@ int stress_clock(
 		for (i = 0; i < SIZEOF_ARRAY(clocks); i++) {
 			int ret = clock_getres(clocks[i].id, &t);
 
-			if ((ret < 0) && (opt_flags & OPT_FLAGS_VERIFY))
-				pr_fail(stderr, "%s: clock_getres failed for "
+			if ((ret < 0) && (g_opt_flags & OPT_FLAGS_VERIFY))
+				pr_fail("%s: clock_getres failed for "
 				"timer '%s', errno=%d (%s)\n",
-				name, clocks[i].name, errno, strerror(errno));
+				args->name, clocks[i].name, errno, strerror(errno));
 			ret = clock_gettime(clocks[i].id, &t);
-			if ((ret < 0) && (opt_flags & OPT_FLAGS_VERIFY))
-				pr_fail(stderr, "%s: clock_gettime failed for "
+			if ((ret < 0) && (g_opt_flags & OPT_FLAGS_VERIFY))
+				pr_fail("%s: clock_gettime failed for "
 				"timer '%s', errno=%d (%s)\n",
-				name, clocks[i].name, errno, strerror(errno));
+				args->name, clocks[i].name, errno, strerror(errno));
 		}
 
 #if (_XOPEN_SOURCE >= 600 || _POSIX_C_SOURCE >= 200112L)
@@ -140,9 +134,9 @@ int stress_clock(
 			 *  clock_nanosleep() to return immediately
 			 */
 			ret = clock_nanosleep(clocks_nanosleep[i], TIMER_ABSTIME, &t, NULL);
-			if ((ret < 0) && (opt_flags & OPT_FLAGS_VERIFY))
-				pr_fail(stderr, "%s: clock_nanosleep failed for timer '%s', "
-					"errno=%d (%s)\n", name,
+			if ((ret < 0) && (g_opt_flags & OPT_FLAGS_VERIFY))
+				pr_fail("%s: clock_nanosleep failed for timer '%s', "
+					"errno=%d (%s)\n", args->name,
 					stress_clock_name(clocks_nanosleep[i]),
 					errno, strerror(errno));
 		}
@@ -162,9 +156,9 @@ int stress_clock(
 			memset(&sevp, 0, sizeof(sevp));
 			sevp.sigev_notify = SIGEV_NONE;
 			ret = timer_create(timers[i], &sevp, &timer_id);
-			if ((ret < 0) && (opt_flags & OPT_FLAGS_VERIFY)) {
-				pr_fail(stderr, "%s: timer_create failed for timer '%s', "
-					"errno=%d (%s)\n", name,
+			if ((ret < 0) && (g_opt_flags & OPT_FLAGS_VERIFY)) {
+				pr_fail("%s: timer_create failed for timer '%s', "
+					"errno=%d (%s)\n", args->name,
 					stress_clock_name(timers[i]),
 					errno, strerror(errno));
 				continue;
@@ -177,9 +171,9 @@ int stress_clock(
 			its.it_interval.tv_nsec = 0;
 
 			ret = timer_settime(timer_id, 0, &its, NULL);
-			if ((ret < 0) && (opt_flags & OPT_FLAGS_VERIFY)) {
-				pr_fail(stderr, "%s: timer_settime failed for timer '%s', "
-					"errno=%d (%s)\n", name,
+			if ((ret < 0) && (g_opt_flags & OPT_FLAGS_VERIFY)) {
+				pr_fail("%s: timer_settime failed for timer '%s', "
+					"errno=%d (%s)\n", args->name,
 					stress_clock_name(timers[i]),
 					errno, strerror(errno));
 				goto timer_delete;
@@ -187,39 +181,35 @@ int stress_clock(
 
 			do {
 				ret = timer_gettime(timer_id, &its);
-				if ((ret < 0) && (opt_flags & OPT_FLAGS_VERIFY)) {
-					pr_fail(stderr, "%s: timer_gettime failed for timer '%s', "
-						"errno=%d (%s)\n", name,
+				if ((ret < 0) && (g_opt_flags & OPT_FLAGS_VERIFY)) {
+					pr_fail("%s: timer_gettime failed for timer '%s', "
+						"errno=%d (%s)\n", args->name,
 						stress_clock_name(timers[i]),
 						errno, strerror(errno));
 					goto timer_delete;
 				}
 				loops--;
-			} while ((loops > 0) && opt_do_run && (its.it_value.tv_nsec != 0));
+			} while ((loops > 0) && g_keep_stressing_flag && (its.it_value.tv_nsec != 0));
 
 timer_delete:
 			ret = timer_delete(timer_id);
-			if ((ret < 0) && (opt_flags & OPT_FLAGS_VERIFY)) {
-				pr_fail(stderr, "%s: timer_delete failed for timer '%s', "
-					"errno=%d (%s)\n", name,
+			if ((ret < 0) && (g_opt_flags & OPT_FLAGS_VERIFY)) {
+				pr_fail("%s: timer_delete failed for timer '%s', "
+					"errno=%d (%s)\n", args->name,
 					stress_clock_name(timers[i]),
 					errno, strerror(errno));
 				break;
 			}
 		}
 #endif
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
 	return EXIT_SUCCESS;
 }
 #else
-int stress_clock(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_clock(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
