@@ -115,10 +115,10 @@ static const int unshare_flags[] = {
  *  stress_set_clone_max()
  *	set maximum number of clones allowed
  */
-void stress_set_clone_max(const char *optarg)
+void stress_set_clone_max(const char *opt)
 {
 	set_clone_max = true;
-	opt_clone_max = get_uint64_byte(optarg);
+	opt_clone_max = get_uint64_byte(opt);
 	check_range("clone-max", opt_clone_max,
 		MIN_ZOMBIES, MAX_ZOMBIES);
 }
@@ -224,23 +224,17 @@ static int clone_func(void *arg)
  *  stress_clone()
  *	stress by cloning and exiting
  */
-int stress_clone(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_clone(const args_t *args)
 {
 	uint64_t max_clones = 0;
 	const ssize_t stack_offset =
 		stress_get_stack_direction() *
 		(CLONE_STACK_SIZE - 64);
 
-	(void)instance;
-
 	if (!set_clone_max) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_clone_max = MAX_ZOMBIES;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_clone_max = MIN_ZOMBIES;
 	}
 
@@ -267,14 +261,14 @@ int stress_clone(
 
 			if (max_clones < clones.length)
 				max_clones = clones.length;
-			(*counter)++;
+			inc_counter(args);
 		} else {
 			stress_clone_head_remove();
 		}
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (keep_stressing());
 
-	pr_inf(stdout, "%s: created a maximum of %" PRIu64 " clones\n",
-		name, max_clones);
+	pr_inf("%s: created a maximum of %" PRIu64 " clones\n",
+		args->name, max_clones);
 
 	/* And reap */
 	while (clones.head) {
@@ -286,12 +280,8 @@ int stress_clone(
 	return EXIT_SUCCESS;
 }
 #else
-int stress_clone(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_clone(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
