@@ -81,19 +81,19 @@ static const stress_cpu_stressor_info_t cpu_methods[];
 /* Don't make this static to ensure dithering does not get optimised out */
 uint8_t pixels[STRESS_CPU_DITHER_X][STRESS_CPU_DITHER_Y];
 
-void stress_set_cpu_load(const char *optarg) {
-	opt_cpu_load = get_int32(optarg);
+void stress_set_cpu_load(const char *opt) {
+	opt_cpu_load = get_int32(opt);
 	if ((opt_cpu_load < 0) || (opt_cpu_load > 100)) {
-		fprintf(stderr, "CPU load must in the range 0 to 100.\n");
+		(void)fprintf(stderr, "CPU load must in the range 0 to 100.\n");
 		exit(EXIT_FAILURE);
 	}
 }
 
-void stress_set_cpu_load_slice(const char *optarg)
+void stress_set_cpu_load_slice(const char *opt)
 {
-	opt_cpu_load_slice = get_int32(optarg);
+	opt_cpu_load_slice = get_int32(opt);
 	if ((opt_cpu_load < -5000) || (opt_cpu_load > 5000)) {
-		fprintf(stderr, "CPU load must in the range -5000 to 5000.\n");
+		(void)fprintf(stderr, "CPU load must in the range -5000 to 5000.\n");
 		exit(EXIT_FAILURE);
 	}
 }
@@ -109,11 +109,11 @@ static void HOT stress_cpu_sqrt(const char *name)
 	for (i = 0; i < 16384; i++) {
 		uint64_t rnd = mwc32();
 		double r = sqrt((double)rnd) * sqrt((double)rnd);
-		if ((opt_flags & OPT_FLAGS_VERIFY) &&
+		if ((g_opt_flags & OPT_FLAGS_VERIFY) &&
 		    (uint64_t)rint(r) != rnd) {
-			pr_fail(stderr, "%s: sqrt error detected on "
+			pr_fail("%s: sqrt error detected on "
 				"sqrt(%" PRIu64 ")\n", name, rnd);
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				break;
 		}
 	}
@@ -139,8 +139,8 @@ static void stress_cpu_loop(const char *name)
 		i_sum += i;
 		FORCE_DO_NOTHING();
 	}
-	if ((opt_flags & OPT_FLAGS_VERIFY) && (i_sum != sum))
-		pr_fail(stderr, "%s: cpu loop 0..16383 sum was %" PRIu32 " and "
+	if ((g_opt_flags & OPT_FLAGS_VERIFY) && (i_sum != sum))
+		pr_fail("%s: cpu loop 0..16383 sum was %" PRIu32 " and "
 			"did not match the expected value of %" PRIu32 "\n",
 			name, i_sum, sum);
 }
@@ -165,8 +165,8 @@ static void HOT OPTIMIZE3 stress_cpu_gcd(const char *name)
 		i_sum += a;
 		FORCE_DO_NOTHING();
 	}
-	if ((opt_flags & OPT_FLAGS_VERIFY) && (i_sum != sum))
-		pr_fail(stderr, "%s: gcd error detected, failed modulo "
+	if ((g_opt_flags & OPT_FLAGS_VERIFY) && (i_sum != sum))
+		pr_fail("%s: gcd error detected, failed modulo "
 			"or assigment operations\n", name);
 }
 
@@ -223,8 +223,8 @@ static void HOT OPTIMIZE3 stress_cpu_bitops(const char *name)
 			i_sum += v;
 		}
 	}
-	if ((opt_flags & OPT_FLAGS_VERIFY) && (i_sum != sum))
-		pr_fail(stderr, "%s: bitops error detected, failed "
+	if ((g_opt_flags & OPT_FLAGS_VERIFY) && (i_sum != sum))
+		pr_fail("%s: bitops error detected, failed "
 			"bitops operations\n", name);
 }
 
@@ -314,8 +314,8 @@ static void HOT OPTIMIZE3 stress_cpu_rand(const char *name)
 	for (i = 0; i < 16384; i++)
 		i_sum += mwc32();
 
-	if ((opt_flags & OPT_FLAGS_VERIFY) && (i_sum != sum))
-		pr_fail(stderr, "%s: rand error detected, failed sum of "
+	if ((g_opt_flags & OPT_FLAGS_VERIFY) && (i_sum != sum))
+		pr_fail("%s: rand error detected, failed sum of "
 			"pseudo-random values\n", name);
 }
 
@@ -366,13 +366,13 @@ static void HOT OPTIMIZE3 stress_cpu_nsqrt(const char *name)
 		}
 		rt = (lo + hi) / 2.0;
 
-		if (opt_flags & OPT_FLAGS_VERIFY) {
+		if (g_opt_flags & OPT_FLAGS_VERIFY) {
 			if (j >= max_iter)
-				pr_fail(stderr, "%s: Newton-Raphson sqrt "
+				pr_fail("%s: Newton-Raphson sqrt "
 					"computation took more iterations "
 					"than expected\n", name);
 			if ((int)rintl(rt * rt) != i)
-				pr_fail(stderr, "%s: Newton-Rapshon sqrt not "
+				pr_fail("%s: Newton-Rapshon sqrt not "
 					"accurate enough\n", name);
 		}
 	}
@@ -406,9 +406,9 @@ static void HOT OPTIMIZE3 stress_cpu_phi(const char *name)
 	/* And we have the golden ratio */
 	phi = (long double)b / (long double)a;
 
-	if ((opt_flags & OPT_FLAGS_VERIFY) &&
+	if ((g_opt_flags & OPT_FLAGS_VERIFY) &&
 	    (fabsl(phi - phi_) > precision))
-		pr_fail(stderr, "%s: Golden Ratio phi not accurate enough\n",
+		pr_fail("%s: Golden Ratio phi not accurate enough\n",
 			name);
 }
 
@@ -476,8 +476,8 @@ static void HOT OPTIMIZE3 stress_cpu_euler(const char *name)
 		e += (1.0 / fact);
 	} while ((n < 25) && (fabsl(e - last_e) > precision));
 
-	if ((opt_flags & OPT_FLAGS_VERIFY) && (n >= 25))
-		pr_fail(stderr, "%s: Euler computation took more iterations "
+	if ((g_opt_flags & OPT_FLAGS_VERIFY) && (n >= 25))
+		pr_fail("%s: Euler computation took more iterations "
 			"than expected\n", name);
 }
 
@@ -527,8 +527,8 @@ static void stress_cpu_hash_generic(
 		buffer[i] = '\0';
 		i_sum += hash_func(buffer);
 	}
-	if ((opt_flags & OPT_FLAGS_VERIFY) && (i_sum != result))
-		pr_fail(stderr, "%s: %s error detected, failed hash %s sum\n",
+	if ((g_opt_flags & OPT_FLAGS_VERIFY) && (i_sum != result))
+		pr_fail("%s: %s error detected, failed hash %s sum\n",
 			name, hash_name, hash_name);
 }
 
@@ -571,8 +571,8 @@ static void stress_cpu_jenkin(const char *name)
 	for (i = 0; i < sizeof(buffer); i++)
 		i_sum += jenkin(buffer, sizeof(buffer));
 
-	if ((opt_flags & OPT_FLAGS_VERIFY) && (i_sum != sum))
-		pr_fail(stderr, "%s: jenkin error detected, failed hash "
+	if ((g_opt_flags & OPT_FLAGS_VERIFY) && (i_sum != sum))
+		pr_fail("%s: jenkin error detected, failed hash "
 			"jenkin sum\n", name);
 }
 
@@ -725,15 +725,17 @@ static void HOT OPTIMIZE3 stress_cpu_idct(const char *name)
 		}
 	}
 	/* Final output should be a 8x8 matrix of values 255 */
-	for (i = 0; i < sz; i++) {
-		for (j = 0; j < sz; j++) {
-			if (((int)idct[i][j] != 255) &&
-			    (opt_flags & OPT_FLAGS_VERIFY)) {
-				pr_fail(stderr, "%s: IDCT error detected, "
-					"IDCT[%d][%d] was %d, expecting 255\n",
-					name, i, j, (int)idct[i][j]);
+	if (g_opt_flags & OPT_FLAGS_VERIFY) {
+		for (i = 0; i < sz; i++) {
+			for (j = 0; j < sz; j++) {
+				if ((int)idct[i][j] != 255) {
+					pr_fail("%s: IDCT error detected, "
+						"IDCT[%d][%d] was %d, "
+						"expecting 255\n",
+						name, i, j, (int)idct[i][j]);
+				}
 			}
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				return;
 		}
 	}
@@ -795,9 +797,9 @@ static void HOT OPTIMIZE3 stress_cpu_int ## _sz(const char *name)\
 		int_ops(a, b, c1, c2, c3)			\
 	}							\
 								\
-	if ((opt_flags & OPT_FLAGS_VERIFY) &&			\
+	if ((g_opt_flags & OPT_FLAGS_VERIFY) &&			\
 	    ((a != a_final) || (b != b_final)))			\
-		pr_fail(stderr, "%s: int" # _sz " error detected, " \
+		pr_fail("%s: int" # _sz " error detected, " 	\
 			"failed int" # _sz 			\
 			" math operations\n", name);		\
 }								\
@@ -980,9 +982,9 @@ static void HOT OPTIMIZE3 stress_cpu_int ## _sz ## _ ## _name(const char *name)\
 		int_float_ops(_ftype, flt_a, flt_b, flt_c, flt_d,\
 			_sinf, _cosf, int_a, int_b, c1, c2, c3);\
 	}							\
-	if ((opt_flags & OPT_FLAGS_VERIFY) &&			\
+	if ((g_opt_flags & OPT_FLAGS_VERIFY) &&			\
 	    ((int_a != a_final) || (int_b != b_final)))		\
-		pr_fail(stderr, "%s: int" # _sz " error detected, "\
+		pr_fail("%s: int" # _sz " error detected, "	\
 			"failed int" # _sz "" # _ftype		\
 			" math operations\n", name);		\
 								\
@@ -1131,8 +1133,8 @@ static void HOT OPTIMIZE3 stress_cpu_fibonacci(const char *name)
 		f2 = fn;
 	} while (!(fn & 0x8000000000000000ULL));
 
-	if ((opt_flags & OPT_FLAGS_VERIFY) && (fn_res != fn))
-		pr_fail(stderr, "%s: fibonacci error detected, summation "
+	if ((g_opt_flags & OPT_FLAGS_VERIFY) && (fn_res != fn))
+		pr_fail("%s: fibonacci error detected, summation "
 			"or assignment failure\n", name);
 }
 
@@ -1158,13 +1160,13 @@ static void HOT OPTIMIZE3 stress_cpu_psi(const char *name)
 		i++;
 	} while ((i < max_iter) && (fabsl(psi - last_psi) > precision));
 
-	if (opt_flags & OPT_FLAGS_VERIFY) {
+	if (g_opt_flags & OPT_FLAGS_VERIFY) {
 		if (fabsl(psi - PSI) > 1.0e-15)
-			pr_fail(stderr, "%s: calculation of reciprocal "
+			pr_fail("%s: calculation of reciprocal "
 				"Fibonacci constant phi not as accurate "
 				"as expected\n", name);
 		if (i >= max_iter)
-			pr_fail(stderr, "%s: calculation of reciprocal "
+			pr_fail("%s: calculation of reciprocal "
 				"Fibonacci constant took more iterations "
 				"than expected\n", name);
 	}
@@ -1197,8 +1199,8 @@ static void HOT OPTIMIZE3 stress_cpu_ln2(const char *name)
 		ln2 -= (long double)1.0 / (long double)n++;
 	} while ((n < max_iter) && (fabsl(ln2 - last_ln2) > precision));
 
-	if ((opt_flags & OPT_FLAGS_VERIFY) && (n >= max_iter))
-		pr_fail(stderr, "%s: calculation of ln(2) took more "
+	if ((g_opt_flags & OPT_FLAGS_VERIFY) && (n >= max_iter))
+		pr_fail("%s: calculation of ln(2) took more "
 			"iterations than expected\n", name);
 
 	double_put(ln2);
@@ -1226,8 +1228,8 @@ static void stress_cpu_ackermann(const char *name)
 {
 	uint32_t a = ackermann(3, 10);
 
-	if ((opt_flags & OPT_FLAGS_VERIFY) && (a != 0x1ffd))
-		pr_fail(stderr, "%s: ackermann error detected, "
+	if ((g_opt_flags & OPT_FLAGS_VERIFY) && (a != 0x1ffd))
+		pr_fail("%s: ackermann error detected, "
 			"ackermann(3,10) miscalculated\n", name);
 }
 
@@ -1399,12 +1401,12 @@ static void HOT OPTIMIZE3 stress_cpu_gamma(const char *name)
 
 	double_put(gamma);
 
-	if (opt_flags & OPT_FLAGS_VERIFY) {
+	if (g_opt_flags & OPT_FLAGS_VERIFY) {
 		if (fabsl(gamma - GAMMA) > 1.0e-5)
-			pr_fail(stderr, "%s: calculation of Euler-Mascheroni "
+			pr_fail("%s: calculation of Euler-Mascheroni "
 				"constant not as accurate as expected\n", name);
 		if (k > 80000.0)
-			pr_fail(stderr, "%s: calculation of Euler-Mascheroni "
+			pr_fail("%s: calculation of Euler-Mascheroni "
 				"constant took more iterations than "
 				"expected\n", name);
 	}
@@ -1468,8 +1470,8 @@ static void HOT OPTIMIZE3 stress_cpu_sieve(const char *name)
 		if (STRESS_GETBIT(sieve, i))
 			j++;
 	}
-	if ((opt_flags & OPT_FLAGS_VERIFY) && (j != 664579))
-		pr_fail(stderr, "%s: sieve error detected, number of "
+	if ((g_opt_flags & OPT_FLAGS_VERIFY) && (j != 664579))
+		pr_fail("%s: sieve error detected, number of "
 			"primes has been miscalculated\n", name);
 }
 
@@ -1506,8 +1508,8 @@ static void stress_cpu_prime(const char *name)
 			nprimes++;
 	}
 
-	if ((opt_flags & OPT_FLAGS_VERIFY) && (nprimes != 78498))
-		pr_fail(stderr, "%s: prime error detected, number of primes "
+	if ((g_opt_flags & OPT_FLAGS_VERIFY) && (nprimes != 78498))
+		pr_fail("%s: prime error detected, number of primes "
 			"between 0 and 1000000 miscalculated\n", name);
 }
 
@@ -1546,8 +1548,8 @@ static void HOT OPTIMIZE3 stress_cpu_gray(const char *name)
 #endif
 		sum += gray_code;
 	}
-	if ((opt_flags & OPT_FLAGS_VERIFY) && (sum != 0xffff0000))
-		pr_fail(stderr, "%s: gray code error detected, sum of gray "
+	if ((g_opt_flags & OPT_FLAGS_VERIFY) && (sum != 0xffff0000))
+		pr_fail("%s: gray code error detected, sum of gray "
 			"codes between 0x00000 and 0x10000 miscalculated\n",
 			name);
 }
@@ -1581,8 +1583,8 @@ static void stress_cpu_hanoi(const char *name)
 {
 	uint32_t n = hanoi(20, 'X', 'Y', 'Z');
 
-	if ((opt_flags & OPT_FLAGS_VERIFY) && (n != 1048576))
-		pr_fail(stderr, "%s: number of hanoi moves different from "
+	if ((g_opt_flags & OPT_FLAGS_VERIFY) && (n != 1048576))
+		pr_fail("%s: number of hanoi moves different from "
 			"the expected number\n", name);
 
 	uint64_put(n);
@@ -1626,12 +1628,12 @@ static void HOT OPTIMIZE3 stress_cpu_pi(const char *name)
 	} while ((k < max_iter) && (fabsl(pi - last_pi) > precision));
 
 	/* Quick sanity checks */
-	if (opt_flags & OPT_FLAGS_VERIFY) {
+	if (g_opt_flags & OPT_FLAGS_VERIFY) {
 		if (k >= max_iter)
-			pr_fail(stderr, "%s: number of iterations to compute "
+			pr_fail("%s: number of iterations to compute "
 				"pi was more than expected\n", name);
 		if (fabsl(pi - M_PI) > 1.0e-15)
-			pr_fail(stderr, "%s: accuracy of computed pi is not "
+			pr_fail("%s: accuracy of computed pi is not "
 				"as good as expected\n", name);
 	}
 
@@ -1657,12 +1659,12 @@ static void HOT OPTIMIZE3 stress_cpu_omega(const char *name)
 		n++;
 	} while ((n < max_iter) && (fabsl(omega - last_omega) > precision));
 
-	if (opt_flags & OPT_FLAGS_VERIFY) {
+	if (g_opt_flags & OPT_FLAGS_VERIFY) {
 		if (n >= max_iter)
-			pr_fail(stderr, "%s: number of iterations to compute "
+			pr_fail("%s: number of iterations to compute "
 				"omega was more than expected\n", name);
 		if (fabsl(omega - OMEGA) > 1.0e-16)
-			pr_fail(stderr, "%s: accuracy of computed omega is "
+			pr_fail("%s: accuracy of computed omega is "
 				"not as good as expected\n", name);
 	}
 
@@ -1748,8 +1750,8 @@ static void HOT OPTIMIZE3 stress_cpu_hamming(const char *name)
 		sum += encoded;
 	}
 
-	if ((opt_flags & OPT_FLAGS_VERIFY) && (sum != 0xffff8000))
-		pr_fail(stderr, "%s: hamming error detected, sum of 65536 "
+	if ((g_opt_flags & OPT_FLAGS_VERIFY) && (sum != 0xffff8000))
+		pr_fail("%s: hamming error detected, sum of 65536 "
 			"hamming codes not correct\n", name);
 }
 
@@ -1837,8 +1839,8 @@ static void stress_cpu_parity(const char *name)
 			p = !p;
 			v = v & (v - 1);
 		}
-		if ((opt_flags & OPT_FLAGS_VERIFY) && (p != parity))
-			pr_fail(stderr, "%s: parity error detected, using "
+		if ((g_opt_flags & OPT_FLAGS_VERIFY) && (p != parity))
+			pr_fail("%s: parity error detected, using "
 				"optimised naive method\n",  name);
 
 		/*
@@ -1851,8 +1853,8 @@ static void stress_cpu_parity(const char *name)
 		v ^= v >> 2;
 		v = (v & 0x11111111U) * 0x11111111U;
 		p = (v >> 28) & 1;
-		if ((opt_flags & OPT_FLAGS_VERIFY) && (p != parity))
-			pr_fail(stderr, "%s: parity error detected, using the "
+		if ((g_opt_flags & OPT_FLAGS_VERIFY) && (p != parity))
+			pr_fail("%s: parity error detected, using the "
 				"multiply Shapira method\n",  name);
 
 		/*
@@ -1865,8 +1867,8 @@ static void stress_cpu_parity(const char *name)
 		v ^= v >> 4;
 		v &= 0xf;
 		p = (0x6996 >> v) & 1;
-		if ((opt_flags & OPT_FLAGS_VERIFY) && (p != parity))
-			pr_fail(stderr, "%s: parity error detected, using "
+		if ((g_opt_flags & OPT_FLAGS_VERIFY) && (p != parity))
+			pr_fail("%s: parity error detected, using "
 				"the parallel method\n",  name);
 
 		/*
@@ -1878,8 +1880,8 @@ static void stress_cpu_parity(const char *name)
 		v ^= v >> 16;
 		v ^= v >> 8;
 		p = stress_cpu_parity_table[v & 0xff];
-		if ((opt_flags & OPT_FLAGS_VERIFY) && (p != parity))
-			pr_fail(stderr, "%s: parity error detected, using "
+		if ((g_opt_flags & OPT_FLAGS_VERIFY) && (p != parity))
+			pr_fail("%s: parity error detected, using "
 				"the lookup method, variation 1\n",  name);
 
 		/*
@@ -1889,8 +1891,8 @@ static void stress_cpu_parity(const char *name)
 		 */
 		ptr = (uint8_t *)&val;
 		p = stress_cpu_parity_table[ptr[0] ^ ptr[1] ^ ptr[2] ^ ptr[3]];
-		if ((opt_flags & OPT_FLAGS_VERIFY) && (p != parity))
-			pr_fail(stderr, "%s: parity error detected, using the "
+		if ((g_opt_flags & OPT_FLAGS_VERIFY) && (p != parity))
+			pr_fail("%s: parity error detected, using the "
 				"lookup method, variation 1\n",  name);
 	}
 }
@@ -1962,7 +1964,7 @@ static void stress_cpu_dither(const char *name)
 
 /*
  *  stress_cpu_union
- *	perform bit field operations on a packed union
+ *	perform bit field operations on a union
  */
 static void stress_cpu_union(const char *name)
 {
@@ -1996,7 +1998,7 @@ static void stress_cpu_union(const char *name)
 			uint32_t	b1:1;
 		} bits32;
 		uint32_t	u32:30;
-	} __attribute__ ((packed)) u_t;
+	} u_t;
 
 	static u_t u;
 	size_t i;
@@ -2065,9 +2067,9 @@ static void stress_cpu_queens(const char *name)
 
 	for (all = 1, n = 1; n < 13; n++) {
 		uint32_t solutions = queens_try(0, 0, 0, all);
-		if ((opt_flags & OPT_FLAGS_VERIFY) &&
+		if ((g_opt_flags & OPT_FLAGS_VERIFY) &&
 		    (solutions != queens_solutions[n]))
-			pr_fail(stderr, "%s: queens solution error detected "
+			pr_fail("%s: queens solution error detected "
 				"on board size %" PRIu32 "\n",
 				name, n);
 		all = (all + all) + 1;
@@ -2189,11 +2191,11 @@ int HOT OPTIMIZE3 stress_set_cpu_method(const char *name)
 		}
 	}
 
-	fprintf(stderr, "cpu-method must be one of:");
+	(void)fprintf(stderr, "cpu-method must be one of:");
 	for (info = cpu_methods; info->func; info++) {
-		fprintf(stderr, " %s", info->name);
+		(void)fprintf(stderr, " %s", info->name);
 	}
-	fprintf(stderr, "\n");
+	(void)fprintf(stderr, "\n");
 
 	return -1;
 }
@@ -2202,25 +2204,19 @@ int HOT OPTIMIZE3 stress_set_cpu_method(const char *name)
  *  stress_cpu()
  *	stress CPU by doing floating point math ops
  */
-int stress_cpu(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_cpu(const args_t *args)
 {
 	double bias;
 	stress_cpu_func func = opt_cpu_stressor->func;
 
-	(void)instance;
-
 	/*
 	 * Normal use case, 100% load, simple spinning on CPU
 	 */
 	if (opt_cpu_load == 100) {
 		do {
-			(void)func(name);
-			(*counter)++;
-		} while (opt_do_run && (!max_ops || *counter < max_ops));
+			(void)func(args->name);
+			inc_counter(args);
+		} while (keep_stressing());
 		return EXIT_SUCCESS;
 	}
 
@@ -2229,7 +2225,7 @@ int stress_cpu(
 	 * load stress test(!)
 	 */
 	if (opt_cpu_load == 0) {
-		sleep((int)opt_timeout);
+		sleep((int)g_opt_timeout);
 		return EXIT_SUCCESS;
 	}
 
@@ -2250,32 +2246,32 @@ int stress_cpu(
 			int j;
 
 			for (j = 0; j < -opt_cpu_load_slice; j++) {
-				(void)func(name);
-				if (!opt_do_run)
+				(void)func(args->name);
+				if (!g_keep_stressing_flag)
 					break;
-				(*counter)++;
+				inc_counter(args);
 			}
 			t2 = time_now();
 		} else if (opt_cpu_load_slice == 0) {
 			/* == 0, random time slices */
 			double slice_end = t1 + (((double)mwc16()) / 131072.0);
 			do {
-				(void)func(name);
+				(void)func(args->name);
 				t2 = time_now();
-				if (!opt_do_run)
+				if (!g_keep_stressing_flag)
 					break;
-				(*counter)++;
+				inc_counter(args);
 			} while (t2 < slice_end);
 		} else {
 			/* > 0, time slice in milliseconds */
 			double slice_end = t1 +
 				((double)opt_cpu_load_slice / 1000.0);
 			do {
-				(void)func(name);
+				(void)func(args->name);
 				t2 = time_now();
-				if (!opt_do_run)
+				if (!g_keep_stressing_flag)
 					break;
-				(*counter)++;
+				inc_counter(args);
 			} while (t2 < slice_end);
 		}
 		t = t2 - t1;
@@ -2290,7 +2286,7 @@ int stress_cpu(
 		t3 = time_now();
 		/* Bias takes account of the time to do the delay */
 		bias = (t3 - t2) - delay;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (keep_stressing());
 
 	return EXIT_SUCCESS;
 }
