@@ -28,18 +28,18 @@ static MLOCKED void handle_daemon_sigalrm(int dummy)
 {
 	(void)dummy;
 
-	opt_do_run = false;
+	g_keep_stressing_flag = false;
 }
 
 /*
  *  daemons()
  *	fork off a child and let the parent die
  */
-static void daemons(const char *name, const int fd)
+static void daemons(const args_t *args, const int fd)
 {
 	int fds[3];
 
-	if (stress_sighandler(name, SIGALRM, handle_daemon_sigalrm, NULL) < 0)
+	if (stress_sighandler(args->name, SIGALRM, handle_daemon_sigalrm, NULL) < 0)
 		goto err;
 	if (setsid() < 0)
 		goto err;
@@ -54,7 +54,7 @@ static void daemons(const char *name, const int fd)
 	if ((fds[2] = dup(0)) < 0)
 		goto err1;
 
-	while (opt_do_run) {
+	while (g_keep_stressing_flag) {
 		pid_t pid;
 
 		pid = fork();
@@ -93,34 +93,28 @@ err:	(void)close(fd);
  *  stress_daemon()
  *	stress by multiple daemonizing forks
  */
-int stress_daemon(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_daemon(const args_t *args)
 {
 	int fds[2];
 	pid_t pid;
 
-	(void)instance;
-
-	if (stress_sighandler(name, SIGALRM, handle_daemon_sigalrm, NULL) < 0)
+	if (stress_sighandler(args->name, SIGALRM, handle_daemon_sigalrm, NULL) < 0)
 		return EXIT_FAILURE;
 
 	if (pipe(fds) < 0) {
-		pr_fail_dbg(name, "pipe");
+		pr_fail_dbg("pipe");
 		return EXIT_FAILURE;
 	}
 	pid = fork();
 	if (pid < 0) {
-		pr_fail_dbg(name, "fork");
+		pr_fail_dbg("fork");
 		(void)close(fds[0]);
 		(void)close(fds[1]);
 		return EXIT_FAILURE;
 	} else if (pid == 0) {
 		/* Children */
 		(void)close(fds[0]);
-		daemons(name, fds[1]);
+		daemons(args, fds[1]);
 		(void)close(fds[1]);
 	} else {
 		/* Parent */
@@ -133,14 +127,14 @@ int stress_daemon(
 			if (n < 0) {
 				(void)close(fds[0]);
 				if (errno != EINTR) {
-					pr_dbg(stderr, "read failed: "
+					pr_dbg("read failed: "
 						"errno=%d (%s)\n",
 						errno, strerror(errno));
 				}
 				break;
 			}
-			(*counter)++;
-		} while (opt_do_run && (!max_ops || *counter < max_ops));
+			inc_counter(args);
+		} while (keep_stressing());
 	}
 
 	return EXIT_SUCCESS;
