@@ -65,22 +65,22 @@ static const dccp_opts_t dccp_opts[] = {
  *  stress_set_dccp_opts()
  *	parse --dccp-opts
  */
-int stress_set_dccp_opts(const char *optarg)
+int stress_set_dccp_opts(const char *opt)
 {
 	int i;
 
 	for (i = 0; dccp_opts[i].optname; i++) {
-		if (!strcmp(optarg, dccp_opts[i].optname)) {
+		if (!strcmp(opt, dccp_opts[i].optname)) {
 			opt_dccp_opts = dccp_opts[i].opt;
 			return 0;
 		}
 	}
-	fprintf(stderr, "dccp-opts option '%s' not known, options are:", optarg);
+	(void)fprintf(stderr, "dccp-opts option '%s' not known, options are:", opt);
 	for (i = 0; dccp_opts[i].optname; i++) {
-		fprintf(stderr, "%s %s",
+		(void)fprintf(stderr, "%s %s",
 			i == 0 ? "" : ",", dccp_opts[i].optname);
 	}
-	fprintf(stderr, "\n");
+	(void)fprintf(stderr, "\n");
 	return -1;
 }
 
@@ -88,9 +88,9 @@ int stress_set_dccp_opts(const char *optarg)
  *  stress_set_dccp_port()
  *	set port to use
  */
-void stress_set_dccp_port(const char *optarg)
+void stress_set_dccp_port(const char *opt)
 {
-	stress_set_net_port("dccp-port", optarg,
+	stress_set_net_port("dccp-port", opt,
 		MIN_DCCP_PORT, MAX_DCCP_PORT - STRESS_PROCS_MAX,
 		&opt_dccp_port);
 }
@@ -112,15 +112,12 @@ int stress_set_dccp_domain(const char *name)
  *	client reader
  */
 static void stress_dccp_client(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name,
+	const args_t *args,
 	const pid_t ppid)
 {
 	struct sockaddr *addr;
 
-	(void)setpgid(0, pgrp);
+	(void)setpgid(0, g_pgrp);
 	stress_parent_died_alarm();
 
 	do {
@@ -129,18 +126,18 @@ static void stress_dccp_client(
 		int retries = 0;
 		socklen_t addr_len = 0;
 retry:
-		if (!opt_do_run) {
+		if (!g_keep_stressing_flag) {
 			(void)kill(getppid(), SIGALRM);
 			exit(EXIT_FAILURE);
 		}
 		if ((fd = socket(opt_dccp_domain, SOCK_DCCP, IPPROTO_DCCP)) < 0) {
-			pr_fail_dbg(name, "socket");
+			pr_fail_dbg("socket");
 			/* failed, kick parent to finish */
 			(void)kill(getppid(), SIGALRM);
 			exit(EXIT_FAILURE);
 		}
 
-		stress_set_sockaddr(name, instance, ppid,
+		stress_set_sockaddr(args->name, args->instance, ppid,
 			opt_dccp_domain, opt_dccp_port,
 			&addr, &addr_len, NET_ADDR_ANY);
 		if (connect(fd, addr, addr_len) < 0) {
@@ -152,7 +149,7 @@ retry:
 			if (retries > 100) {
 				/* Give up.. */
 				errno = err;
-				pr_fail_dbg(name, "connect");
+				pr_fail_dbg("connect");
 				(void)kill(getppid(), SIGALRM);
 				exit(EXIT_FAILURE);
 			}
@@ -165,13 +162,13 @@ retry:
 				break;
 			if (n < 0) {
 				if (errno != EINTR)
-					pr_fail_dbg(name, "recv");
+					pr_fail_dbg("recv");
 				break;
 			}
-		} while (opt_do_run && (!max_ops || *counter < max_ops));
+		} while (keep_stressing());
 		(void)shutdown(fd, SHUT_RDWR);
 		(void)close(fd);
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (keep_stressing());
 
 #if defined(AF_UNIX)
 	if (opt_dccp_domain == AF_UNIX) {
@@ -192,7 +189,7 @@ retry:
 static void MLOCKED handle_dccp_sigalrm(int dummy)
 {
 	(void)dummy;
-	opt_do_run = false;
+	g_keep_stressing_flag = false;
 }
 
 /*
@@ -200,10 +197,7 @@ static void MLOCKED handle_dccp_sigalrm(int dummy)
  *	server writer
  */
 static int stress_dccp_server(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name,
+	const args_t *args,
 	const pid_t pid,
 	const pid_t ppid)
 {
@@ -211,38 +205,38 @@ static int stress_dccp_server(
 	int fd, status;
 	int so_reuseaddr = 1;
 	socklen_t addr_len = 0;
-	struct sockaddr *addr;
+	struct sockaddr *addr = NULL;
 	uint64_t msgs = 0;
 	int rc = EXIT_SUCCESS;
 
-	(void)setpgid(pid, pgrp);
+	(void)setpgid(pid, g_pgrp);
 
-	if (stress_sighandler(name, SIGALRM, handle_dccp_sigalrm, NULL) < 0) {
+	if (stress_sighandler(args->name, SIGALRM, handle_dccp_sigalrm, NULL) < 0) {
 		rc = EXIT_FAILURE;
 		goto die;
 	}
 	if ((fd = socket(opt_dccp_domain, SOCK_DCCP, IPPROTO_DCCP)) < 0) {
 		rc = exit_status(errno);
-		pr_fail_dbg(name, "socket");
+		pr_fail_dbg("socket");
 		goto die;
 	}
 	if (setsockopt(fd, SOL_SOCKET, SO_REUSEADDR,
 		&so_reuseaddr, sizeof(so_reuseaddr)) < 0) {
-		pr_fail_dbg(name, "setsockopt");
+		pr_fail_dbg("setsockopt");
 		rc = EXIT_FAILURE;
 		goto die_close;
 	}
 
-	stress_set_sockaddr(name, instance, ppid,
+	stress_set_sockaddr(args->name, args->instance, ppid,
 		opt_dccp_domain, opt_dccp_port,
 		&addr, &addr_len, NET_ADDR_ANY);
 	if (bind(fd, addr, addr_len) < 0) {
 		rc = exit_status(errno);
-		pr_fail_dbg(name, "bind");
+		pr_fail_dbg("bind");
 		goto die_close;
 	}
 	if (listen(fd, 10) < 0) {
-		pr_fail_dbg(name, "listen");
+		pr_fail_dbg("listen");
 		rc = EXIT_FAILURE;
 		goto die_close;
 	}
@@ -262,18 +256,18 @@ static int stress_dccp_server(
 #endif
 			len = sizeof(saddr);
 			if (getsockname(fd, &saddr, &len) < 0) {
-				pr_fail_dbg(name, "getsockname");
+				pr_fail_dbg("getsockname");
 				(void)close(sfd);
 				break;
 			}
 			len = sizeof(sndbuf);
 			if (getsockopt(fd, SOL_SOCKET, SO_SNDBUF, &sndbuf, &len) < 0) {
-				pr_fail_dbg(name, "getsockopt");
+				pr_fail_dbg("getsockopt");
 				(void)close(sfd);
 				break;
 			}
 
-			memset(buf, 'A' + (*counter % 26), sizeof(buf));
+			memset(buf, 'A' + (*args->counter % 26), sizeof(buf));
 			switch (opt_dccp_opts) {
 			case DCCP_OPT_SEND:
 				for (i = 16; i < sizeof(buf); i += 16) {
@@ -284,7 +278,7 @@ again:
 						if (errno == EAGAIN)
 							goto again;
 						if (errno != EINTR)
-							pr_fail_dbg(name, "send");
+							pr_fail_dbg("send");
 						break;
 					} else
 						msgs++;
@@ -300,7 +294,7 @@ again:
 				msg.msg_iovlen = j;
 				if (sendmsg(sfd, &msg, 0) < 0) {
 					if (errno != EINTR)
-						pr_fail_dbg(name, "sendmsg");
+						pr_fail_dbg("sendmsg");
 				} else
 					msgs += j;
 				break;
@@ -318,30 +312,30 @@ again:
 				}
 				if (sendmmsg(sfd, msgvec, MSGVEC_SIZE, 0) < 0) {
 					if (errno != EINTR)
-						pr_fail_dbg(name, "sendmmsg");
+						pr_fail_dbg("sendmmsg");
 				} else
 					msgs += (MSGVEC_SIZE * j);
 				break;
 #endif
 			default:
 				/* Should never happen */
-				pr_err(stderr, "%s: bad option %d\n", name, opt_dccp_opts);
+				pr_err("%s: bad option %d\n", args->name, opt_dccp_opts);
 				(void)close(sfd);
 				goto die_close;
 			}
 			if (getpeername(sfd, &saddr, &len) < 0) {
-				pr_fail_dbg(name, "getpeername");
+				pr_fail_dbg("getpeername");
 			}
 			(void)close(sfd);
 		}
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
 die_close:
 	(void)close(fd);
 die:
 #if defined(AF_UNIX)
-	if (opt_dccp_domain == AF_UNIX) {
+	if (addr && (opt_dccp_domain == AF_UNIX)) {
 		struct sockaddr_un *addr_un = (struct sockaddr_un *)addr;
 		(void)unlink(addr_un->sun_path);
 	}
@@ -350,7 +344,7 @@ die:
 		(void)kill(pid, SIGKILL);
 		(void)waitpid(pid, &status, 0);
 	}
-	pr_dbg(stderr, "%s: %" PRIu64 " messages sent\n", name, msgs);
+	pr_dbg("%s: %" PRIu64 " messages sent\n", args->name, msgs);
 
 	return rc;
 }
@@ -359,40 +353,32 @@ die:
  *  stress_dccp
  *	stress by heavy dccp  I/O
  */
-int stress_dccp(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_dccp(const args_t *args)
 {
 	pid_t pid, ppid = getppid();
 
-	pr_dbg(stderr, "%s: process [%d] using socket port %d\n",
-		name, (int)getpid(), opt_dccp_port + instance);
+	pr_dbg("%s: process [%d] using socket port %d\n",
+		args->name, (int)args->pid, opt_dccp_port + args->instance);
 
 again:
 	pid = fork();
 	if (pid < 0) {
-		if (opt_do_run && (errno == EAGAIN))
+		if (g_keep_stressing_flag && (errno == EAGAIN))
 			goto again;
-		pr_fail_dbg(name, "fork");
+		pr_fail_dbg("fork");
 		return EXIT_FAILURE;
 	} else if (pid == 0) {
-		stress_dccp_client(counter, instance, max_ops, name, ppid);
+		stress_dccp_client(args, ppid);
 		exit(EXIT_SUCCESS);
 	} else {
-		return stress_dccp_server(counter, instance, max_ops, name, pid, ppid);
+		return stress_dccp_server(args, pid, ppid);
 	}
 }
 
 #else
 
-int stress_dccp(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_dccp(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
