@@ -49,10 +49,10 @@ static dentry_order_t order = ORDER_RANDOM;
 static uint64_t opt_dentries = DEFAULT_DENTRIES;
 static bool set_dentries = false;
 
-void stress_set_dentries(const char *optarg)
+void stress_set_dentries(const char *opt)
 {
 	set_dentries = true;
-	opt_dentries = get_uint64(optarg);
+	opt_dentries = get_uint64(opt);
 	check_range("dentries", opt_dentries,
 		MIN_DENTRIES, MAX_DENTRIES);
 }
@@ -61,22 +61,22 @@ void stress_set_dentries(const char *optarg)
  *  stress_set_dentry_order()
  *	set dentry ordering from give option
  */
-int stress_set_dentry_order(const char *optarg)
+int stress_set_dentry_order(const char *opt)
 {
 	const dentry_removal_t *dr;
 
 	for (dr = dentry_removals; dr->name; dr++) {
-		if (!strcmp(dr->name, optarg)) {
+		if (!strcmp(dr->name, opt)) {
 			order = dr->order;
 			return 0;
 		}
 	}
 
-	fprintf(stderr, "dentry-order must be one of:");
+	(void)fprintf(stderr, "dentry-order must be one of:");
 	for (dr = dentry_removals; dr->name; dr++) {
-		fprintf(stderr, " %s", dr->name);
+		(void)fprintf(stderr, " %s", dr->name);
 	}
-	fprintf(stderr, "\n");
+	(void)fprintf(stderr, "\n");
 
 	return -1;
 }
@@ -86,12 +86,10 @@ int stress_set_dentry_order(const char *optarg)
  *	remove all dentries
  */
 static void stress_dentry_unlink(
-	const char *name,
-	const uint32_t instance,
+	const args_t *args,
 	const uint64_t n)
 {
 	uint64_t i, j;
-	const pid_t pid = getpid();
 	uint64_t prime;
 	dentry_order_t ord;
 
@@ -107,8 +105,8 @@ static void stress_dentry_unlink(
 			j = (n - 1) - i;
 			gray_code = (j >> 1) ^ j;
 
-			stress_temp_filename(path, sizeof(path),
-				name, pid, instance, gray_code);
+			stress_temp_filename_args(args,
+				path, sizeof(path), gray_code);
 			(void)unlink(path);
 		}
 		break;
@@ -119,8 +117,8 @@ static void stress_dentry_unlink(
 			uint64_t k = j % n;
 			uint64_t gray_code = (k >> 1) ^ k;
 
-			stress_temp_filename(path, sizeof(path),
-				name, pid, instance, gray_code);
+			stress_temp_filename_args(args,
+				path, sizeof(path), gray_code);
 			(void)unlink(path);
 		}
 		break;
@@ -130,8 +128,8 @@ static void stress_dentry_unlink(
 			char path[PATH_MAX];
 			uint64_t gray_code = (i >> 1) ^ i;
 
-			stress_temp_filename(path, sizeof(path),
-				name, pid, instance, gray_code);
+			stress_temp_filename_args(args,
+				path, sizeof(path), gray_code);
 			(void)unlink(path);
 		}
 		break;
@@ -143,23 +141,18 @@ static void stress_dentry_unlink(
  *  stress_dentry
  *	stress dentries
  */
-int stress_dentry(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_dentry(const args_t *args)
 {
-	const pid_t pid = getpid();
 	int ret;
 
 	if (!set_dentries) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_dentries = MAX_DENTRIES;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_dentries = MIN_DENTRIES;
 	}
 
-	ret = stress_temp_dir_mk(name, pid, instance);
+	ret = stress_temp_dir_mk_args(args);
 	if (ret < 0)
 		return exit_status(-ret);
 
@@ -171,36 +164,35 @@ int stress_dentry(
 			uint64_t gray_code = (i >> 1) ^ i;
 			int fd;
 
-			stress_temp_filename(path, sizeof(path),
-				name, pid, instance, gray_code);
+			stress_temp_filename_args(args,
+				path, sizeof(path), gray_code);
 
 			if ((fd = open(path, O_CREAT | O_RDWR,
 					S_IRUSR | S_IWUSR)) < 0) {
 				if (errno != ENOSPC)
-					pr_fail_err(name, "open");
+					pr_fail_err("open");
 				n = i;
 				break;
 			}
 			(void)close(fd);
 
-			if (!opt_do_run ||
-			    (max_ops && *counter >= max_ops))
+			if (!keep_stressing())
 				goto abort;
 
-			(*counter)++;
+			inc_counter(args);
 		}
-		stress_dentry_unlink(name, instance, n);
-		if (!opt_do_run)
+		stress_dentry_unlink(args, n);
+		if (!g_keep_stressing_flag)
 			break;
 		sync();
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (keep_stressing());
 
 abort:
 	/* force unlink of all files */
-	pr_tidy(stderr, "%s: removing %" PRIu64 " entries\n",
-		name, opt_dentries);
-	stress_dentry_unlink(name, instance, opt_dentries);
-	(void)stress_temp_dir_rm(name, pid, instance);
+	pr_tidy("%s: removing %" PRIu64 " entries\n",
+		args->name, opt_dentries);
+	stress_dentry_unlink(args, opt_dentries);
+	(void)stress_temp_dir_rm_args(args);
 
 	return EXIT_SUCCESS;
 }
