@@ -24,15 +24,26 @@
  */
 #include "stress-ng.h"
 
+static uint64_t opt_dir_dirs = DEFAULT_DIR_DIRS;
+
+/*
+ *  stress_set_dir_dirs()
+ *      set number of dir directories from given option string
+ */
+void stress_set_dir_dirs(const char *opt)
+{
+	opt_dir_dirs = get_uint64_byte(opt);
+	check_range("dir-dirs", opt_dir_dirs,
+		MIN_DIR_DIRS, MAX_DIR_DIRS);
+}
+
 /*
  *  stress_dir_tidy()
  *	remove all dentries
  */
 static void stress_dir_tidy(
-	const uint64_t n,
-	const char *name,
-	const pid_t pid,
-	const uint64_t instance)
+	const args_t *args,
+	const uint64_t n)
 {
 	uint64_t i;
 
@@ -40,8 +51,8 @@ static void stress_dir_tidy(
 		char path[PATH_MAX];
 		uint64_t gray_code = (i >> 1) ^ i;
 
-		(void)stress_temp_filename(path, sizeof(path),
-			name, pid, instance, gray_code);
+		(void)stress_temp_filename_args(args,
+			path, sizeof(path), gray_code);
 		(void)rmdir(path);
 	}
 }
@@ -50,54 +61,48 @@ static void stress_dir_tidy(
  *  stress_dir
  *	stress directory mkdir and rmdir
  */
-int stress_dir(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_dir(const args_t *args)
 {
-	const pid_t pid = getpid();
 	int ret;
 
-	ret = stress_temp_dir_mk(name, pid, instance);
+	ret = stress_temp_dir_mk_args(args);
 	if (ret < 0)
 		return exit_status(-ret);
 
 	do {
-		uint64_t i, n = DEFAULT_DIRS;
+		uint64_t i, n = opt_dir_dirs;
 
 		for (i = 0; i < n; i++) {
 			char path[PATH_MAX];
 			uint64_t gray_code = (i >> 1) ^ i;
 
-			(void)stress_temp_filename(path, sizeof(path),
-				name, pid, instance, gray_code);
+			(void)stress_temp_filename_args(args,
+				path, sizeof(path), gray_code);
 			if (mkdir(path, S_IRUSR | S_IWUSR) < 0) {
 				if ((errno != ENOSPC) && (errno != ENOMEM)) {
-					pr_fail_err(name, "mkdir");
+					pr_fail_err("mkdir");
 					n = i;
 					break;
 				}
 			}
 
-			if (!opt_do_run ||
-			    (max_ops && *counter >= max_ops))
+			if (!keep_stressing())
 				goto abort;
 
-			(*counter)++;
+			inc_counter(args);
 		}
-		stress_dir_tidy(n, name, pid, instance);
-		if (!opt_do_run)
+		stress_dir_tidy(args, n);
+		if (!g_keep_stressing_flag)
 			break;
 		sync();
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (keep_stressing());
 
 abort:
 	/* force unlink of all files */
-	pr_tidy(stderr, "%s: removing %" PRIu32 " directories\n",
-		name, DEFAULT_DIRS);
-	stress_dir_tidy(DEFAULT_DIRS, name, pid, instance);
-	(void)stress_temp_dir_rm(name, pid, instance);
+	pr_tidy("%s: removing %" PRIu64 " directories\n",
+		args->name, opt_dir_dirs);
+	stress_dir_tidy(args, opt_dir_dirs);
+	(void)stress_temp_dir_rm_args(args);
 
 	return ret;
 }
