@@ -52,19 +52,14 @@ static void stress_dir_tidy(
  *  stress_dir
  *	stress deep recursive directory mkdir and rmdir
  */
-int stress_dirdeep(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_dirdeep(const args_t *args)
 {
-	const pid_t pid = getpid();
 	int ret = EXIT_SUCCESS;
 	size_t rootpathlen;
 	char path[PATH_MAX * 4];
 	char rootpath[PATH_MAX];
 
-	(void)stress_temp_dir(rootpath, sizeof(rootpath), name, pid, instance);
+	(void)stress_temp_dir_args(args, rootpath, sizeof(rootpath));
 	rootpathlen = strlen(rootpath);
 
 	do {
@@ -84,33 +79,32 @@ int stress_dirdeep(
 				if ((errno != ENOSPC) && (errno != ENOMEM) &&
 				    (errno != ENAMETOOLONG) && (errno != EDQUOT) &&
 				    (errno != EMLINK))
-					pr_fail_err(name, "mkdir");
+					pr_fail_err("mkdir");
 				break;
 			}
 
-			if (!opt_do_run ||
-			    (max_ops && *counter >= max_ops))
+			if (!keep_stressing())
 				goto abort;
 
-			snprintf(tmp, sizeof(tmp), "/%1" PRIu32, mwc32() % 10);
+			(void)snprintf(tmp, sizeof(tmp), "/%1" PRIu32, mwc32() % 10);
 			if (len + 2 >= sizeof(path))
 				break;
 
 			strncat(path, tmp, sizeof(path) - len);
 			len += 2;
 
-			(*counter)++;
+			inc_counter(args);
 		}
 
 		stress_dir_tidy(rootpath, path);
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 		sync();
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (keep_stressing());
 
 abort:
 	/* force unlink of all files */
-	pr_tidy(stderr, "%s: removing directories\n", name);
+	pr_tidy("%s: removing directories\n", args->name);
 	stress_dir_tidy(rootpath, path);
 
 	return ret;
