@@ -43,29 +43,24 @@ static void MLOCKED stress_segvhandler(int dummy)
  *  stress_fault()
  *	stress min and max page faulting
  */
-int stress_fault(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_fault(const args_t *args)
 {
 	struct rusage usage;
 	char filename[PATH_MAX];
 	int ret;
 	NOCLOBBER int i;
-	const pid_t pid = getpid();
 
-	ret = stress_temp_dir_mk(name, pid, instance);
+	ret = stress_temp_dir_mk_args(args);
 	if (ret < 0)
 		return exit_status(-ret);
 
-	(void)stress_temp_filename(filename, sizeof(filename),
-		name, pid, instance, mwc32());
+	(void)stress_temp_filename_args(args,
+		filename, sizeof(filename), mwc32());
 	(void)umask(0077);
 
 	i = 0;
 
-	if (stress_sighandler(name, SIGSEGV, stress_segvhandler, NULL) < 0)
+	if (stress_sighandler(args->name, SIGSEGV, stress_segvhandler, NULL) < 0)
 		return EXIT_FAILURE;
 
 	do {
@@ -75,8 +70,8 @@ int stress_fault(
 		ret = sigsetjmp(jmp_env, 1);
 		if (ret) {
 			do_jmp = false;
-			pr_err(stderr, "%s: unexpected segmentation fault\n",
-				name);
+			pr_err("%s: unexpected segmentation fault\n",
+				args->name);
 			break;
 		}
 
@@ -84,7 +79,7 @@ int stress_fault(
 		if (fd < 0) {
 			if ((errno == ENOSPC) || (errno == ENOMEM))
 				continue;	/* Try again */
-			pr_fail_err(name, "open");
+			pr_fail_err("open");
 			break;
 		}
 #if _XOPEN_SOURCE >= 600 || _POSIX_C_SOURCE >= 200112L
@@ -94,7 +89,7 @@ int stress_fault(
 				continue;	/* Try again */
 			}
 			(void)close(fd);
-			pr_fail_err(name, "posix_fallocate");
+			pr_fail_err("posix_fallocate");
 			break;
 		}
 #else
@@ -102,7 +97,7 @@ int stress_fault(
 			char buffer[1];
 
 redo:
-			if (opt_do_run &&
+			if (g_keep_stressing_flag &&
 			    (write(fd, buffer, sizeof(buffer)) < 0)) {
 				if ((errno == EAGAIN) || (errno == EINTR))
 					goto redo;
@@ -111,14 +106,14 @@ redo:
 					continue;
 				}
 				(void)close(fd);
-				pr_fail_err(name, "write");
+				pr_fail_err("write");
 				break;
 			}
 		}
 #endif
 		ret = sigsetjmp(jmp_env, 1);
 		if (ret) {
-			if (!opt_do_run || (max_ops && *counter >= max_ops))
+			if (!keep_stressing())
 				do_jmp = false;
 			if (fd != -1)
 				(void)close(fd);
@@ -139,16 +134,16 @@ redo:
 		(void)fd;
 
 		if (ptr == MAP_FAILED) {
-			pr_err(stderr, "%s: mmap failed: errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			pr_err("%s: mmap failed: errno=%d (%s)\n",
+				args->name, errno, strerror(errno));
 			break;
 
 		}
 		*ptr = 0;	/* Cause the page fault */
 
 		if (munmap(ptr, 1) < 0) {
-			pr_err(stderr, "%s: munmap failed: errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			pr_err("%s: munmap failed: errno=%d (%s)\n",
+				args->name, errno, strerror(errno));
 			break;
 		}
 
@@ -158,15 +153,15 @@ next:
 			(void)unlink(filename);
 
 		i++;
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 	/* Clean up, most times this is redundant */
 	(void)unlink(filename);
-	(void)stress_temp_dir_rm(name, pid, instance);
+	(void)stress_temp_dir_rm_args(args);
 
 	if (!getrusage(RUSAGE_SELF, &usage)) {
-		pr_dbg(stderr, "%s: page faults: minor: %lu, major: %lu\n",
-			name, usage.ru_minflt, usage.ru_majflt);
+		pr_dbg("%s: page faults: minor: %lu, major: %lu\n",
+			args->name, usage.ru_minflt, usage.ru_majflt);
 	}
 
 	return EXIT_SUCCESS;
