@@ -33,11 +33,13 @@
 static uint64_t opt_fiemap_size = DEFAULT_FIEMAP_SIZE;
 static bool set_fiemap_size = false;
 
-void stress_set_fiemap_size(const char *optarg)
+void stress_set_fiemap_size(const char *opt)
 {
 	set_fiemap_size = true;
-	opt_fiemap_size = get_uint64_byte(optarg);
-	check_range("fiemap-size", opt_fiemap_size,
+	opt_fiemap_size =
+		get_uint64_byte_filesystem(opt,
+			stressor_instances(STRESS_FIEMAP));
+	check_range_bytes("fiemap-size", opt_fiemap_size,
 		MIN_FIEMAP_SIZE, MAX_FIEMAP_SIZE);
 }
 
@@ -50,10 +52,9 @@ void stress_set_fiemap_size(const char *optarg)
  *	extents in the file
  */
 static int stress_fiemap_writer(
-	const char *name,
+	const args_t *args,
 	const int fd,
-	uint64_t *counters,
-	const uint64_t max_ops)
+	uint64_t *counters)
 {
 	uint8_t buf[1];
 	uint64_t len = (off_t)opt_fiemap_size - sizeof(buf);
@@ -76,7 +77,7 @@ static int stress_fiemap_writer(
 			break;
 		if (write(fd, buf, sizeof(buf)) < 0) {
 			if ((errno != EAGAIN) && (errno != EINTR)) {
-				pr_fail_err(name, "write");
+				pr_fail_err("write");
 				goto tidy;
 			}
 		}
@@ -94,7 +95,7 @@ static int stress_fiemap_writer(
 #endif
 		for (i = 0; i < MAX_FIEMAP_PROCS; i++)
 			counter += counters[i];
-	} while (opt_do_run && (!max_ops || counter < max_ops));
+	} while (keep_stressing());
 	rc = EXIT_SUCCESS;
 tidy:
 	(void)close(fd);
@@ -106,11 +107,7 @@ tidy:
  *  stress_fiemap_ioctl()
  *	exercise the FIEMAP ioctl
  */
-static void stress_fiemap_ioctl(
-	const char *name,
-	int fd,
-	uint64_t *const counter,
-	const uint64_t max_ops)
+static void stress_fiemap_ioctl(const args_t *args, int fd)
 {
 	do {
 		struct fiemap *fiemap, *tmp;
@@ -118,14 +115,14 @@ static void stress_fiemap_ioctl(
 
 		fiemap = (struct fiemap *)calloc(1, sizeof(struct fiemap));
 		if (!fiemap) {
-			pr_err(stderr, "Out of memory allocating fiemap\n");
+			pr_err("Out of memory allocating fiemap\n");
 			break;
 		}
 		fiemap->fm_length = ~0;
 
 		/* Find out how many extents there are */
 		if (ioctl(fd, FS_IOC_FIEMAP, fiemap) < 0) {
-			pr_fail_err(name, "FS_IOC_FIEMAP ioctl()");
+			pr_fail_err("FS_IOC_FIEMAP ioctl()");
 			free(fiemap);
 			break;
 		}
@@ -138,7 +135,7 @@ static void stress_fiemap_ioctl(
 		tmp = (struct fiemap *)realloc(fiemap,
 			sizeof(struct fiemap) + extents_size);
 		if (!tmp) {
-			pr_fail_err(name, "FS_IOC_FIEMAP ioctl()");
+			pr_fail_err("FS_IOC_FIEMAP ioctl()");
 			free(fiemap);
 			break;
 		}
@@ -149,13 +146,13 @@ static void stress_fiemap_ioctl(
 		fiemap->fm_mapped_extents = 0;
 
 		if (ioctl(fd, FS_IOC_FIEMAP, fiemap) < 0) {
-			pr_fail_err(name, "FS_IOC_FIEMAP ioctl()");
+			pr_fail_err("FS_IOC_FIEMAP ioctl()");
 			free(fiemap);
 			break;
 		}
 		free(fiemap);
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 }
 
 /*
@@ -163,10 +160,8 @@ static void stress_fiemap_ioctl(
  *	helper to spawn off fiemap stressor
  */
 static inline pid_t stress_fiemap_spawn(
-	const char *name,
-	const int fd,
-	uint64_t *const counter,
-	const uint64_t max_ops)
+	const args_t *args,
+	const int fd)
 {
 	pid_t pid;
 
@@ -174,12 +169,12 @@ static inline pid_t stress_fiemap_spawn(
 	if (pid < 0)
 		return -1;
 	if (pid == 0) {
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
-		stress_fiemap_ioctl(name, fd, counter, max_ops);
+		stress_fiemap_ioctl(args, fd);
 		exit(EXIT_SUCCESS);
 	}
-	(void)setpgid(pid, pgrp);
+	(void)setpgid(pid, g_pgrp);
 	return pid;
 }
 
@@ -188,25 +183,21 @@ static inline pid_t stress_fiemap_spawn(
  *  stress_fiemap
  *	stress fiemap IOCTL
  */
-int stress_fiemap(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_fiemap(const args_t *args)
 {
-	pid_t pids[MAX_FIEMAP_PROCS], mypid;
+	pid_t pids[MAX_FIEMAP_PROCS];
 	int ret, fd, rc = EXIT_FAILURE, status;
 	char filename[PATH_MAX];
 	size_t i;
 	const size_t counters_sz = sizeof(uint64_t) * MAX_FIEMAP_PROCS;
 	uint64_t *counters;
-	uint64_t ops_per_proc = max_ops / MAX_FIEMAP_PROCS;
-	uint64_t ops_remaining = max_ops % MAX_FIEMAP_PROCS;
+	uint64_t ops_per_proc = args->max_ops / MAX_FIEMAP_PROCS;
+	uint64_t ops_remaining = args->max_ops % MAX_FIEMAP_PROCS;
 
 	if (!set_fiemap_size) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_fiemap_size = MAX_SEEK_SIZE;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_fiemap_size = MIN_SEEK_SIZE;
 	}
 
@@ -214,59 +205,64 @@ int stress_fiemap(
 	counters = mmap(NULL, counters_sz, PROT_READ | PROT_WRITE,
 		MAP_SHARED | MAP_ANONYMOUS, -1, 0);
 	if (counters == MAP_FAILED) {
-		pr_err(stderr, "%s: mmap failed: errno=%d (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: mmap failed: errno=%d (%s)\n",
+			args->name, errno, strerror(errno));
 		return EXIT_NO_RESOURCE;
 	}
 	memset(counters, 0, counters_sz);
 
-	mypid = getpid();
-	ret = stress_temp_dir_mk(name, mypid, instance);
+	ret = stress_temp_dir_mk_args(args);
 	if (ret < 0) {
 		rc = exit_status(-ret);
 		goto clean;
 	}
 
-	(void)stress_temp_filename(filename, sizeof(filename),
-		name, mypid, instance, mwc32());
+	(void)stress_temp_filename_args(args,
+		filename, sizeof(filename), mwc32());
 	(void)umask(0077);
 	if ((fd = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
 		rc = exit_status(errno);
-		pr_fail_err(name, "open");
+		pr_fail_err("open");
 		goto clean;
 	}
 	(void)unlink(filename);
 
 	for (i = 0; i < MAX_FIEMAP_PROCS; i++) {
-		uint64_t ops = ops_per_proc +
+		uint64_t proc_max_ops = ops_per_proc +
 			((i == 0) ? ops_remaining : 0);
-		pids[i] = stress_fiemap_spawn(name, fd,
-				&counters[i], ops);
+
+		const args_t new_args = {
+			&counters[i],
+			args->name,
+			proc_max_ops,
+			args->instance,
+			args->pid,
+			args->ppid,
+			args->page_size
+		};
+
+		pids[i] = stress_fiemap_spawn(&new_args, fd);
 		if (pids[i] < 0)
 			goto fail;
 	}
-	rc = stress_fiemap_writer(name, fd, counters, max_ops);
+	rc = stress_fiemap_writer(args, fd, counters);
 
 	/* And reap stressors */
 	for (i = 0; i < MAX_FIEMAP_PROCS; i++) {
 		(void)kill(pids[i], SIGKILL);
 		(void)waitpid(pids[i], &status, 0);
-		(*counter) += counters[i];
+		(*args->counter) += counters[i];
 	}
 fail:
 	(void)close(fd);
 clean:
 	(void)munmap(counters, counters_sz);
-	(void)stress_temp_dir_rm(name, mypid, instance);
+	(void)stress_temp_dir_rm_args(args);
 	return rc;
 }
 #else
-int stress_fiemap(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_fiemap(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
