@@ -27,11 +27,12 @@
 
 static uint64_t opt_fifo_readers = DEFAULT_FIFO_READERS;
 static bool set_fifo_readers = false;
+static const uint64_t wrap_mask = 0xffff000000000000ULL;
 
-void stress_set_fifo_readers(const char *optarg)
+void stress_set_fifo_readers(const char *opt)
 {
 	set_fifo_readers = true;
-	opt_fifo_readers = get_uint64(optarg);
+	opt_fifo_readers = get_uint64(opt);
 	check_range("fifo-readers", opt_fifo_readers,
 		MIN_FIFO_READERS, MAX_FIFO_READERS);
 }
@@ -52,12 +53,12 @@ static pid_t fifo_spawn(
 		return -1;
 	}
 	if (pid == 0) {
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
 		func(name, fifoname);
 		exit(EXIT_SUCCESS);
 	}
-	(void)setpgid(pid, pgrp);
+	(void)setpgid(pid, g_pgrp);
 	return pid;
 }
 
@@ -69,15 +70,14 @@ static void stress_fifo_reader(const char *name, const char *fifoname)
 {
 	int fd;
 	uint64_t val, lastval = 0;
-	uint64_t wrap_mask = 0xffff000000000000ULL;
 
 	fd = open(fifoname, O_RDONLY | O_NONBLOCK);
 	if (fd < 0) {
-		pr_err(stderr, "%s: fifo read open failed: errno=%d (%s)\n",
+		pr_err("%s: fifo read open failed: errno=%d (%s)\n",
 			name, errno, strerror(errno));
 		return;
 	}
-	while (opt_do_run) {
+	while (g_keep_stressing_flag) {
 		ssize_t sz;
 		int ret;
 		struct timeval timeout;
@@ -93,34 +93,35 @@ static void stress_fifo_reader(const char *name, const char *fifoname)
 		if (ret < 0) {
 			if ((errno == EAGAIN) || (errno == EINTR))
 				continue;
-			pr_err(stderr, "%s: select failed: errno=%d (%s)\n",
+			pr_err("%s: select failed: errno=%d (%s)\n",
 				name, errno, strerror(errno));
 			break;
 		} else if (ret == 0) {
-			pr_err(stderr, "%s: read timeout!\n", name);
+			pr_err("%s: read timeout!\n", name);
 			break;
 		}
 		sz = read(fd, &val, sizeof(val));
 		if (sz < 0) {
 			if ((errno == EAGAIN) || (errno == EINTR))
 				continue;
-			pr_err(stderr, "%s: fifo read failed: errno=%d (%s)\n",
+			pr_err("%s: fifo read failed: errno=%d (%s)\n",
 				name, errno, strerror(errno));
 			break;
 		}
 		if (sz == 0)
 			break;
 		if (sz != sizeof(val)) {
-			pr_err(stderr, "%s: fifo read did not get uint64\n",
+			pr_err("%s: fifo read did not get uint64\n",
 				name);
 			break;
 		}
 		if ((val < lastval) &&
 		    ((~val & wrap_mask) && (lastval & wrap_mask))) {
-			pr_err(stderr, "%s: fifo read did not get "
+			pr_err("%s: fifo read did not get "
 				"expected value\n", name);
 			break;
 		}
+		lastval = val;
 	}
 	(void)close(fd);
 }
@@ -130,47 +131,42 @@ static void stress_fifo_reader(const char *name, const char *fifoname)
  *  stress_fifo
  *	stress by heavy fifo I/O
  */
-int stress_fifo(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_fifo(const args_t *args)
 {
 	pid_t pids[MAX_FIFO_READERS];
 	int fd;
 	char fifoname[PATH_MAX];
 	uint64_t i, val = 0ULL;
 	int rc = EXIT_FAILURE;
-	const pid_t pid = getpid();
 
 	if (!set_fifo_readers) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_fifo_readers = MAX_FIFO_READERS;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_fifo_readers = MIN_FIFO_READERS;
 	}
 
-	rc = stress_temp_dir_mk(name, pid, instance);
+	rc = stress_temp_dir_mk_args(args);
 	if (rc < 0)
 		return exit_status(-rc);
 
-	(void)stress_temp_filename(fifoname, sizeof(fifoname),
-		name, pid, instance, mwc32());
+	(void)stress_temp_filename_args(args,
+		fifoname, sizeof(fifoname), mwc32());
 	(void)umask(0077);
 
 	if (mkfifo(fifoname, S_IRUSR | S_IWUSR) < 0) {
 		rc = exit_status(errno);
-		pr_err(stderr, "%s: mkfifo failed: errno=%d (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: mkfifo failed: errno=%d (%s)\n",
+			args->name, errno, strerror(errno));
 		goto tidy;
 	}
 
 	memset(pids, 0, sizeof(pids));
 	for (i = 0; i < opt_fifo_readers; i++) {
-		pids[i] = fifo_spawn(stress_fifo_reader, name, fifoname);
+		pids[i] = fifo_spawn(stress_fifo_reader, args->name, fifoname);
 		if (pids[i] < 0)
 			goto reap;
-		if (!opt_do_run) {
+		if (!g_keep_stressing_flag) {
 			rc = EXIT_SUCCESS;
 			goto reap;
 		}
@@ -182,9 +178,9 @@ int stress_fifo(
 			rc = 0;
 		} else {
 			rc = exit_status(fd);
-			pr_err(stderr, "%s: fifo write open failed: "
+			pr_err("%s: fifo write open failed: "
 				"errno=%d (%s)\n",
-				name, errno, strerror(errno));
+				args->name, errno, strerror(errno));
 		}
 		goto reap;
 	}
@@ -197,14 +193,15 @@ int stress_fifo(
 			if ((errno == EAGAIN) || (errno == EINTR))
 				continue;
 			if (errno) {
-				pr_fail_dbg(name, "write");
+				pr_fail_dbg("write");
 				break;
 			}
 			continue;
 		}
 		val++;
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		val &= ~wrap_mask;
+		inc_counter(args);
+	} while (keep_stressing());
 
 	(void)close(fd);
 	rc = EXIT_SUCCESS;
@@ -219,7 +216,7 @@ reap:
 	}
 tidy:
 	(void)unlink(fifoname);
-	(void)stress_temp_dir_rm(name, pid, instance);
+	(void)stress_temp_dir_rm_args(args);
 
 	return rc;
 }
