@@ -64,11 +64,11 @@ int stress_filename_opts(const char *opt)
 			return 0;
 		}
 	}
-	fprintf(stderr, "filename-opt option '%s' not known, options are:", opt);
+	(void)fprintf(stderr, "filename-opt option '%s' not known, options are:", opt);
 	for (i = 0; filename_opts[i].opt_text; i++)
-		fprintf(stderr, "%s %s",
+		(void)fprintf(stderr, "%s %s",
 			i == 0 ? "" : ",", filename_opts[i].opt_text);
-	fprintf(stderr, "\n");
+	(void)fprintf(stderr, "\n");
 	return -1;
 }
 
@@ -77,7 +77,7 @@ int stress_filename_opts(const char *opt)
  *	determine allowed filename chars by probing
  */
 static int stress_filename_probe(
-	const char *name,
+	const args_t *args,
 	char *filename,
 	char *ptr,
 	size_t *chars_allowed)
@@ -99,12 +99,12 @@ static int stress_filename_probe(
 		if ((fd = creat(filename, S_IRUSR | S_IWUSR)) < 0) {
 			/* We only expect EINVAL on bad filenames */
 			if (errno != EINVAL) {
-				pr_err(stderr, "%s: creat() failed when probing "
+				pr_err("%s: creat() failed when probing "
 					"for allowed filename characters, "
 					"errno = %d (%s)\n",
-					name, errno, strerror(errno));
-				pr_inf(stdout, "%s: perhaps retry and use "
-					"--filename-opts posix\n", name);
+					args->name, errno, strerror(errno));
+				pr_inf("%s: perhaps retry and use "
+					"--filename-opts posix\n", args->name);
 				*chars_allowed = 0;
 				return -errno;
 			}
@@ -185,7 +185,7 @@ static void stress_filename_generate_random(
  *	should_pass = false - expect it to fail (name too long)
  */
 static void stress_filename_test(
-	const char *name,
+	const args_t *args,
 	const char *filename,
 	const size_t sz_max,
 	const bool should_pass)
@@ -196,9 +196,9 @@ static void stress_filename_test(
 		if ((!should_pass) && (errno == ENAMETOOLONG))
 			return;
 
-		pr_fail(stderr, "%s: open failed on file of length "
+		pr_fail("%s: open failed on file of length "
 			"%zu bytes, errno=%d (%s)\n",
-			name, sz_max, errno, strerror(errno));
+			args->name, sz_max, errno, strerror(errno));
 	} else {
 		(void)close(fd);
 		(void)unlink(filename);
@@ -209,13 +209,8 @@ static void stress_filename_test(
  *  stress_filename()
  *	stress filename sizes etc
  */
-int stress_filename (
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_filename (const args_t *args)
 {
-	const pid_t pid = getpid();
 	int ret, rc = EXIT_FAILURE;
 	size_t sz_left, sz_max;
 	char dirname[PATH_MAX];
@@ -224,21 +219,21 @@ int stress_filename (
 	struct statvfs buf;
 	size_t i, chars_allowed = 0, sz;
 
-	stress_temp_dir(dirname, sizeof(dirname), name, pid, instance);
+	stress_temp_dir_args(args, dirname, sizeof(dirname));
 	if (mkdir(dirname, S_IRWXU) < 0) {
 		if (errno != EEXIST) {
-			pr_fail_err(name, "mkdir");
+			pr_fail_err("mkdir");
 			return EXIT_FAILURE;
 		}
 	}
 
 	if (statvfs(dirname, &buf) < 0) {
-		pr_fail_err(name, "statvfs");
+		pr_fail_err("statvfs");
 		goto tidy_dir;
 	}
-	if (instance == 0)
-		pr_dbg(stderr, "%s: maximum file size: %lu bytes\n",
-			name, (long unsigned) buf.f_namemax);
+	if (args->instance == 0)
+		pr_dbg("%s: maximum file size: %lu bytes\n",
+			args->name, (long unsigned) buf.f_namemax);
 
 	strncpy(filename, dirname, sizeof(filename) - 1);
 	ptr = filename + strlen(dirname);
@@ -248,7 +243,7 @@ int stress_filename (
 	sz_max = (size_t)buf.f_namemax;
 
 	if (sz_left >= PATH_MAX) {
-		pr_fail(stderr, "%s: max file name larger than PATH_MAX\n", name);
+		pr_fail("%s: max file name larger than PATH_MAX\n", args->name);
 		goto tidy_dir;
 	}
 
@@ -262,7 +257,7 @@ int stress_filename (
 		break;
 	case STRESS_FILENAME_PROBE:
 	default:
-		ret = stress_filename_probe(name, filename, ptr, &chars_allowed);
+		ret = stress_filename_probe(args, filename, ptr, &chars_allowed);
 		if (ret < 0) {
 			rc = exit_status(-ret);
 			goto tidy_dir;
@@ -270,14 +265,14 @@ int stress_filename (
 		break;
 	}
 
-	if (instance == 0)
-		pr_dbg(stdout, "%s: filesystem allows %zu unique "
+	if (args->instance == 0)
+		pr_dbg("%s: filesystem allows %zu unique "
 			"characters in a filename\n",
-			name, chars_allowed);
+			args->name, chars_allowed);
 
 	if (chars_allowed == 0) {
-		pr_fail(stderr, "%s: cannot determine allowed characters "
-			"in a filename\n", name);
+		pr_fail("%s: cannot determine allowed characters "
+			"in a filename\n", args->name);
 		goto tidy_dir;
 	}
 
@@ -293,46 +288,46 @@ int stress_filename (
 
 		/* Should succeed */
 		stress_filename_generate(ptr, 1, ch);
-		stress_filename_test(name, filename, 1, true);
+		stress_filename_test(args, filename, 1, true);
 		stress_filename_generate_random(ptr, 1, chars_allowed);
-		stress_filename_test(name, filename, 1, true);
+		stress_filename_test(args, filename, 1, true);
 
 		/* Should succeed */
 		stress_filename_generate(ptr, sz_max, ch);
-		stress_filename_test(name, filename, sz_max, true);
+		stress_filename_test(args, filename, sz_max, true);
 		stress_filename_generate_random(ptr, sz_max, chars_allowed);
-		stress_filename_test(name, filename, sz_max, true);
+		stress_filename_test(args, filename, sz_max, true);
 
 		/* Should succeed */
 		stress_filename_generate(ptr, sz_max - 1, ch);
-		stress_filename_test(name, filename, sz_max - 1, true);
+		stress_filename_test(args, filename, sz_max - 1, true);
 		stress_filename_generate_random(ptr, sz_max - 1, chars_allowed);
-		stress_filename_test(name, filename, sz_max - 1, true);
+		stress_filename_test(args, filename, sz_max - 1, true);
 
 		/* Should fail */
 		stress_filename_generate(ptr, sz_max + 1, ch);
-		stress_filename_test(name, filename, sz_max + 1, false);
+		stress_filename_test(args, filename, sz_max + 1, false);
 		stress_filename_generate_random(ptr, sz_max + 1, chars_allowed);
-		stress_filename_test(name, filename, sz_max + 1, false);
+		stress_filename_test(args, filename, sz_max + 1, false);
 
 		/* Should succeed */
 		stress_filename_generate(ptr, sz, ch);
-		stress_filename_test(name, filename, sz, true);
+		stress_filename_test(args, filename, sz, true);
 		stress_filename_generate_random(ptr, sz, chars_allowed);
-		stress_filename_test(name, filename, sz, true);
+		stress_filename_test(args, filename, sz, true);
 
 		/* Should succeed */
 		stress_filename_generate(ptr, rnd_sz, ch);
-		stress_filename_test(name, filename, rnd_sz, true);
+		stress_filename_test(args, filename, rnd_sz, true);
 		stress_filename_generate_random(ptr, rnd_sz, chars_allowed);
-		stress_filename_test(name, filename, rnd_sz, true);
+		stress_filename_test(args, filename, rnd_sz, true);
 
 		sz++;
 		if (sz > sz_max)
 			sz = 1;
 
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
 	rc = EXIT_SUCCESS;
 
