@@ -33,10 +33,10 @@ static bool set_vfork_max = false;
  *  stress_set_fork_max()
  *	set maximum number of forks allowed
  */
-void stress_set_fork_max(const char *optarg)
+void stress_set_fork_max(const char *opt)
 {
 	set_fork_max = true;
-	opt_fork_max = get_uint64_byte(optarg);
+	opt_fork_max = get_uint64_byte(opt);
 	check_range("fork-max", opt_fork_max,
 		MIN_FORKS, MAX_FORKS);
 }
@@ -45,10 +45,10 @@ void stress_set_fork_max(const char *optarg)
  *  stress_set_vfork_max()
  *	set maximum number of vforks allowed
  */
-void stress_set_vfork_max(const char *optarg)
+void stress_set_vfork_max(const char *opt)
 {
 	set_vfork_max = true;
-	opt_vfork_max = get_uint64_byte(optarg);
+	opt_vfork_max = get_uint64_byte(opt);
 	check_range("vfork-max", opt_vfork_max,
 		MIN_VFORKS, MAX_VFORKS);
 }
@@ -59,15 +59,10 @@ void stress_set_vfork_max(const char *optarg)
  *	fork function fork_fn (fork or vfork)
  */
 static int stress_fork_fn(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name,
+	const args_t *args,
 	pid_t (*fork_fn)(void),
 	const uint64_t fork_max)
 {
-	(void)instance;
-
 	pid_t pids[MAX_FORKS];
 
 	do {
@@ -83,9 +78,9 @@ static int stress_fork_fn(
 				_exit(0);
 			}
 			if (pid > -1)
-				(void)setpgid(pids[i], pgrp);
+				(void)setpgid(pids[i], g_pgrp);
 			pids[i] = pid;
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				break;
 		}
 		for (i = 0; i < fork_max; i++) {
@@ -93,16 +88,16 @@ static int stress_fork_fn(
 				int status;
 				/* Parent, wait for child */
 				(void)waitpid(pids[i], &status, 0);
-				(*counter)++;
+				inc_counter(args);
 			}
 		}
 
 		for (i = 0; i < fork_max; i++) {
-			if ((pids[i] < 0) && (opt_flags & OPT_FLAGS_VERIFY)) {
-				pr_fail(stderr, "%s: fork failed\n", name);
+			if ((pids[i] < 0) && (g_opt_flags & OPT_FLAGS_VERIFY)) {
+				pr_fail("%s: fork failed\n", args->name);
 			}
 		}
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (keep_stressing());
 
 	return EXIT_SUCCESS;
 }
@@ -111,21 +106,16 @@ static int stress_fork_fn(
  *  stress_fork()
  *	stress by forking and exiting
  */
-int stress_fork(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_fork(const args_t *args)
 {
 	if (!set_fork_max) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_fork_max = MAX_FORKS;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_fork_max = MIN_FORKS;
 	}
 
-	return stress_fork_fn(counter, instance, max_ops,
-		name, fork, opt_fork_max);
+	return stress_fork_fn(args, fork, opt_fork_max);
 }
 
 
@@ -133,19 +123,14 @@ int stress_fork(
  *  stress_vfork()
  *	stress by vforking and exiting
  */
-int stress_vfork(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_vfork(const args_t *args)
 {
 	if (!set_vfork_max) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_vfork_max = MAX_VFORKS;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_vfork_max = MIN_VFORKS;
 	}
 
-	return stress_fork_fn(counter, instance, max_ops,
-		name, vfork, opt_vfork_max);
+	return stress_fork_fn(args, vfork, opt_vfork_max);
 }
