@@ -57,28 +57,24 @@ static inline int futex_wait(
  * 	efficiently use futex, but to stress the futex system call
  *	by rapidly calling it on wait and wakes
  */
-int stress_futex(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_futex(const args_t *args)
 {
-	uint64_t *timeout = &shared->futex.timeout[instance];
-	uint32_t *futex = &shared->futex.futex[instance];
+	uint64_t *timeout = &g_shared->futex.timeout[args->instance];
+	uint32_t *futex = &g_shared->futex.futex[args->instance];
 	pid_t pid;
 
 again:
 	pid = fork();
 	if (pid < 0) {
-		if (opt_do_run && (errno == EAGAIN))
+		if (g_keep_stressing_flag && (errno == EAGAIN))
 			goto again;
-		pr_err(stderr, "%s: fork failed: errno=%d: (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: fork failed: errno=%d: (%s)\n",
+			args->name, errno, strerror(errno));
 	}
 	if (pid > 0) {
 		int status;
 
-		(void)setpgid(pid, pgrp);
+		(void)setpgid(pid, g_pgrp);
 
 		do {
 			int ret;
@@ -87,25 +83,25 @@ again:
 			 * Break early in case wake gets stuck
 			 * (which it shouldn't)
 			 */
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				break;
 			ret = futex_wake(futex, 1);
-			if (opt_flags & OPT_FLAGS_VERIFY) {
+			if (g_opt_flags & OPT_FLAGS_VERIFY) {
 				if (ret < 0)
-					pr_fail_err(name, "futex wake");
+					pr_fail_err("futex wake");
 			}
-		} while (opt_do_run && (!max_ops || *counter < max_ops));
+		} while (keep_stressing());
 
 		/* Kill waiter process */
 		(void)kill(pid, SIGKILL);
 		(void)waitpid(pid, &status, 0);
 
-		pr_dbg(stderr, "%s: futex timeouts: %" PRIu64 "\n",
-			name, *timeout);
+		pr_dbg("%s: futex timeouts: %" PRIu64 "\n",
+			args->name, *timeout);
 	} else {
 		uint64_t threshold = THRESHOLD;
 
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
 
 		do {
@@ -114,7 +110,7 @@ again:
 			int ret;
 
 			/* Break early before potential long wait */
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				break;
 
 			ret = futex_wait(futex, 0, &t);
@@ -124,29 +120,26 @@ again:
 				(*timeout)++;
 				if (*timeout > threshold) {
 					/*
-					 * Backoff for a short while and						 * start again
+					 * Backoff for a short while
+					 * and start again
 					 */
 					(void)shim_usleep(250000);
 					threshold += THRESHOLD;
 				}
 			} else {
-				if ((ret < 0) && (opt_flags & OPT_FLAGS_VERIFY)) {
-					pr_fail_err(name, "futex wait");
+				if ((ret < 0) && (g_opt_flags & OPT_FLAGS_VERIFY)) {
+					pr_fail_err("futex wait");
 				}
-				(*counter)++;
+				inc_counter(args);
 			}
-		} while (opt_do_run && (!max_ops || *counter < max_ops));
+		} while (keep_stressing());
 	}
 
 	return EXIT_SUCCESS;
 }
 #else
-int stress_futex(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_futex(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
