@@ -31,14 +31,8 @@
  *  stress_getrandom
  *	stress reading random values using getrandom()
  */
-int stress_getrandom(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_getrandom(const args_t *args)
 {
-	(void)instance;
-
 	do {
 #if defined(__OpenBSD__)
 		char buffer[256];
@@ -49,23 +43,19 @@ int stress_getrandom(
 
 		ret = shim_getrandom(buffer, sizeof(buffer), 0);
 		if (ret < 0) {
-			if (errno == EAGAIN)
+			if ((errno == EAGAIN) || (errno == EINTR))
 				continue;
-			pr_fail_err(name, "getrandom");
+			pr_fail_err("getrandom");
 			return EXIT_FAILURE;
 		}
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
 	return EXIT_SUCCESS;
 }
 #else
-int stress_getrandom(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_getrandom(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
