@@ -137,19 +137,21 @@ static const hdd_opts_t hdd_opts[] = {
 	{ "utimes",	HDD_OPT_UTIMES, 0, 0, 0 },
 };
 
-void stress_set_hdd_bytes(const char *optarg)
+void stress_set_hdd_bytes(const char *opt)
 {
 	set_hdd_bytes = true;
-	opt_hdd_bytes =  get_uint64_byte(optarg);
-	check_range("hdd-bytes", opt_hdd_bytes,
+	opt_hdd_bytes =
+		get_uint64_byte_filesystem(opt,
+			stressor_instances(STRESS_HDD));
+	check_range_bytes("hdd-bytes", opt_hdd_bytes,
 		MIN_HDD_BYTES, MAX_HDD_BYTES);
 }
 
-void stress_set_hdd_write_size(const char *optarg)
+void stress_set_hdd_write_size(const char *opt)
 {
 	set_hdd_write_size = true;
-	opt_hdd_write_size = get_uint64_byte(optarg);
-	check_range("hdd-write-size", opt_hdd_write_size,
+	opt_hdd_write_size = get_uint64_byte(opt);
+	check_range_bytes("hdd-write-size", opt_hdd_write_size,
 		MIN_HDD_WRITE_SIZE, MAX_HDD_WRITE_SIZE);
 }
 
@@ -251,7 +253,7 @@ int stress_hdd_opts(char *opts)
 
 					for (j = 0; hdd_opts[j].opt; j++) {
 						if ((exclude & hdd_opts[j].flag) == exclude) {
-							fprintf(stderr,
+							(void)fprintf(stderr,
 								"hdd-opt option '%s' is not "
 								"compatible with option '%s'\n",
 								token,
@@ -268,11 +270,11 @@ int stress_hdd_opts(char *opts)
 			}
 		}
 		if (!opt_ok) {
-			fprintf(stderr, "hdd-opt option '%s' not known, options are:", token);
+			(void)fprintf(stderr, "hdd-opt option '%s' not known, options are:", token);
 			for (i = 0; i < SIZEOF_ARRAY(hdd_opts); i++)
-				fprintf(stderr, "%s %s",
+				(void)fprintf(stderr, "%s %s",
 					i == 0 ? "" : ",", hdd_opts[i].opt);
-			fprintf(stderr, "\n");
+			(void)fprintf(stderr, "\n");
 			return -1;
 		}
 	}
@@ -284,7 +286,7 @@ int stress_hdd_opts(char *opts)
  *  stress_hdd_advise()
  *	set posix_fadvise options
  */
-static int stress_hdd_advise(const char *name, const int fd, const int flags)
+static int stress_hdd_advise(const args_t *args, const int fd, const int flags)
 {
 #if (defined(POSIX_FADV_SEQ) || defined(POSIX_FADV_RANDOM) || \
     defined(POSIX_FADV_NOREUSE) || defined(POSIX_FADV_WILLNEED) || \
@@ -298,13 +300,13 @@ static int stress_hdd_advise(const char *name, const int fd, const int flags)
 	for (i = 0; i < SIZEOF_ARRAY(hdd_opts); i++) {
 		if (hdd_opts[i].flag & flags) {
 			if (posix_fadvise(fd, 0, 0, hdd_opts[i].advice) < 0) {
-				pr_fail_err(name, "posix_fadvise");
+				pr_fail_err("posix_fadvise");
 				return -1;
 			}
 		}
 	}
 #else
-	(void)name;
+	(void)args;
 	(void)fd;
 	(void)flags;
 #endif
@@ -314,16 +316,11 @@ static int stress_hdd_advise(const char *name, const int fd, const int flags)
  *  stress_hdd
  *	stress I/O via writes
  */
-int stress_hdd(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_hdd(const args_t *args)
 {
 	uint8_t *buf = NULL;
 	uint8_t *alloc_buf;
 	uint64_t i, min_size, remainder;
-	const pid_t pid = getpid();
 	int rc = EXIT_FAILURE;
 	ssize_t ret;
 	char filename[PATH_MAX];
@@ -332,16 +329,16 @@ int stress_hdd(
 	size_t opt_index = 0;
 
 	if (!set_hdd_bytes) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_hdd_bytes = MAX_HDD_BYTES;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_hdd_bytes = MIN_HDD_BYTES;
 	}
 
 	if (!set_hdd_write_size) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_hdd_write_size = MAX_HDD_WRITE_SIZE;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_hdd_write_size = MIN_HDD_WRITE_SIZE;
 	}
 
@@ -355,29 +352,29 @@ int stress_hdd(
 	/* Ensure I/O size is not too small */
 	if (opt_hdd_write_size < min_size) {
 		opt_hdd_write_size = min_size;
-		pr_inf(stdout, "%s: increasing read/write size to %"
-			PRIu64 " bytes\n", name, opt_hdd_write_size);
+		pr_inf("%s: increasing read/write size to %"
+			PRIu64 " bytes\n", args->name, opt_hdd_write_size);
 	}
 
 	/* Ensure we get same sized iovec I/O sizes */
 	remainder = opt_hdd_write_size % HDD_IO_VEC_MAX;
 	if ((opt_hdd_flags & HDD_OPT_IOVEC) && (remainder != 0)) {
 		opt_hdd_write_size += HDD_IO_VEC_MAX - remainder;
-		pr_inf(stdout, "%s: increasing read/write size to %"
+		pr_inf("%s: increasing read/write size to %"
 			PRIu64 " bytes in iovec mode\n",
-			name, opt_hdd_write_size);
+			args->name, opt_hdd_write_size);
 	}
 
 	/* Ensure complete file size is not less than the I/O size */
 	if (opt_hdd_bytes < opt_hdd_write_size) {
 		opt_hdd_bytes = opt_hdd_write_size;
-		pr_inf(stdout, "%s: increasing file size to write size of %"
+		pr_inf("%s: increasing file size to write size of %"
 			PRIu64 " bytes\n",
-			name, opt_hdd_bytes);
+			args->name, opt_hdd_bytes);
 	}
 
 
-	ret = stress_temp_dir_mk(name, pid, instance);
+	ret = stress_temp_dir_mk_args(args);
 	if (ret < 0)
 		return exit_status(-ret);
 
@@ -392,8 +389,8 @@ int stress_hdd(
 	/* Work around lack of posix_memalign */
 	alloc_buf = malloc((size_t)opt_hdd_write_size + BUF_ALIGNMENT);
 	if (!alloc_buf) {
-		pr_err(stderr, "%s: cannot allocate buffer\n", name);
-		(void)stress_temp_dir_rm(name, pid, instance);
+		pr_err("%s: cannot allocate buffer\n", args->name);
+		(void)stress_temp_dir_rm_args(args);
 		return rc;
 	}
 	buf = (uint8_t *)align_address(alloc_buf, BUF_ALIGNMENT);
@@ -401,8 +398,8 @@ int stress_hdd(
 	ret = posix_memalign((void **)&alloc_buf, BUF_ALIGNMENT, (size_t)opt_hdd_write_size);
 	if (ret || !alloc_buf) {
 		rc = exit_status(errno);
-		pr_err(stderr, "%s: cannot allocate buffer\n", name);
-		(void)stress_temp_dir_rm(name, pid, instance);
+		pr_err("%s: cannot allocate buffer\n", args->name);
+		(void)stress_temp_dir_rm_args(args);
 		return rc;
 	}
 	buf = alloc_buf;
@@ -410,8 +407,8 @@ int stress_hdd(
 
 	stress_strnrnd((char *)buf, opt_hdd_write_size);
 
-	(void)stress_temp_filename(filename, sizeof(filename),
-		name, pid, instance, mwc32());
+	(void)stress_temp_filename_args(args,
+		filename, sizeof(filename), mwc32());
 	do {
 		int fd;
 		struct stat statbuf;
@@ -421,7 +418,7 @@ int stress_hdd(
 		 * aggressive option with no other option enables
 		 * the "work through all the options" mode
 		 */
-		if (!opts_set && (opt_flags & OPT_FLAGS_AGGRESSIVE)) {
+		if (!opts_set && (g_opt_flags & OPT_FLAGS_AGGRESSIVE)) {
 			opt_index = (opt_index + 1) % SIZEOF_ARRAY(hdd_opts);
 
 			opt_hdd_flags  = hdd_opts[opt_index].flag;
@@ -436,17 +433,17 @@ int stress_hdd(
 		if ((fd = open(filename, flags, S_IRUSR | S_IWUSR)) < 0) {
 			if ((errno == ENOSPC) || (errno == ENOMEM))
 				continue;	/* Retry */
-			pr_fail_err(name, "open");
+			pr_fail_err("open");
 			goto finish;
 		}
 		if (ftruncate(fd, (off_t)0) < 0) {
-			pr_fail_err(name, "ftruncate");
+			pr_fail_err("ftruncate");
 			(void)close(fd);
 			goto finish;
 		}
 		(void)unlink(filename);
 
-		if (stress_hdd_advise(name, fd, fadvise_flags) < 0) {
+		if (stress_hdd_advise(args, fd, fadvise_flags) < 0) {
 			(void)close(fd);
 			goto finish;
 		}
@@ -461,12 +458,12 @@ int stress_hdd(
 					(mwc64() % opt_hdd_bytes) & ~511;
 
 				if (lseek(fd, offset, SEEK_SET) < 0) {
-					pr_fail_err(name, "lseek");
+					pr_fail_err("lseek");
 					(void)close(fd);
 					goto finish;
 				}
 rnd_wr_retry:
-				if (!opt_do_run || (max_ops && *counter >= max_ops))
+				if (!keep_stressing())
 					break;
 
 				for (j = 0; j < opt_hdd_write_size; j++)
@@ -479,13 +476,13 @@ rnd_wr_retry:
 					if (errno == ENOSPC)
 						break;
 					if (errno) {
-						pr_fail_err(name, "write");
+						pr_fail_err("write");
 						(void)close(fd);
 						goto finish;
 					}
 					continue;
 				}
-				(*counter)++;
+				inc_counter(args);
 			}
 		}
 		/* Sequential Write */
@@ -493,7 +490,7 @@ rnd_wr_retry:
 			for (i = 0; i < opt_hdd_bytes; i += opt_hdd_write_size) {
 				size_t j;
 seq_wr_retry:
-				if (!opt_do_run || (max_ops && *counter >= max_ops))
+				if (!keep_stressing())
 					break;
 
 				for (j = 0; j < opt_hdd_write_size; j += 512)
@@ -505,18 +502,18 @@ seq_wr_retry:
 					if (errno == ENOSPC)
 						break;
 					if (errno) {
-						pr_fail_err(name, "write");
+						pr_fail_err("write");
 						(void)close(fd);
 						goto finish;
 					}
 					continue;
 				}
-				(*counter)++;
+				inc_counter(args);
 			}
 		}
 
 		if (fstat(fd, &statbuf) < 0) {
-			pr_fail_err(name, "fstat");
+			pr_fail_err("fstat");
 			(void)close(fd);
 			continue;
 		}
@@ -530,13 +527,13 @@ seq_wr_retry:
 			uint64_t baddata = 0;
 
 			if (lseek(fd, 0, SEEK_SET) < 0) {
-				pr_fail_err(name, "lseek");
+				pr_fail_err("lseek");
 				(void)close(fd);
 				goto finish;
 			}
 			for (i = 0; i < hdd_read_size; i += opt_hdd_write_size) {
 seq_rd_retry:
-				if (!opt_do_run || (max_ops && *counter >= max_ops))
+				if (!keep_stressing())
 					break;
 
 				ret = stress_hdd_read(fd, buf, (size_t)opt_hdd_write_size);
@@ -544,7 +541,7 @@ seq_rd_retry:
 					if ((errno == EAGAIN) || (errno == EINTR))
 						goto seq_rd_retry;
 					if (errno) {
-						pr_fail_err(name, "read");
+						pr_fail_err("read");
 						(void)close(fd);
 						goto finish;
 					}
@@ -553,7 +550,7 @@ seq_rd_retry:
 				if (ret != (ssize_t)opt_hdd_write_size)
 					misreads++;
 
-				if (opt_flags & OPT_FLAGS_VERIFY) {
+				if (g_opt_flags & OPT_FLAGS_VERIFY) {
 					size_t j;
 
 					for (j = 0; j < opt_hdd_write_size; j += 512) {
@@ -569,15 +566,15 @@ seq_rd_retry:
 						}
 					}
 				}
-				(*counter)++;
+				inc_counter(args);
 			}
 			if (misreads)
-				pr_dbg(stderr, "%s: %" PRIu64
+				pr_dbg("%s: %" PRIu64
 					" incomplete sequential reads\n",
-					name, misreads);
+					args->name, misreads);
 			if (baddata)
-				pr_fail(stderr, "%s: incorrect data found %"
-					PRIu64 " times\n", name, baddata);
+				pr_fail("%s: incorrect data found %"
+					PRIu64 " times\n", args->name, baddata);
 		}
 		/* Random Read */
 		if (opt_hdd_flags & HDD_OPT_RD_RND) {
@@ -588,19 +585,19 @@ seq_rd_retry:
 				off_t offset = (mwc64() % (opt_hdd_bytes - opt_hdd_write_size)) & ~511;
 
 				if (lseek(fd, offset, SEEK_SET) < 0) {
-					pr_fail_err(name, "lseek");
+					pr_fail_err("lseek");
 					(void)close(fd);
 					goto finish;
 				}
 rnd_rd_retry:
-				if (!opt_do_run || (max_ops && *counter >= max_ops))
+				if (!keep_stressing())
 					break;
 				ret = stress_hdd_read(fd, buf, (size_t)opt_hdd_write_size);
 				if (ret <= 0) {
 					if ((errno == EAGAIN) || (errno == EINTR))
 						goto rnd_rd_retry;
 					if (errno) {
-						pr_fail_err(name, "read");
+						pr_fail_err("read");
 						(void)close(fd);
 						goto finish;
 					}
@@ -609,7 +606,7 @@ rnd_rd_retry:
 				if (ret != (ssize_t)opt_hdd_write_size)
 					misreads++;
 
-				if (opt_flags & OPT_FLAGS_VERIFY) {
+				if (g_opt_flags & OPT_FLAGS_VERIFY) {
 					size_t j;
 
 					for (j = 0; j < opt_hdd_write_size; j += 512) {
@@ -625,21 +622,20 @@ rnd_rd_retry:
 						}
 					}
 				}
-
-				(*counter)++;
+				inc_counter(args);
 			}
 			if (misreads)
-				pr_dbg(stderr, "%s: %" PRIu64
+				pr_dbg("%s: %" PRIu64
 					" incomplete random reads\n",
-					name, misreads);
+					args->name, misreads);
 		}
 		(void)close(fd);
 
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (keep_stressing());
 
 	rc = EXIT_SUCCESS;
 finish:
 	free(alloc_buf);
-	(void)stress_temp_dir_rm(name, pid, instance);
+	(void)stress_temp_dir_rm_args(args);
 	return rc;
 }
