@@ -32,10 +32,10 @@ static bool set_hsearch_size = false;
  *  stress_set_hsearch_size()
  *      set hsearch size from given option string
  */
-void stress_set_hsearch_size(const char *optarg)
+void stress_set_hsearch_size(const char *opt)
 {
 	set_hsearch_size = true;
-	opt_hsearch_size = get_uint64_byte(optarg);
+	opt_hsearch_size = get_uint64_byte(opt);
 	check_range("hsearch-size", opt_hsearch_size,
 		MIN_TSEARCH_SIZE, MAX_TSEARCH_SIZE);
 }
@@ -44,22 +44,16 @@ void stress_set_hsearch_size(const char *optarg)
  *  stress_hsearch()
  *	stress hsearch
  */
-int stress_hsearch(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_hsearch(const args_t *args)
 {
 	size_t i, max;
 	int ret = EXIT_FAILURE;
 	char **keys;
 
-	(void)instance;
-
 	if (!set_hsearch_size) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_hsearch_size = MAX_HSEARCH_SIZE;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_hsearch_size = MIN_HSEARCH_SIZE;
 	}
 
@@ -67,12 +61,12 @@ int stress_hsearch(
 
 	/* Make hash table with 25% slack */
 	if (!hcreate(max + (max / 4))) {
-		pr_fail_err(name, "hcreate");
+		pr_fail_err("hcreate");
 		return EXIT_FAILURE;
 	}
 
 	if ((keys = calloc(max, sizeof(char *))) == NULL) {
-		pr_err(stderr, "%s: cannot allocate keys\n", name);
+		pr_err("%s: cannot allocate keys\n", args->name);
 		goto free_hash;
 	}
 
@@ -81,10 +75,10 @@ int stress_hsearch(
 		char buffer[32];
 		ENTRY e;
 
-		snprintf(buffer, sizeof(buffer), "%zu", i);
+		(void)snprintf(buffer, sizeof(buffer), "%zu", i);
 		keys[i] = strdup(buffer);
 		if (!keys[i]) {
-			pr_err(stderr, "%s: cannot allocate key\n", name);
+			pr_err("%s: cannot allocate key\n", args->name);
 			goto free_all;
 		}
 
@@ -92,30 +86,30 @@ int stress_hsearch(
 		e.data = (void *)i;
 
 		if (hsearch(e, ENTER) == NULL) {
-			pr_err(stderr, "%s: cannot allocate new hash item\n", name);
+			pr_err("%s: cannot allocate new hash item\n", args->name);
 			goto free_all;
 		}
 	}
 
 	do {
-		for (i = 0; opt_do_run && i < max; i++) {
+		for (i = 0; g_keep_stressing_flag && i < max; i++) {
 			ENTRY e, *ep;
 
 			e.key = keys[i];
 			e.data = NULL;	/* Keep Coverity quiet */
 			ep = hsearch(e, FIND);
-			if (opt_flags & OPT_FLAGS_VERIFY) {
+			if (g_opt_flags & OPT_FLAGS_VERIFY) {
 				if (ep == NULL) {
-					pr_fail(stderr, "%s: cannot find key %s\n", name, keys[i]);
+					pr_fail("%s: cannot find key %s\n", args->name, keys[i]);
 				} else {
 					if (i != (size_t)ep->data) {
-						pr_fail(stderr, "%s: hash returned incorrect data %zd\n", name, i);
+						pr_fail("%s: hash returned incorrect data %zd\n", args->name, i);
 					}
 				}
 			}
 		}
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
 	ret = EXIT_SUCCESS;
 
