@@ -35,27 +35,22 @@
  *  stress set/get io priorities
  *	stress system by rapid io priority changes
  */
-int stress_ioprio(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_ioprio(const args_t *args)
 {
-	const pid_t pid = getpid();
 	const uid_t uid = getuid();
 	const pid_t grp = getpgrp();
 	int fd, rc = EXIT_FAILURE;
 	char filename[PATH_MAX];
 
-	if (stress_temp_dir_mk(name, pid, instance) < 0)
+	if (stress_temp_dir_mk_args(args) < 0)
 		return rc;
 
-	(void)stress_temp_filename(filename, sizeof(filename),
-		name, pid, instance, mwc32());
+	(void)stress_temp_filename_args(args,
+		filename, sizeof(filename), mwc32());
 	(void)umask(0077);
 	if ((fd = open(filename, O_WRONLY | O_CREAT, S_IRUSR | S_IWUSR)) < 0) {
 		rc = exit_status(errno);
-		pr_fail_err(name, "open");
+		pr_fail_err("open");
 		goto cleanup_dir;
 	}
 	(void)unlink(filename);
@@ -65,34 +60,34 @@ int stress_ioprio(
 		struct iovec iov[MAX_IOV];
 		char buffer[MAX_IOV][BUF_SIZE];
 
-		if (shim_ioprio_get(IOPRIO_WHO_PROCESS, pid) < 0) {
-			pr_fail(stderr, "%s: ioprio_get(OPRIO_WHO_PROCESS, %d), "
+		if (shim_ioprio_get(IOPRIO_WHO_PROCESS, args->pid) < 0) {
+			pr_fail("%s: ioprio_get(OPRIO_WHO_PROCESS, %d), "
 				"errno = %d (%s)\n",
-				name, pid, errno, strerror(errno));
+				args->name, args->pid, errno, strerror(errno));
 			goto cleanup_file;
 		}
 		if (shim_ioprio_get(IOPRIO_WHO_PROCESS, 0) < 0) {
-			pr_fail(stderr, "%s: ioprio_get(OPRIO_WHO_PROCESS, 0), "
+			pr_fail("%s: ioprio_get(OPRIO_WHO_PROCESS, 0), "
 				"errno = %d (%s)\n",
-				name, errno, strerror(errno));
+				args->name, errno, strerror(errno));
 			goto cleanup_file;
 		}
 		if (shim_ioprio_get(IOPRIO_WHO_PGRP, grp) < 0) {
-			pr_fail(stderr, "%s: ioprio_get(OPRIO_WHO_PGRP, %d), "
+			pr_fail("%s: ioprio_get(OPRIO_WHO_PGRP, %d), "
 				"errno = %d (%s)\n",
-				name, pgrp, errno, strerror(errno));
+				args->name, g_pgrp, errno, strerror(errno));
 			goto cleanup_file;
 		}
 		if (shim_ioprio_get(IOPRIO_WHO_PGRP, 0) < 0) {
-			pr_fail(stderr, "%s: ioprio_get(OPRIO_WHO_PGRP, 0), "
+			pr_fail("%s: ioprio_get(OPRIO_WHO_PGRP, 0), "
 				"errno = %d (%s)\n",
-				name, errno, strerror(errno));
+				args->name, errno, strerror(errno));
 			goto cleanup_file;
 		}
 		if (shim_ioprio_get(IOPRIO_WHO_USER, uid) < 0) {
-			pr_fail(stderr, "%s: ioprio_get(OPRIO_WHO_USR, %d), "
+			pr_fail("%s: ioprio_get(OPRIO_WHO_USR, %d), "
 				"errno = %d (%s)\n",
-				name, uid, errno, strerror(errno));
+				args->name, uid, errno, strerror(errno));
 			goto cleanup_file;
 		}
 
@@ -103,84 +98,80 @@ int stress_ioprio(
 		}
 
 		if (pwritev(fd, iov, MAX_IOV, (off_t)512 * mwc16()) < 0) {
-			pr_fail_err(name, "pwritev");
+			pr_fail_err("pwritev");
 			goto cleanup_file;
 		}
 		(void)fsync(fd);
 
-		if (shim_ioprio_set(IOPRIO_WHO_PROCESS, pid,
+		if (shim_ioprio_set(IOPRIO_WHO_PROCESS, args->pid,
 			IOPRIO_PRIO_VALUE(IOPRIO_CLASS_IDLE, 0)) < 0) {
 			if (errno != EPERM) {
-				pr_fail(stderr, "%s: ioprio_set("
+				pr_fail("%s: ioprio_set("
 					"IOPRIO_WHO_PROCESS, %d, "
 					"(IOPRIO_CLASS_IDLE, 0)), "
 					"errno = %d (%s)\n",
-					name, pid, errno, strerror(errno));
+					args->name, args->pid, errno, strerror(errno));
 				goto cleanup_file;
 			}
 		}
 
 		if (pwritev(fd, iov, MAX_IOV, (off_t)512 * mwc16()) < 0) {
-			pr_fail_err(name, "pwritev");
+			pr_fail_err("pwritev");
 			goto cleanup_file;
 		}
 		(void)fsync(fd);
 
 		for (i = 0; i < 8; i++) {
-			if (shim_ioprio_set(IOPRIO_WHO_PROCESS, pid,
+			if (shim_ioprio_set(IOPRIO_WHO_PROCESS, args->pid,
 				IOPRIO_PRIO_VALUE(IOPRIO_CLASS_BE, i)) < 0) {
 				if (errno != EPERM) {
-					pr_fail(stderr, "%s: ioprio_set("
+					pr_fail("%s: ioprio_set("
 						"IOPRIO_WHO_PROCESS, %d, "
 						"(IOPRIO_CLASS_BE, %d)), "
 						"errno = %d (%s)\n",
-						name, pid, i, errno, strerror(errno));
+						args->name, args->pid, i, errno, strerror(errno));
 					goto cleanup_file;
 				}
 			}
 			if (pwritev(fd, iov, MAX_IOV, (off_t)512 * mwc16()) < 0) {
-				pr_fail_err(name, "pwritev");
+				pr_fail_err("pwritev");
 				goto cleanup_file;
 			}
 			(void)fsync(fd);
 		}
 		for (i = 0; i < 8; i++) {
-			if (shim_ioprio_set(IOPRIO_WHO_PROCESS, pid,
+			if (shim_ioprio_set(IOPRIO_WHO_PROCESS, args->pid,
 				IOPRIO_PRIO_VALUE(IOPRIO_CLASS_RT, i)) < 0) {
 				if (errno != EPERM) {
-					pr_fail(stderr, "%s: ioprio_set("
+					pr_fail("%s: ioprio_set("
 						"IOPRIO_WHO_PROCESS, %d, "
 						"(IOPRIO_CLASS_RT, %d)), "
 						"errno = %d (%s)\n",
-						name, pid, i, errno, strerror(errno));
+						args->name, args->pid, i, errno, strerror(errno));
 					goto cleanup_file;
 				}
 			}
 			if (pwritev(fd, iov, MAX_IOV, (off_t)512 * mwc16()) < 0) {
-				pr_fail_err(name, "pwritev");
+				pr_fail_err("pwritev");
 				goto cleanup_file;
 			}
 			(void)fsync(fd);
 		}
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
 	rc = EXIT_SUCCESS;
 
 cleanup_file:
 	(void)close(fd);
 cleanup_dir:
-	(void)stress_temp_dir_rm(name, pid, instance);
+	(void)stress_temp_dir_rm_args(args);
 
 	return rc;
 }
 #else
-int stress_ioprio(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_ioprio(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
