@@ -34,10 +34,10 @@ static double start;
  *  stress_set_itimer_freq()
  *	set itimer frequency from given option
  */
-void stress_set_itimer_freq(const char *optarg)
+void stress_set_itimer_freq(const char *opt)
 {
 	set_itimer_freq = true;
-	opt_itimer_freq = get_uint64(optarg);
+	opt_itimer_freq = get_uint64(opt);
 	check_range("itimer-freq", opt_itimer_freq,
 		MIN_TIMER_FREQ, MAX_TIMER_FREQ);
 }
@@ -50,7 +50,7 @@ static void stress_itimer_set(struct itimerval *timer)
 {
 	double rate;
 
-	if (opt_flags & OPT_FLAGS_TIMER_RAND) {
+	if (g_opt_flags & OPT_FLAGS_TIMER_RAND) {
 		/* Mix in some random variation */
 		double r = ((double)(mwc32() % 10000) - 5000.0) / 40000.0;
 		rate = rate_us + (rate_us * r);
@@ -86,15 +86,15 @@ static void stress_itimer_handler(int sig)
 			goto cancel;
 	/* High freq timer, check periodically for timeout */
 	if ((itimer_counter & 65535) == 0)
-		if ((time_now() - start) > (double)opt_timeout)
+		if ((time_now() - start) > (double)g_opt_timeout)
 			goto cancel;
-	if (opt_do_run) {
+	if (g_keep_stressing_flag) {
 		stress_itimer_set(&timer);
 		return;
 	}
 
 cancel:
-	opt_do_run = false;
+	g_keep_stressing_flag = false;
 	/* Cancel timer if we detect no more runs */
 	memset(&timer, 0, sizeof(timer));
 	(void)setitimer(ITIMER_PROF, &timer, NULL);
@@ -104,17 +104,11 @@ cancel:
  *  stress_itimer
  *	stress itimer
  */
-int stress_itimer(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_itimer(const args_t *args)
 {
 	struct itimerval timer;
 	sigset_t mask;
 
-	(void)instance;
-
 	sigemptyset(&mask);
 	sigaddset(&mask, SIGINT);
 	sigprocmask(SIG_SETMASK, &mask, NULL);
@@ -122,19 +116,19 @@ int stress_itimer(
 	start = time_now();
 
 	if (!set_itimer_freq) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_itimer_freq = MAX_ITIMER_FREQ;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_itimer_freq = MIN_ITIMER_FREQ;
 	}
 	rate_us = opt_itimer_freq ? 1000000 / opt_itimer_freq : 1000000;
 
-	if (stress_sighandler(name, SIGPROF, stress_itimer_handler, NULL) < 0)
+	if (stress_sighandler(args->name, SIGPROF, stress_itimer_handler, NULL) < 0)
 		return EXIT_FAILURE;
 
 	stress_itimer_set(&timer);
 	if (setitimer(ITIMER_PROF, &timer, NULL) < 0) {
-		pr_fail_err(name, "setitimer");
+		pr_fail_err("setitimer");
 		return EXIT_FAILURE;
 	}
 
@@ -142,8 +136,8 @@ int stress_itimer(
 		struct itimerval t;
 		getitimer(ITIMER_PROF, &t);
 
-		*counter = itimer_counter;
-	} while (opt_do_run && (!max_ops || itimer_counter < max_ops));
+		*args->counter = itimer_counter;
+	} while (keep_stressing());
 
 	memset(&timer, 0, sizeof(timer));
 	(void)setitimer(ITIMER_PROF, &timer, NULL);
