@@ -38,51 +38,47 @@ enum {
 	KCMP_TYPES,
 };
 
-#define KCMP(pid1, pid2, type, idx1, idx2)		\
-{							\
-	int rc = shim_kcmp(pid1, pid2, type, idx1, idx2);\
-							\
-	if (rc < 0) {	 				\
-		if (errno == EPERM) {			\
-			pr_inf(stdout, capfail, name);	\
-			break;				\
-		}					\
-		pr_fail_err(name, "kcmp: " # type);	\
-	}						\
-	if (!opt_do_run)				\
-		break;					\
+#define KCMP(pid1, pid2, type, idx1, idx2)			\
+{								\
+	int rc = shim_kcmp(pid1, pid2, type, idx1, idx2);	\
+								\
+	if (rc < 0) {	 					\
+		if (errno == EPERM) {				\
+			pr_inf(capfail, args->name);		\
+			break;					\
+		}						\
+		pr_fail_err("kcmp: " # type);			\
+	}							\
+	if (!g_keep_stressing_flag)				\
+		break;						\
 }
 
-#define KCMP_VERIFY(pid1, pid2, type, idx1, idx2, res)	\
-{							\
-	int rc = shim_kcmp(pid1, pid2, type, idx1, idx2);\
-							\
-	if (rc != res) {				\
-		if (rc < 0) {				\
-			if (errno == EPERM) {		\
-				pr_inf(stdout, capfail, name); \
-				break;			\
-			}				\
-			pr_fail_err(name, "kcmp: " # type);\
-		} else {				\
-			pr_fail(stderr, "%s: kcmp " # type \
-			" returned %d, expected: %d\n",	\
-			name, rc, ret);			\
-		}					\
-	}						\
-	if (!opt_do_run)				\
-		break;					\
+#define KCMP_VERIFY(pid1, pid2, type, idx1, idx2, res)		\
+{								\
+	int rc = shim_kcmp(pid1, pid2, type, idx1, idx2);	\
+								\
+	if (rc != res) {					\
+		if (rc < 0) {					\
+			if (errno == EPERM) {			\
+				pr_inf(capfail, args->name); 	\
+				break;				\
+			}					\
+			pr_fail_err("kcmp: " # type);		\
+		} else {					\
+			pr_fail( "%s: kcmp " # type		\
+			" returned %d, expected: %d\n",		\
+			args->name, rc, ret);			\
+		}						\
+	}							\
+	if (!g_keep_stressing_flag)				\
+		break;						\
 }
 
 /*
  *  stress_kcmp
  *	stress sys_kcmp
  */
-int stress_kcmp(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_kcmp(const args_t *args)
 {
 	pid_t pid1;
 	int fd1;
@@ -92,28 +88,26 @@ int stress_kcmp(
 		"%s: need CAP_SYS_PTRACE capability to run kcmp stressor, "
 		"aborting stress test\n";
 
-	(void)instance;
-
 	if ((fd1 = open("/dev/null", O_WRONLY)) < 0) {
-		pr_fail_err(name, "open");
+		pr_fail_err("open");
 		return EXIT_FAILURE;
 	}
 
 again:
 	pid1 = fork();
 	if (pid1 < 0) {
-		if (opt_do_run && (errno == EAGAIN))
+		if (g_keep_stressing_flag && (errno == EAGAIN))
 			goto again;
 
-		pr_fail_dbg(name, "fork");
+		pr_fail_dbg("fork");
 		(void)close(fd1);
 		return EXIT_FAILURE;
 	} else if (pid1 == 0) {
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
 
 		/* Child */
-		while (opt_do_run)
+		while (g_keep_stressing_flag)
 			pause();
 
 		/* will never get here */
@@ -123,10 +117,10 @@ again:
 		/* Parent */
 		int fd2, status, pid2;
 
-		(void)setpgid(pid1, pgrp);
+		(void)setpgid(pid1, g_pgrp);
 		pid2 = getpid();
 		if ((fd2 = open("/dev/null", O_WRONLY)) < 0) {
-			pr_fail_err(name, "open");
+			pr_fail_err("open");
 			ret = EXIT_FAILURE;
 			goto reap;
 		}
@@ -162,7 +156,7 @@ again:
 			KCMP(pid2, pid2, KCMP_VM, 0, 0);
 
 			/* Same simple checks */
-			if (opt_flags & OPT_FLAGS_VERIFY) {
+			if (g_opt_flags & OPT_FLAGS_VERIFY) {
 				KCMP_VERIFY(pid1, pid1, KCMP_FILE, fd1, fd1, 0);
 				KCMP_VERIFY(pid1, pid1, KCMP_FILES, 0, 0, 0);
 				KCMP_VERIFY(pid1, pid1, KCMP_FS, 0, 0, 0);
@@ -172,8 +166,8 @@ again:
 				KCMP_VERIFY(pid1, pid1, KCMP_VM, 0, 0, 0);
 				KCMP_VERIFY(pid1, pid2, KCMP_SYSVSEM, 0, 0, 0);
 			}
-			(*counter)++;
-		} while (opt_do_run && (!max_ops || *counter < max_ops));
+			inc_counter(args);
+		} while (keep_stressing());
 reap:
 		if (fd2 >= 0)
 			(void)close(fd2);
@@ -184,12 +178,8 @@ reap:
 	return ret;
 }
 #else
-int stress_kcmp(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_kcmp(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
