@@ -72,26 +72,23 @@ static key_serial_t sys_request_key(
  *  stress_key
  *	stress key operations
  */
-int stress_key(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_key(const args_t *args)
 {
 	key_serial_t keys[MAX_KEYS];
 	pid_t ppid = getppid();
+	bool timeout_supported = true;
 
 	do {
-		size_t i, n = 0;
+		size_t i = 0, n = 0;
 		char description[64];
 		char payload[64];
 
 		/* Add as many keys as we are allowed */
 		for (n = 0; n < MAX_KEYS; n++) {
-			snprintf(description, sizeof(description),
+			(void)snprintf(description, sizeof(description),
 				"stress-ng-key-%u-%" PRIu32
-				"-%zu", ppid, instance, n);
-			snprintf(payload, sizeof(payload),
+				"-%zu", ppid, args->instance, n);
+			(void)snprintf(payload, sizeof(payload),
 				"somedata-%zu", n);
 
 			keys[n] = sys_add_key("user", description,
@@ -99,56 +96,68 @@ int stress_key(
 				KEY_SPEC_PROCESS_KEYRING);
 			if (keys[n] < 0) {
 				if ((errno != ENOMEM) && (errno != EDQUOT))
-					pr_fail_err(name, "add_key");
-				break;
+					pr_fail_err("add_key");
+				goto tidy;
 			}
 #if defined(KEYCTL_SET_TIMEOUT)
-			if (sys_keyctl(KEYCTL_SET_TIMEOUT, keys[n], 1) < 0)
-				pr_fail_err(name, "keyctl KEYCTL_SET_TIMEOUT");
+			if (timeout_supported) {
+				if (sys_keyctl(KEYCTL_SET_TIMEOUT, keys[n], 1) < 0) {
+					/* Some platforms don't support this */
+					if (errno == ENOSYS) {
+						timeout_supported = false;
+					} else {
+						pr_fail_err("keyctl KEYCTL_SET_TIMEOUT");
+					}
+				}
+			}
+			if (!g_keep_stressing_flag)
+				goto tidy;
 #endif
 		}
 
 		/* And manipulate the keys */
 		for (i = 0; i < n; i++) {
-			snprintf(description, sizeof(description),
+			(void)snprintf(description, sizeof(description),
 				"stress-ng-key-%u-%" PRIu32
-				"-%zu", ppid, instance, i);
+				"-%zu", ppid, args->instance, i);
 #if defined(KEYCTL_DESCRIBE)
 			if (sys_keyctl(KEYCTL_DESCRIBE, keys[i], description) < 0)
-				pr_fail_err(name, "keyctl KEYCTL_DESCRIBE");
-			if (!opt_do_run)
-				break;
+				pr_fail_err("keyctl KEYCTL_DESCRIBE");
+			if (!g_keep_stressing_flag)
+				goto tidy;
 #endif
 
-			snprintf(payload, sizeof(payload),
+			(void)snprintf(payload, sizeof(payload),
 				"somedata-%zu", n);
 #if defined(KEYCTL_UPDATE)
 			if (sys_keyctl(KEYCTL_UPDATE, keys[i],
 			    payload, strlen(payload)) < 0) {
 				if ((errno != ENOMEM) && (errno != EDQUOT))
-					pr_fail_err(name, "keyctl KEYCTL_UPDATE");
+					pr_fail_err("keyctl KEYCTL_UPDATE");
 			}
-			if (!opt_do_run)
-				break;
+			if (!g_keep_stressing_flag)
+				goto tidy;
 #endif
 
 #if defined(KEYCTL_READ)
 			memset(payload, 0, sizeof(payload));
 			if (sys_keyctl(KEYCTL_READ, keys[i],
 			    payload, sizeof(payload)) < 0)
-				pr_fail_err(name, "keyctl KEYCTL_READ");
-			if (!opt_do_run)
-				break;
+				pr_fail_err("keyctl KEYCTL_READ");
+			if (!g_keep_stressing_flag)
+				goto tidy;
 #endif
 
 #if defined(__NR_request_key)
-			snprintf(description, sizeof(description),
+			(void)snprintf(description, sizeof(description),
 				"stress-ng-key-%u-%" PRIu32
-				"-%zu", ppid, instance, i);
+				"-%zu", ppid, args->instance, i);
 			if (sys_request_key("user", description, NULL,
 				KEY_SPEC_PROCESS_KEYRING) < 0) {
-				pr_fail_err(name, "request_key");
+				pr_fail_err("request_key");
 			}
+			if (!g_keep_stressing_flag)
+				goto tidy;
 #endif
 
 
@@ -171,29 +180,28 @@ int stress_key(
 #if defined(KEYCTL_INVALIDATE)
 			(void)sys_keyctl(KEYCTL_INVALIDATE, keys[i]);
 #endif
-			(*counter)++;
+			inc_counter(args);
 		}
+tidy:
 		/* If we hit too many errors and bailed out early, clean up */
 		while (i < n) {
+			if (keys[i] >= 0) {
 #if defined(KEYCTL_CLEAR)
-			(void)sys_keyctl(KEYCTL_CLEAR, keys[i]);
+				(void)sys_keyctl(KEYCTL_CLEAR, keys[i]);
 #endif
 #if defined(KEYCTL_INVALIDATE)
-			(void)sys_keyctl(KEYCTL_INVALIDATE, keys[i]);
+				(void)sys_keyctl(KEYCTL_INVALIDATE, keys[i]);
 #endif
+			}
 			i++;
 		}
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (keep_stressing());
 
 	return EXIT_SUCCESS;
 }
 #else
-int stress_key(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_key(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
