@@ -28,30 +28,22 @@
  *  stress on sched_kill()
  *	stress system by rapid kills
  */
-int stress_kill(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_kill(const args_t *args)
 {
-	const pid_t pid = getpid();
-
-	(void)instance;
-
-	if (stress_sighandler(name, SIGUSR1, SIG_IGN, NULL) < 0)
+	if (stress_sighandler(args->name, SIGUSR1, SIG_IGN, NULL) < 0)
 		return EXIT_FAILURE;
 
 	do {
 		int ret;
 
-		ret = kill(pid, SIGUSR1);
-		if ((ret < 0) && (opt_flags & OPT_FLAGS_VERIFY))
-			pr_fail_err(name, "kill");
+		ret = kill(args->pid, SIGUSR1);
+		if ((ret < 0) && (g_opt_flags & OPT_FLAGS_VERIFY))
+			pr_fail_err("kill");
 
 		/* Zero signal can be used to see if process exists */
-		ret = kill(pid, 0);
-		if ((ret < 0) && (opt_flags & OPT_FLAGS_VERIFY))
-			pr_fail_err(name, "kill");
+		ret = kill(args->pid, 0);
+		if ((ret < 0) && (g_opt_flags & OPT_FLAGS_VERIFY))
+			pr_fail_err("kill");
 
 		/*
 		 * Zero signal can be used to see if process exists,
@@ -59,11 +51,11 @@ int stress_kill(
 		 * permission to send to
 		 */
 		ret = kill(-1, 0);
-		if ((ret < 0) && (opt_flags & OPT_FLAGS_VERIFY))
-			pr_fail_err(name, "kill");
+		if ((ret < 0) && (g_opt_flags & OPT_FLAGS_VERIFY))
+			pr_fail_err("kill");
 
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
 	return EXIT_SUCCESS;
 }
