@@ -32,10 +32,10 @@ static uint64_t lease_sigio;
 static uint64_t opt_lease_breakers = DEFAULT_LEASE_BREAKERS;
 static bool set_lease_breakers = false;
 
-void stress_set_lease_breakers(const char *optarg)
+void stress_set_lease_breakers(const char *opt)
 {
 	set_lease_breakers = true;
-	opt_lease_breakers = get_uint64(optarg);
+	opt_lease_breakers = get_uint64(opt);
 	check_range("lease-breakers", opt_lease_breakers,
 		MIN_LEASE_BREAKERS, MAX_LEASE_BREAKERS);
 }
@@ -58,29 +58,27 @@ static void MLOCKED stress_lease_handler(int dummy)
  *	spawn a process
  */
 static pid_t stress_lease_spawn(
-	const char *filename,
-	const char *name,
-	const uint64_t max_ops,
-	uint64_t *counter)
+	const args_t *args,
+	const char *filename)
 {
 	pid_t pid;
 
 	if (!set_lease_breakers) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_lease_breakers = MAX_LEASE_BREAKERS;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_lease_breakers = MIN_LEASE_BREAKERS;
 	}
 
 again:
 	pid = fork();
 	if (pid < 0) {
-		if (opt_do_run && (errno == EAGAIN))
+		if (g_keep_stressing_flag && (errno == EAGAIN))
 			goto again;
 		return -1;
 	}
 	if (pid == 0) {
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
 
 		do {
@@ -90,16 +88,16 @@ again:
 			fd = open(filename, O_NONBLOCK | O_WRONLY, S_IRUSR | S_IWUSR);
 			if (fd < 0) {
 				if (errno != EWOULDBLOCK && errno != EACCES) {
-					pr_dbg(stderr, "%s: open failed (child): errno=%d: (%s)\n",
-						name, errno, strerror(errno));
+					pr_dbg("%s: open failed (child): errno=%d: (%s)\n",
+						args->name, errno, strerror(errno));
 				}
 				continue;
 			}
 			(void)close(fd);
-		} while (opt_do_run && (!max_ops || *counter < max_ops));
+		} while (keep_stressing());
 		exit(EXIT_SUCCESS);
 	}
-	(void)setpgid(pid, pgrp);
+	(void)setpgid(pid, g_pgrp);
 	return pid;
 }
 
@@ -107,43 +105,38 @@ again:
  *  stress_lease
  *	stress by fcntl lease activity
  */
-int stress_lease(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_lease(const args_t *args)
 {
 	char filename[PATH_MAX];
 	int ret, fd, status;
 	pid_t l_pids[MAX_LEASE_BREAKERS];
-	pid_t pid = getpid();
 	uint64_t i;
 
 	memset(l_pids, 0, sizeof(l_pids));
 
-	if (stress_sighandler(name, SIGIO, stress_lease_handler, NULL) < 0)
+	if (stress_sighandler(args->name, SIGIO, stress_lease_handler, NULL) < 0)
 		return EXIT_FAILURE;
 
-	ret = stress_temp_dir_mk(name, pid, instance);
+	ret = stress_temp_dir_mk_args(args);
 	if (ret < 0)
 		return exit_status(-ret);
-	(void)stress_temp_filename(filename, PATH_MAX,
-		name, pid, instance, mwc32());
+	(void)stress_temp_filename_args(args,
+		filename, sizeof(filename), mwc32());
 
 	fd = creat(filename, S_IRUSR | S_IWUSR);
 	if (fd < 0) {
 		ret = exit_status(errno);
-		pr_err(stderr, "%s: creat failed: errno=%d: (%s)\n",
-			name, errno, strerror(errno));
-		(void)stress_temp_dir_rm(name, pid, instance);
+		pr_err("%s: creat failed: errno=%d: (%s)\n",
+			args->name, errno, strerror(errno));
+		(void)stress_temp_dir_rm_args(args);
 		return ret;
 	}
 	(void)close(fd);
 
 	for (i = 0; i < opt_lease_breakers; i++) {
-		l_pids[i] = stress_lease_spawn(filename, name, max_ops, counter);
+		l_pids[i] = stress_lease_spawn(args, filename);
 		if (l_pids[i] < 0) {
-			pr_err(stderr, "%s: failed to start all the lease breaker processes\n", name);
+			pr_err("%s: failed to start all the lease breaker processes\n", args->name);
 			goto reap;
 		}
 	}
@@ -152,26 +145,26 @@ int stress_lease(
 		fd = open(filename, O_WRONLY | O_APPEND, S_IRUSR | S_IWUSR);
 		if (fd < 0) {
 			ret = exit_status(errno);
-			pr_err(stderr, "%s: open failed (parent): errno=%d: (%s)\n",
-				name, errno, strerror(errno));
+			pr_err("%s: open failed (parent): errno=%d: (%s)\n",
+				args->name, errno, strerror(errno));
 			goto reap;
 		}
 		while (fcntl(fd, F_SETLEASE, F_WRLCK) < 0) {
-			if (!opt_do_run) {
+			if (!g_keep_stressing_flag) {
 				(void)close(fd);
 				goto reap;
 			}
 		}
-		(*counter)++;
+		inc_counter(args);
 		(void)shim_sched_yield();
 		if (fcntl(fd, F_SETLEASE, F_UNLCK) < 0) {
-			pr_err(stderr, "%s: fcntl failed: errno=%d: (%s)\n",
-				name, errno, strerror(errno));
+			pr_err("%s: fcntl failed: errno=%d: (%s)\n",
+				args->name, errno, strerror(errno));
 			(void)close(fd);
 			break;
 		}
 		(void)close(fd);
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (keep_stressing());
 
 	ret = EXIT_SUCCESS;
 
@@ -184,19 +177,15 @@ reap:
 	}
 
 	(void)unlink(filename);
-	(void)stress_temp_dir_rm(name, pid, instance);
+	(void)stress_temp_dir_rm_args(args);
 
-	pr_dbg(stderr, "%s: %" PRIu64 " lease sigio interrupts caught\n", name, lease_sigio);
+	pr_dbg("%s: %" PRIu64 " lease sigio interrupts caught\n", args->name, lease_sigio);
 
 	return ret;
 }
 #else
-int stress_lease(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_lease(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
