@@ -127,7 +127,7 @@ static void stress_locka_info_free(void)
  *  stress_locka_unlock()
  *	pop oldest lock record off list and unlock it
  */
-static int stress_locka_unlock(const char *name, const int fd)
+static int stress_locka_unlock(const args_t *args, const int fd)
 {
 	struct flock f;
 
@@ -144,7 +144,7 @@ static int stress_locka_unlock(const char *name, const int fd)
 	stress_locka_info_head_remove();
 
 	if (fcntl(fd, F_SETLK, &f) < 0) {
-		pr_fail_err(name, "F_SETLK");
+		pr_fail_err("F_SETLK");
 		return -1;
 	}
 	return 0;
@@ -155,13 +155,10 @@ static int stress_locka_unlock(const char *name, const int fd)
  *	hammer advisory lock/unlock to create some file lock contention
  */
 static int stress_locka_contention(
-	const char *name,
-	const int fd,
-	uint64_t *const counter,
-	const uint64_t max_ops)
+	const args_t *args,
+	const int fd)
 {
 	mwc_reseed();
-	pid_t pid = getpid();
 
 	do {
 		off_t offset;
@@ -171,7 +168,7 @@ static int stress_locka_contention(
 		struct flock f;
 
 		if (locka_infos.length >= LOCK_MAX)
-			if (stress_locka_unlock(name, fd) < 0)
+			if (stress_locka_unlock(args, fd) < 0)
 				return -1;
 
 		len  = (mwc16() + 1) & 0xfff;
@@ -181,7 +178,7 @@ static int stress_locka_contention(
 		f.l_whence = SEEK_SET;
 		f.l_start = offset;
 		f.l_len = len;
-		f.l_pid = pid;
+		f.l_pid = args->pid;
 
 		rc = fcntl(fd, F_GETLK, &f);
 		if (rc < 0)
@@ -191,15 +188,15 @@ static int stress_locka_contention(
 
 		locka_info = stress_locka_info_new();
 		if (!locka_info) {
-			pr_fail_err(name, "calloc");
+			pr_fail_err("calloc");
 			return -1;
 		}
 		locka_info->offset = offset;
 		locka_info->len = len;
-		locka_info->pid = pid;
+		locka_info->pid = args->pid;
 
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
 	return 0;
 }
@@ -208,14 +205,10 @@ static int stress_locka_contention(
  *  stress_locka
  *	stress file locking via advisory locking
  */
-int stress_locka(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_locka(const args_t *args)
 {
 	int fd, ret = EXIT_FAILURE;
-	pid_t pid = getpid(), cpid = -1;
+	pid_t cpid = -1;
 	char filename[PATH_MAX];
 	char dirname[PATH_MAX];
 	char buffer[4096];
@@ -228,11 +221,11 @@ int stress_locka(
 	 *  There will be a race to create the directory
 	 *  so EEXIST is expected on all but one instance
 	 */
-	(void)stress_temp_dir(dirname, sizeof(dirname), name, pid, instance);
+	(void)stress_temp_dir_args(args, dirname, sizeof(dirname));
 	if (mkdir(dirname, S_IRWXU) < 0) {
 		if (errno != EEXIST) {
 			ret = exit_status(errno);
-			pr_fail_err(name, "mkdir");
+			pr_fail_err("mkdir");
 			return ret;
 		}
 	}
@@ -242,23 +235,23 @@ int stress_locka(
 	 *  as we need to share this among all the other
 	 *  stress flock processes
 	 */
-	(void)stress_temp_filename(filename, sizeof(filename),
-		name, pid, instance, mwc32());
+	(void)stress_temp_filename_args(args,
+		filename, sizeof(filename), mwc32());
 
 	if ((fd = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
 		ret = exit_status(errno);
-		pr_fail_err(name, "open");
+		pr_fail_err("open");
 		(void)rmdir(dirname);
 		return ret;
 	}
 
 	if (lseek(fd, 0, SEEK_SET) < 0) {
-		pr_fail_err(name, "lseek");
+		pr_fail_err("lseek");
 		goto tidy;
 	}
 	for (offset = 0; offset < LOCK_FILE_SIZE; offset += sizeof(buffer)) {
 redo:
-		if (!opt_do_run) {
+		if (!g_keep_stressing_flag) {
 			ret = EXIT_SUCCESS;
 			goto tidy;
 		}
@@ -267,7 +260,7 @@ redo:
 			if ((errno == EAGAIN) || (errno == EINTR))
 				goto redo;
 			ret = exit_status(errno);
-			pr_fail_err(name, "write");
+			pr_fail_err("write");
 			goto tidy;
 		}
 	}
@@ -275,27 +268,27 @@ redo:
 again:
 	cpid = fork();
 	if (cpid < 0) {
-		if (!opt_do_run) {
+		if (!g_keep_stressing_flag) {
 			ret = EXIT_SUCCESS;
 			goto tidy;
 		}
 		if (errno == EAGAIN)
 			goto again;
-		pr_fail_err(name, "fork");
+		pr_fail_err("fork");
 		goto tidy;
 	}
 	if (cpid == 0) {
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
 
-		if (stress_locka_contention(name, fd, counter, max_ops) < 0)
+		if (stress_locka_contention(args, fd) < 0)
 			exit(EXIT_FAILURE);
 		stress_locka_info_free();
 		exit(EXIT_SUCCESS);
 	}
-	(void)setpgid(cpid, pgrp);
+	(void)setpgid(cpid, g_pgrp);
 
-	if (stress_locka_contention(name, fd, counter, max_ops) == 0)
+	if (stress_locka_contention(args, fd) == 0)
 		ret = EXIT_SUCCESS;
 tidy:
 	if (cpid > 0) {
@@ -313,12 +306,8 @@ tidy:
 	return ret;
 }
 #else
-int stress_locka(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_locka(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
