@@ -33,10 +33,10 @@ static bool set_lsearch_size = false;
  *  stress_set_lsearch_size()
  *      set lsearch size from given option string
  */
-void stress_set_lsearch_size(const char *optarg)
+void stress_set_lsearch_size(const char *opt)
 {
 	set_lsearch_size = true;
-	opt_lsearch_size = get_uint64_byte(optarg);
+	opt_lsearch_size = get_uint64_byte(opt);
 	check_range("lsearch-size", opt_lsearch_size,
 		MIN_TSEARCH_SIZE, MAX_TSEARCH_SIZE);
 }
@@ -54,58 +54,52 @@ static int cmp(const void *p1, const void *p2)
  *  stress_lsearch()
  *	stress lsearch
  */
-int stress_lsearch(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_lsearch(const args_t *args)
 {
 	int32_t *data, *root;
 	size_t i, max;
 
-	(void)instance;
-
 	if (!set_lsearch_size) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_lsearch_size = MAX_LSEARCH_SIZE;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_lsearch_size = MIN_LSEARCH_SIZE;
 	}
 	max = (size_t)opt_lsearch_size;
 
 	if ((data = calloc(max, sizeof(int32_t))) == NULL) {
-		pr_fail_dbg(name, "malloc");
-		return EXIT_FAILURE;
+		pr_fail_dbg("malloc");
+		return EXIT_NO_RESOURCE;
 	}
 	if ((root = calloc(max, sizeof(int32_t))) == NULL) {
 		free(data);
-		pr_fail_dbg(name, "malloc");
-		return EXIT_FAILURE;
+		pr_fail_dbg("malloc");
+		return EXIT_NO_RESOURCE;
 	}
 
 	do {
 		size_t n = 0;
 
 		/* Step #1, populate with data */
-		for (i = 0; opt_do_run && i < max; i++) {
+		for (i = 0; g_keep_stressing_flag && i < max; i++) {
 			data[i] = ((mwc32() & 0xfff) << 20) ^ i;
 			(void)lsearch(&data[i], root, &n, sizeof(int32_t), cmp);
 		}
 		/* Step #2, find */
-		for (i = 0; opt_do_run && i < n; i++) {
+		for (i = 0; g_keep_stressing_flag && i < n; i++) {
 			int32_t *result;
 
 			result = lfind(&data[i], root, &n, sizeof(int32_t), cmp);
-			if (opt_flags & OPT_FLAGS_VERIFY) {
+			if (g_opt_flags & OPT_FLAGS_VERIFY) {
 				if (result == NULL)
-					pr_fail(stderr, "%s: element %zu could not be found\n", name, i);
+					pr_fail("%s: element %zu could not be found\n", args->name, i);
 				else if (*result != data[i])
-					pr_fail(stderr, "%s: element %zu found %" PRIu32 ", expecting %" PRIu32 "\n",
-					name, i, *result, data[i]);
+					pr_fail("%s: element %zu found %" PRIu32 ", expecting %" PRIu32 "\n",
+					args->name, i, *result, data[i]);
 			}
 		}
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
 	free(root);
 	free(data);
