@@ -33,26 +33,28 @@ static bool set_malloc_max = false;
 static int opt_malloc_threshold = DEFAULT_MALLOC_THRESHOLD;
 static bool set_malloc_threshold = false;
 
-void stress_set_malloc_bytes(const char *optarg)
+void stress_set_malloc_bytes(const char *opt)
 {
 	set_malloc_bytes = true;
-	opt_malloc_bytes = (size_t)get_uint64_byte(optarg);
-	check_range("malloc-bytes", opt_malloc_bytes,
-		MIN_MALLOC_BYTES, MAX_MALLOC_BYTES);
+	opt_malloc_bytes = (size_t)
+		get_uint64_byte_memory(opt,
+			stressor_instances(STRESS_MALLOC));
+	check_range_bytes("malloc-bytes", opt_malloc_bytes,
+		MIN_MALLOC_BYTES, MAX_MEM_LIMIT);
 }
 
-void stress_set_malloc_max(const char *optarg)
+void stress_set_malloc_max(const char *opt)
 {
 	set_malloc_max = true;
-	opt_malloc_max = (size_t)get_uint64_byte(optarg);
+	opt_malloc_max = (size_t)get_uint64_byte(opt);
 	check_range("malloc-max", opt_malloc_max,
 		MIN_MALLOC_MAX, MAX_MALLOC_MAX);
 }
 
-void stress_set_malloc_threshold(const char *optarg)
+void stress_set_malloc_threshold(const char *opt)
 {
 	set_malloc_threshold = true;
-	opt_malloc_threshold = (size_t)get_uint64_byte(optarg);
+	opt_malloc_threshold = (size_t)get_uint64_byte(opt);
 	check_range("malloc-threshold", opt_malloc_threshold,
 		MIN_MALLOC_THRESHOLD, MAX_MALLOC_THRESHOLD);
 }
@@ -74,26 +76,22 @@ static inline size_t stress_alloc_size(void)
  *	stress malloc by performing a mix of
  *	allocation and frees
  */
-int stress_malloc(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_malloc(const args_t *args)
 {
 	pid_t pid;
 	uint32_t restarts = 0, nomems = 0;
 
 	if (!set_malloc_bytes) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_malloc_bytes = MAX_MALLOC_BYTES;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_malloc_bytes = MIN_MALLOC_BYTES;
 	}
 
 	if (!set_malloc_max) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_malloc_max = MAX_MALLOC_MAX;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_malloc_max = MIN_MALLOC_MAX;
 	}
 
@@ -105,36 +103,36 @@ int stress_malloc(
 again:
 	pid = fork();
 	if (pid < 0) {
-		if (opt_do_run && (errno == EAGAIN))
+		if (g_keep_stressing_flag && (errno == EAGAIN))
 			goto again;
-		pr_err(stderr, "%s: fork failed: errno=%d: (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: fork failed: errno=%d: (%s)\n",
+			args->name, errno, strerror(errno));
 	} else if (pid > 0) {
 		int status, ret;
 
-		(void)setpgid(pid, pgrp);
+		(void)setpgid(pid, g_pgrp);
 		stress_parent_died_alarm();
 
 		/* Parent, wait for child */
 		ret = waitpid(pid, &status, 0);
 		if (ret < 0) {
 			if (errno != EINTR)
-				pr_dbg(stderr, "%s: waitpid(): errno=%d (%s)\n",
-					name, errno, strerror(errno));
+				pr_dbg("%s: waitpid(): errno=%d (%s)\n",
+					args->name, errno, strerror(errno));
 			(void)kill(pid, SIGTERM);
 			(void)kill(pid, SIGKILL);
 			(void)waitpid(pid, &status, 0);
 		} else if (WIFSIGNALED(status)) {
-			pr_dbg(stderr, "%s: child died: %s (instance %d)\n",
-				name, stress_strsignal(WTERMSIG(status)),
-				instance);
+			pr_dbg("%s: child died: %s (instance %d)\n",
+				args->name, stress_strsignal(WTERMSIG(status)),
+				args->instance);
 			/* If we got killed by OOM killer, re-start */
 			if (WTERMSIG(status) == SIGKILL) {
 				log_system_mem_info();
-				pr_dbg(stderr, "%s: assuming killed by OOM "
+				pr_dbg("%s: assuming killed by OOM "
 					"killer, restarting again "
 					"(instance %d)\n",
-					name, instance);
+					args->name, args->instance);
 				restarts++;
 				goto again;
 			}
@@ -143,11 +141,11 @@ again:
 		void *addr[opt_malloc_max];
 		size_t j;
 
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		memset(addr, 0, sizeof(addr));
 
 		/* Make sure this is killable by OOM killer */
-		set_oom_adjustment(name, true);
+		set_oom_adjustment(args->name, true);
 
 		do {
 			unsigned int rnd = mwc32();
@@ -162,7 +160,7 @@ again:
 			 * some time and we should bail out before
 			 * exerting any more memory pressure
 			 */
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				goto abort;
 
 			if (addr[i]) {
@@ -170,7 +168,7 @@ again:
 				if (action) {
 					free(addr[i]);
 					addr[i] = NULL;
-					(*counter)++;
+					inc_counter(args);
 				} else {
 					void *tmp;
 					size_t len = stress_alloc_size();
@@ -179,7 +177,7 @@ again:
 					if (tmp) {
 						addr[i] = tmp;
 						(void)mincore_touch_pages(addr[i], len);
-						(*counter)++;
+						inc_counter(args);
 					}
 				}
 			} else {
@@ -195,21 +193,21 @@ again:
 						addr[i] = malloc(len);
 					}
 					if (addr[i]) {
-						(*counter)++;
+						inc_counter(args);
 						(void)mincore_touch_pages(addr[i], len);
 					}
 				}
 			}
-		} while (opt_do_run && (!max_ops || *counter < max_ops));
+		} while (keep_stressing());
 abort:
 		for (j = 0; j < opt_malloc_max; j++) {
 			free(addr[j]);
 		}
 	}
 	if (restarts + nomems > 0)
-		pr_dbg(stderr, "%s: OOM restarts: %" PRIu32
+		pr_dbg("%s: OOM restarts: %" PRIu32
 			", out of memory restarts: %" PRIu32 ".\n",
-			name, restarts, nomems);
+			args->name, restarts, nomems);
 
 	return EXIT_SUCCESS;
 }
