@@ -24,17 +24,36 @@
  */
 #include "stress-ng.h"
 
-#define MAX_MEM_FDS 	(256)
-
 static size_t opt_memfd_bytes = DEFAULT_MEMFD_BYTES;
 static bool set_memfd_bytes;
 
-void stress_set_memfd_bytes(const char *optarg)
+static uint64_t opt_memfd_fds = DEFAULT_MEMFD_FDS;
+static bool set_memfd_fds = false;
+
+/*
+ *  stress_set_memfd_bytes
+ *	set max size of each memfd size
+ */
+void stress_set_memfd_bytes(const char *opt)
 {
 	set_memfd_bytes = true;
-	opt_memfd_bytes = (size_t)get_uint64_byte(optarg);
-	check_range("memfd-bytes", opt_memfd_bytes,
-		MIN_MEMFD_BYTES, MAX_MEMFD_BYTES);
+	opt_memfd_bytes = (size_t)
+		get_uint64_byte_memory(opt,
+			stressor_instances(STRESS_MEMFD));
+	check_range_bytes("memfd-bytes", opt_memfd_bytes,
+		MIN_MEMFD_BYTES, MAX_MEM_LIMIT);
+}
+
+/*
+ *  stress_set_memfd_fds()
+ *      set number of memfd file descriptors
+ */
+void stress_set_memfd_fds(const char *opt)
+{
+	set_memfd_fds = true;
+	opt_memfd_fds = get_uint64_byte(opt);
+	check_range("memfd-fds", opt_memfd_fds,
+		MIN_MEMFD_FDS, MAX_MEMFD_FDS);
 }
 
 #if defined(__linux__) && defined(__NR_memfd_create)
@@ -42,32 +61,28 @@ void stress_set_memfd_bytes(const char *optarg)
 /*
  *  Create allocations using memfd_create, ftruncate and mmap
  */
-static void stress_memfd_allocs(
-	const char *name,
-	uint64_t *const counter,
-	const uint64_t max_ops)
+static void stress_memfd_allocs(const args_t *args)
 {
-	int fds[MAX_MEM_FDS];
-	void *maps[MAX_MEM_FDS];
-	size_t i;
-	const size_t page_size = stress_get_pagesize();
+	int fds[opt_memfd_fds];
+	void *maps[opt_memfd_fds];
+	uint64_t i;
+	const size_t page_size = args->page_size;
 	const size_t min_size = 2 * page_size;
-	size_t size = opt_memfd_bytes / MAX_MEM_FDS;
-	const pid_t pid = getpid();
+	size_t size = opt_memfd_bytes / opt_memfd_fds;
 
 	if (size < min_size)
 		size = min_size;
 
 	do {
-		for (i = 0; i < MAX_MEM_FDS; i++) {
+		for (i = 0; i < opt_memfd_fds; i++) {
 			fds[i] = -1;
 			maps[i] = MAP_FAILED;
 		}
 
-		for (i = 0; i < MAX_MEM_FDS; i++) {
+		for (i = 0; i < opt_memfd_fds; i++) {
 			char filename[PATH_MAX];
 
-			snprintf(filename, sizeof(filename), "memfd-%u-%zu", pid, i);
+			(void)snprintf(filename, sizeof(filename), "memfd-%u-%" PRIu64, args->pid, i);
 			fds[i] = shim_memfd_create(filename, 0);
 			if (fds[i] < 0) {
 				switch (errno) {
@@ -79,102 +94,105 @@ static void stress_memfd_allocs(
 				case ENOSYS:
 				case EFAULT:
 				default:
-					pr_err(stderr, "%s: memfd_create failed: errno=%d (%s)\n",
-						name, errno, strerror(errno));
-					opt_do_run = false;
+					pr_err("%s: memfd_create failed: errno=%d (%s)\n",
+						args->name, errno, strerror(errno));
+					g_keep_stressing_flag = false;
 					goto clean;
 				}
 			}
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				goto clean;
 		}
 
-		for (i = 0; i < MAX_MEM_FDS; i++) {
-			if (fds[i] >= 0) {
-				ssize_t ret;
-				size_t whence;
+		for (i = 0; i < opt_memfd_fds; i++) {
+			ssize_t ret;
+			size_t whence;
 
-				if (!opt_do_run)
+			if (fds[i] < 0)
+				continue;
+
+			if (!g_keep_stressing_flag)
+				break;
+
+			/* Allocate space */
+			ret = ftruncate(fds[i], size);
+			if (ret < 0) {
+				switch (errno) {
+				case EINTR:
+					break;
+				default:
+					pr_fail_err("ftruncate");
 					break;
-
-				/* Allocate space */
-				ret = ftruncate(fds[i], size);
-				if (ret < 0) {
-					switch (errno) {
-					case EINTR:
-						break;
-					default:
-						pr_fail_err(name, "ftruncate");
-						break;
-					}
 				}
-				/*
-				 * ..and map it in, using MAP_POPULATE
-				 * to force page it in
-				 */
-				maps[i] = mmap(NULL, size, PROT_WRITE,
-					MAP_FILE | MAP_SHARED | MAP_POPULATE,
-					fds[i], 0);
-				mincore_touch_pages(maps[i], size);
-				madvise_random(maps[i], size);
+			}
+			/*
+			 * ..and map it in, using MAP_POPULATE
+			 * to force page it in
+			 */
+			maps[i] = mmap(NULL, size, PROT_WRITE,
+				MAP_FILE | MAP_SHARED | MAP_POPULATE,
+				fds[i], 0);
+			mincore_touch_pages(maps[i], size);
+			madvise_random(maps[i], size);
 
 #if defined(FALLOC_FL_PUNCH_HOLE) && defined(FALLOC_FL_KEEP_SIZE)
-				/*
-				 *  ..and punch a hole
-				 */
-				whence = (mwc32() % size) & ~(page_size - 1);
-				ret = shim_fallocate(fds[i], FALLOC_FL_PUNCH_HOLE |
-					FALLOC_FL_KEEP_SIZE, whence, page_size);
-				(void)ret;
+			/*
+			 *  ..and punch a hole
+			 */
+			whence = (mwc32() % size) & ~(page_size - 1);
+			ret = shim_fallocate(fds[i], FALLOC_FL_PUNCH_HOLE |
+				FALLOC_FL_KEEP_SIZE, whence, page_size);
+			(void)ret;
 #endif
-			}
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				goto clean;
 		}
 
-		for (i = 0; i < MAX_MEM_FDS; i++) {
+		for (i = 0; i < opt_memfd_fds; i++) {
+			if (fds[i] < 0)
+				continue;
 #if defined(SEEK_SET)
 			if (lseek(fds[i], (off_t)size>> 1, SEEK_SET) < 0) {
 				if (errno != ENXIO)
-					pr_fail_err(name, "lseek SEEK_SET on memfd");
+					pr_fail_err("lseek SEEK_SET on memfd");
 			}
 #endif
 #if defined(SEEK_CUR)
 			if (lseek(fds[i], (off_t)0, SEEK_CUR) < 0) {
 				if (errno != ENXIO)
-					pr_fail_err(name, "lseek SEEK_CUR on memfd");
+					pr_fail_err("lseek SEEK_CUR on memfd");
 			}
 #endif
 #if defined(SEEK_END)
 			if (lseek(fds[i], (off_t)0, SEEK_END) < 0) {
 				if (errno != ENXIO)
-					pr_fail_err(name, "lseek SEEK_END on memfd");
+					pr_fail_err("lseek SEEK_END on memfd");
 			}
 #endif
 #if defined(SEEK_HOLE)
 			if (lseek(fds[i], (off_t)0, SEEK_HOLE) < 0) {
 				if (errno != ENXIO)
-					pr_fail_err(name, "lseek SEEK_HOLE on memfd");
+					pr_fail_err("lseek SEEK_HOLE on memfd");
 			}
 #endif
 #if defined(SEEK_DATA)
 			if (lseek(fds[i], (off_t)0, SEEK_DATA) < 0) {
 				if (errno != ENXIO)
-					pr_fail_err(name, "lseek SEEK_DATA on memfd");
+					pr_fail_err("lseek SEEK_DATA on memfd");
 			}
 #endif
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				goto clean;
 		}
 clean:
-		for (i = 0; i < MAX_MEM_FDS; i++) {
+		for (i = 0; i < opt_memfd_fds; i++) {
 			if (maps[i] != MAP_FAILED)
 				(void)munmap(maps[i], size);
 			if (fds[i] >= 0)
 				(void)close(fds[i]);
 		}
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 }
 
 
@@ -182,92 +200,84 @@ clean:
  *  stress_memfd()
  *	stress memfd
  */
-int stress_memfd(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_memfd(const args_t *args)
 {
 	pid_t pid;
 	uint32_t ooms = 0, segvs = 0, nomems = 0;
 
 	if (!set_memfd_bytes) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_memfd_bytes = MAX_MEMFD_BYTES;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_memfd_bytes = MIN_MEMFD_BYTES;
 	}
 
 again:
-	if (!opt_do_run)
+	if (!g_keep_stressing_flag)
 		return EXIT_SUCCESS;
 	pid = fork();
 	if (pid < 0) {
 		if (errno == EAGAIN)
 			goto again;
-		pr_err(stderr, "%s: fork failed: errno=%d: (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: fork failed: errno=%d: (%s)\n",
+			args->name, errno, strerror(errno));
 	} else if (pid > 0) {
 		int status, ret;
 
-		(void)setpgid(pid, pgrp);
+		(void)setpgid(pid, g_pgrp);
 		stress_parent_died_alarm();
 
 		/* Parent, wait for child */
 		ret = waitpid(pid, &status, 0);
 		if (ret < 0) {
 			if (errno != EINTR)
-				pr_dbg(stderr, "%s: waitpid(): errno=%d (%s)\n",
-					name, errno, strerror(errno));
+				pr_dbg("%s: waitpid(): errno=%d (%s)\n",
+					args->name, errno, strerror(errno));
 			(void)kill(pid, SIGTERM);
 			(void)kill(pid, SIGKILL);
 			(void)waitpid(pid, &status, 0);
 		} else if (WIFSIGNALED(status)) {
-			pr_dbg(stderr, "%s: child died: %s (instance %d)\n",
-				name, stress_strsignal(WTERMSIG(status)), instance);
+			pr_dbg("%s: child died: %s (instance %d)\n",
+				args->name, stress_strsignal(WTERMSIG(status)), args->instance);
 			/* If we got killed by OOM killer, re-start */
 			if ((WTERMSIG(status) == SIGKILL) ||
 			    (WTERMSIG(status) == SIGSEGV)) {
 				log_system_mem_info();
-				pr_dbg(stderr, "%s: assuming killed by OOM killer, "
+				pr_dbg("%s: assuming killed by OOM killer, "
 					"restarting again (instance %d)\n",
-					name, instance);
+					args->name, args->instance);
 				ooms++;
 				goto again;
 			}
 
 		} else if (WTERMSIG(status) == SIGSEGV) {
-			pr_dbg(stderr, "%s: killed by SIGSEGV, "
+			pr_dbg("%s: killed by SIGSEGV, "
 				"restarting again "
 				"(instance %d)\n",
-				name, instance);
+				args->name, args->instance);
 			segvs++;
 			goto again;
 		}
 	} else if (pid == 0) {
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 
 		/* Make sure this is killable by OOM killer */
-		set_oom_adjustment(name, true);
+		set_oom_adjustment(args->name, true);
 
-		stress_memfd_allocs(name, counter, max_ops);
+		stress_memfd_allocs(args);
 	}
 
 	if (ooms + segvs + nomems > 0)
-		pr_dbg(stderr, "%s: OOM restarts: %" PRIu32
+		pr_dbg("%s: OOM restarts: %" PRIu32
 			", SEGV restarts: %" PRIu32
 			", out of memory restarts: %" PRIu32 ".\n",
-			name, ooms, segvs, nomems);
+			args->name, ooms, segvs, nomems);
 
 	return EXIT_SUCCESS;
 }
 #else
-int stress_memfd(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_memfd(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
