@@ -32,31 +32,25 @@
  *  stress_mincore()
  *	stress mincore system call
  */
-int stress_mincore(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_mincore(const args_t *args)
 {
 	uint8_t *addr = 0;
-	const size_t page_size = stress_get_pagesize();
+	const size_t page_size = args->page_size;
 	const ptrdiff_t mask = ~(page_size - 1);
 
-	(void)instance;
-
 	do {
 		int i;
 
-		for (i = 0; (i < 100) && opt_do_run; i++) {
+		for (i = 0; (i < 100) && g_keep_stressing_flag; i++) {
 			int ret, redo = 0;
 			unsigned char vec[1];
 
-			if (opt_flags & OPT_FLAGS_MINCORE_RAND)
+			if (g_opt_flags & OPT_FLAGS_MINCORE_RAND)
 				if (addr < (uint8_t *)page_size)
 					addr = (uint8_t *)((ptrdiff_t)(mwc64() & mask));
 redo:
 			errno = 0;
-			ret = mincore((void *)addr, page_size, vec);
+			ret = shim_mincore((void *)addr, page_size, vec);
 			if (ret < 0) {
 				switch (errno) {
 				case ENOMEM:
@@ -67,29 +61,26 @@ redo:
 						goto redo;
 					/* fall through */
 				default:
-					pr_fail(stderr, "%s: mincore on address %p error: %d %s\n ",
-						name, addr, errno, strerror(errno));
+					pr_fail("%s: mincore on address %p error: %d %s\n ",
+						args->name, addr, errno,
+						strerror(errno));
 					return EXIT_FAILURE;
 				}
 			}
-			if (opt_flags & OPT_FLAGS_MINCORE_RAND)
+			if (g_opt_flags & OPT_FLAGS_MINCORE_RAND)
 				addr = (uint8_t *)(ptrdiff_t)
 					(((ptrdiff_t)addr >> 1) & mask);
 			else
 				addr += page_size;
 		}
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
 	return EXIT_SUCCESS;
 }
 #else
-int stress_mincore(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_mincore(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
