@@ -41,10 +41,8 @@ static const int modes[] = {
  *	remove all files
  */
 static void stress_mknod_tidy(
-	const uint64_t n,
-	const char *name,
-	const pid_t pid,
-	const uint64_t instance)
+	const args_t *args,
+	const uint64_t n)
 {
 	uint64_t i;
 
@@ -52,8 +50,8 @@ static void stress_mknod_tidy(
 		char path[PATH_MAX];
 		uint64_t gray_code = (i >> 1) ^ i;
 
-		(void)stress_temp_filename(path, sizeof(path),
-			name, pid, instance, gray_code);
+		(void)stress_temp_filename_args(args,
+			path, sizeof(path), gray_code);
 		(void)unlink(path);
 	}
 }
@@ -62,22 +60,17 @@ static void stress_mknod_tidy(
  *  stress_mknod
  *	stress mknod creates
  */
-int stress_mknod(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_mknod(const args_t *args)
 {
-	const pid_t pid = getpid();
 	const size_t num_nodes = SIZEOF_ARRAY(modes);
 	int ret;
 
 	if (num_nodes == 0) {
-		pr_err(stderr, "%s: aborting, no valid mknod modes.\n",
-			name);
+		pr_err("%s: aborting, no valid mknod modes.\n",
+			args->name);
 		return EXIT_FAILURE;
 	}
-	ret = stress_temp_dir_mk(name, pid, instance);
+	ret = stress_temp_dir_mk_args(args);
 	if (ret < 0)
 		return exit_status(-ret);
 
@@ -89,33 +82,32 @@ int stress_mknod(
 			uint64_t gray_code = (i >> 1) ^ i;
 			int mode = modes[mwc32() % num_nodes];
 
-			(void)stress_temp_filename(path, sizeof(path),
-				name, pid, instance, gray_code);
+			(void)stress_temp_filename_args(args,
+				path, sizeof(path), gray_code);
 			if (mknod(path, mode | S_IRUSR | S_IWUSR, 0) < 0) {
 				if ((errno == ENOSPC) || (errno == ENOMEM))
 					continue;	/* Try again */
-				pr_fail_err(name, "mknod");
+				pr_fail_err("mknod");
 				n = i;
 				break;
 			}
 
-			if (!opt_do_run ||
-			    (max_ops && *counter >= max_ops))
+			if (!keep_stressing())
 				goto abort;
 
-			(*counter)++;
+			inc_counter(args);
 		}
-		stress_mknod_tidy(n, name, pid, instance);
-		if (!opt_do_run)
+		stress_mknod_tidy(args, n);
+		if (!g_keep_stressing_flag)
 			break;
 		sync();
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (keep_stressing());
 
 abort:
 	/* force unlink of all files */
-	pr_tidy(stderr, "%s: removing %" PRIu32 " nodes\n", name, DEFAULT_DIRS);
-	stress_mknod_tidy(DEFAULT_DIRS, name, pid, instance);
-	(void)stress_temp_dir_rm(name, pid, instance);
+	pr_tidy("%s: removing %" PRIu32 " nodes\n", args->name, DEFAULT_DIRS);
+	stress_mknod_tidy(args, DEFAULT_DIRS);
+	(void)stress_temp_dir_rm_args(args);
 
 	return EXIT_SUCCESS;
 }
