@@ -35,12 +35,12 @@
 #endif
 
 /*
- *  mlock_shim()
+ *  do_mlock()
  *	if mlock2 is available, randonly exerise this
  *	or mlock.  If not available, just fallback to
  *	mlock.  Also, pick random mlock2 flags
  */
-static int mlock_shim(const void *addr, size_t len)
+static int do_mlock(const void *addr, size_t len)
 {
 	static bool use_mlock2 = true;
 
@@ -67,9 +67,9 @@ static int mlock_shim(const void *addr, size_t len)
 	return mlock((const void *)addr, len);
 }
 #else
-static inline int mlock_shim(const void *addr, size_t len)
+static inline int do_mlock(const void *addr, size_t len)
 {
-	return mlock((void *)addr, len);
+	return mlock((const void *)addr, len);
 }
 #endif
 
@@ -78,77 +78,74 @@ static inline int mlock_shim(const void *addr, size_t len)
  *  stress_mlock()
  *	stress mlock with pages being locked/unlocked
  */
-int stress_mlock(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_mlock(const args_t *args)
 {
-	const size_t page_size = stress_get_pagesize();
+	const size_t page_size = args->page_size;
 	pid_t pid;
 	size_t max = sysconf(_SC_MAPPED_FILES);
 	uint8_t **mappings;
 	max = max > MLOCK_MAX ? MLOCK_MAX : max;
 
 	if ((mappings = calloc(max, sizeof(uint8_t *))) == NULL) {
-		pr_fail_dbg(name, "malloc");
+		pr_fail_dbg("malloc");
 		return EXIT_NO_RESOURCE;
 	}
 again:
 	pid = fork();
 	if (pid < 0) {
-		if (opt_do_run && (errno == EAGAIN))
+		if (g_keep_stressing_flag && (errno == EAGAIN))
 			goto again;
-		pr_err(stderr, "%s: fork failed: errno=%d: (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: fork failed: errno=%d: (%s)\n",
+			args->name, errno, strerror(errno));
 	} else if (pid > 0) {
 		int status, ret;
 
-		(void)setpgid(pid, pgrp);
+		(void)setpgid(pid, g_pgrp);
 		stress_parent_died_alarm();
 
 		/* Parent, wait for child */
 		ret = waitpid(pid, &status, 0);
 		if (ret < 0) {
 			if (errno != EINTR)
-				pr_dbg(stderr, "%s: waitpid(): errno=%d (%s)\n",
-					name, errno, strerror(errno));
+				pr_dbg("%s: waitpid(): errno=%d (%s)\n",
+					args->name, errno, strerror(errno));
 			(void)kill(pid, SIGTERM);
 			(void)kill(pid, SIGKILL);
 			(void)waitpid(pid, &status, 0);
 		} else if (WIFSIGNALED(status)) {
-			pr_dbg(stderr, "%s: child died: %s (instance %d)\n",
-				name, stress_strsignal(WTERMSIG(status)),
-				instance);
+			pr_dbg("%s: child died: %s (instance %d)\n",
+				args->name, stress_strsignal(WTERMSIG(status)),
+				args->instance);
 			/* If we got killed by OOM killer, re-start */
 			if (WTERMSIG(status) == SIGKILL) {
 				log_system_mem_info();
-				pr_dbg(stderr, "%s: assuming killed by OOM "
+				pr_dbg("%s: assuming killed by OOM "
 					"killer, restarting again "
-					"(instance %d)\n", name, instance);
+					"(instance %d)\n", args->name,
+					args->instance);
 				goto again;
 			}
 			/* If we got killed by sigsegv, re-start */
 			if (WTERMSIG(status) == SIGSEGV) {
-				pr_dbg(stderr, "%s: killed by SIGSEGV, "
+				pr_dbg("%s: killed by SIGSEGV, "
 					"restarting again "
 					"(instance %d)\n",
-					name, instance);
+					args->name, args->instance);
 				goto again;
 			}
 		}
 	} else if (pid == 0) {
 		size_t i, n;
 
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 
 		/* Make sure this is killable by OOM killer */
-		set_oom_adjustment(name, true);
+		set_oom_adjustment(args->name, true);
 
 		do {
-			for (n = 0; opt_do_run && (n < max); n++) {
+			for (n = 0; g_keep_stressing_flag && (n < max); n++) {
 				int ret;
-				if (!opt_do_run || (max_ops && *counter >= max_ops))
+				if (!keep_stressing())
 					break;
 
 				mappings[n] = (uint8_t *)mmap(NULL, page_size * 3,
@@ -156,13 +153,13 @@ again:
 					MAP_SHARED | MAP_ANONYMOUS, -1, 0);
 				if (mappings[n] == MAP_FAILED)
 					break;
-				ret = mlock_shim((void *)(mappings[n] + page_size), page_size);
+				ret = do_mlock((void *)(mappings[n] + page_size), page_size);
 				if (ret < 0) {
 					if (errno == EAGAIN)
 						continue;
 					if (errno == ENOMEM)
 						break;
-					pr_fail_err(name, "mlock");
+					pr_fail_err("mlock");
 					break;
 				} else {
 					/*
@@ -173,7 +170,7 @@ again:
 				 	 */
 					mappings[n] = (uint8_t *)
 						((ptrdiff_t)mappings[n] | 1);
-					(*counter)++;
+					inc_counter(args);
 				}
 			}
 
@@ -186,15 +183,17 @@ again:
 					(void)munlock((void *)((uint8_t *)addr + page_size), page_size);
 				munmap((void *)addr, page_size * 3);
 			}
-#if !defined(__gnu_hurd__)
-			(void)mlockall(MCL_CURRENT);
-			(void)mlockall(MCL_FUTURE);
+#if defined(MCL_CURRENT)
+			(void)shim_mlockall(MCL_CURRENT);
+#endif
+#if defined(MCL_FUTURE)
+			(void)shim_mlockall(MCL_FUTURE);
+#endif
 #if defined(MCL_ONFAULT)
-			(void)mlockall(MCL_ONFAULT);
+			(void)shim_mlockall(MCL_ONFAULT);
 #endif
-#endif
-			for (n = 0; opt_do_run && (n < max); n++) {
-				if (!opt_do_run || (max_ops && *counter >= max_ops))
+			for (n = 0; g_keep_stressing_flag && (n < max); n++) {
+				if (!keep_stressing())
 					break;
 
 				mappings[n] = (uint8_t *)mmap(NULL, page_size,
@@ -203,12 +202,11 @@ again:
 				if (mappings[n] == MAP_FAILED)
 					break;
 			}
-#if !defined(__gnu_hurd__)
-			(void)munlockall();
-#endif
+			(void)shim_munlockall();
+
 			for (i = 0; i < n;  i++)
 				munmap((void *)mappings[i], page_size);
-		} while (opt_do_run && (!max_ops || *counter < max_ops));
+		} while (keep_stressing());
 	}
 
 	free(mappings);
@@ -216,12 +214,8 @@ again:
 	return EXIT_SUCCESS;
 }
 #else
-int stress_mlock(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_mlock(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
