@@ -70,11 +70,7 @@ static void __strncat(char *dst, char *src, size_t *n)
  *  stress_mmapfork()
  *	stress mappings + fork VM subystem
  */
-int stress_mmapfork(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_mmapfork(const args_t *args)
 {
 	pid_t pids[MAX_PIDS];
 	struct sysinfo info;
@@ -83,8 +79,6 @@ int stress_mmapfork(
 	int32_t instances;
 	int8_t segv_reasons = 0;
 
-	(void)instance;
-
 	if ((instances = stressor_instances(STRESS_MMAPFORK)) < 1)
 		instances = stress_get_processors_configured();
 
@@ -94,7 +88,7 @@ int stress_mmapfork(
 		memset(pids, 0, sizeof(pids));
 
 		for (n = 0; n < MAX_PIDS; n++) {
-retry:			if (!opt_do_run)
+retry:			if (!g_keep_stressing_flag)
 				goto reap;
 
 			pids[n] = fork();
@@ -108,14 +102,14 @@ retry:			if (!opt_do_run)
 			}
 			if (pids[n] == 0) {
 				/* Child */
-				(void)setpgid(0, pgrp);
+				(void)setpgid(0, g_pgrp);
 				stress_parent_died_alarm();
 
-				if (stress_sighandler(name, SIGSEGV, stress_segvhandler, NULL) < 0)
+				if (stress_sighandler(args->name, SIGSEGV, stress_segvhandler, NULL) < 0)
 					_exit(_EXIT_FAILURE);
 
 				if (sysinfo(&info) < 0) {
-					pr_fail_err(name, "sysinfo");
+					pr_fail_err("sysinfo");
 					_exit(_EXIT_FAILURE);
 				}
 
@@ -125,20 +119,20 @@ retry:			if (!opt_do_run)
 					MAP_POPULATE | MAP_SHARED | MAP_ANONYMOUS, -1, 0);
 				if (ptr != MAP_FAILED) {
 					segv_ret = _EXIT_SEGV_MADV_WILLNEED;
-					madvise(ptr, len, MADV_WILLNEED);
+					(void)shim_madvise(ptr, len, MADV_WILLNEED);
 
 					segv_ret = _EXIT_SEGV_MEMSET;
 					memset(ptr, 0, len);
 
 					segv_ret = _EXIT_SEGV_MADV_DONTNEED;
-					madvise(ptr, len, MADV_DONTNEED);
+					(void)shim_madvise(ptr, len, MADV_DONTNEED);
 
 					segv_ret = _EXIT_SEGV_MUNMAP;
 					munmap(ptr, len);
 				}
 				_exit(EXIT_SUCCESS);
 			}
-			(void)setpgid(pids[n], pgrp);
+			(void)setpgid(pids[n], g_pgrp);
 		}
 reap:
 		for (i = 0; i < n; i++) {
@@ -146,8 +140,8 @@ reap:
 
 			if (waitpid(pids[i], &status, 0) < 0) {
 				if (errno != EINTR) {
-					pr_err(stderr, "%s: waitpid errno=%d (%s)\n",
-						name, errno, strerror(errno));
+					pr_err("%s: waitpid errno=%d (%s)\n",
+						args->name, errno, strerror(errno));
 				}
 			} else {
 				if (WIFEXITED(status)) {
@@ -160,8 +154,8 @@ reap:
 				}
 			}
 		}
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
 	if (segv_count) {
 		char buffer[1024];
@@ -180,19 +174,15 @@ reap:
 		if (segv_reasons & _EXIT_SEGV_MUNMAP)
 			__strncat(buffer, " munmap", &n);
 
-		pr_dbg(stderr, "%s: SIGSEGV errors: %" PRIu64 " (where:%s)\n",
-			name, segv_count, buffer);
+		pr_dbg("%s: SIGSEGV errors: %" PRIu64 " (where:%s)\n",
+			args->name, segv_count, buffer);
 	}
 
 	return EXIT_SUCCESS;
 }
 #else
-int stress_mmapfork(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_mmapfork(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
