@@ -30,79 +30,76 @@
  *  stress_mmapmany()
  *	stress mmap with many pages being mapped
  */
-int stress_mmapmany(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_mmapmany(const args_t *args)
 {
-	const size_t page_size = stress_get_pagesize();
+	const size_t page_size = args->page_size;
 	pid_t pid;
 	ssize_t max = sysconf(_SC_MAPPED_FILES);
 	uint8_t **mappings;
 	max = STRESS_MAXIMUM(max, MMAP_MAX);
 
 	if (max < 1) {
-		pr_fail_dbg(name, "sysconf(_SC_MAPPED_FILES)");
+		pr_fail_dbg("sysconf(_SC_MAPPED_FILES)");
 		return EXIT_NO_RESOURCE;
 	}
 	if ((mappings = calloc(max, sizeof(uint8_t *))) == NULL) {
-		pr_fail_dbg(name, "malloc");
+		pr_fail_dbg("malloc");
 		return EXIT_NO_RESOURCE;
 	}
 again:
 	pid = fork();
 	if (pid < 0) {
-		if (opt_do_run && (errno == EAGAIN))
+		if (g_keep_stressing_flag && (errno == EAGAIN))
 			goto again;
-		pr_err(stderr, "%s: fork failed: errno=%d: (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: fork failed: errno=%d: (%s)\n",
+			args->name, errno, strerror(errno));
 	} else if (pid > 0) {
 		int status, ret;
 
-		(void)setpgid(pid, pgrp);
+		(void)setpgid(pid, g_pgrp);
 
 		/* Parent, wait for child */
 		ret = waitpid(pid, &status, 0);
 		if (ret < 0) {
 			if (errno != EINTR)
-				pr_dbg(stderr, "%s: waitpid(): errno=%d (%s)\n",
-					name, errno, strerror(errno));
+				pr_dbg("%s: waitpid(): errno=%d (%s)\n",
+					args->name, errno, strerror(errno));
 			(void)kill(pid, SIGTERM);
 			(void)kill(pid, SIGKILL);
 			(void)waitpid(pid, &status, 0);
 		} else if (WIFSIGNALED(status)) {
-			pr_dbg(stderr, "%s: child died: %s (instance %d)\n",
-				name, stress_strsignal(WTERMSIG(status)),
-				instance);
+			pr_dbg("%s: child died: %s (instance %d)\n",
+				args->name, stress_strsignal(WTERMSIG(status)),
+				args->instance);
 			/* If we got killed by OOM killer, re-start */
 			if (WTERMSIG(status) == SIGKILL) {
-				pr_dbg(stderr, "%s: assuming killed by OOM "
+				pr_dbg("%s: assuming killed by OOM "
 					"killer, restarting again "
-					"(instance %d)\n", name, instance);
+					"(instance %d)\n", args->name,
+					args->instance);
 				goto again;
 			}
 			/* If we got killed by sigsegv, re-start */
 			if (WTERMSIG(status) == SIGSEGV) {
-				pr_dbg(stderr, "%s: killed by SIGSEGV, "
+				pr_dbg("%s: killed by SIGSEGV, "
 					"restarting again "
 					"(instance %d)\n",
-					name, instance);
+					args->name, args->instance);
 				goto again;
 			}
 		}
 	} else if (pid == 0) {
 		ssize_t i, n;
 
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
 
 		/* Make sure this is killable by OOM killer */
-		set_oom_adjustment(name, true);
+		set_oom_adjustment(args->name, true);
 
 		do {
-			for (n = 0; opt_do_run && (n < max); n++) {
-				if (!opt_do_run || (max_ops && *counter >= max_ops))
+			for (n = 0; g_keep_stressing_flag && (n < max); n++) {
+				if (!keep_stressing())
 					break;
 
 				mappings[n] = (uint8_t *)mmap(NULL,
@@ -113,7 +110,7 @@ again:
 					break;
 				if (munmap((void *)(mappings[n] + page_size), page_size) < 0)
 					break;
-				(*counter)++;
+				inc_counter(args);
 			}
 
 			for (i = 0; i < n;  i++) {
@@ -121,7 +118,7 @@ again:
 				munmap((void *)(mappings[i] + page_size), page_size);
 				munmap((void *)(mappings[i] + page_size + page_size), page_size);
 			}
-		} while (opt_do_run && (!max_ops || *counter < max_ops));
+		} while (keep_stressing());
 	}
 
 	free(mappings);
