@@ -36,12 +36,12 @@ typedef struct {
 static int opt_mq_size = DEFAULT_MQ_SIZE;
 static bool set_mq_size = false;
 
-void stress_set_mq_size(const char *optarg)
+void stress_set_mq_size(const char *opt)
 {
 	uint64_t sz;
 
 	set_mq_size = true;
-	sz = get_uint64_byte(optarg);
+	sz = get_uint64_byte(opt);
 	opt_mq_size = (int)sz;
 	check_range("mq-size", sz, MIN_MQ_SIZE, MAX_MQ_SIZE);
 }
@@ -57,13 +57,9 @@ static void stress_mq_notify_func(union sigval s)
  *  stress_mq
  *	stress POSIX message queues
  */
-int stress_mq(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_mq(const args_t *args)
 {
-	pid_t pid = getpid();
+	pid_t pid;
 	mqd_t mq = -1;
 	int sz, max_sz;
 	FILE *fp;
@@ -74,15 +70,15 @@ int stress_mq(
 	struct timespec abs_timeout;
 
 	if (!set_mq_size) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_mq_size = MAX_MQ_SIZE;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_mq_size = MIN_MQ_SIZE;
 	}
 	sz = opt_mq_size;
 
-	snprintf(mq_name, sizeof(mq_name), "/%s-%i-%" PRIu32,
-		name, pid, instance);
+	(void)snprintf(mq_name, sizeof(mq_name), "/%s-%i-%" PRIu32,
+		args->name, args->pid, args->instance);
 	if ((fp = fopen("/proc/sys/fs/mqueue/msg_default", "r")) != NULL) {
 		if (fscanf(fp, "%20d", &max_sz) != 1)
 			max_sz = MAX_MQ_SIZE;
@@ -112,23 +108,23 @@ int stress_mq(
 		sz--;
 	}
 	if (mq < 0) {
-		pr_fail_dbg(name, "mq_open");
+		pr_fail_dbg("mq_open");
 		return EXIT_FAILURE;
 	}
 	if (sz < opt_mq_size) {
-		pr_inf(stdout, "%s: POSIX message queue requested "
+		pr_inf("%s: POSIX message queue requested "
 			"size %d messages, maximum of %d allowed\n",
-			name, opt_mq_size, sz);
+			args->name, opt_mq_size, sz);
 	}
-	pr_dbg(stderr, "POSIX message queue %s with %lu messages\n",
+	pr_dbg("POSIX message queue %s with %lu messages\n",
 		mq_name, (unsigned long)attr.mq_maxmsg);
 
 	if (time(&time_start) == ((time_t)-1)) {
 		do_timed = false;
-		pr_fail_dbg(name, "mq_timed send and receive skipped, can't get time");
+		pr_fail_dbg("mq_timed send and receive skipped, can't get time");
 	} else {
 		do_timed = true;
-		abs_timeout.tv_sec = time_start + opt_timeout + 1;
+		abs_timeout.tv_sec = time_start + g_opt_timeout + 1;
 		abs_timeout.tv_nsec = 0;
 	}
 
@@ -136,9 +132,9 @@ int stress_mq(
 again:
 	pid = fork();
 	if (pid < 0) {
-		if (opt_do_run && (errno == EAGAIN))
+		if (g_keep_stressing_flag && (errno == EAGAIN))
 			goto again;
-		pr_fail_dbg(name, "fork");
+		pr_fail_dbg("fork");
 		return EXIT_FAILURE;
 	} else if (pid == 0) {
 		struct sigevent sigev;
@@ -148,10 +144,10 @@ again:
 		sigev.sigev_notify_function = stress_mq_notify_func;
 		sigev.sigev_notify_attributes = NULL;
 
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
 
-		while (opt_do_run) {
+		while (g_keep_stressing_flag) {
 			uint64_t i = 0;
 
 			for (;;) {
@@ -171,17 +167,17 @@ again:
 					ret = mq_receive(mq, (char *)&msg, sizeof(msg), NULL);
 
 				if (ret < 0) {
-					pr_fail_dbg(name, timed ? "mq_timedreceive" : "mq_receive");
+					pr_fail_dbg(timed ? "mq_timedreceive" : "mq_receive");
 					break;
 				}
 				if (msg.stop)
 					break;
-				if (opt_flags & OPT_FLAGS_VERIFY) {
+				if (g_opt_flags & OPT_FLAGS_VERIFY) {
 					if (msg.value != i) {
-						pr_fail(stderr, "%s: mq_receive: expected message "
+						pr_fail("%s: mq_receive: expected message "
 							"containing 0x%" PRIx64
 							" but received 0x%" PRIx64 " instead\n",
-							name, i, msg.value);
+							args->name, i, msg.value);
 					}
 				}
 				i++;
@@ -195,18 +191,18 @@ again:
 		msg_t msg;
 
 		/* Parent */
-		(void)setpgid(pid, pgrp);
+		(void)setpgid(pid, g_pgrp);
 
 		do {
 			int ret;
 			const uint64_t timed = (i & 1);
 
 			memset(&msg, 0, sizeof(msg));
-			msg.value = (*counter);
+			msg.value = (*args->counter);
 			msg.stop = false;
 			if ((attr_count++ & 31) == 0) {
 				if (mq_getattr(mq, &attr) < 0)
-					pr_fail_dbg(name, "mq_getattr");
+					pr_fail_dbg("mq_getattr");
 			}
 
 			/*
@@ -219,36 +215,32 @@ again:
 
 			if (ret < 0) {
 				if (errno != EINTR)
-					pr_fail_dbg(name, timed ? "mq_timedsend" : "mq_send");
+					pr_fail_dbg(timed ? "mq_timedsend" : "mq_send");
 				break;
 			}
 			i++;
-			(*counter)++;
-		} while (opt_do_run && (!max_ops || *counter < max_ops));
+			inc_counter(args);
+		} while (keep_stressing());
 
-		msg.value = (*counter);
+		msg.value = (*args->counter);
 		msg.stop = true;
 
 		if (mq_send(mq, (char *)&msg, sizeof(msg), 1) < 0) {
-			pr_fail_dbg(name, "termination mq_send");
+			pr_fail_dbg("termination mq_send");
 		}
 		(void)kill(pid, SIGKILL);
 		(void)waitpid(pid, &status, 0);
 
 		if (mq_close(mq) < 0)
-			pr_fail_dbg(name, "mq_close");
+			pr_fail_dbg("mq_close");
 		if (mq_unlink(mq_name) < 0)
-			pr_fail_dbg(name, "mq_unlink");
+			pr_fail_dbg("mq_unlink");
 	}
 	return EXIT_SUCCESS;
 }
 #else
-int stress_mq(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_mq(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
