@@ -28,17 +28,10 @@
  *  stress on sched_nice()
  *	stress system by sched_nice
  */
-int stress_nice(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_nice(const args_t *args)
 {
 	int max_prio, min_prio;
 
-	(void)instance;
-	(void)name;
-
 #if defined(RLIMIT_NICE)
 	{
 		struct rlimit rlim;
@@ -66,7 +59,7 @@ int stress_nice(
 			int i;
 
 			/* Child */
-			(void)setpgid(0, pgrp);
+			(void)setpgid(0, g_pgrp);
 			stress_parent_died_alarm();
 
 			pid = getpid();
@@ -79,7 +72,7 @@ int stress_nice(
 
 					while (time_now() - start < delay)
 						;
-					(*counter)++;
+					inc_counter(args);
 				}
 			}
 			_exit(0);
@@ -87,7 +80,7 @@ int stress_nice(
 		if (pid > 0) {
 			int status;
 
-			(void)setpgid(pid, pgrp);
+			(void)setpgid(pid, g_pgrp);
 
 			/* Parent, wait for child */
 			if (waitpid(pid, &status, 0) < 0) {
@@ -95,7 +88,7 @@ int stress_nice(
 				(void)kill(pid, SIGKILL);
 			}
 		}
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (keep_stressing());
 
 	return EXIT_SUCCESS;
 }
