@@ -28,39 +28,48 @@
  *  stress_null
  *	stress writing to /dev/null
  */
-int stress_null(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_null(const args_t *args)
 {
 	int fd;
 	char buffer[4096];
 
-	(void)instance;
-
-	if ((fd = open("/dev/null", O_WRONLY)) < 0) {
-		pr_fail_err(name, "open");
+	if ((fd = open("/dev/null", O_RDWR)) < 0) {
+		pr_fail_err("open");
 		return EXIT_FAILURE;
 	}
 
 	memset(buffer, 0xff, sizeof(buffer));
 	do {
 		ssize_t ret;
+#if defined(__linux__)
+		void *ptr;
+		const size_t page_size = args->page_size;
+#endif
 
 		ret = write(fd, buffer, sizeof(buffer));
 		if (ret <= 0) {
 			if ((errno == EAGAIN) || (errno == EINTR))
 				continue;
 			if (errno) {
-				pr_fail_err(name, "write");
+				pr_fail_err("write");
 				(void)close(fd);
 				return EXIT_FAILURE;
 			}
 			continue;
 		}
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+
+#if defined(__linux__)
+		ptr = mmap(NULL, page_size, PROT_WRITE,
+			MAP_PRIVATE | MAP_ANONYMOUS, fd, mwc64() & ~(page_size - 1));
+		if (ptr != MAP_FAILED) {
+			memset(ptr, mwc8(), page_size);
+			shim_msync(ptr, page_size, MS_SYNC);
+			(void)munmap(ptr, page_size);
+		}
+#endif
+
+		inc_counter(args);
+	} while (keep_stressing());
 	(void)close(fd);
 
 	return EXIT_SUCCESS;
