@@ -192,39 +192,34 @@ static int stress_numa_get_mem_nodes(node_t **node_ptr)
  *  stress_numa()
  *	stress the Linux NUMA interfaces
  */
-int stress_numa(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_numa(const args_t *args)
 {
 	long numa_nodes;
 	unsigned long max_nodes;
 	const unsigned long lbits = NUMA_LONG_BITS;
-	const unsigned long page_sz = stress_get_pagesize();
+	const unsigned long page_sz = args->page_size;
 	const unsigned long num_pages = MMAP_SZ / page_sz;
 	uint8_t *buf;
 	node_t *n;
-	const pid_t mypid = getpid();
 	int rc = EXIT_FAILURE;
 
 	numa_nodes = stress_numa_get_mem_nodes(&n);
 	if (numa_nodes < 1) {
-		pr_inf(stdout, "%s: no NUMA nodes not found, "
-			"aborting test\n", name);
+		pr_inf("%s: no NUMA nodes not found, "
+			"aborting test\n", args->name);
 		rc = EXIT_NO_RESOURCE;
 		goto numa_free;
 	}
 	max_nodes = stress_numa_get_max_nodes();
 	if (max_nodes == 0) {
-		pr_inf(stderr, "%s: cannot determine maximum number "
-			"of NUMA nodes, aborting test\n", name);
+		pr_inf("%s: cannot determine maximum number "
+			"of NUMA nodes, aborting test\n", args->name);
 		rc = EXIT_NO_RESOURCE;
 		goto numa_free;
 	}
-	if (!instance) {
-		pr_inf(stdout, "%s: system has %lu of a maximum %lu memory NUMA nodes\n",
-			name, numa_nodes, max_nodes);
+	if (!args->instance) {
+		pr_inf("%s: system has %lu of a maximum %lu memory NUMA nodes\n",
+			args->name, numa_nodes, max_nodes);
 	}
 
 	/*
@@ -234,8 +229,8 @@ int stress_numa(
 		MAP_ANONYMOUS | MAP_PRIVATE, 0, 0);
 	if (buf == MAP_FAILED) {
 		rc = exit_status(errno);
-		pr_fail(stderr, "%s: mmap'd region of %zu bytes failed",
-			name, (size_t)MMAP_SZ);
+		pr_fail("%s: mmap'd region of %zu bytes failed",
+			args->name, (size_t)MMAP_SZ);
 		goto numa_free;
 	}
 
@@ -253,19 +248,19 @@ int stress_numa(
 		ret = shim_get_mempolicy(&mode, node_mask, max_nodes,
 			(unsigned long)buf, MPOL_F_ADDR);
 		if (ret < 0) {
-			pr_fail_err(name, "get_mempolicy");
+			pr_fail_err("get_mempolicy");
 			goto err;
 		}
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 
 		ret = shim_set_mempolicy(MPOL_PREFERRED, NULL, max_nodes);
 		if (ret < 0) {
-			pr_fail_err(name, "set_mempolicy");
+			pr_fail_err("set_mempolicy");
 			goto err;
 		}
 		memset(buf, 0xff, MMAP_SZ);
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 
 		/*
@@ -284,13 +279,13 @@ int stress_numa(
 			max_nodes, MPOL_MF_STRICT);
 		if (ret < 0) {
 			if (errno != EIO) {
-				pr_fail_err(name, "mbind");
+				pr_fail_err("mbind");
 				goto err;
 			}
 		} else {
 			memset(buf, 0xaa, MMAP_SZ);
 		}
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 
 		/*
@@ -302,13 +297,13 @@ int stress_numa(
 			max_nodes, MPOL_DEFAULT);
 		if (ret < 0) {
 			if (errno != EIO) {
-				pr_fail_err(name, "mbind");
+				pr_fail_err("mbind");
 				goto err;
 			}
 		} else {
 			memset(buf, 0x5c, MMAP_SZ);
 		}
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 
 		/* Move to next node */
@@ -320,13 +315,13 @@ int stress_numa(
 		memset(old_node_mask, 0xff, sizeof(old_node_mask));
 		memset(node_mask, 0, sizeof(node_mask));
 		STRESS_SETBIT(node_mask, n->node_id);
-		ret = shim_migrate_pages(mypid, max_nodes,
+		ret = shim_migrate_pages(args->pid, max_nodes,
 			old_node_mask, node_mask);
 		if (ret < 0) {
-			pr_fail_err(name, "migrate_pages");
+			pr_fail_err("migrate_pages");
 			goto err;
 		}
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 
 		n_tmp = n;
@@ -339,18 +334,18 @@ int stress_numa(
 				dest_nodes[i] = n_tmp->node_id;
 			}
 			memset(status, 0, sizeof(status));
-			ret = shim_move_pages(mypid, num_pages, pages,
+			ret = shim_move_pages(args->pid, num_pages, pages,
 				dest_nodes, status, MPOL_MF_MOVE);
 			if (ret < 0) {
-				pr_fail_err(name, "move_pages");
+				pr_fail_err("move_pages");
 				goto err;
 			}
 			memset(buf, j, MMAP_SZ);
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				break;
 		}
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
 	rc = EXIT_SUCCESS;
 err:
@@ -361,12 +356,8 @@ numa_free:
 	return rc;
 }
 #else
-int stress_numa(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_numa(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
