@@ -36,10 +36,10 @@ static size_t opt_pipe_data_size = 512;
  *  stress_set_pipe_size()
  *	set pipe size in bytes
  */
-void stress_set_pipe_size(const char *optarg)
+void stress_set_pipe_size(const char *opt)
 {
-	opt_pipe_size = (size_t)get_uint64_byte(optarg);
-	check_range("pipe-size", opt_pipe_size, 4, 1024 * 1024);
+	opt_pipe_size = (size_t)get_uint64_byte(opt);
+	check_range_bytes("pipe-size", opt_pipe_size, 4, 1024 * 1024);
 }
 #endif
 
@@ -47,10 +47,10 @@ void stress_set_pipe_size(const char *optarg)
  *  stress_set_pipe_size()
  *	set pipe data write size in bytes
  */
-void stress_set_pipe_data_size(const char *optarg)
+void stress_set_pipe_data_size(const char *opt)
 {
-	opt_pipe_data_size = (size_t)get_uint64_byte(optarg);
-	check_range("pipe-data_size", opt_pipe_data_size,
+	opt_pipe_data_size = (size_t)get_uint64_byte(opt);
+	check_range_bytes("pipe-data_size", opt_pipe_data_size,
 		4, stress_get_pagesize());
 }
 
@@ -85,7 +85,7 @@ static inline int pipe_memchk(char *buf, char val, const size_t sz)
  *  pipe_change_size()
  *	see if we can change the pipe size
  */
-static void pipe_change_size(const char *name, const int fd)
+static void pipe_change_size(const args_t *args, const int fd)
 {
 #if defined(F_GETPIPE_SZ)
 	ssize_t sz;
@@ -94,24 +94,24 @@ static void pipe_change_size(const char *name, const int fd)
 		return;
 
 #if !(defined(__linux__) && NEED_GLIBC(2,9,0))
-	if (opt_pipe_size < stress_get_pagesize())
+	if (opt_pipe_size < args->page_size)
 		return;
 #endif
 	if (fcntl(fd, F_SETPIPE_SZ, opt_pipe_size) < 0) {
-		pr_err(stderr, "%s: cannot set pipe size, keeping "
+		pr_err("%s: cannot set pipe size, keeping "
 			"default pipe size, errno=%d (%s)\n",
-			name, errno, strerror(errno));
+			args->name, errno, strerror(errno));
 	}
 #if defined(F_GETPIPE_SZ)
 	/* Sanity check size */
 	if ((sz = fcntl(fd, F_GETPIPE_SZ)) < 0) {
-		pr_err(stderr, "%s: cannot get pipe size, errno=%d (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: cannot get pipe size, errno=%d (%s)\n",
+			args->name, errno, strerror(errno));
 	} else {
 		if ((size_t)sz != opt_pipe_size) {
-			pr_err(stderr, "%s: cannot set desired pipe size, "
+			pr_err("%s: cannot set desired pipe size, "
 				"pipe size=%zd, errno=%d (%s)\n",
-				name, sz, errno, strerror(errno));
+				args->name, sz, errno, strerror(errno));
 		}
 	}
 #endif
@@ -123,51 +123,45 @@ static void pipe_change_size(const char *name, const int fd)
  *  stress_pipe
  *	stress by heavy pipe I/O
  */
-int stress_pipe(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_pipe(const args_t *args)
 {
 	pid_t pid;
 	int pipefds[2];
 
-	(void)instance;
-
 #if defined(__linux__) && NEED_GLIBC(2,9,0)
 	if (pipe2(pipefds, O_DIRECT) < 0) {
-		pr_fail_dbg(name, "pipe2");
+		pr_fail_dbg("pipe2");
 		return EXIT_FAILURE;
 	}
 #else
 	if (pipe(pipefds) < 0) {
-		pr_fail_dbg(name, "pipe");
+		pr_fail_dbg("pipe");
 		return EXIT_FAILURE;
 	}
 #endif
 
 #if defined(F_SETPIPE_SZ)
-	pipe_change_size(name, pipefds[0]);
-	pipe_change_size(name, pipefds[1]);
+	pipe_change_size(args, pipefds[0]);
+	pipe_change_size(args, pipefds[1]);
 #endif
 
 again:
 	pid = fork();
 	if (pid < 0) {
-		if (opt_do_run && (errno == EAGAIN))
+		if (g_keep_stressing_flag && (errno == EAGAIN))
 			goto again;
 		(void)close(pipefds[0]);
 		(void)close(pipefds[1]);
-		pr_fail_dbg(name, "fork");
+		pr_fail_dbg("fork");
 		return EXIT_FAILURE;
 	} else if (pid == 0) {
 		int val = 0;
 
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
 
 		(void)close(pipefds[1]);
-		while (opt_do_run) {
+		while (g_keep_stressing_flag) {
 			char buf[opt_pipe_data_size];
 			ssize_t n;
 
@@ -176,18 +170,18 @@ again:
 				if ((errno == EAGAIN) || (errno == EINTR))
 					continue;
 				if (errno) {
-					pr_fail_dbg(name, "read");
+					pr_fail_dbg("read");
 					break;
 				}
-				pr_fail_dbg(name, "zero byte read");
+				pr_fail_dbg("zero byte read");
 				break;
 			}
 			if (!strcmp(buf, PIPE_STOP))
 				break;
-			if ((opt_flags & OPT_FLAGS_VERIFY) &&
+			if ((g_opt_flags & OPT_FLAGS_VERIFY) &&
 			    pipe_memchk(buf, val++, (size_t)n)) {
-				pr_fail(stderr, "%s: pipe read error detected, "
-					"failed to read expected data\n", name);
+				pr_fail("%s: pipe read error detected, "
+					"failed to read expected data\n", args->name);
 			}
 		}
 		(void)close(pipefds[0]);
@@ -197,7 +191,7 @@ again:
 		int val = 0, status;
 
 		/* Parent */
-		(void)setpgid(pid, pgrp);
+		(void)setpgid(pid, g_pgrp);
 		(void)close(pipefds[0]);
 
 		do {
@@ -209,18 +203,18 @@ again:
 				if ((errno == EAGAIN) || (errno == EINTR))
 					continue;
 				if (errno) {
-					pr_fail_dbg(name, "write");
+					pr_fail_dbg("write");
 					break;
 				}
 				continue;
 			}
-			(*counter)++;
-		} while (opt_do_run && (!max_ops || *counter < max_ops));
+			inc_counter(args);
+		} while (keep_stressing());
 
 		strncpy(buf, PIPE_STOP, opt_pipe_data_size);
 		if (write(pipefds[1], buf, sizeof(buf)) <= 0) {
 			if (errno != EPIPE)
-				pr_fail_dbg(name, "termination write");
+				pr_fail_dbg("termination write");
 		}
 		(void)kill(pid, SIGKILL);
 		(void)waitpid(pid, &status, 0);
