@@ -33,20 +33,20 @@
  *  pipe_read()
  *	read a pipe with some verification and checking
  */
-static int pipe_read(const char *name, const int fd, const int n)
+static int pipe_read(const args_t *args, const int fd, const int n)
 {
 	char buf[POLL_BUF];
 	ssize_t ret;
 
 redo:
-	if (!opt_do_run)
+	if (!g_keep_stressing_flag)
 		return -1;
 	ret = read(fd, buf, sizeof(buf));
-	if (opt_flags & OPT_FLAGS_VERIFY) {
+	if (g_opt_flags & OPT_FLAGS_VERIFY) {
 		if (ret < 0) {
 			if ((errno == EAGAIN) || (errno == EINTR))
 				goto redo;
-			pr_fail(stderr, "%s: pipe read error detected\n", name);
+			pr_fail("%s: pipe read error detected\n", args->name);
 			return ret;
 		}
 		if (ret > 0) {
@@ -54,9 +54,9 @@ redo:
 
 			for (i = 0; i < ret; i++) {
 				if (buf[i] != '0' + n) {
-					pr_fail(stderr, "%s: pipe read error, "
+					pr_fail("%s: pipe read error, "
 						"expecting different data on "
-						"pipe\n", name);
+						"pipe\n", args->name);
 					return ret;
 				}
 			}
@@ -69,22 +69,16 @@ redo:
  *  stress_poll()
  *	stress system by rapid polling system calls
  */
-int stress_poll(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_poll(const args_t *args)
 {
 	int pipefds[MAX_PIPES][2];
 	int i;
 	pid_t pid;
 	int rc = EXIT_SUCCESS;
 
-	(void)instance;
-
 	for (i = 0; i < MAX_PIPES; i++) {
 		if (pipe(pipefds[i]) < 0) {
-			pr_fail_dbg(name, "pipe");
+			pr_fail_dbg("pipe");
 			while (--i >= 0) {
 				(void)close(pipefds[i][0]);
 				(void)close(pipefds[i][1]);
@@ -96,16 +90,16 @@ int stress_poll(
 again:
 	pid = fork();
 	if (pid < 0) {
-		if (opt_do_run && (errno == EAGAIN))
+		if (g_keep_stressing_flag && (errno == EAGAIN))
 			goto again;
-		pr_fail_dbg(name, "fork");
+		pr_fail_dbg("fork");
 		rc = EXIT_FAILURE;
 		goto tidy;
 	}
 	else if (pid == 0) {
 		/* Child writer */
 
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
 
 		for (i = 0; i < MAX_PIPES; i++)
@@ -122,10 +116,10 @@ again:
 			if (ret < (ssize_t)sizeof(buf)) {
 				if ((errno == EAGAIN) || (errno == EINTR))
 					continue;
-				pr_fail_dbg(name, "write");
+				pr_fail_dbg("write");
 				goto abort;
 			}
-		 } while (opt_do_run && (!max_ops || *counter < max_ops));
+		 } while (keep_stressing());
 abort:
 		for (i = 0; i < MAX_PIPES; i++)
 			(void)close(pipefds[i][1]);
@@ -137,7 +131,7 @@ abort:
 		struct pollfd fds[MAX_PIPES];
 		fd_set rfds;
 
-		(void)setpgid(pid, pgrp);
+		(void)setpgid(pid, g_pgrp);
 
 		FD_ZERO(&rfds);
 		for (i = 0; i < MAX_PIPES; i++) {
@@ -154,54 +148,53 @@ abort:
 			struct timeval tv;
 			int ret;
 
-			if (!opt_do_run || (max_ops && *counter >= max_ops))
+			if (!keep_stressing())
 				break;
 
 			/* First, stress out poll */
 			ret = poll(fds, MAX_PIPES, 1);
-			if ((opt_flags & OPT_FLAGS_VERIFY) &&
+			if ((g_opt_flags & OPT_FLAGS_VERIFY) &&
 			    (ret < 0) && (errno != EINTR)) {
-				pr_fail_err(name, "poll");
+				pr_fail_err("poll");
 			}
 			if (ret > 0) {
 				for (i = 0; i < MAX_PIPES; i++) {
 					if (fds[i].revents == POLLIN) {
-						if (pipe_read(name, fds[i].fd, i) < 0)
+						if (pipe_read(args, fds[i].fd, i) < 0)
 							break;
 					}
 				}
-				(*counter)++;
+				inc_counter(args);
 			}
 
-			if (!opt_do_run || (max_ops && *counter >= max_ops))
+			if (!keep_stressing())
 				break;
 			/* Second, stress out select */
 			tv.tv_sec = 0;
 			tv.tv_usec = 20000;
 			ret = select(maxfd + 1, &rfds, NULL, NULL, &tv);
-			if ((opt_flags & OPT_FLAGS_VERIFY) &&
+			if ((g_opt_flags & OPT_FLAGS_VERIFY) &&
 			    (ret < 0) && (errno != EINTR)) {
-				pr_fail_err(name, "select");
+				pr_fail_err("select");
 			}
 			if (ret > 0) {
 				for (i = 0; i < MAX_PIPES; i++) {
 					if (FD_ISSET(pipefds[i][0], &rfds)) {
-						if (pipe_read(name, pipefds[i][0], i) < 0)
+						if (pipe_read(args, pipefds[i][0], i) < 0)
 							break;
 					}
 					FD_SET(pipefds[i][0], &rfds);
 				}
-				(*counter)++;
+				inc_counter(args);
 			}
-			if (!opt_do_run || (max_ops && *counter >= max_ops))
+			if (!keep_stressing())
 				break;
 			/*
 			 * Third, stress zero sleep, this is like
 			 * a select zero timeout
 			 */
 			(void)sleep(0);
-
-		} while (opt_do_run && (!max_ops || *counter < max_ops));
+		} while (keep_stressing());
 
 		(void)kill(pid, SIGKILL);
 		(void)waitpid(pid, &status, 0);
