@@ -30,6 +30,7 @@
 #define MAX_READ_THREADS	(4)
 
 typedef struct ctxt {
+	const args_t *args;
 	const char *path;
 	char *badbuf;
 	bool proc_write;
@@ -55,7 +56,7 @@ static inline void stress_proc_rw(const char *path, char *badbuf, const bool pro
 	 */
 	while (i < (4096 * PROC_BUF_SZ)) {
 		ssize_t sz = 1 + (mwc32() % sizeof(buffer));
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 		ret = read(fd, buffer, sz);
 		if (ret < 0)
@@ -115,7 +116,6 @@ static void *stress_proc_rw_thread(void *ctxt_ptr)
 {
 	static void *nowt = NULL;
 	uint8_t stack[SIGSTKSZ + STACK_ALIGNMENT];
-	stack_t ss;
 	ctxt_t *ctxt = (ctxt_t *)ctxt_ptr;
 
 	/*
@@ -131,14 +131,10 @@ static void *stress_proc_rw_thread(void *ctxt_ptr)
 	 *  so this is probably just totally unncessary.
 	 */
 	memset(stack, 0, sizeof(stack));
-	ss.ss_sp = (void *)align_address(stack, STACK_ALIGNMENT);
-	ss.ss_size = SIGSTKSZ;
-	ss.ss_flags = 0;
-	if (sigaltstack(&ss, NULL) < 0) {
-		pr_fail_err("pthread", "sigaltstack");
+	if (stress_sigaltstack(stack, SIGSTKSZ) < 0)
 		return &nowt;
-	}
-	while (keep_running && opt_do_run)
+
+	while (keep_running && g_keep_stressing_flag)
 		stress_proc_rw(ctxt->path, ctxt->badbuf, ctxt->proc_write);
 
 	return &nowt;
@@ -148,13 +144,14 @@ static void *stress_proc_rw_thread(void *ctxt_ptr)
  *  stress_proc_rw_threads()
  *	create a bunch of threads to thrash read a proc entry
  */
-static void stress_proc_rw_threads(char *path, const bool proc_write)
+static void stress_proc_rw_threads(const args_t *args, char *path, const bool proc_write)
 {
 	size_t i;
 	pthread_t pthreads[MAX_READ_THREADS];
 	int ret[MAX_READ_THREADS];
 	ctxt_t ctxt;
 
+	ctxt.args = args;
 	ctxt.path = path;
 	ctxt.proc_write = proc_write;
 	ctxt.badbuf = mmap(NULL, PROC_BUF_SZ, PROT_READ,
@@ -171,7 +168,7 @@ static void stress_proc_rw_threads(char *path, const bool proc_write)
 				stress_proc_rw_thread, &ctxt);
 	}
 	for (i = 0; i < 8; i++) {
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 		stress_proc_rw(path, ctxt.badbuf, proc_write);
 	}
@@ -191,6 +188,7 @@ static void stress_proc_rw_threads(char *path, const bool proc_write)
  *	read directory
  */
 static void stress_proc_dir(
+	const args_t *args,
 	const char *path,
 	const bool recurse,
 	const int depth,
@@ -199,7 +197,7 @@ static void stress_proc_dir(
 	DIR *dp;
 	struct dirent *d;
 
-	if (!opt_do_run)
+	if (!g_keep_stressing_flag)
 		return;
 
 	/* Don't want to go too deep */
@@ -213,7 +211,7 @@ static void stress_proc_dir(
 	while ((d = readdir(dp)) != NULL) {
 		char name[PATH_MAX];
 
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 		if (!strcmp(d->d_name, ".") ||
 		    !strcmp(d->d_name, ".."))
@@ -221,15 +219,15 @@ static void stress_proc_dir(
 		switch (d->d_type) {
 		case DT_DIR:
 			if (recurse) {
-				snprintf(name, sizeof(name),
+				(void)snprintf(name, sizeof(name),
 					"%s/%s", path, d->d_name);
-				stress_proc_dir(name, recurse, depth + 1, proc_write);
+				stress_proc_dir(args, name, recurse, depth + 1, proc_write);
 			}
 			break;
 		case DT_REG:
-			snprintf(name, sizeof(name),
+			(void)snprintf(name, sizeof(name),
 				"%s/%s", path, d->d_name);
-			stress_proc_rw_threads(name, proc_write);
+			stress_proc_rw_threads(args, name, proc_write);
 			break;
 		default:
 			break;
@@ -242,99 +240,85 @@ static void stress_proc_dir(
  *  stress_procfs
  *	stress reading all of /proc
  */
-int stress_procfs(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_procfs(const args_t *args)
 {
 	bool proc_write = true;
 
-	(void)instance;
-	(void)name;
-
 	sigfillset(&set);
 
 	if (geteuid() == 0)
 		proc_write = false;
 
 	do {
-		stress_proc_dir("/proc/self", true, 0, proc_write);
-		(*counter)++;
-		if (!opt_do_run || (max_ops && *counter >= max_ops))
+		stress_proc_dir(args, "/proc/self", true, 0, proc_write);
+		inc_counter(args);
+		if (!keep_stressing())
 			break;
 
-
-		stress_proc_dir("/proc/sys", true, 0, proc_write);
-		(*counter)++;
-		if (!opt_do_run || (max_ops && *counter >= max_ops))
+		stress_proc_dir(args,"/proc/sys", true, 0, proc_write);
+		inc_counter(args);
+		if (!keep_stressing())
 			break;
 
-		stress_proc_dir("/proc/sysvipc", true, 0, proc_write);
-		(*counter)++;
-		if (!opt_do_run || (max_ops && *counter >= max_ops))
+		stress_proc_dir(args,"/proc/sysvipc", true, 0, proc_write);
+		inc_counter(args);
+		if (!keep_stressing())
 			break;
 
-		stress_proc_dir("/proc/fs", true, 0, proc_write);
-		(*counter)++;
-		if (!opt_do_run || (max_ops && *counter >= max_ops))
+		stress_proc_dir(args,"/proc/fs", true, 0, proc_write);
+		inc_counter(args);
+		if (!keep_stressing())
 			break;
 
-		stress_proc_dir("/proc/bus", true, 0, proc_write);
-		(*counter)++;
-		if (!opt_do_run || (max_ops && *counter >= max_ops))
+		stress_proc_dir(args,"/proc/bus", true, 0, proc_write);
+		inc_counter(args);
+		if (!keep_stressing())
 			break;
 
-		stress_proc_dir("/proc/irq", true, 0, proc_write);
-		(*counter)++;
-		if (!opt_do_run || (max_ops && *counter >= max_ops))
+		stress_proc_dir(args,"/proc/irq", true, 0, proc_write);
+		inc_counter(args);
+		if (!keep_stressing())
 			break;
 
-		stress_proc_dir("/proc/scsi", true, 0, proc_write);
-		(*counter)++;
-		if (!opt_do_run || (max_ops && *counter >= max_ops))
+		stress_proc_dir(args,"/proc/scsi", true, 0, proc_write);
+		inc_counter(args);
+		if (!keep_stressing())
 			break;
 
-		stress_proc_dir("/proc/tty", true, 0, proc_write);
-		(*counter)++;
-		if (!opt_do_run || (max_ops && *counter >= max_ops))
+		stress_proc_dir(args,"/proc/tty", true, 0, proc_write);
+		inc_counter(args);
+		if (!keep_stressing())
 			break;
 
-		stress_proc_dir("/proc/driver", true, 0, proc_write);
-		(*counter)++;
-		if (!opt_do_run || (max_ops && *counter >= max_ops))
+		stress_proc_dir(args,"/proc/driver", true, 0, proc_write);
+		inc_counter(args);
+		if (!keep_stressing())
 			break;
 
-		stress_proc_dir("/proc/tty", true, 0, proc_write);
-		(*counter)++;
-		if (!opt_do_run || (max_ops && *counter >= max_ops))
+		stress_proc_dir(args,"/proc/tty", true, 0, proc_write);
+		inc_counter(args);
+		if (!keep_stressing())
 			break;
 
-		stress_proc_dir("/proc/self", true, 0, proc_write);
-		(*counter)++;
-		if (!opt_do_run || (max_ops && *counter >= max_ops))
+		stress_proc_dir(args,"/proc/self", true, 0, proc_write);
+		inc_counter(args);
+		if (!keep_stressing())
 			break;
 
-		stress_proc_dir("/proc/thread_self", true, 0, proc_write);
-		(*counter)++;
-		if (!opt_do_run || (max_ops && *counter >= max_ops))
+		stress_proc_dir(args,"/proc/thread_self", true, 0, proc_write);
+		inc_counter(args);
+		if (!keep_stressing())
 			break;
 
-		stress_proc_dir("/proc", false, 0, proc_write);
-		(*counter)++;
-		if (!opt_do_run || (max_ops && *counter >= max_ops))
-			break;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		stress_proc_dir(args,"/proc", false, 0, proc_write);
+		inc_counter(args);
+	} while (keep_stressing());
 
 	return EXIT_SUCCESS;
 }
 #else
-int stress_procfs(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_procfs(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
