@@ -42,19 +42,19 @@ static sigset_t set;
 static uint64_t opt_pthread_max = DEFAULT_PTHREAD;
 static bool set_pthread_max = false;
 
-void stress_set_pthread_max(const char *optarg)
+void stress_set_pthread_max(const char *opt)
 {
 	set_pthread_max = true;
-	opt_pthread_max = get_uint64_byte(optarg);
+	opt_pthread_max = get_uint64_byte(opt);
 	check_range("pthread-max", opt_pthread_max,
 		MIN_PTHREAD, MAX_PTHREAD);
 }
 
-void stress_adjust_pthread_max(uint64_t max)
+void stress_adjust_pthread_max(const uint64_t max)
 {
 	if (opt_pthread_max > max) {
 		opt_pthread_max = max;
-		pr_inf(stdout, "re-adjusting maximum threads to "
+		pr_inf("re-adjusting maximum threads to "
 			"soft limit of %" PRIu64 "\n",
 			opt_pthread_max);
 	}
@@ -73,18 +73,16 @@ static inline long sys_get_robust_list(int pid, struct robust_list_head **head_p
  *  stress_pthread_func()
  *	pthread that exits immediately
  */
-static void *stress_pthread_func(void *ctxt)
+static void *stress_pthread_func(void *parg)
 {
 	uint8_t stack[SIGSTKSZ + STACK_ALIGNMENT];
-	stack_t ss;
 	static void *nowt = NULL;
 	int ret;
 #if defined(__linux__) && defined(__NR_get_robust_list)
 	struct robust_list_head *head_ptr;
 	size_t len_ptr;
 #endif
-
-	(void)ctxt;
+	const args_t *args = ((pthread_args_t *)parg)->args;
 
 	/*
 	 *  Block all signals, let controlling thread
@@ -98,13 +96,9 @@ static void *stress_pthread_func(void *ctxt)
 	 *  However, we block signals in this thread
 	 *  so this is probably just totally unncessary.
 	 */
-	ss.ss_sp = (void *)align_address(stack, STACK_ALIGNMENT);
-	ss.ss_size = SIGSTKSZ;
-	ss.ss_flags = 0;
-	if (sigaltstack(&ss, NULL) < 0) {
-		pr_fail_err("pthread", "sigaltstack");
+	memset(stack, 0, sizeof(stack));
+	if (stress_sigaltstack(stack, SIGSTKSZ) < 0)
 		goto die;
-	}
 
 #if defined(__linux__) && defined(__NR_get_robust_list)
 	/*
@@ -112,7 +106,7 @@ static void *stress_pthread_func(void *ctxt)
 	 */
 	if (sys_get_robust_list(0, &head_ptr, &len_ptr) < 0) {
 		if (errno != ENOSYS) {
-			pr_fail_err("pthread", "get_robust_list");
+			pr_fail_err("get_robust_list");
 			goto die;
 		}
 	}
@@ -123,13 +117,13 @@ static void *stress_pthread_func(void *ctxt)
 	 */
 	ret = pthread_spin_lock(&spinlock);
 	if (ret) {
-		pr_fail_errno("pthread", "spinlock lock", ret);
+		pr_fail_errno("spinlock lock", ret);
 		goto die;
 	}
 	pthread_count++;
 	ret = pthread_spin_unlock(&spinlock);
 	if (ret) {
-		pr_fail_errno("pthread", "spin unlock", ret);
+		pr_fail_errno("spin unlock", ret);
 		goto die;
 	}
 
@@ -139,20 +133,19 @@ static void *stress_pthread_func(void *ctxt)
 	 */
 	ret = pthread_mutex_lock(&mutex);
 	if (ret) {
-		pr_fail_errno("pthread", "mutex unlock", ret);
+		pr_fail_errno("mutex unlock", ret);
 		goto die;
 	}
 	while (!thread_terminate) {
 		ret = pthread_cond_wait(&cond, &mutex);
 		if (ret) {
-			pr_fail_errno("pthread",
-				"pthread condition wait", ret);
+			pr_fail_errno("pthread condition wait", ret);
 			break;
 		}
 	}
 	ret = pthread_mutex_unlock(&mutex);
 	if (ret)
-		pr_fail_errno("pthread", "mutex unlock", ret);
+		pr_fail_errno("mutex unlock", ret);
 die:
 	return &nowt;
 }
@@ -161,37 +154,34 @@ die:
  *  stress_pthread()
  *	stress by creating pthreads
  */
-int stress_pthread(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_pthread(const args_t *args)
 {
 	pthread_t pthreads[MAX_PTHREAD];
 	bool ok = true;
 	uint64_t limited = 0, attempted = 0;
 	int ret;
+	pthread_args_t pargs = { args };
 
 	if (!set_pthread_max) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_pthread_max = MAX_PTHREAD;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_pthread_max = MIN_PTHREAD;
 	}
 
 	ret = pthread_cond_init(&cond, NULL);
 	if (ret) {
-		pr_fail_errno(name, "pthread_cond_init", ret);
+		pr_fail_errno("pthread_cond_init", ret);
 		return EXIT_FAILURE;
 	}
 	ret = pthread_spin_init(&spinlock, 0);
 	if (ret) {
-		pr_fail_errno(name, "pthread_spin_init", ret);
+		pr_fail_errno("pthread_spin_init", ret);
 		return EXIT_FAILURE;
 	}
 	ret = pthread_mutex_init(&mutex, NULL);
 	if (ret) {
-		pr_fail_errno(name, "pthread_mutx_init", ret);
+		pr_fail_errno("pthread_mutx_init", ret);
 		return EXIT_FAILURE;
 	}
 
@@ -202,9 +192,9 @@ int stress_pthread(
 		thread_terminate = false;
 		pthread_count = 0;
 
-		for (i = 0; (i < opt_pthread_max) && (!max_ops || *counter < max_ops); i++) {
+		for (i = 0; (i < opt_pthread_max) && (!args->max_ops || *args->counter < args->max_ops); i++) {
 			ret = pthread_create(&pthreads[i], NULL,
-				stress_pthread_func, NULL);
+				stress_pthread_func, (void *)&pargs);
 			if (ret) {
 				/* Out of resources, don't try any more */
 				if (ret == EAGAIN) {
@@ -212,12 +202,12 @@ int stress_pthread(
 					break;
 				}
 				/* Something really unexpected */
-				pr_fail_errno(name, "pthread create", ret);
+				pr_fail_errno("pthread create", ret);
 				ok = false;
 				break;
 			}
-			(*counter)++;
-			if (!opt_do_run)
+			inc_counter(args);
+			if (!g_keep_stressing_flag)
 				break;
 		}
 		attempted++;
@@ -231,14 +221,14 @@ int stress_pthread(
 
 			ret = pthread_mutex_lock(&mutex);
 			if (ret) {
-				pr_fail_errno(name, "mutex lock", ret);
+				pr_fail_errno("mutex lock", ret);
 				ok = false;
 				goto reap;
 			}
 			all_running = (pthread_count == i);
 			ret = pthread_mutex_unlock(&mutex);
 			if (ret) {
-				pr_fail_errno(name, "mutex unlock", ret);
+				pr_fail_errno("mutex unlock", ret);
 				ok = false;
 				goto reap;
 			}
@@ -249,40 +239,39 @@ int stress_pthread(
 
 		ret = pthread_mutex_lock(&mutex);
 		if (ret) {
-			pr_fail_errno(name, "mutex lock", ret);
+			pr_fail_errno("mutex lock", ret);
 			ok = false;
 			goto reap;
 		}
 		thread_terminate = true;
 		ret = pthread_cond_broadcast(&cond);
 		if (ret) {
-			pr_fail_errno(name,
-				"pthread condition broadcast", ret);
+			pr_fail_errno("pthread condition broadcast", ret);
 			ok = false;
 			/* fall through and unlock */
 		}
 		ret = pthread_mutex_unlock(&mutex);
 		if (ret) {
-			pr_fail_errno(name, "mutex unlock", ret);
+			pr_fail_errno("mutex unlock", ret);
 			ok = false;
 		}
 reap:
 		for (j = 0; j < i; j++) {
 			ret = pthread_join(pthreads[j], NULL);
 			if (ret) {
-				pr_fail_errno(name, "pthread join", ret);
+				pr_fail_errno("pthread join", ret);
 				ok = false;
 			}
 		}
-	} while (ok && opt_do_run && (!max_ops || *counter < max_ops));
+	} while (ok && keep_stressing());
 
 	if (limited) {
-		pr_inf(stdout, "%s: %.2f%% of iterations could not reach "
+		pr_inf("%s: %.2f%% of iterations could not reach "
 			"requested %" PRIu64 " threads (instance %"
 			PRIu32 ")\n",
-			name,
+			args->name,
 			100.0 * (double)limited / (double)attempted,
-			opt_pthread_max, instance);
+			opt_pthread_max, args->instance);
 	}
 
 	(void)pthread_cond_destroy(&cond);
@@ -292,12 +281,8 @@ reap:
 	return EXIT_SUCCESS;
 }
 #else
-int stress_pthread(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_pthread(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
