@@ -29,61 +29,74 @@
 #include <termio.h>
 #include <termios.h>
 
-#define MAX_PTYS	(65536)
-
 typedef struct {
 	char *slavename;
 	int master;
 	int slave;
 } pty_info_t;
 
+#endif
+
+static uint64_t opt_pty_max = DEFAULT_PTYS;
+
+/*
+ *  stress_set_pty_max()
+ *	set ptr maximum
+ */
+void stress_set_pty_max(const char *opt)
+{
+	opt_pty_max = get_uint64_byte(opt);
+	check_range("pty-max", opt_pty_max,
+		MIN_PTYS, MAX_PTYS);
+}
+
+#if defined(__linux__)
+
 /*
  *  stress_pty
  *	stress pyt handling
  */
-int stress_pty(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_pty(const args_t *args)
 {
 	int rc = EXIT_FAILURE;
 
-	(void)instance;
-
 	do {
 		size_t i, n;
-		pty_info_t ptys[MAX_PTYS];
+		pty_info_t ptys[opt_pty_max];
 
 		memset(ptys, 0, sizeof ptys);
 
-		for (n = 0; n < MAX_PTYS; n++) {
+		for (n = 0; n < opt_pty_max; n++) {
 			ptys[n].slave = -1;
 			ptys[n].master = open("/dev/ptmx", O_RDWR);
 			if (ptys[n].master < 0) {
-				if (errno != ENOSPC)
-					pr_fail_err(name, "open /dev/ptmx");
-				goto clean;
+				if ((errno != ENOSPC) && (errno != EMFILE)) {
+					pr_fail_err("open /dev/ptmx");
+					goto clean;
+				}
+			} else {
+				ptys[n].slavename = ptsname(ptys[n].master);
+				if (!ptys[n].slavename) {
+					pr_fail_err("ptsname");
+					goto clean;
+				}
+				if (grantpt(ptys[n].master) < 0) {
+					pr_fail_err("grantpt");
+					goto clean;
+				}
+				if (unlockpt(ptys[n].master) < 0) {
+					pr_fail_err("unlockpt");
+					goto clean;
+				}
+				ptys[n].slave = open(ptys[n].slavename, O_RDWR);
+				if (ptys[n].slave < 0) {
+					if (errno != EMFILE) {
+						pr_fail_err("open slave pty");
+						goto clean;
+					}
+				}
 			}
-			ptys[n].slavename = ptsname(ptys[n].master);
-			if (!ptys[n].slavename) {
-				pr_fail_err(name, "ptsname");
-				goto clean;
-			}
-			if (grantpt(ptys[n].master) < 0) {
-				pr_fail_err(name, "grantpt");
-				goto clean;
-			}
-			if (unlockpt(ptys[n].master) < 0) {
-				pr_fail_err(name, "unlockpt");
-				goto clean;
-			}
-			ptys[n].slave = open(ptys[n].slavename, O_RDWR);
-			if (ptys[n].slave < 0) {
-				pr_fail_err(name, "open slave pty");
-				goto clean;
-			}
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				goto clean;
 		}
 		/*
@@ -95,68 +108,70 @@ int stress_pty(
 			struct winsize ws;
 			int arg;
 
+			if ((ptys[i].master < 0) || (ptys[i].slave < 0))
+				continue;
 #if defined(TCGETS)
 			if (ioctl(ptys[i].slave, TCGETS, &ios) < 0)
-				pr_fail_err(name, "ioctl TCGETS on slave pty");
+				pr_fail_err("ioctl TCGETS on slave pty");
 #endif
 #if defined(TCSETS)
 			if (ioctl(ptys[i].slave, TCSETS, &ios) < 0)
-				pr_fail_err(name, "ioctl TCSETS on slave pty");
+				pr_fail_err("ioctl TCSETS on slave pty");
 #endif
 #if defined(TCSETSW)
 			if (ioctl(ptys[i].slave, TCSETSW, &ios) < 0)
-				pr_fail_err(name, "ioctl TCSETSW on slave pty");
+				pr_fail_err("ioctl TCSETSW on slave pty");
 #endif
 #if defined(TCSETSF)
 			if (ioctl(ptys[i].slave, TCSETSF, &ios) < 0)
-				pr_fail_err(name, "ioctl TCSETSF on slave pty");
+				pr_fail_err("ioctl TCSETSF on slave pty");
 #endif
 #if defined(TCGETA)
 			if (ioctl(ptys[i].slave, TCGETA, &io) < 0)
-				pr_fail_err(name, "ioctl TCGETA on slave pty");
+				pr_fail_err("ioctl TCGETA on slave pty");
 #endif
 #if defined(TCSETA)
 			if (ioctl(ptys[i].slave, TCSETA, &io) < 0)
-				pr_fail_err(name, "ioctl TCSETA on slave pty");
+				pr_fail_err("ioctl TCSETA on slave pty");
 #endif
 #if defined(TCSETAW)
 			if (ioctl(ptys[i].slave, TCSETAW, &io) < 0)
-				pr_fail_err(name, "ioctl TCSETAW on slave pty");
+				pr_fail_err("ioctl TCSETAW on slave pty");
 #endif
 #if defined(TCSETAF)
 			if (ioctl(ptys[i].slave, TCSETAF, &io) < 0)
-				pr_fail_err(name, "ioctl TCSETAF on slave pty");
+				pr_fail_err("ioctl TCSETAF on slave pty");
 #endif
 #if defined(TIOCGLCKTRMIOS)
 			if (ioctl(ptys[i].slave, TIOCGLCKTRMIOS, &ios) < 0)
-				pr_fail_err(name, "ioctl TIOCGLCKTRMIOS on slave pty");
+				pr_fail_err("ioctl TIOCGLCKTRMIOS on slave pty");
 #endif
 #if defined(TIOCGLCKTRMIOS)
 			if (ioctl(ptys[i].slave, TIOCGLCKTRMIOS, &ios) < 0)
-				pr_fail_err(name, "ioctl TIOCGLCKTRMIOS on slave pty");
+				pr_fail_err("ioctl TIOCGLCKTRMIOS on slave pty");
 #endif
 #if defined(TIOCGWINSZ)
 			if (ioctl(ptys[i].slave, TIOCGWINSZ, &ws) < 0)
-				pr_fail_err(name, "ioctl TIOCGWINSZ on slave pty");
+				pr_fail_err("ioctl TIOCGWINSZ on slave pty");
 #endif
 #if defined(TIOCSWINSZ)
 			if (ioctl(ptys[i].slave, TIOCSWINSZ, &ws) < 0)
-				pr_fail_err(name, "ioctl TIOCSWINSZ on slave pty");
+				pr_fail_err("ioctl TIOCSWINSZ on slave pty");
 #endif
 #if defined(FIONREAD)
 			if (ioctl(ptys[i].slave, FIONREAD, &arg) < 0)
-				pr_fail_err(name, "ioctl FIONREAD on slave pty");
+				pr_fail_err("ioctl FIONREAD on slave pty");
 #endif
 #if defined(TIOCINQ)
 			if (ioctl(ptys[i].slave, TIOCINQ, &arg) < 0)
-				pr_fail_err(name, "ioctl TIOCINQ on slave pty");
+				pr_fail_err("ioctl TIOCINQ on slave pty");
 #endif
 #if defined(TIOCOUTQ)
 			if (ioctl(ptys[i].slave, TIOCOUTQ, &arg) < 0)
-				pr_fail_err(name, "ioctl TIOCOUTQ on slave pty");
+				pr_fail_err("ioctl TIOCOUTQ on slave pty");
 #endif
 
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				goto clean;
 		}
 clean:
@@ -166,22 +181,19 @@ clean:
 		for (i = 0; i < n; i++) {
 			if (ptys[i].slave != -1)
 				(void)close(ptys[i].slave);
-			(void)close(ptys[i].master);
+			if (ptys[i].master != -1)
+				(void)close(ptys[i].master);
 		}
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
 	rc = EXIT_SUCCESS;
 
 	return rc;
 }
 #else
-int stress_pty(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_pty(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
