@@ -47,10 +47,10 @@ static void MLOCKED stress_qsort_handler(int dummy)
  *  stress_set_qsort_size()
  *	set qsort size
  */
-void stress_set_qsort_size(const void *optarg)
+void stress_set_qsort_size(const char *opt)
 {
 	set_qsort_size = true;
-	opt_qsort_size = get_uint64_byte(optarg);
+	opt_qsort_size = get_uint64_byte(opt);
 	check_range("qsort-size", opt_qsort_size,
 		MIN_QSORT_SIZE, MAX_QSORT_SIZE);
 }
@@ -98,33 +98,27 @@ static int stress_qsort_cmp_3(const void *p1, const void *p2)
  *  stress_qsort()
  *	stress qsort
  */
-int stress_qsort(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_qsort(const args_t *args)
 {
 	int32_t *data, *ptr;
 	size_t n, i;
 	struct sigaction old_action;
 	int ret;
 
-	(void)instance;
-
 	if (!set_qsort_size) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_qsort_size = MAX_QSORT_SIZE;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_qsort_size = MIN_QSORT_SIZE;
 	}
 	n = (size_t)opt_qsort_size;
 
 	if ((data = calloc(n, sizeof(int32_t))) == NULL) {
-		pr_fail_dbg(name, "malloc");
+		pr_fail_dbg("calloc");
 		return EXIT_NO_RESOURCE;
 	}
 
-	if (stress_sighandler(name, SIGALRM, stress_qsort_handler, &old_action) < 0) {
+	if (stress_sighandler(args->name, SIGALRM, stress_qsort_handler, &old_action) < 0) {
 		free(data);
 		return EXIT_FAILURE;
 	}
@@ -134,7 +128,7 @@ int stress_qsort(
 		/*
 		 * We return here if SIGALRM jmp'd back
 		 */
-		(void)stress_sigrestore(name, SIGALRM, &old_action);
+		(void)stress_sigrestore(args->name, SIGALRM, &old_action);
 		goto tidy;
 	}
 
@@ -145,56 +139,56 @@ int stress_qsort(
 	do {
 		/* Sort "random" data */
 		qsort(data, n, sizeof(uint32_t), stress_qsort_cmp_1);
-		if (opt_flags & OPT_FLAGS_VERIFY) {
+		if (g_opt_flags & OPT_FLAGS_VERIFY) {
 			for (ptr = data, i = 0; i < n - 1; i++, ptr++) {
 				if (*ptr > *(ptr+1)) {
-					pr_fail(stderr, "%s: sort error "
+					pr_fail("%s: sort error "
 						"detected, incorrect ordering "
-						"found\n", name);
+						"found\n", args->name);
 					break;
 				}
 			}
 		}
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 
 		/* Reverse sort */
 		qsort(data, n, sizeof(uint32_t), stress_qsort_cmp_2);
-		if (opt_flags & OPT_FLAGS_VERIFY) {
+		if (g_opt_flags & OPT_FLAGS_VERIFY) {
 			for (ptr = data, i = 0; i < n - 1; i++, ptr++) {
 				if (*ptr < *(ptr+1)) {
-					pr_fail(stderr, "%s: reverse sort "
+					pr_fail("%s: reverse sort "
 						"error detected, incorrect "
-						"ordering found\n", name);
+						"ordering found\n", args->name);
 					break;
 				}
 			}
 		}
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 		/* And re-order by byte compare */
 		qsort((uint8_t *)data, n * 4, sizeof(uint8_t), stress_qsort_cmp_3);
 
 		/* Reverse sort this again */
 		qsort(data, n, sizeof(uint32_t), stress_qsort_cmp_2);
-		if (opt_flags & OPT_FLAGS_VERIFY) {
+		if (g_opt_flags & OPT_FLAGS_VERIFY) {
 			for (ptr = data, i = 0; i < n - 1; i++, ptr++) {
 				if (*ptr < *(ptr+1)) {
-					pr_fail(stderr, "%s: reverse sort "
+					pr_fail("%s: reverse sort "
 						"error detected, incorrect "
-						"ordering found\n", name);
+						"ordering found\n", args->name);
 					break;
 				}
 			}
 		}
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
 	do_jmp = false;
-	(void)stress_sigrestore(name, SIGALRM, &old_action);
+	(void)stress_sigrestore(args->name, SIGALRM, &old_action);
 tidy:
 	free(data);
 
