@@ -31,18 +31,20 @@
 static uint64_t opt_readahead_bytes = DEFAULT_READAHEAD_BYTES;
 static bool set_readahead_bytes = false;
 
-void stress_set_readahead_bytes(const char *optarg)
+void stress_set_readahead_bytes(const char *opt)
 {
 	set_readahead_bytes = true;
-	opt_readahead_bytes =  get_uint64_byte(optarg);
-	check_range("hdd-bytes", opt_readahead_bytes,
+	opt_readahead_bytes =
+		get_uint64_byte_filesystem(opt,
+			stressor_instances(STRESS_READAHEAD));
+	check_range_bytes("hdd-bytes", opt_readahead_bytes,
 		MIN_HDD_BYTES, MAX_HDD_BYTES);
 }
 
 #if defined(__linux__) && NEED_GLIBC(2,3,0)
 
 static int do_readahead(
-	const char *name,
+	const args_t *args,
 	const int fd,
 	off_t *offsets,
 	const uint64_t readahead_bytes)
@@ -52,7 +54,7 @@ static int do_readahead(
 	for (i = 0; i < MAX_OFFSETS; i++) {
 		offsets[i] = (mwc64() % (readahead_bytes - BUF_SIZE)) & ~511;
 		if (readahead(fd, offsets[i], BUF_SIZE) < 0) {
-			pr_fail_err(name, "ftruncate");
+			pr_fail_err("ftruncate");
 			return -1;
 		}
 	}
@@ -63,17 +65,12 @@ static int do_readahead(
  *  stress_readahead
  *	stress file system cache via readahead calls
  */
-int stress_readahead(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_readahead(const args_t *args)
 {
 	uint8_t *buf = NULL;
 	uint64_t readahead_bytes, i;
 	uint64_t misreads = 0;
 	uint64_t baddata = 0;
-	const pid_t pid = getpid();
 	int ret, rc = EXIT_FAILURE;
 	char filename[PATH_MAX];
 	int flags = O_CREAT | O_RDWR | O_TRUNC;
@@ -81,42 +78,42 @@ int stress_readahead(
 	struct stat statbuf;
 
 	if (!set_readahead_bytes) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_readahead_bytes = MAX_HDD_BYTES;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_readahead_bytes = MIN_HDD_BYTES;
 	}
 
-	if (stress_temp_dir_mk(name, pid, instance) < 0)
+	if (stress_temp_dir_mk_args(args) < 0)
 		return EXIT_FAILURE;
 
 	ret = posix_memalign((void **)&buf, BUF_ALIGNMENT, BUF_SIZE);
 	if (ret || !buf) {
 		rc = exit_status(errno);
-		pr_err(stderr, "%s: cannot allocate buffer\n", name);
-		(void)stress_temp_dir_rm(name, pid, instance);
+		pr_err("%s: cannot allocate buffer\n", args->name);
+		(void)stress_temp_dir_rm_args(args);
 		return rc;
 	}
 
-	(void)stress_temp_filename(filename, sizeof(filename),
-		name, pid, instance, mwc32());
+	(void)stress_temp_filename_args(args,
+		filename, sizeof(filename), mwc32());
 
 	(void)umask(0077);
 	if ((fd = open(filename, flags, S_IRUSR | S_IWUSR)) < 0) {
 		rc = exit_status(errno);
-		pr_fail_err(name, "open");
+		pr_fail_err("open");
 		goto finish;
 	}
 	if (ftruncate(fd, (off_t)0) < 0) {
 		rc = exit_status(errno);
-		pr_fail_err(name, "ftruncate");
+		pr_fail_err("ftruncate");
 		goto close_finish;
 	}
 	(void)unlink(filename);
 
 #if defined(POSIX_FADV_DONTNEED)
 	if (posix_fadvise(fd, 0, opt_readahead_bytes, POSIX_FADV_DONTNEED) < 0) {
-		pr_fail_err(name, "posix_fadvise");
+		pr_fail_err("posix_fadvise");
 		goto close_finish;
 	}
 #endif
@@ -127,9 +124,9 @@ int stress_readahead(
 		size_t j;
 		off_t o = i / BUF_SIZE;
 seq_wr_retry:
-		if (!opt_do_run) {
-			pr_inf(stdout, "%s: test expired during test setup "
-				"(writing of data file)\n", name);
+		if (!g_keep_stressing_flag) {
+			pr_inf("%s: test expired during test setup "
+				"(writing of data file)\n", args->name);
 			rc = EXIT_SUCCESS;
 			goto close_finish;
 		}
@@ -144,7 +141,7 @@ seq_wr_retry:
 			if (errno == ENOSPC)
 				break;
 			if (errno) {
-				pr_fail_err(name, "pwrite");
+				pr_fail_err("pwrite");
 				goto close_finish;
 			}
 			continue;
@@ -152,7 +149,7 @@ seq_wr_retry:
 	}
 
 	if (fstat(fd, &statbuf) < 0) {
-		pr_fail_err(name, "fstat");
+		pr_fail_err("fstat");
 		goto close_finish;
 	}
 
@@ -163,19 +160,19 @@ seq_wr_retry:
 	do {
 		off_t offsets[MAX_OFFSETS];
 
-		if (do_readahead(name, fd, offsets, readahead_bytes) < 0)
+		if (do_readahead(args, fd, offsets, readahead_bytes) < 0)
 			goto close_finish;
 
 		for (i = 0; i < MAX_OFFSETS; i++) {
 rnd_rd_retry:
-			if (!opt_do_run || (max_ops && *counter >= max_ops))
+			if (!keep_stressing())
 				break;
 			ret = pread(fd, buf, BUF_SIZE, offsets[i]);
 			if (ret <= 0) {
 				if ((errno == EAGAIN) || (errno == EINTR))
 					goto rnd_rd_retry;
 				if (errno) {
-					pr_fail_err(name, "read");
+					pr_fail_err("read");
 					goto close_finish;
 				}
 				continue;
@@ -183,7 +180,7 @@ rnd_rd_retry:
 			if (ret != BUF_SIZE)
 				misreads++;
 
-			if (opt_flags & OPT_FLAGS_VERIFY) {
+			if (g_opt_flags & OPT_FLAGS_VERIFY) {
 				size_t j;
 				off_t o = offsets[i] / BUF_SIZE;
 
@@ -193,35 +190,31 @@ rnd_rd_retry:
 						baddata++;
 				}
 				if (baddata) {
-					pr_fail(stderr, "error in data between %ju and %ju\n",
+					pr_fail("error in data between %ju and %ju\n",
 						(intmax_t)offsets[i],
 						(intmax_t)offsets[i] + BUF_SIZE - 1);
 				}
 			}
-			(*counter)++;
+			inc_counter(args);
 		}
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (keep_stressing());
 
 	rc = EXIT_SUCCESS;
 close_finish:
 	(void)close(fd);
 finish:
 	free(buf);
-	(void)stress_temp_dir_rm(name, pid, instance);
+	(void)stress_temp_dir_rm_args(args);
 
 	if (misreads)
-		pr_dbg(stderr, "%s: %" PRIu64 " incomplete random reads\n",
-			name, misreads);
+		pr_dbg("%s: %" PRIu64 " incomplete random reads\n",
+			args->name, misreads);
 
 	return rc;
 }
 #else
-int stress_readahead(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_readahead(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
