@@ -34,11 +34,15 @@
 #include <termio.h>
 #include <termios.h>
 #endif
+#if defined(HAVE_LIB_PTHREAD) && defined(__linux__)
+#include <semaphore.h>
+#endif
 
 #define RESOURCE_FORKS 	(1024)
 #define MAX_LOOPS	(1024)
 
 typedef struct {
+	void *m_malloc;
 	void *m_sbrk;
 	void *m_alloca;
 	void *m_mmap;
@@ -47,6 +51,7 @@ typedef struct {
 	int pipe_ret;
 	int fd_open;
 	int fd_sock;
+	int fd_socketpair[2];
 #if defined(__NR_eventfd)
 	int fd_ev;
 #endif
@@ -71,6 +76,14 @@ typedef struct {
 	int pty_master;
 	int pty_slave;
 #endif
+#if defined(HAVE_LIB_RT) && defined(__linux__) && defined(SIGUNUSED)
+	bool timerok;
+	timer_t timerid;
+#endif
+#if defined(HAVE_LIB_PTHREAD) && defined(__linux__)
+	bool semok;
+	sem_t sem;
+#endif
 } info_t;
 
 static pid_t pids[RESOURCE_FORKS];
@@ -91,7 +104,7 @@ static void *stress_pthread_func(void *ctxt)
 }
 #endif
 
-static void waste_resources(
+static void NORETURN waste_resources(
 	const size_t page_size,
 	const size_t pipe_size)
 {
@@ -106,29 +119,34 @@ static void waste_resources(
 
 	memset(&info, 0, sizeof(info));
 
-	for (i = 0; opt_do_run && (i < MAX_LOOPS); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < MAX_LOOPS); i++) {
 #if defined(__NR_memfd_create)
 		char name[32];
 #endif
+		if (!(mwc32() & 0xf)) {
+			info[i].m_malloc = calloc(1, page_size);
+			if (!g_keep_stressing_flag)
+				break;
+		}
 		if (!(mwc32() & 0xf)) {
 			info[i].m_sbrk = sbrk(page_size);
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				break;
 		}
 		if (!(mwc32() & 0xf)) {
 			info[i].m_alloca = alloca(page_size);
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				break;
 		}
 		if (!(mwc32() & 0xf)) {
 			info[i].m_mmap_size = page_size;
 			info[i].m_mmap = mmap(NULL, info[i].m_mmap_size,
 				PROT_READ | PROT_WRITE, MAP_ANONYMOUS | MAP_SHARED, -1, 0);
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				break;
 			if (info[i].m_mmap != MAP_FAILED) {
 				mincore_touch_pages(info[i].m_mmap, info[i].m_mmap_size);
-				if (!opt_do_run)
+				if (!g_keep_stressing_flag)
 					break;
 			}
 		}
@@ -141,35 +159,42 @@ static void waste_resources(
 #else
 		(void)pipe_size;
 #endif
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 		info[i].fd_open = open("/dev/null", O_RDONLY);
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 #if defined(__NR_eventfd)
 		info[i].fd_ev = eventfd(0, 0);
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 #endif
 #if defined(__NR_memfd_create)
-		snprintf(name, sizeof(name), "memfd-%u-%zu", pid, i);
+		(void)snprintf(name, sizeof(name), "memfd-%u-%zu", pid, i);
 		info[i].fd_memfd = shim_memfd_create(name, 0);
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 #endif
 		info[i].fd_sock = socket(
 			domains[mwc32() % SIZEOF_ARRAY(domains)],
 			types[mwc32() % SIZEOF_ARRAY(types)], 0);
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
+
+		if (socketpair(AF_UNIX, SOCK_STREAM, 0,
+			info[i].fd_socketpair) < 0) {
+			info[i].fd_socketpair[0] = -1;
+			info[i].fd_socketpair[1] = -1;
+		}
+
 #if defined(__NR_userfaultfd)
 		info[i].fd_uf = shim_userfaultfd(0);
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 #endif
 #if defined(O_TMPFILE)
 		info[i].fd_tmp = open("/tmp", O_TMPFILE | O_RDWR, S_IRUSR | S_IWUSR);
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 		if (info[i].fd_tmp != -1) {
 			size_t sz = page_size * mwc32();
@@ -207,12 +232,10 @@ static void waste_resources(
 #endif
 #if defined(__linux__)
 		{
-			char *slavename;
-
 			info[i].pty_master = open("/dev/ptmx", O_RDWR);
 			info[i].pty_slave = -1;
 			if (info[i].pty_master >= 0) {
-				slavename = ptsname(info[i].pty_master);
+				const char *slavename = ptsname(info[i].pty_master);
 				info[i].pty_slave = open(slavename, O_RDWR);
 			}
 		}
@@ -224,9 +247,26 @@ static void waste_resources(
 				pthread_create(&info[i].pthread, NULL,
 					stress_pthread_func, NULL);
 #endif
+
+#if defined(HAVE_LIB_RT) && defined(__linux__) && defined(SIGUNUSED)
+		if (!i) {
+			struct sigevent sevp;
+
+			sevp.sigev_notify = SIGEV_NONE;
+			sevp.sigev_signo = SIGUNUSED;
+			sevp.sigev_value.sival_ptr = &info[i].timerid;
+			info[i].timerok =
+				(timer_create(CLOCK_REALTIME, &sevp, &info[i].timerid) == 0);
+		}
+#endif
+#if defined(HAVE_LIB_PTHREAD) && defined(__linux__)
+		info[i].semok = (sem_init(&info[i].sem, 1, 1) >= 0);
+#endif
 	}
 
-	for (i = 0; opt_do_run && (i < MAX_LOOPS); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < MAX_LOOPS); i++) {
+		if (info[i].m_malloc)
+			free(info[i].m_malloc);
 		if (info[i].m_mmap && (info[i].m_mmap != MAP_FAILED))
 			(void)munmap(info[i].m_mmap, info[i].m_mmap_size);
 		if (info[i].pipe_ret != -1) {
@@ -245,31 +285,51 @@ static void waste_resources(
 #endif
 		if (info[i].fd_sock != -1)
 			(void)close(info[i].fd_sock);
+		if (info[i].fd_socketpair[0] != -1)
+			(void)close(info[i].fd_socketpair[0]);
+		if (info[i].fd_socketpair[1] != -1)
+			(void)close(info[i].fd_socketpair[1]);
+
 #if defined(__NR_userfaultfd)
 		if (info[i].fd_uf != -1)
 			(void)close(info[i].fd_uf);
 #endif
+
 #if defined(O_TMPFILE)
 		if (info[i].fd_tmp != -1)
 			(void)close(info[i].fd_tmp);
 #endif
+
 #if defined(HAVE_LIB_PTHREAD)
 		if ((!i) && (!info[i].pthread_ret))
 			(void)pthread_join(info[i].pthread, NULL);
 #endif
+
+#if defined(HAVE_LIB_RT) && defined(__linux__) && defined(SIGUNUSED)
+		if ((!i) && (info[i].timerok)) {
+			(void)timer_delete(info[i].timerid);
+		}
+#endif
+
 #if defined(__linux__) && NEED_GLIBC(2,9,0)
 		if (info[i].wd_inotify != -1)
 			(void)inotify_rm_watch(info[i].fd_inotify, info[i].wd_inotify);
 		if (info[i].fd_inotify != -1)
 			(void)close(info[i].fd_inotify);
 #endif
+
 #if defined(__linux__)
 		if (info[i].pty_slave != -1)
 			(void)close(info[i].pty_slave);
 		if (info[i].pty_master != -1)
 			(void)close(info[i].pty_master);
+#endif
+#if defined(HAVE_LIB_PTHREAD) && defined(__linux__)
+		if (info[i].semok)
+			(void)sem_destroy(&info[i].sem);
 #endif
 	}
+	_exit(0);
 }
 
 static void MLOCKED kill_children(void)
@@ -278,7 +338,7 @@ static void MLOCKED kill_children(void)
 
 	for (i = 0; i < RESOURCE_FORKS; i++) {
 		if (pids[i])
-			kill(pids[i], SIGKILL);
+			(void)kill(pids[i], SIGKILL);
 	}
 
 	for (i = 0; i < RESOURCE_FORKS; i++) {
@@ -301,19 +361,13 @@ static void MLOCKED stress_alrmhandler(int dummy)
  *  stress_resources()
  *	stress by forking and exiting
  */
-int stress_resources(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_resources(const args_t *args)
 {
-	const size_t page_size = stress_get_pagesize();
+	const size_t page_size = args->page_size;
 	const size_t pipe_size = stress_probe_max_pipe_size();
 	int ret;
 
-	(void)instance;
-
-	if (stress_sighandler(name, SIGALRM, stress_alrmhandler, NULL) < 0)
+	if (stress_sighandler(args->name, SIGALRM, stress_alrmhandler, NULL) < 0)
 		return EXIT_FAILURE;
 
 	ret = sigsetjmp(jmp_env, 1);
@@ -330,26 +384,26 @@ int stress_resources(
 			pid_t pid = fork();
 
 			if (pid == 0) {
-				(void)setpgid(0, pgrp);
+				(void)setpgid(0, g_pgrp);
 				ret = sigsetjmp(jmp_env, 1);
 				if (ret)
 					_exit(0);
-				set_oom_adjustment(name, true);
+				set_oom_adjustment(args->name, true);
 				waste_resources(page_size, pipe_size);
-				_exit(0);
+				_exit(0); /* should never get here */
 			}
 			if (pid > -1)
-				(void)setpgid(pids[i], pgrp);
+				(void)setpgid(pids[i], g_pgrp);
 			pids[i] = pid;
 
-			if (!opt_do_run) {
+			if (!g_keep_stressing_flag) {
 				kill_children();
 				return EXIT_SUCCESS;
 			}
-			(*counter)++;
+			inc_counter(args);
 		}
 		kill_children();
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (keep_stressing());
 
 	return EXIT_SUCCESS;
 }
