@@ -47,7 +47,7 @@ static void MLOCKED stress_rmap_handler(int dummy)
 {
 	(void)dummy;
 
-	kill(getppid(), SIGALRM);
+	(void)kill(getppid(), SIGALRM);
 	exit(0);
 }
 
@@ -64,30 +64,30 @@ static void stress_rmap_child(
 		const int sync_flag = mwc8() ? MS_ASYNC : MS_SYNC;
 
 		switch (mwc32() & 3) {
-		case 0: for (i = 0; opt_do_run && (i < MAPPINGS_MAX); i++) {
+		case 0: for (i = 0; g_keep_stressing_flag && (i < MAPPINGS_MAX); i++) {
 				memset(mappings[i], mwc8(), sz);
 				shim_msync(mappings[i], sz, sync_flag);
 			}
 			break;
-		case 1: for (i = MAPPINGS_MAX - 1; opt_do_run && (i >= 0); i--) {
+		case 1: for (i = MAPPINGS_MAX - 1; g_keep_stressing_flag && (i >= 0); i--) {
 				memset(mappings[i], mwc8(), sz);
 				shim_msync(mappings[i], sz, sync_flag);
 			}
 			break;
-		case 2: for (i = 0; opt_do_run && (i < MAPPINGS_MAX); i++) {
+		case 2: for (i = 0; g_keep_stressing_flag && (i < MAPPINGS_MAX); i++) {
 				size_t j = mwc32() % MAPPINGS_MAX;
 				memset(mappings[j], mwc8(), sz);
 				shim_msync(mappings[j], sz, sync_flag);
 			}
 			break;
-		case 3: for (i = 0; opt_do_run && (i < MAPPINGS_MAX - 1); i++) {
+		case 3: for (i = 0; g_keep_stressing_flag && (i < MAPPINGS_MAX - 1); i++) {
 				memcpy(mappings[i], mappings[i + 1], sz);
 				shim_msync(mappings[i], sz, sync_flag);
 			}
 			break;
 		}
 		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (g_keep_stressing_flag && (!max_ops || *counter < max_ops));
 
 	exit(0);
 }
@@ -96,17 +96,12 @@ static void stress_rmap_child(
  *  stress_rmap()
  *	stress mmap
  */
-int stress_rmap(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_rmap(const args_t *args)
 {
-	const size_t page_size = stress_get_pagesize();
+	const size_t page_size = args->page_size;
 	const size_t sz = ((MAPPINGS_MAX - 1) + MAPPING_PAGES) * page_size;
 	const size_t counters_sz =
 		(page_size + sizeof(uint64_t) * RMAP_CHILD_MAX) & ~(page_size - 1);
-	const pid_t mypid = getpid();
 	int fd = -1;
 	size_t i;
 	ssize_t rc;
@@ -119,8 +114,8 @@ int stress_rmap(
 	counters = (uint64_t *)mmap(NULL, counters_sz, PROT_READ | PROT_WRITE,
 		MAP_SHARED | MAP_ANONYMOUS, -1, 0);
 	if (counters == MAP_FAILED) {
-		pr_err(stderr, "%s: mmap failed: errno=%d (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: mmap failed: errno=%d (%s)\n",
+			args->name, errno, strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 	memset(counters, 0, counters_sz);
@@ -128,31 +123,31 @@ int stress_rmap(
 	memset(mappings, 0, sizeof(mappings));
 
 	/* Make sure this is killable by OOM killer */
-	set_oom_adjustment(name, true);
+	set_oom_adjustment(args->name, true);
 
-	rc = stress_temp_dir_mk(name, mypid, instance);
+	rc = stress_temp_dir_mk_args(args);
 	if (rc < 0)
 		return exit_status(-rc);
 
-	(void)stress_temp_filename(filename, sizeof(filename),
-		name, mypid, instance, mwc32());
+	(void)stress_temp_filename_args(args,
+		filename, sizeof(filename), mwc32());
 
 	(void)umask(0077);
 	if ((fd = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
 		rc = exit_status(errno);
-		pr_fail_err(name, "open");
+		pr_fail_err("open");
 		(void)unlink(filename);
-		(void)stress_temp_dir_rm(name, mypid, instance);
+		(void)stress_temp_dir_rm_args(args);
 		(void)munmap((void *)counters, counters_sz);
 
 		return rc;
 	}
 	(void)unlink(filename);
 
-	if (posix_fallocate(fd, 0, sz) < 0) {
-		pr_fail_err(name, "posix_fallocate");
+	if (shim_fallocate(fd, 0, 0, sz) < 0) {
+		pr_fail_err("fallocate");
 		(void)close(fd);
-		(void)stress_temp_dir_rm(name, mypid, instance);
+		(void)stress_temp_dir_rm_args(args);
 		(void)munmap((void *)counters, counters_sz);
 
 		return EXIT_FAILURE;
@@ -175,23 +170,23 @@ int stress_rmap(
 	for (i = 0; i < RMAP_CHILD_MAX; i++) {
 		pids[i] = fork();
 		if (pids[i] < 0) {
-			pr_err(stderr, "%s: fork failed: errno=%d: (%s)\n",
-				name, errno, strerror(errno));
+			pr_err("%s: fork failed: errno=%d: (%s)\n",
+				args->name, errno, strerror(errno));
 			goto cleanup;
 		} else if (pids[i] == 0) {
-			if (stress_sighandler(name, SIGALRM,
+			if (stress_sighandler(args->name, SIGALRM,
 			    stress_rmap_handler, NULL) < 0)
 				exit(EXIT_FAILURE);
 
-			(void)setpgid(0, pgrp);
+			(void)setpgid(0, g_pgrp);
 			stress_parent_died_alarm();
 
 			/* Make sure this is killable by OOM killer */
-			set_oom_adjustment(name, true);
-			stress_rmap_child(&counters[i], max_ops / RMAP_CHILD_MAX,
+			set_oom_adjustment(args->name, true);
+			stress_rmap_child(&counters[i], args->max_ops / RMAP_CHILD_MAX,
 				page_size, mappings);
 		} else {
-			(void)setpgid(pids[i], pgrp);
+			(void)setpgid(pids[i], g_pgrp);
 		}
 	}
 
@@ -201,8 +196,8 @@ int stress_rmap(
 	do {
 		(void)select(0, NULL, NULL, NULL, NULL);
 		for (i = 0; i < RMAP_CHILD_MAX; i++)
-			*counter += counters[i];
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+			*args->counter += counters[i];
+	} while (keep_stressing());
 
 cleanup:
 	/*
@@ -218,8 +213,8 @@ cleanup:
 		ret = waitpid(pids[i], &status, 0);
 		if (ret < 0) {
 			if (errno != EINTR)
-				pr_dbg(stderr, "%s: waitpid(): errno=%d (%s)\n",
-					name, errno, strerror(errno));
+				pr_dbg("%s: waitpid(): errno=%d (%s)\n",
+					args->name, errno, strerror(errno));
 			(void)kill(pids[i], SIGTERM);
 			(void)kill(pids[i], SIGKILL);
 			(void)waitpid(pids[i], &status, 0);
@@ -228,7 +223,7 @@ cleanup:
 
 	(void)munmap((void *)counters, counters_sz);
 	(void)close(fd);
-	(void)stress_temp_dir_rm(name, mypid, instance);
+	(void)stress_temp_dir_rm_args(args);
 
 	for (i = 0; i < MAPPINGS_MAX; i++) {
 		if (mappings[i] != MAP_FAILED)
@@ -240,12 +235,8 @@ cleanup:
 	return EXIT_SUCCESS;
 }
 #else
-int stress_rmap(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_rmap(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
