@@ -51,16 +51,11 @@
  *  stress_seal
  *	stress file sealing
  */
-int stress_seal(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_seal(const args_t *args)
 {
 	int fd, ret;
 	int rc = EXIT_FAILURE;
-	const size_t page_size = stress_get_pagesize();
-	const pid_t pid = getpid();
+	const size_t page_size = args->page_size;
 	char filename[PATH_MAX];
 
 	do {
@@ -68,28 +63,28 @@ int stress_seal(
 		uint8_t *ptr;
 		char buf[page_size];
 
-		snprintf(filename, sizeof(filename), "%s-%d-%" PRIu32 "-%" PRIu32,
-			name, pid, instance, mwc32());
+		(void)snprintf(filename, sizeof(filename), "%s-%d-%" PRIu32 "-%" PRIu32,
+			args->name, args->pid, args->instance, mwc32());
 
 		fd = shim_memfd_create(filename, MFD_ALLOW_SEALING);
 		if (fd < 0) {
 			if (errno == ENOSYS) {
-				pr_inf(stdout, "%s: aborting, unimplemented "
-					"system call memfd_created\n", name);
+				pr_inf("%s: aborting, unimplemented "
+					"system call memfd_created\n", args->name);
 				return EXIT_NO_RESOURCE;
 			}
-			pr_fail_err(name, "memfd_create");
+			pr_fail_err("memfd_create");
 			return EXIT_FAILURE;
 		}
 
 		if (ftruncate(fd, sz) < 0) {
-			pr_fail_err(name, "ftruncate");
+			pr_fail_err("ftruncate");
 			(void)close(fd);
 			goto err;
 		}
 
 		if (fcntl(fd, F_GET_SEALS) < 0) {
-			pr_fail_err(name, "fcntl F_GET_SEALS");
+			pr_fail_err("fcntl F_GET_SEALS");
 			(void)close(fd);
 			goto err;
 		}
@@ -98,13 +93,13 @@ int stress_seal(
 		 *  Add shrink SEAL, file cannot be make smaller
 		 */
 		if (fcntl(fd, F_ADD_SEALS, F_SEAL_SHRINK) < 0) {
-			pr_fail_err(name, "fcntl F_ADD_SEALS F_SEAL_SHRINK");
+			pr_fail_err("fcntl F_ADD_SEALS F_SEAL_SHRINK");
 			(void)close(fd);
 			goto err;
 		}
 		ret = ftruncate(fd, 0);
 		if ((ret == 0) || ((ret < 0) && (errno != EPERM))) {
-			pr_fail_err(name, "ftruncate did not fail with EPERM");
+			pr_fail_err("ftruncate did not fail with EPERM");
 			(void)close(fd);
 			goto err;
 		}
@@ -113,13 +108,13 @@ int stress_seal(
 		 *  Add grow SEAL, file cannot be made larger
 		 */
 		if (fcntl(fd, F_ADD_SEALS, F_SEAL_GROW) < 0) {
-			pr_fail_err(name, "fcntl F_ADD_SEALS F_SEAL_GROW");
+			pr_fail_err("fcntl F_ADD_SEALS F_SEAL_GROW");
 			(void)close(fd);
 			goto err;
 		}
 		ret = ftruncate(fd, sz + 1);
 		if ((ret == 0) || ((ret < 0) && (errno != EPERM))) {
-			pr_fail_err(name, "ftruncate did not fail with EPERM");
+			pr_fail_err("ftruncate did not fail with EPERM");
 			(void)close(fd);
 			goto err;
 		}
@@ -133,14 +128,14 @@ int stress_seal(
 		if (ptr == MAP_FAILED) {
 			if (errno == ENOMEM)
 				goto next;
-			pr_fail_err(name, "mmap");
+			pr_fail_err("mmap");
 			(void)close(fd);
 			goto err;
 		}
 		memset(ptr, 0xea, page_size);
 		ret = fcntl(fd, F_ADD_SEALS, F_SEAL_WRITE);
 		if ((ret == 0) || ((ret < 0) && (errno != EBUSY))) {
-			pr_fail_err(name, "fcntl F_ADD_SEALS F_SEAL_WRITE did not fail with EBUSY");
+			pr_fail_err("fcntl F_ADD_SEALS F_SEAL_WRITE did not fail with EBUSY");
 			(void)munmap(ptr, sz);
 			(void)close(fd);
 			goto err;
@@ -152,22 +147,22 @@ int stress_seal(
 		 *  Now write seal the file, no more writes allowed
 		 */
 		if (fcntl(fd, F_ADD_SEALS, F_SEAL_WRITE) < 0) {
-			pr_fail_err(name, "fcntl F_ADD_SEALS F_SEAL_WRITE");
+			pr_fail_err("fcntl F_ADD_SEALS F_SEAL_WRITE");
 			(void)close(fd);
 			goto err;
 		}
 		memset(buf, 0xff, sizeof(buf));
 		ret = write(fd, buf, sizeof(buf));
 		if ((ret == 0) || ((ret < 0) && (errno != EPERM))) {
-			pr_fail_err(name, "write on sealed file did not fail with EPERM");
+			pr_fail_err("write on sealed file did not fail with EPERM");
 			(void)close(fd);
 			goto err;
 		}
 next:
 		(void)close(fd);
 
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
 	rc = EXIT_SUCCESS;
 err:
@@ -175,12 +170,8 @@ err:
 	return rc;
 }
 #else
-int stress_seal(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_seal(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
