@@ -31,10 +31,10 @@
 static uint64_t opt_semaphore_posix_procs = DEFAULT_SEMAPHORE_PROCS;
 static bool set_semaphore_posix_procs = false;
 
-void stress_set_semaphore_posix_procs(const char *optarg)
+void stress_set_semaphore_posix_procs(const char *opt)
 {
 	set_semaphore_posix_procs = true;
-	opt_semaphore_posix_procs = get_uint64_byte(optarg);
+	opt_semaphore_posix_procs = get_uint64_byte(opt);
 	check_range("sem-procs", opt_semaphore_posix_procs,
 		MIN_SEMAPHORE_PROCS, MAX_SEMAPHORE_PROCS);
 }
@@ -48,17 +48,17 @@ void stress_set_semaphore_posix_procs(const char *optarg)
 void stress_semaphore_posix_init(void)
 {
 	/* create a mutex */
-	if (sem_init(&shared->sem_posix.sem, 1, 1) >= 0) {
-		shared->sem_posix.init = true;
+	if (sem_init(&g_shared->sem_posix.sem, 1, 1) >= 0) {
+		g_shared->sem_posix.init = true;
 		return;
 	}
 
-	if (opt_sequential) {
-		pr_inf(stdout, "semaphore init (POSIX) failed: errno=%d: "
+	if (g_opt_sequential) {
+		pr_inf("semaphore init (POSIX) failed: errno=%d: "
 			"(%s), skipping semaphore stressor\n",
 			errno, strerror(errno));
 	} else {
-		pr_err(stderr, "semaphore init (POSIX) failed: errno=%d: "
+		pr_err("semaphore init (POSIX) failed: errno=%d: "
 			"(%s)\n", errno, strerror(errno));
 	}
 }
@@ -69,9 +69,9 @@ void stress_semaphore_posix_init(void)
  */
 void stress_semaphore_posix_destroy(void)
 {
-	if (shared->sem_posix.init) {
-		if (sem_destroy(&shared->sem_posix.sem) < 0) {
-			pr_err(stderr, "semaphore destroy failed: errno=%d (%s)\n",
+	if (g_shared->sem_posix.init) {
+		if (sem_destroy(&g_shared->sem_posix.sem) < 0) {
+			pr_err("semaphore destroy failed: errno=%d (%s)\n",
 				errno, strerror(errno));
 		}
 	}
@@ -81,67 +81,61 @@ void stress_semaphore_posix_destroy(void)
  *  semaphore_posix_thrash()
  *	exercise the semaphore
  */
-static void semaphore_posix_thrash(
-	const char *name,
-	const uint64_t max_ops,
-	uint64_t *counter)
+static void semaphore_posix_thrash(const args_t *args)
 {
 	do {
 		int i;
 		struct timespec timeout;
 
 		if (clock_gettime(CLOCK_REALTIME, &timeout) < 0) {
-			pr_fail_dbg(name, "clock_gettime");
+			pr_fail_dbg("clock_gettime");
 			return;
 		}
 		timeout.tv_sec++;
 
 		for (i = 0; i < 1000; i++) {
-			if (sem_timedwait(&shared->sem_posix.sem, &timeout) < 0) {
+			if (sem_timedwait(&g_shared->sem_posix.sem, &timeout) < 0) {
 				if (errno == ETIMEDOUT)
 					goto timed_out;
 				if (errno != EINTR)
-					pr_fail_dbg(name, "sem_wait");
+					pr_fail_dbg("sem_wait");
 				break;
 			}
-			(*counter)++;
-			if (sem_post(&shared->sem_posix.sem) < 0) {
-				pr_fail_dbg(name, "sem_post");
+			inc_counter(args);
+			if (sem_post(&g_shared->sem_posix.sem) < 0) {
+				pr_fail_dbg("sem_post");
 				break;
 			}
 timed_out:
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				break;
 		}
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (keep_stressing());
 }
 
 /*
  *  semaphore_posix_spawn()
  *	spawn a process
  */
-static pid_t semaphore_posix_spawn(
-	const char *name,
-	const uint64_t max_ops,
-	uint64_t *counter)
+static pid_t semaphore_posix_spawn(const args_t *args)
 {
 	pid_t pid;
 
 again:
 	pid = fork();
 	if (pid < 0) {
-		if (opt_do_run && (errno == EAGAIN))
+		if (g_keep_stressing_flag && (errno == EAGAIN))
 			goto again;
 		return -1;
 	}
 	if (pid == 0) {
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
 
-		semaphore_posix_thrash(name, max_ops, counter);
+		semaphore_posix_thrash(args);
 		exit(EXIT_SUCCESS);
 	}
-	(void)setpgid(pid, pgrp);
+	(void)setpgid(pid, g_pgrp);
 	return pid;
 }
 
@@ -149,38 +143,32 @@ again:
  *  stress_sem()
  *	stress system by POSIX sem ops
  */
-int stress_sem(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_sem(const args_t *args)
 {
 	pid_t pids[MAX_SEMAPHORE_PROCS];
 	uint64_t i;
 
-	(void)instance;
-
 	if (!set_semaphore_posix_procs) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_semaphore_posix_procs = MAX_SEMAPHORE_PROCS;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_semaphore_posix_procs = MIN_SEMAPHORE_PROCS;
 	}
 
-	if (!shared->sem_posix.init) {
-		pr_err(stderr, "%s: aborting, semaphore not initialised\n", name);
+	if (!g_shared->sem_posix.init) {
+		pr_err("%s: aborting, semaphore not initialised\n", args->name);
 		return EXIT_FAILURE;
 	}
 
 	memset(pids, 0, sizeof(pids));
 	for (i = 0; i < opt_semaphore_posix_procs; i++) {
-		pids[i] = semaphore_posix_spawn(name, max_ops, counter);
-		if (!opt_do_run || pids[i] < 0)
+		pids[i] = semaphore_posix_spawn(args);
+		if (!g_keep_stressing_flag || pids[i] < 0)
 			goto reap;
 	}
 
 	/* Wait for termination */
-	while (opt_do_run && (!max_ops || *counter < max_ops))
+	while (keep_stressing())
 		(void)shim_usleep(100000);
 reap:
 	for (i = 0; i < opt_semaphore_posix_procs; i++) {
@@ -206,12 +194,8 @@ void stress_semaphore_posix_destroy(void)
 {
 }
 
-int stress_sem(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_sem(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
