@@ -31,11 +31,11 @@
 static int64_t opt_sendfile_size = DEFAULT_SENDFILE_SIZE;
 static bool set_sendfile_size = false;
 
-void stress_set_sendfile_size(const char *optarg)
+void stress_set_sendfile_size(const char *opt)
 {
 	set_sendfile_size = true;
-	opt_sendfile_size = get_uint64_byte(optarg);
-	check_range("sendfile-size", opt_sendfile_size,
+	opt_sendfile_size = get_uint64_byte(opt);
+	check_range_bytes("sendfile-size", opt_sendfile_size,
 		MIN_SENDFILE_SIZE, MAX_SENDFILE_SIZE);
 }
 
@@ -45,47 +45,42 @@ void stress_set_sendfile_size(const char *optarg)
  *  stress_sendfile
  *	stress reading of a temp file and writing to /dev/null via sendfile
  */
-int stress_sendfile(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_sendfile(const args_t *args)
 {
 	char filename[PATH_MAX];
 	int fdin, fdout, ret, rc = EXIT_SUCCESS;
 	size_t sz;
-	const pid_t pid = getpid();
 
 	if (!set_sendfile_size) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_sendfile_size = MAX_SENDFILE_SIZE;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_sendfile_size = MIN_SENDFILE_SIZE;
 	}
 	sz = (size_t)opt_sendfile_size;
 
-	ret = stress_temp_dir_mk(name, pid, instance);
+	ret = stress_temp_dir_mk_args(args);
 	if (ret < 0)
 		return exit_status(-ret);
 
 	(void)umask(0077);
 
-	(void)stress_temp_filename(filename, sizeof(filename),
-		name, pid, instance, mwc32());
+	(void)stress_temp_filename_args(args,
+		filename, sizeof(filename), mwc32());
 
 	if ((fdin = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
 		rc = exit_status(errno);
-		pr_fail_err(name, "open");
+		pr_fail_err("open");
 		goto dir_out;
 	}
 	ret = posix_fallocate(fdin, (off_t)0, (off_t)sz);
 	if (ret < 0) {
 		rc = exit_status(errno);
-		pr_fail_err(name, "open");
+		pr_fail_err("open");
 		goto dir_out;
 	}
 	if ((fdout = open("/dev/null", O_WRONLY)) < 0) {
-		pr_fail_err(name, "open");
+		pr_fail_err("open");
 		rc = EXIT_FAILURE;
 		goto close_in;
 	}
@@ -95,12 +90,12 @@ int stress_sendfile(
 		if (sendfile(fdout, fdin, &offset, sz) < 0) {
 			if (errno == EINTR)
 				continue;
-			pr_fail_err(name, "sendfile");
+			pr_fail_err("sendfile");
 			rc = EXIT_FAILURE;
 			goto close_out;
 		}
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
 close_out:
 	(void)close(fdout);
@@ -108,17 +103,13 @@ close_in:
 	(void)close(fdin);
 	(void)unlink(filename);
 dir_out:
-	(void)stress_temp_dir_rm(name, pid, instance);
+	(void)stress_temp_dir_rm_args(args);
 
 	return rc;
 }
 #else
-int stress_sendfile(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_sendfile(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
