@@ -49,7 +49,7 @@ static size_t opt_shm_sysv_segments = DEFAULT_SHM_SYSV_SEGMENTS;
 static bool set_shm_sysv_bytes = false;
 static bool set_shm_sysv_segments = false;
 
-static int shm_flags[] = {
+static const int shm_flags[] = {
 #if defined(SHM_HUGETLB)
 	SHM_HUGETLB,
 #endif
@@ -68,18 +68,20 @@ static int shm_flags[] = {
 	0
 };
 
-void stress_set_shm_sysv_bytes(const char *optarg)
+void stress_set_shm_sysv_bytes(const char *opt)
 {
 	set_shm_sysv_bytes = true;
-	opt_shm_sysv_bytes = (size_t)get_uint64_byte(optarg);
-	check_range("shm-sysv-bytes", opt_shm_sysv_bytes,
-		MIN_SHM_SYSV_BYTES, MAX_SHM_SYSV_BYTES);
+	opt_shm_sysv_bytes = (size_t)get_uint64_byte(opt);
+	check_range_bytes("shm-sysv-bytes", opt_shm_sysv_bytes,
+		MIN_SHM_SYSV_BYTES, MAX_MEM_LIMIT);
 }
 
-void stress_set_shm_sysv_segments(const char *optarg)
+void stress_set_shm_sysv_segments(const char *opt)
 {
 	opt_shm_sysv_segments = true;
-	opt_shm_sysv_segments = (size_t)get_uint64_byte(optarg);
+	opt_shm_sysv_segments = (size_t)
+		get_uint64_byte_memory(opt,
+			stressor_instances(STRESS_SHM_SYSV));
 	check_range("shm-sysv-segments", opt_shm_sysv_segments,
 		MIN_SHM_SYSV_SEGMENTS, MAX_SHM_SYSV_SEGMENTS);
 }
@@ -117,7 +119,7 @@ static MLOCKED void handle_shm_sysv_sigalrm(int dummy)
 {
 	(void)dummy;
 
-	opt_do_run = false;
+	g_keep_stressing_flag = false;
 }
 
 /*
@@ -128,10 +130,8 @@ static MLOCKED void handle_shm_sysv_sigalrm(int dummy)
  *	be reaped cleanly if this process gets prematurely killed.
  */
 static int stress_shm_sysv_child(
+	const args_t *args,
 	const int fd,
-	uint64_t *const counter,
-	const uint64_t max_ops,
-	const char *name,
 	const size_t max_sz,
 	const size_t page_size)
 {
@@ -145,7 +145,7 @@ static int stress_shm_sysv_child(
 	int mask = ~0;
 	int32_t instances;
 
-	if (stress_sighandler(name, SIGALRM, handle_shm_sysv_sigalrm, NULL) < 0)
+	if (stress_sighandler(args->name, SIGALRM, handle_shm_sysv_sigalrm, NULL) < 0)
 		return EXIT_FAILURE;
 
 	memset(addrs, 0, sizeof(addrs));
@@ -154,7 +154,7 @@ static int stress_shm_sysv_child(
 		shm_ids[i] = -1;
 
 	/* Make sure this is killable by OOM killer */
-	set_oom_adjustment(name, true);
+	set_oom_adjustment(args->name, true);
 
 	if ((instances = stressor_instances(STRESS_SHM_SYSV)) < 1)
 		instances = stress_get_processors_configured();
@@ -179,7 +179,7 @@ static int stress_shm_sysv_child(
 				sz = shmall;
 			if ((freemem > page_size) && sz > freemem)
 				sz = freemem;
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				goto reap;
 
 			for (count = 0; count < KEY_GET_RETRIES; count++) {
@@ -195,7 +195,7 @@ static int stress_shm_sysv_child(
 				do {
 					size_t j;
 
-					if (!opt_do_run)
+					if (!g_keep_stressing_flag)
 						goto reap;
 
 					/* Get a unique random key */
@@ -206,7 +206,7 @@ static int stress_shm_sysv_child(
 							break;
 						}
 					}
-					if (!opt_do_run)
+					if (!g_keep_stressing_flag)
 						goto reap;
 
 				} while (!unique);
@@ -232,7 +232,7 @@ static int stress_shm_sysv_child(
 			}
 			if (shm_id < 0) {
 				ok = false;
-				pr_fail_err(name, "shmget");
+				pr_fail_err("shmget");
 				rc = EXIT_FAILURE;
 				goto reap;
 			}
@@ -241,8 +241,8 @@ static int stress_shm_sysv_child(
 			msg.index = i;
 			msg.shm_id = shm_id;
 			if (write(fd, &msg, sizeof(msg)) < 0) {
-				pr_err(stderr, "%s: write failed: errno=%d: (%s)\n",
-					name, errno, strerror(errno));
+				pr_err("%s: write failed: errno=%d: (%s)\n",
+					args->name, errno, strerror(errno));
 				rc = EXIT_FAILURE;
 				goto reap;
 			}
@@ -250,7 +250,7 @@ static int stress_shm_sysv_child(
 			addr = shmat(shm_id, NULL, 0);
 			if (addr == (char *) -1) {
 				ok = false;
-				pr_fail_err(name, "shmat");
+				pr_fail_err("shmat");
 				rc = EXIT_FAILURE;
 				goto reap;
 			}
@@ -258,20 +258,20 @@ static int stress_shm_sysv_child(
 			shm_ids[i] = shm_id;
 			keys[i] = key;
 
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				goto reap;
 			(void)mincore_touch_pages(addr, sz);
 			(void)shim_msync(addr, sz, (mwc32() & 1) ? MS_ASYNC : MS_SYNC);
 
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				goto reap;
 			(void)madvise_random(addr, sz);
 
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				goto reap;
 			if (stress_shm_sysv_check(addr, sz, page_size) < 0) {
 				ok = false;
-				pr_fail(stderr, "%s: memory check failed\n", name);
+				pr_fail("%s: memory check failed\n", args->name);
 				rc = EXIT_FAILURE;
 				goto reap;
 			}
@@ -280,7 +280,7 @@ static int stress_shm_sysv_child(
 				struct shmid_ds ds;
 
 				if (shmctl(shm_id, IPC_STAT, &ds) < 0)
-					pr_fail_dbg(name, "shmctl IPC_STAT");
+					pr_fail_dbg("shmctl IPC_STAT");
 			}
 #endif
 #if defined(__linux__) && defined(IPC_INFO)
@@ -288,7 +288,7 @@ static int stress_shm_sysv_child(
 				struct shminfo s;
 
 				if (shmctl(shm_id, IPC_INFO, (struct shmid_ds *)&s) < 0)
-					pr_fail_dbg(name, "semctl IPC_INFO");
+					pr_fail_dbg("semctl IPC_INFO");
 			}
 #endif
 #if defined(__linux__) && defined(SHM_INFO)
@@ -296,22 +296,22 @@ static int stress_shm_sysv_child(
 				struct shm_info s;
 
 				if (shmctl(shm_id, SHM_INFO, (struct shmid_ds *)&s) < 0)
-					pr_fail_dbg(name, "semctl SHM_INFO");
+					pr_fail_dbg("semctl SHM_INFO");
 			}
 #endif
-			(*counter)++;
+			inc_counter(args);
 		}
 reap:
 		for (i = 0; i < opt_shm_sysv_segments; i++) {
 			if (addrs[i]) {
 				if (shmdt(addrs[i]) < 0) {
-					pr_fail_err(name, "shmdt");
+					pr_fail_err("shmdt");
 				}
 			}
 			if (shm_ids[i] >= 0) {
 				if (shmctl(shm_ids[i], IPC_RMID, NULL) < 0) {
 					if (errno != EIDRM)
-						pr_fail_err(name, "shmctl");
+						pr_fail_err("shmctl");
 				}
 			}
 
@@ -319,22 +319,22 @@ reap:
 			msg.index = i;
 			msg.shm_id = -1;
 			if (write(fd, &msg, sizeof(msg)) < 0) {
-				pr_dbg(stderr, "%s: write failed: errno=%d: (%s)\n",
-					name, errno, strerror(errno));
+				pr_dbg("%s: write failed: errno=%d: (%s)\n",
+					args->name, errno, strerror(errno));
 				ok = false;
 			}
 			addrs[i] = NULL;
 			shm_ids[i] = -1;
 			keys[i] = 0;
 		}
-	} while (ok && opt_do_run && (!max_ops || *counter < max_ops));
+	} while (ok && keep_stressing());
 
 	/* Inform parent of end of run */
 	msg.index = -1;
 	msg.shm_id = -1;
 	if (write(fd, &msg, sizeof(msg)) < 0) {
-		pr_err(stderr, "%s: write failed: errno=%d: (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: write failed: errno=%d: (%s)\n",
+			args->name, errno, strerror(errno));
 		rc = EXIT_FAILURE;
 	}
 
@@ -345,13 +345,9 @@ reap:
  *  stress_shm_sysv()
  *	stress SYSTEM V shared memory
  */
-int stress_shm_sysv(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_shm_sysv(const args_t *args)
 {
-	const size_t page_size = stress_get_pagesize();
+	const size_t page_size = args->page_size;
 	size_t orig_sz, sz;
 	int pipefds[2];
 	int rc = EXIT_SUCCESS;
@@ -361,23 +357,23 @@ int stress_shm_sysv(
 	uint32_t restarts = 0;
 
 	if (!set_shm_sysv_bytes) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_shm_sysv_bytes = MAX_SHM_SYSV_BYTES;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_shm_sysv_bytes = MIN_SHM_SYSV_BYTES;
 	}
 
 	if (!set_shm_sysv_segments) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_shm_sysv_segments = MAX_SHM_SYSV_SEGMENTS;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_shm_sysv_segments = MIN_SHM_SYSV_SEGMENTS;
 	}
 	orig_sz = sz = opt_shm_sysv_bytes & ~(page_size - 1);
 
-	while (opt_do_run && retry) {
+	while (g_keep_stressing_flag && retry) {
 		if (pipe(pipefds) < 0) {
-			pr_fail_dbg(name, "pipe");
+			pr_fail_dbg("pipe");
 			return EXIT_FAILURE;
 		}
 fork_again:
@@ -386,8 +382,8 @@ fork_again:
 			/* Can't fork, retry? */
 			if (errno == EAGAIN)
 				goto fork_again;
-			pr_err(stderr, "%s: fork failed: errno=%d: (%s)\n",
-				name, errno, strerror(errno));
+			pr_err("%s: fork failed: errno=%d: (%s)\n",
+				args->name, errno, strerror(errno));
 			(void)close(pipefds[0]);
 			(void)close(pipefds[1]);
 
@@ -397,14 +393,14 @@ fork_again:
 			/* Parent */
 			int status, shm_ids[MAX_SHM_SYSV_SEGMENTS];
 
-			(void)setpgid(pid, pgrp);
-			set_oom_adjustment(name, false);
+			(void)setpgid(pid, g_pgrp);
+			set_oom_adjustment(args->name, false);
 			(void)close(pipefds[1]);
 
 			for (i = 0; i < (ssize_t)MAX_SHM_SYSV_SEGMENTS; i++)
 				shm_ids[i] = -1;
 
-			while (opt_do_run) {
+			while (g_keep_stressing_flag) {
 				shm_msg_t 	msg;
 				ssize_t n;
 
@@ -419,10 +415,10 @@ fork_again:
 					if ((errno == EAGAIN) || (errno == EINTR))
 						continue;
 					if (errno) {
-						pr_fail_dbg(name, "read");
+						pr_fail_dbg("read");
 						break;
 					}
-					pr_fail_dbg(name, "zero byte read");
+					pr_fail_dbg("zero byte read");
 					break;
 				}
 				if ((msg.index < 0) ||
@@ -438,9 +434,9 @@ fork_again:
 				if ((WTERMSIG(status) == SIGKILL) ||
 				    (WTERMSIG(status) == SIGBUS)) {
 					log_system_mem_info();
-					pr_dbg(stderr, "%s: assuming killed by OOM killer, "
+					pr_dbg("%s: assuming killed by OOM killer, "
 						"restarting again (instance %d)\n",
-						name, instance);
+						args->name, args->instance);
 					restarts++;
 				}
 			}
@@ -458,7 +454,7 @@ fork_again:
 			}
 		} else if (pid == 0) {
 			/* Child, stress memory */
-			(void)setpgid(0, pgrp);
+			(void)setpgid(0, g_pgrp);
 			stress_parent_died_alarm();
 
 			/*
@@ -466,22 +462,21 @@ fork_again:
 			 * doubles the OOM score
 			 */
 			if (nice(5) < 0)
-				pr_dbg(stderr, "%s: nice of child failed, "
-					"(instance %d)\n", name, instance);
+				pr_dbg("%s: nice of child failed, "
+					"(instance %d)\n", args->name, args->instance);
 
 			(void)close(pipefds[0]);
-			rc = stress_shm_sysv_child(pipefds[1], counter,
-				max_ops, name, sz, page_size);
+			rc = stress_shm_sysv_child(args, pipefds[1], sz, page_size);
 			(void)close(pipefds[1]);
 			_exit(rc);
 		}
 	}
 	if (orig_sz != sz)
-		pr_dbg(stderr, "%s: reduced shared memory size from "
-			"%zu to %zu bytes\n", name, orig_sz, sz);
+		pr_dbg("%s: reduced shared memory size from "
+			"%zu to %zu bytes\n", args->name, orig_sz, sz);
 	if (restarts) {
-		pr_dbg(stderr, "%s: OOM restarts: %" PRIu32 "\n",
-			name, restarts);
+		pr_dbg("%s: OOM restarts: %" PRIu32 "\n",
+			args->name, restarts);
 	}
 	return rc;
 }
