@@ -32,42 +32,36 @@
  *  stress_sigfd
  *	stress signalfd reads
  */
-int stress_sigfd(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_sigfd(const args_t *args)
 {
-	pid_t pid, ppid = getpid();
+	pid_t pid, ppid = args->pid;
 	int sfd;
 	sigset_t mask;
 
-	(void)instance;
-
 	sigemptyset(&mask);
 	sigaddset(&mask, SIGRTMIN);
 	if (sigprocmask(SIG_BLOCK, &mask, NULL) < 0) {
-		pr_fail_dbg(name, "sigprocmask");
+		pr_fail_dbg("sigprocmask");
 		return EXIT_FAILURE;
 	}
 	sfd = signalfd(-1, &mask, 0);
 	if (sfd < 0) {
-		pr_fail_dbg(name, "signalfd");
+		pr_fail_dbg("signalfd");
 		return EXIT_FAILURE;
 	}
 
 again:
 	pid = fork();
 	if (pid < 0) {
-		if (opt_do_run && (errno == EAGAIN))
+		if (g_keep_stressing_flag && (errno == EAGAIN))
 			goto again;
-		pr_fail_dbg(name, "fork");
+		pr_fail_dbg("fork");
 		return EXIT_FAILURE;
 	} else if (pid == 0) {
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
 
-		while (opt_do_run) {
+		while (g_keep_stressing_flag) {
 			union sigval s;
 			int ret;
 
@@ -83,7 +77,7 @@ again:
 		/* Parent */
 		int status;
 
-		(void)setpgid(pid, pgrp);
+		(void)setpgid(pid, g_pgrp);
 		do {
 			int ret;
 			struct signalfd_siginfo fdsi;
@@ -93,7 +87,7 @@ again:
 				if ((errno == EAGAIN) || (errno == EINTR))
 					continue;
 				if (errno) {
-					pr_fail_dbg(name, "signalfd read");
+					pr_fail_dbg("signalfd read");
 					(void)close(sfd);
 					_exit(EXIT_FAILURE);
 				}
@@ -101,15 +95,15 @@ again:
 			}
 			if (ret == 0)
 				break;
-			if (opt_flags & OPT_FLAGS_VERIFY) {
+			if (g_opt_flags & OPT_FLAGS_VERIFY) {
 				if (fdsi.ssi_signo != (uint32_t)SIGRTMIN) {
-					pr_fail(stderr, "%s: unexpected signal %d",
-						name, fdsi.ssi_signo);
+					pr_fail("%s: unexpected signal %d",
+						args->name, fdsi.ssi_signo);
 					break;
 				}
 			}
-			(*counter)++;
-		} while (opt_do_run && (!max_ops || *counter < max_ops));
+			inc_counter(args);
+		} while (keep_stressing());
 
 		/* terminal child */
 		(void)kill(pid, SIGKILL);
@@ -118,12 +112,8 @@ again:
 	return EXIT_SUCCESS;
 }
 #else
-int stress_sigfd(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_sigfd(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
