@@ -37,36 +37,29 @@ static void MLOCKED stress_usr1_handler(int dummy)
  *  stress_sigpending
  *	stress sigpending system call
  */
-int stress_sigpending(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_sigpending(const args_t *args)
 {
 	sigset_t sigset;
-	const pid_t mypid = getpid();
 
-	(void)instance;
-
-	if (stress_sighandler(name, SIGUSR1, stress_usr1_handler, NULL) < 0)
+	if (stress_sighandler(args->name, SIGUSR1, stress_usr1_handler, NULL) < 0)
 		return EXIT_FAILURE;
 
 	do {
 		sigemptyset(&sigset);
 		sigaddset(&sigset, SIGUSR1);
 		if (sigprocmask(SIG_SETMASK, &sigset, NULL) < 0) {
-			pr_fail_err(name, "sigprocmask");
+			pr_fail_err("sigprocmask");
 			return EXIT_FAILURE;
 		}
 
-		(void)kill(mypid, SIGUSR1);
+		(void)kill(args->pid, SIGUSR1);
 		if (sigpending(&sigset) < 0) {
-			pr_fail_err(name, "sigpending");
+			pr_fail_err("sigpending");
 			continue;
 		}
 		/* We should get a SIGUSR1 here */
 		if (!sigismember(&sigset, SIGUSR1)) {
-			pr_fail_err(name, "sigismember");
+			pr_fail_err("sigismember");
 			continue;
 		}
 
@@ -76,16 +69,16 @@ int stress_sigpending(
 
 		/* And it is no longer pending */
 		if (sigpending(&sigset) < 0) {
-			pr_fail_err(name, "sigpending");
+			pr_fail_err("sigpending");
 			continue;
 		}
 		if (sigismember(&sigset, SIGUSR1)) {
-			pr_fail_err(name, "sigismember");
+			pr_fail_err("sigismember");
 			continue;
 		}
-		/* Success! */
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+
+		inc_counter(args);
+	} while (keep_stressing());
 
 	return EXIT_SUCCESS;
 }
