@@ -35,42 +35,38 @@ static void MLOCKED stress_sigqhandler(int dummy)
  *  stress_sigq
  *	stress by heavy sigqueue message sending
  */
-int stress_sigq(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_sigq(const args_t *args)
 {
 	pid_t pid;
 
-	if (stress_sighandler(name, SIGUSR1, stress_sigqhandler, NULL) < 0)
+	if (stress_sighandler(args->name, SIGUSR1, stress_sigqhandler, NULL) < 0)
 		return EXIT_FAILURE;
 
 again:
 	pid = fork();
 	if (pid < 0) {
-		if (opt_do_run && (errno == EAGAIN))
+		if (g_keep_stressing_flag && (errno == EAGAIN))
 			goto again;
-		pr_fail_dbg(name, "fork");
+		pr_fail_dbg("fork");
 		return EXIT_FAILURE;
 	} else if (pid == 0) {
 		sigset_t mask;
 
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
 
 		sigemptyset(&mask);
 		sigaddset(&mask, SIGUSR1);
 
-		while (opt_do_run) {
+		while (g_keep_stressing_flag) {
 			siginfo_t info;
 			sigwaitinfo(&mask, &info);
 			if (info.si_value.sival_int)
 				break;
 		}
-		pr_dbg(stderr, "%s: child got termination notice\n", name);
-		pr_dbg(stderr, "%s: exited on pid [%d] (instance %" PRIu32 ")\n",
-			name, getpid(), instance);
+		pr_dbg("%s: child got termination notice\n", args->name);
+		pr_dbg("%s: exited on pid [%d] (instance %" PRIu32 ")\n",
+			args->name, getpid(), args->instance);
 		_exit(0);
 	} else {
 		/* Parent */
@@ -81,10 +77,10 @@ again:
 			memset(&s, 0, sizeof(s));
 			s.sival_int = 0;
 			sigqueue(pid, SIGUSR1, s);
-			(*counter)++;
-		} while (opt_do_run && (!max_ops || *counter < max_ops));
+			inc_counter(args);
+		} while (keep_stressing());
 
-		pr_dbg(stderr, "%s: parent sent termination notice\n", name);
+		pr_dbg("%s: parent sent termination notice\n", args->name);
 		memset(&s, 0, sizeof(s));
 		s.sival_int = 1;
 		sigqueue(pid, SIGUSR1, s);
@@ -97,12 +93,8 @@ again:
 	return EXIT_SUCCESS;
 }
 #else
-int stress_sigq(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_sigq(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
