@@ -30,11 +30,7 @@
  *  stress_sigsuspend
  *	stress sigsuspend
  */
-int stress_sigsuspend(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_sigsuspend(const args_t *args)
 {
 	pid_t pid[MAX_SIGSUSPEND_PIDS];
 	size_t n, i;
@@ -45,13 +41,11 @@ int stress_sigsuspend(
 	const size_t counters_size =
 		(sizeof(uint64_t) * MAX_SIGSUSPEND_PIDS) << CACHE_STRIDE_SHIFT;
 
-	(void)instance;
-
 	v_counters = counters = (uint64_t *)mmap(NULL, counters_size,
 			PROT_READ | PROT_WRITE,
 			MAP_SHARED | MAP_ANONYMOUS, -1, 0);
 	if (counters == MAP_FAILED) {
-		pr_fail_dbg(name, "mmap");
+		pr_fail_dbg("mmap");
 		return EXIT_FAILURE;
 	}
 	memset(counters, 0, counters_size);
@@ -63,21 +57,21 @@ int stress_sigsuspend(
 again:
 		pid[n] = fork();
 		if (pid[n] < 0) {
-			if (opt_do_run && (errno == EAGAIN))
+			if (g_keep_stressing_flag && (errno == EAGAIN))
 				goto again;
-			pr_fail_dbg(name, "fork");
+			pr_fail_dbg("fork");
 			goto reap;
 		} else if (pid[n] == 0) {
-			(void)setpgid(0, pgrp);
+			(void)setpgid(0, g_pgrp);
 			stress_parent_died_alarm();
 
-			while (opt_do_run) {
+			while (g_keep_stressing_flag) {
 				sigsuspend(&mask);
 				v_counters[n << CACHE_STRIDE_SHIFT]++;
 			}
 			_exit(0);
 		}
-		(void)setpgid(pid[n], pgrp);
+		(void)setpgid(pid[n], g_pgrp);
 	}
 
 	/* Parent */
@@ -85,11 +79,11 @@ again:
 		c = 0;
 		for (i = 0; i < n; i++) {
 			c += v_counters[i << CACHE_STRIDE_SHIFT];
-			kill(pid[i], SIGUSR1);
+			(void)kill(pid[i], SIGUSR1);
 		}
-	} while (opt_do_run && (!max_ops || c < max_ops));
+	} while (keep_stressing());
 
-	*counter = c;
+	*args->counter = c;
 
 reap:
 	for (i = 0; i < n; i++) {
