@@ -31,7 +31,6 @@
 #include <sys/un.h>
 
 #define MSG_ID			'M'
-#define MAX_FDS			(65536)
 
 #endif
 
@@ -41,9 +40,9 @@ static int opt_socket_fd_port = DEFAULT_SOCKET_FD_PORT;
  *  stress_set_socket_fd_port()
  *	set port to use
  */
-void stress_set_socket_fd_port(const char *optarg)
+void stress_set_socket_fd_port(const char *opt)
 {
-	stress_set_net_port("sockfd-port", optarg,
+	stress_set_net_port("sockfd-port", opt,
 		MIN_SOCKET_FD_PORT, MAX_SOCKET_FD_PORT - STRESS_PROCS_MAX,
 		&opt_socket_fd_port);
 }
@@ -132,16 +131,13 @@ static inline int stress_socket_fd_recv(const int fd)
  *	client reader
  */
 static void stress_socket_client(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name,
+	const args_t *args,
 	const pid_t ppid,
 	const size_t max_fd)
 {
 	struct sockaddr *addr;
 
-	(void)setpgid(0, pgrp);
+	(void)setpgid(0, g_pgrp);
 	stress_parent_died_alarm();
 
 	do {
@@ -149,18 +145,18 @@ static void stress_socket_client(
 		size_t i;
 		socklen_t addr_len = 0;
 retry:
-		if (!opt_do_run) {
+		if (!g_keep_stressing_flag) {
 			(void)kill(getppid(), SIGALRM);
 			exit(EXIT_FAILURE);
 		}
 		if ((fd = socket(AF_UNIX, SOCK_STREAM, 0)) < 0) {
-			pr_fail_dbg(name, "socket");
+			pr_fail_dbg("socket");
 			/* failed, kick parent to finish */
 			(void)kill(getppid(), SIGALRM);
 			exit(EXIT_FAILURE);
 		}
 
-		stress_set_sockaddr(name, instance, ppid,
+		stress_set_sockaddr(args->name, args->instance, ppid,
 			AF_UNIX, opt_socket_fd_port,
 			&addr, &addr_len, NET_ADDR_ANY);
 		if (connect(fd, addr, addr_len) < 0) {
@@ -169,7 +165,7 @@ retry:
 			retries++;
 			if (retries > 100) {
 				/* Give up.. */
-				pr_fail_dbg(name, "connect");
+				pr_fail_dbg("connect");
 				(void)kill(getppid(), SIGALRM);
 				exit(EXIT_FAILURE);
 			}
@@ -186,7 +182,7 @@ retry:
 
 		(void)shutdown(fd, SHUT_RDWR);
 		(void)close(fd);
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (keep_stressing());
 
 	struct sockaddr_un *addr_un = (struct sockaddr_un *)addr;
 	(void)unlink(addr_un->sun_path);
@@ -202,7 +198,7 @@ retry:
 static void MLOCKED handle_socket_sigalrm(int dummy)
 {
 	(void)dummy;
-	opt_do_run = false;
+	g_keep_stressing_flag = false;
 }
 
 /*
@@ -210,10 +206,7 @@ static void MLOCKED handle_socket_sigalrm(int dummy)
  *	server writer
  */
 static int stress_socket_server(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name,
+	const args_t *args,
 	const pid_t pid,
 	const pid_t ppid,
 	const size_t max_fd)
@@ -226,34 +219,34 @@ static int stress_socket_server(
 	uint64_t msgs = 0;
 	int rc = EXIT_SUCCESS;
 
-	(void)setpgid(pid, pgrp);
+	(void)setpgid(pid, g_pgrp);
 
-	if (stress_sighandler(name, SIGALRM, handle_socket_sigalrm, NULL) < 0) {
+	if (stress_sighandler(args->name, SIGALRM, handle_socket_sigalrm, NULL) < 0) {
 		rc = EXIT_FAILURE;
 		goto die;
 	}
 	if ((fd = socket(AF_UNIX, SOCK_STREAM, 0)) < 0) {
 		rc = exit_status(errno);
-		pr_fail_dbg(name, "socket");
+		pr_fail_dbg("socket");
 		goto die;
 	}
 	if (setsockopt(fd, SOL_SOCKET, SO_REUSEADDR,
 		&so_reuseaddr, sizeof(so_reuseaddr)) < 0) {
-		pr_fail_dbg(name, "setsockopt");
+		pr_fail_dbg("setsockopt");
 		rc = EXIT_FAILURE;
 		goto die_close;
 	}
 
-	stress_set_sockaddr(name, instance, ppid,
+	stress_set_sockaddr(args->name, args->instance, ppid,
 		AF_UNIX, opt_socket_fd_port,
 		&addr, &addr_len, NET_ADDR_ANY);
 	if (bind(fd, addr, addr_len) < 0) {
 		rc = exit_status(errno);
-		pr_fail_dbg(name, "bind");
+		pr_fail_dbg("bind");
 		goto die_close;
 	}
 	if (listen(fd, 10) < 0) {
-		pr_fail_dbg(name, "listen");
+		pr_fail_dbg("listen");
 		rc = EXIT_FAILURE;
 		goto die_close;
 	}
@@ -273,8 +266,8 @@ static int stress_socket_server(
 			}
 			(void)close(sfd);
 		}
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
 die_close:
 	(void)close(fd);
@@ -288,7 +281,7 @@ die:
 		(void)kill(pid, SIGKILL);
 		(void)waitpid(pid, &status, 0);
 	}
-	pr_dbg(stderr, "%s: %" PRIu64 " messages sent\n", name, msgs);
+	pr_dbg("%s: %" PRIu64 " messages sent\n", args->name, msgs);
 
 	return rc;
 }
@@ -297,38 +290,30 @@ die:
  *  stress_sockfd
  *	stress socket fd passing
  */
-int stress_sockfd(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_sockfd(const args_t *args)
 {
 	pid_t pid, ppid = getppid();
 	const size_t max_fd = stress_get_file_limit();
 
-	pr_dbg(stderr, "%s: process [%d] using socket port %d\n",
-		name, getpid(), opt_socket_fd_port + instance);
+	pr_dbg("%s: process [%d] using socket port %d\n",
+		args->name, args->pid, opt_socket_fd_port + args->instance);
 again:
 	pid = fork();
 	if (pid < 0) {
-		if (opt_do_run && (errno == EAGAIN))
+		if (g_keep_stressing_flag && (errno == EAGAIN))
 			goto again;
-		pr_fail_dbg(name, "fork");
+		pr_fail_dbg("fork");
 		return EXIT_FAILURE;
 	} else if (pid == 0) {
-		stress_socket_client(counter, instance, max_ops, name, ppid, max_fd);
+		stress_socket_client(args, ppid, max_fd);
 		exit(EXIT_SUCCESS);
 	} else {
-		return stress_socket_server(counter, instance, max_ops, name, pid, ppid, max_fd);
+		return stress_socket_server(args, pid, ppid, max_fd);
 	}
 }
 #else
-int stress_sockfd(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_sockfd(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
