@@ -69,7 +69,6 @@ static void socket_pair_close(
 
 	for (i = 0; i < max; i++)
 		(void)close(fds[i][which]);
-
 }
 
 /*
@@ -77,10 +76,7 @@ static void socket_pair_close(
  *	this stressor needs to be oom-able in the parent
  *	and child cases
  */
-static int stress_sockpair_oomable(
-	uint64_t *const counter,
-	const uint64_t max_ops,
-	const char *name)
+static int stress_sockpair_oomable(const args_t *args)
 {
 	pid_t pid;
 	int socket_pair_fds[MAX_SOCKET_PAIRS][2], i, max;
@@ -91,30 +87,30 @@ static int stress_sockpair_oomable(
 	}
 
 	if (max == 0) {
-		pr_fail_dbg(name, "socket_pair");
+		pr_fail_dbg("socket_pair");
 		return EXIT_FAILURE;
 	}
 
 again:
 	pid = fork();
 	if (pid < 0) {
-		if (opt_do_run && (errno == EAGAIN))
+		if (g_keep_stressing_flag && (errno == EAGAIN))
 			goto again;
 		socket_pair_close(socket_pair_fds, max, 0);
 		socket_pair_close(socket_pair_fds, max, 1);
-		pr_fail_dbg(name, "fork");
+		pr_fail_dbg("fork");
 		return EXIT_FAILURE;
 	} else if (pid == 0) {
-		set_oom_adjustment(name, true);
-		(void)setpgid(0, pgrp);
+		set_oom_adjustment(args->name, true);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
 
 		socket_pair_close(socket_pair_fds, max, 1);
-		while (opt_do_run) {
+		while (g_keep_stressing_flag) {
 			uint8_t buf[SOCKET_PAIR_BUF];
 			ssize_t n;
 
-			for (i = 0; opt_do_run && (i < max); i++) {
+			for (i = 0; g_keep_stressing_flag && (i < max); i++) {
 				n = read(socket_pair_fds[i][0], buf, sizeof(buf));
 				if (n <= 0) {
 					if ((errno == EAGAIN) || (errno == EINTR))
@@ -124,15 +120,15 @@ again:
 					if (errno == EMFILE) /* Occurs on socket shutdown */
 						goto abort;
 					if (errno) {
-						pr_fail_dbg(name, "read");
-						break;
+						pr_fail_dbg("read");
+						goto abort;
 					}
 					continue;
 				}
-				if ((opt_flags & OPT_FLAGS_VERIFY) &&
+				if ((g_opt_flags & OPT_FLAGS_VERIFY) &&
 				    socket_pair_memchk(buf, (size_t)n)) {
-					pr_fail(stderr, "%s: socket_pair read error detected, "
-						"failed to read expected data\n", name);
+					pr_fail("%s: socket_pair read error detected, "
+						"failed to read expected data\n", args->name);
 				}
 			}
 		}
@@ -143,11 +139,11 @@ abort:
 		uint8_t buf[SOCKET_PAIR_BUF];
 		int val = 0, status;
 
-		(void)setpgid(pid, pgrp);
+		(void)setpgid(pid, g_pgrp);
 		/* Parent */
 		socket_pair_close(socket_pair_fds, max, 0);
 		do {
-			for (i = 0; opt_do_run && (i < max); i++) {
+			for (i = 0; g_keep_stressing_flag && (i < max); i++) {
 				ssize_t ret;
 
 				socket_pair_memset(buf, val++, sizeof(buf));
@@ -156,18 +152,18 @@ abort:
 					if ((errno == EAGAIN) || (errno == EINTR))
 						continue;
 					if (errno) {
-						pr_fail_dbg(name, "write");
+						pr_fail_dbg("write");
 						break;
 					}
 					continue;
 				}
-				(*counter)++;
+				inc_counter(args);
 			}
-		} while (opt_do_run && (!max_ops || *counter < max_ops));
+		} while (keep_stressing());
 
 		for (i = 0; i < max; i++) {
 			if (shutdown(socket_pair_fds[i][1], SHUT_RDWR) < 0)
-				pr_fail_dbg(name, "socket shutdown");
+				pr_fail_dbg("socket shutdown");
 		}
 		(void)kill(pid, SIGKILL);
 		(void)waitpid(pid, &status, 0);
@@ -180,44 +176,39 @@ abort:
  *  stress_sockpair
  *	stress by heavy socket_pair I/O
  */
-int stress_sockpair(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_sockpair(const args_t *args)
 {
 	pid_t pid;
 	uint32_t restarts = 0;
 
-	(void)instance;
 again:
 	pid = fork();
 	if (pid < 0) {
-		if (opt_do_run && (errno == EAGAIN))
+		if (g_keep_stressing_flag && (errno == EAGAIN))
 			goto again;
 	} else if (pid > 0) {
 		int status, ret;
 
 		/* Parent, wait for child */
-		(void)setpgid(pid, pgrp);
+		(void)setpgid(pid, g_pgrp);
 		ret = waitpid(pid, &status, 0);
 		if (ret < 0) {
 			if (errno != EINTR)
-				pr_dbg(stderr, "%s: waitpid(): errno=%d (%s)\n",
-					name, errno, strerror(errno));
+				pr_dbg("%s: waitpid(): errno=%d (%s)\n",
+					args->name, errno, strerror(errno));
 			(void)kill(pid, SIGTERM);
 			(void)kill(pid, SIGKILL);
 			(void)waitpid(pid, &status, 0);
 		} else if (WIFSIGNALED(status)) {
-			pr_dbg(stderr, "%s: child died: %s (instance %d)\n",
-				name, stress_strsignal(WTERMSIG(status)),
-				instance);
+			pr_dbg("%s: child died: %s (instance %d)\n",
+				args->name, stress_strsignal(WTERMSIG(status)),
+				args->instance);
 			/* If we got killed by OOM killer, re-start */
 			if (WTERMSIG(status) == SIGKILL) {
 				log_system_mem_info();
-				pr_dbg(stderr, "%s: assuming killed by OOM killer, "
+				pr_dbg("%s: assuming killed by OOM killer, "
 					"restarting again (instance %d)\n",
-					name, instance);
+					args->name, args->instance);
 				restarts++;
 				goto again;
 			}
@@ -226,18 +217,18 @@ again:
 		/* Child, lets do some sockpair stressing... */
 		int ret;
 
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
-		set_oom_adjustment(name, true);
+		set_oom_adjustment(args->name, true);
 
-		ret = stress_sockpair_oomable(counter, max_ops, name);
+		ret = stress_sockpair_oomable(args);
 
 		exit(ret);
 	}
 
 	if (restarts > 0) {
-		pr_dbg(stderr, "%s: OOM restarts: %" PRIu32 "\n",
-			name, restarts);
+		pr_dbg("%s: OOM restarts: %" PRIu32 "\n",
+			args->name, restarts);
 	}
 	return EXIT_SUCCESS;
 }
