@@ -27,12 +27,14 @@
 static size_t opt_splice_bytes = DEFAULT_SPLICE_BYTES;
 static bool set_splice_bytes = false;
 
-void stress_set_splice_bytes(const char *optarg)
+void stress_set_splice_bytes(const char *opt)
 {
 	set_splice_bytes = true;
-	opt_splice_bytes = (size_t)get_uint64_byte(optarg);
-	check_range("splice-bytes", opt_splice_bytes,
-		MIN_SPLICE_BYTES, MAX_SPLICE_BYTES);
+	opt_splice_bytes = (size_t)
+		get_uint64_byte_memory(opt,
+			stressor_instances(STRESS_SPLICE));
+	check_range_bytes("splice-bytes", opt_splice_bytes,
+		MIN_SPLICE_BYTES, MAX_MEM_LIMIT);
 }
 
 #if defined(__linux__) && NEED_GLIBC(2,5,0)
@@ -41,39 +43,33 @@ void stress_set_splice_bytes(const char *optarg)
  *  stress_splice
  *	stress copying of /dev/zero to /dev/null
  */
-int stress_splice(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_splice(const args_t *args)
 {
 	int fd_in, fd_out, fds[2];
 
 	if (!set_splice_bytes) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_splice_bytes = MAX_SPLICE_BYTES;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_splice_bytes = MIN_SPLICE_BYTES;
 	}
 
-	(void)instance;
-
 	if (pipe(fds) < 0) {
-		pr_fail_err(name, "pipe");
+		pr_fail_err("pipe");
 		return EXIT_FAILURE;
 	}
 
 	if ((fd_in = open("/dev/zero", O_RDONLY)) < 0) {
 		(void)close(fds[0]);
 		(void)close(fds[1]);
-		pr_fail_err(name, "open");
+		pr_fail_err("open");
 		return EXIT_FAILURE;
 	}
 	if ((fd_out = open("/dev/null", O_WRONLY)) < 0) {
 		(void)close(fd_in);
 		(void)close(fds[0]);
 		(void)close(fds[1]);
-		pr_fail_err(name, "open");
+		pr_fail_err("open");
 		return EXIT_FAILURE;
 	}
 
@@ -92,8 +88,8 @@ int stress_splice(
 		if (ret < 0)
 			break;
 
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 	(void)close(fd_out);
 	(void)close(fd_in);
 	(void)close(fds[0]);
@@ -102,12 +98,8 @@ int stress_splice(
 	return EXIT_SUCCESS;
 }
 #else
-int stress_splice(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_splice(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
