@@ -42,19 +42,11 @@ static void MLOCKED stress_segvhandler(int dummy)
  *  stress_stack
  *	stress by forcing stack overflows
  */
-int stress_stack(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_stack(const args_t *args)
 {
-#if !defined(__minix__)
 	uint8_t stack[SIGSTKSZ + STACK_ALIGNMENT];
-	stack_t ss;
-#endif
 	pid_t pid;
 
-#if !defined(__minix__)
 	/*
 	 *  We need to create an alternative signal
 	 *  stack so when a segfault occurs we use
@@ -63,68 +55,62 @@ int stress_stack(
 	 *  stack
 	 */
 	memset(stack, 0, sizeof(stack));
-	ss.ss_sp = (void *)align_address(stack, STACK_ALIGNMENT);
-	ss.ss_size = SIGSTKSZ;
-	ss.ss_flags = 0;
-	if (sigaltstack(&ss, NULL) < 0) {
-		pr_fail_err(name, "sigaltstack");
+	if (stress_sigaltstack(stack, SIGSTKSZ) < 0)
 		return EXIT_FAILURE;
-	}
-#endif
 
 again:
 	pid = fork();
 	if (pid < 0) {
-		if (opt_do_run && (errno == EAGAIN))
+		if (g_keep_stressing_flag && (errno == EAGAIN))
 			goto again;
-		pr_err(stderr, "%s: fork failed: errno=%d: (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: fork failed: errno=%d: (%s)\n",
+			args->name, errno, strerror(errno));
 	} else if (pid > 0) {
 		int status, ret;
 
 		/* Parent, wait for child */
-		(void)setpgid(pid, pgrp);
+		(void)setpgid(pid, g_pgrp);
 		ret = waitpid(pid, &status, 0);
 		if (ret < 0) {
 			if (errno != EINTR)
-				pr_dbg(stderr, "%s: waitpid(): errno=%d (%s)\n",
-					name, errno, strerror(errno));
+				pr_dbg("%s: waitpid(): errno=%d (%s)\n",
+					args->name, errno, strerror(errno));
 			(void)kill(pid, SIGTERM);
 			(void)kill(pid, SIGKILL);
 			(void)waitpid(pid, &status, 0);
 		} else if (WIFSIGNALED(status)) {
-			pr_dbg(stderr, "%s: child died: %s (instance %d)\n",
-				name, stress_strsignal(WTERMSIG(status)),
-				instance);
+			pr_dbg("%s: child died: %s (instance %d)\n",
+				args->name, stress_strsignal(WTERMSIG(status)),
+				args->instance);
 			/* If we got killed by OOM killer, re-start */
 			if (WTERMSIG(status) == SIGKILL) {
 				log_system_mem_info();
-				pr_dbg(stderr, "%s: assuming killed by OOM "
+				pr_dbg("%s: assuming killed by OOM "
 					"killer, restarting again "
-					"(instance %d)\n", name, instance);
+					"(instance %d)\n", args->name, args->instance);
 				goto again;
 			}
 		}
 	} else if (pid == 0) {
 		char *start_ptr = sbrk(0);
 
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
 
 		if (start_ptr == (void *) -1) {
-			pr_err(stderr, "%s: sbrk(0) failed: errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			pr_err("%s: sbrk(0) failed: errno=%d (%s)\n",
+				args->name, errno, strerror(errno));
 			exit(EXIT_FAILURE);
 		}
 
 		/* Make sure this is killable by OOM killer */
-		set_oom_adjustment(name, true);
+		set_oom_adjustment(args->name, true);
 
 		for (;;) {
 			struct sigaction new_action;
 			int ret;
 
-			if (!opt_do_run || (max_ops && *counter >= max_ops))
+			if (!keep_stressing())
 				break;
 
 			memset(&new_action, 0, sizeof new_action);
@@ -133,11 +119,11 @@ again:
 			new_action.sa_flags = SA_ONSTACK;
 
 			if (sigaction(SIGSEGV, &new_action, NULL) < 0) {
-				pr_fail_err(name, "sigaction");
+				pr_fail_err("sigaction");
 				return EXIT_FAILURE;
 			}
 			if (sigaction(SIGBUS, &new_action, NULL) < 0) {
-				pr_fail_err(name, "sigaction");
+				pr_fail_err("sigaction");
 				return EXIT_FAILURE;
 			}
 			ret = sigsetjmp(jmp_env, 1);
@@ -145,12 +131,12 @@ again:
 			 * We return here if we segfault, so
 			 * first check if we need to terminate
 			 */
-			if (!opt_do_run || (max_ops && *counter >= max_ops))
+			if (!keep_stressing())
 				break;
 
 			if (ret) {
 				/* We end up here after handling the fault */
-				(*counter)++;
+				inc_counter(args);
 			} else {
 				/* Expand the stack and cause a fault */
 				char *last_ptr = 0;
@@ -161,7 +147,7 @@ again:
 					 * need this else gcc optimises out
 					 * the alloca()
 					 */
-					if (opt_flags & OPT_STACK_FILL)
+					if (g_opt_flags & OPT_STACK_FILL)
 						memset(ptr, 0, 256 * KB);
 					else
 						*ptr = 0;
@@ -169,7 +155,7 @@ again:
 					/* Force gcc to actually do the alloca */
 					uint64_put((uint64_t)(last_ptr - ptr));
 					last_ptr = ptr;
-				} while (opt_do_run);
+				} while (g_keep_stressing_flag);
 			}
 		}
 	}
