@@ -28,7 +28,7 @@
 
 #include <ucontext.h>
 
-#define MMAPSTACK_SIZE		(2 * MB)
+#define MMAPSTACK_SIZE		(256 * KB)
 
 static ucontext_t c_main, c_test;
 static sigjmp_buf jmp_env;
@@ -54,32 +54,45 @@ static void stress_stackmmap_push_msync(void)
 	static void *laddr;
 
 	if (addr != laddr) {
-		(void)shim_msync(addr, page_size, mwc8() >= 128 ? MS_SYNC : MS_ASYNC);
+		(void)shim_msync(addr, page_size,
+			(mwc8() & 1) ? MS_ASYNC : MS_SYNC);
 		laddr = addr;
 	}
-	if (opt_do_run)
+	if (g_keep_stressing_flag)
 		stress_stackmmap_push_msync();
 }
 
+/*
+ *  start the push here
+ */
+static void stress_stackmmap_push_start(void)
+{
+	int ret;
+
+	ret = sigsetjmp(jmp_env, 1);
+
+	/* If we hit a segfault on the stack then swap back context */
+	if (!ret)
+		stress_stackmmap_push_msync();
+
+	swapcontext(&c_test, &c_main);
+}
+
 /*
  *  stress_stackmmap
  *	stress a file memory map'd stack
  */
-int stress_stackmmap(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_stackmmap(const args_t *args)
 {
-	int fd, ret;
+	int fd;
 	volatile int rc = EXIT_FAILURE;		/* could be clobbered */
-	const pid_t pid = getpid();
-	stack_t ss;
 	struct sigaction new_action;
 	char filename[PATH_MAX];
-	uint8_t stack_sig[SIGSTKSZ + STACK_ALIGNMENT];	/* ensure we have a sig stack */
 
-	page_size = stress_get_pagesize();
+	/* stack for SEGV handler must not be on the stack */
+	static uint8_t stack_sig[SIGSTKSZ + STACK_ALIGNMENT]; 
+
+	page_size = args->page_size;
 	page_mask = ~(page_size - 1);
 
 	/*
@@ -93,7 +106,7 @@ int stress_stackmmap(
 	sigemptyset(&new_action.sa_mask);
 	new_action.sa_flags = SA_ONSTACK;
 	if (sigaction(SIGSEGV, &new_action, NULL) < 0) {
-		pr_fail_err(name, "sigaction");
+		pr_fail_err("sigaction");
 		return EXIT_FAILURE;
 	}
 
@@ -103,54 +116,49 @@ int stress_stackmmap(
 	 *  mmap'd stack
 	 */
 	memset(stack_sig, 0, sizeof(stack_sig));
-	ss.ss_sp = (void *)align_address(stack_sig, STACK_ALIGNMENT);
-	ss.ss_size = SIGSTKSZ;
-	ss.ss_flags = 0;
-	if (sigaltstack(&ss, NULL) < 0) {
-		pr_fail_err(name, "sigaltstack");
+	if (stress_sigaltstack(stack_sig, SIGSTKSZ) < 0)
 		return EXIT_FAILURE;
-	}
 
-	if (stress_temp_dir_mk(name, pid, instance) < 0)
+	if (stress_temp_dir_mk_args(args) < 0)
 		return EXIT_FAILURE;
-	(void)stress_temp_filename(filename, sizeof(filename),
-		name, pid, instance, mwc32());
+	(void)stress_temp_filename_args(args,
+		filename, sizeof(filename), mwc32());
 
 	/* Create file back'd mmaping for the stack */
 	fd = open(filename, O_SYNC | O_RDWR | O_CREAT, S_IRUSR | S_IWUSR);
 	if (fd < 0) {
-		pr_fail_err(name, "mmap'd stack file open");
+		pr_fail_err("mmap'd stack file open");
 		goto tidy_dir;
 	}
 	(void)unlink(filename);
 	if (ftruncate(fd, MMAPSTACK_SIZE) < 0) {
-		pr_fail_err(name, "ftruncate");
+		pr_fail_err("ftruncate");
 		(void)close(fd);
 		goto tidy_dir;
 	}
 	stack_mmap = mmap(NULL, MMAPSTACK_SIZE, PROT_READ | PROT_WRITE,
 		MAP_SHARED, fd, 0);
 	if (stack_mmap == MAP_FAILED) {
-		pr_fail_err(name, "mmap");
+		pr_fail_err("mmap");
 		(void)close(fd);
 		goto tidy_dir;
 	}
 	(void)close(fd);
 
-	if (madvise(stack_mmap, MMAPSTACK_SIZE, MADV_RANDOM) < 0) {
-		pr_dbg(stderr, "%s: madvise failed: errno=%d (%s)\n",
-			name, errno, strerror(errno));
+	if (shim_madvise(stack_mmap, MMAPSTACK_SIZE, MADV_RANDOM) < 0) {
+		pr_dbg("%s: madvise failed: errno=%d (%s)\n",
+			args->name, errno, strerror(errno));
 	}
+	memset(stack_mmap, 0, MMAPSTACK_SIZE);
 
 	memset(&c_test, 0, sizeof(c_test));
 	if (getcontext(&c_test) < 0) {
-		pr_fail_err(name, "getcontext");
+		pr_fail_err("getcontext");
 		goto tidy_mmap;
 	}
 	c_test.uc_stack.ss_sp = stack_mmap;
 	c_test.uc_stack.ss_size = MMAPSTACK_SIZE;
 	c_test.uc_link = &c_main;
-	makecontext(&c_test, stress_stackmmap_push_msync, 0);
 
 	/*
 	 *  set jmp handler to jmp back into the loop on a full
@@ -158,28 +166,22 @@ int stress_stackmmap(
 	 *  new context using the new mmap'd stack
 	 */
 	do {
-		ret = sigsetjmp(jmp_env, 1);
-		if (!ret)
-			swapcontext(&c_main, &c_test);
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		makecontext(&c_test, stress_stackmmap_push_start, 0);
+		swapcontext(&c_main, &c_test);
+		inc_counter(args);
+	} while (keep_stressing());
 
 	rc = EXIT_SUCCESS;
 
 tidy_mmap:
 	munmap(stack_mmap, MMAPSTACK_SIZE);
 tidy_dir:
-	(void)stress_temp_dir_rm(name, pid, instance);
-
+	(void)stress_temp_dir_rm_args(args);
 	return rc;
 }
 #else
-int stress_stackmmap(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_stackmmap(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
