@@ -61,8 +61,8 @@ static inline void strchk(
 	const char *msg,
 	bool *failed)
 {
-	if ((opt_flags & OPT_FLAGS_VERIFY) && (!ok)) {
-		pr_fail(stderr, "%s: %s did not return expected result\n",
+	if ((g_opt_flags & OPT_FLAGS_VERIFY) && (!ok)) {
+		pr_fail("%s: %s did not return expected result\n",
 			name, msg);
 		*failed = true;
 	}
@@ -92,7 +92,7 @@ static void stress_strcasecmp(
 
 	(void)len2;
 
-	for (i = 1; opt_do_run && (i < len1); i++) {
+	for (i = 1; g_keep_stressing_flag && (i < len1); i++) {
 		STRCHK(name, 0 == __strcasecmp(str1, str1), failed);
 		STRCHK(name, 0 == __strcasecmp(str2, str2), failed);
 
@@ -126,7 +126,7 @@ static void stress_strncasecmp(
 
 	(void)len2;
 
-	for (i = 1; opt_do_run && (i < len1); i++) {
+	for (i = 1; g_keep_stressing_flag && (i < len1); i++) {
 		STRCHK(name, 0 == __strncasecmp(str1, str1, len1), failed);
 		STRCHK(name, 0 == __strncasecmp(str2, str2, len2), failed);
 
@@ -160,7 +160,7 @@ static void stress_index(
 
 	(void)len2;
 
-	for (i = 0; opt_do_run && (i < len1 - 1); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < len1 - 1); i++) {
 		STRCHK(name, NULL == __index(str1, '_'), failed);
 		STRCHK(name, NULL != __index(str1, str1[0]), failed);
 
@@ -187,7 +187,7 @@ static void stress_rindex(
 
 	(void)len2;
 
-	for (i = 0; opt_do_run && (i < len1 - 1); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < len1 - 1); i++) {
 		STRCHK(name, NULL == __rindex(str1, '_'), failed);
 		STRCHK(name, NULL != __rindex(str1, str1[0]), failed);
 
@@ -218,7 +218,7 @@ static void stress_strlcpy(
 	const size_t str_len1 = strlen(str1);
 	const size_t str_len2 = strlen(str2);
 
-	for (i = 0; opt_do_run && (i < len1 - 1); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < len1 - 1); i++) {
 		STRCHK(name, str_len1 == __strlcpy(buf, str1, buf_len), failed);
 		STRCHK(name, str_len2 == __strlcpy(buf, str2, buf_len), failed);
 	}
@@ -242,7 +242,7 @@ static void stress_strcpy(
 
 	char buf[len1 + len2 + 1];
 
-	for (i = 0; opt_do_run && (i < len1 - 1); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < len1 - 1); i++) {
 		STRCHK(name, buf == __strcpy(buf, str1), failed);
 		STRCHK(name, buf == __strcpy(buf, str2), failed);
 	}
@@ -273,7 +273,7 @@ static void stress_strlcat(
 	const size_t str_len2 = strlen(str2);
 	const size_t str_len = str_len1 + str_len2;
 
-	for (i = 0; opt_do_run && (i < len1 - 1); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < len1 - 1); i++) {
 		*buf = '\0';
 		STRCHK(name, str_len1 == __strlcat(buf, str1, buf_len), failed);
 		*buf = '\0';
@@ -305,7 +305,7 @@ static void stress_strcat(
 
 	char buf[len1 + len2 + 1];
 
-	for (i = 0; opt_do_run && (i < len1 - 1); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < len1 - 1); i++) {
 		*buf = '\0';
 		STRCHK(name, buf == __strcat(buf, str1), failed);
 		*buf = '\0';
@@ -337,7 +337,7 @@ static void stress_strncat(
 	char * (*__strncat)(char *dest, const char *src, size_t n) = libc_func;
 	char buf[len1 + len2 + 1];
 
-	for (i = 0; opt_do_run && (i < len1 - 1); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < len1 - 1); i++) {
 		*buf = '\0';
 		STRCHK(name, buf == __strncat(buf, str1, len1), failed);
 		*buf = '\0';
@@ -369,7 +369,7 @@ static void stress_strchr(
 
 	(void)len2;
 
-	for (i = 0; opt_do_run && (i < len1 - 1); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < len1 - 1); i++) {
 		STRCHK(name, NULL == __strchr(str1, '_'), failed);
 		STRCHK(name, NULL != __strchr(str1, str1[0]), failed);
 
@@ -396,7 +396,7 @@ static void stress_strrchr(
 
 	(void)len2;
 
-	for (i = 0; opt_do_run && (i < len1 - 1); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < len1 - 1); i++) {
 		STRCHK(name, NULL == __strrchr(str1, '_'), failed);
 		STRCHK(name, NULL != __strrchr(str1, str1[0]), failed);
 
@@ -423,7 +423,7 @@ static void stress_strcmp(
 
 	(void)len2;
 
-	for (i = 1; opt_do_run && (i < len1); i++) {
+	for (i = 1; g_keep_stressing_flag && (i < len1); i++) {
 		STRCHK(name, 0 == __strcmp(str1, str1), failed);
 		STRCHK(name, 0 == __strcmp(str2, str2), failed);
 
@@ -455,7 +455,7 @@ static void stress_strncmp(
 	register size_t i;
 	int (*__strncmp)(const char *s1, const char *s2, size_t n) = libc_func;
 
-	for (i = 1; opt_do_run && (i < len1); i++) {
+	for (i = 1; g_keep_stressing_flag && (i < len1); i++) {
 		STRCHK(name, 0 == __strncmp(str1, str1, len1), failed);
 		STRCHK(name, 0 == __strncmp(str2, str2, len2), failed);
 
@@ -488,7 +488,7 @@ static void stress_strcoll(
 
 	(void)len2;
 
-	for (i = 1; opt_do_run && (i < len1); i++) {
+	for (i = 1; g_keep_stressing_flag && (i < len1); i++) {
 		STRCHK(name, 0 == __strcoll(str1, str1), failed);
 		STRCHK(name, 0 == __strcoll(str2, str2), failed);
 
@@ -521,12 +521,12 @@ static void stress_strlen(
 	size_t (*__strlen)(const char *s) = libc_func;
 
 
-	for (i = 0; opt_do_run && (i < len1 - 1); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < len1 - 1); i++) {
 		STRCHK(name, len1 - 1 == __strlen(str1), failed);
 		STRCHK(name, len1 - 1 - i == __strlen(str1 + i), failed);
 	}
 
-	for (i = 0; opt_do_run && (i < len2 - 1); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < len2 - 1); i++) {
 		STRCHK(name, len2 - 1 == __strlen(str2), failed);
 		STRCHK(name, len2 - 1 - i == __strlen(str2 + i), failed);
 	}
@@ -549,7 +549,7 @@ static void stress_strxfrm(
 	char buf[len1 + len2];
 	size_t (*__strxfrm)(char *dest, const char *src, size_t n) = libc_func;
 
-	for (i = 0; opt_do_run && (i < len1 - 1); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < len1 - 1); i++) {
 		*buf = '\0';
 		STRCHK(name, 0 != __strxfrm(buf, str1, sizeof(buf)), failed);
 		*buf = '\0';
@@ -627,18 +627,18 @@ int stress_set_str_method(const char *name)
 	stress_str_stressor_info_t const *info = str_methods;
 
 
-	for (info = str_methods; opt_do_run && info->func; info++) {
+	for (info = str_methods; g_keep_stressing_flag && info->func; info++) {
 		if (!strcmp(info->name, name)) {
 			opt_str_stressor = info;
 			return 0;
 		}
 	}
 
-	fprintf(stderr, "str-method must be one of:");
+	(void)fprintf(stderr, "str-method must be one of:");
 	for (info = str_methods; info->func; info++) {
-		fprintf(stderr, " %s", info->name);
+		(void)fprintf(stderr, " %s", info->name);
 	}
-	fprintf(stderr, "\n");
+	(void)fprintf(stderr, "\n");
 
 	return -1;
 }
@@ -647,27 +647,21 @@ int stress_set_str_method(const char *name)
  *  stress_str()
  *	stress CPU by doing various string operations
  */
-int stress_str(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_str(const args_t *args)
 {
 	stress_str_func func = opt_str_stressor->func;
 	const void *libc_func = opt_str_stressor->libc_func;
 	bool failed = false;
 
-	(void)instance;
-
 	do {
 		char str1[256], str2[128];
 
 		stress_strnrnd(str1, sizeof(str1));
 		stress_strnrnd(str2, sizeof(str2));
 
-		(void)func(libc_func, name, str1, sizeof(str1), str2, sizeof(str2), &failed);
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		(void)func(libc_func, args->name, str1, sizeof(str1), str2, sizeof(str2), &failed);
+		inc_counter(args);
+	} while (keep_stressing());
 
 	return failed ? EXIT_FAILURE : EXIT_SUCCESS;
 }
