@@ -44,11 +44,13 @@ static const int sync_modes[] = {
 static off_t opt_sync_file_bytes = DEFAULT_SYNC_FILE_BYTES;
 static bool set_sync_file_bytes = false;
 
-void stress_set_sync_file_bytes(const char *optarg)
+void stress_set_sync_file_bytes(const char *opt)
 {
 	set_sync_file_bytes = true;
-	opt_sync_file_bytes = (off_t)get_uint64_byte(optarg);
-	check_range("sync_file-bytes", opt_sync_file_bytes,
+	opt_sync_file_bytes = (off_t)
+		get_uint64_byte_filesystem(opt,
+			stressor_instances(STRESS_SYNC_FILE));
+	check_range_bytes("sync_file-bytes", opt_sync_file_bytes,
 		MIN_SYNC_FILE_BYTES, MAX_SYNC_FILE_BYTES);
 }
 
@@ -89,28 +91,28 @@ static inline int shim_sync_file_range(
  *  shrink and re-allocate the file to be sync'd
  *
  */
-static int stress_sync_allocate(const char *name, const int fd)
+static int stress_sync_allocate(const args_t *args, const int fd)
 {
 	int ret;
 
 	ret = ftruncate(fd, 0);
 	if (ret < 0) {
-		pr_err(stderr, "%s: ftruncate failed: errno=%d (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: ftruncate failed: errno=%d (%s)\n",
+			args->name, errno, strerror(errno));
 		return -errno;
 	}
 
 	ret = fdatasync(fd);
 	if (ret < 0) {
-		pr_err(stderr, "%s: fdatasync failed: errno=%d (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: fdatasync failed: errno=%d (%s)\n",
+			args->name, errno, strerror(errno));
 		return -errno;
 	}
 
 	ret = shim_fallocate(fd, 0, (off_t)0, opt_sync_file_bytes);
 	if (ret < 0) {
-		pr_err(stderr, "%s: fallocate failed: errno=%d (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: fallocate failed: errno=%d (%s)\n",
+			args->name, errno, strerror(errno));
 		return -errno;
 	}
 	return 0;
@@ -120,34 +122,29 @@ static int stress_sync_allocate(const char *name, const int fd)
  *  stress_sync_file
  *	stress the sync_file_range system call
  */
-int stress_sync_file(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_sync_file(const args_t *args)
 {
-	const pid_t pid = getpid();
 	int fd, ret;
 	char filename[PATH_MAX];
 
 	if (!set_sync_file_bytes) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_sync_file_bytes = MAX_SYNC_FILE_BYTES;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_sync_file_bytes = MIN_SYNC_FILE_BYTES;
 	}
 
-	ret = stress_temp_dir_mk(name, pid, instance);
+	ret = stress_temp_dir_mk_args(args);
 	if (ret < 0)
 		return exit_status(-ret);
 
-	(void)stress_temp_filename(filename, sizeof(filename),
-		name, pid, instance, mwc32());
+	(void)stress_temp_filename_args(args,
+		filename, sizeof(filename), mwc32());
 	(void)umask(0077);
 	if ((fd = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
 		ret = exit_status(errno);
-		pr_fail_err(name, "open");
-		(void)stress_temp_dir_rm(name, pid, instance);
+		pr_fail_err("open");
+		(void)stress_temp_dir_rm_args(args);
 		return ret;
 	}
 	(void)unlink(filename);
@@ -157,54 +154,59 @@ int stress_sync_file(
 		const size_t mode_index = mwc32() % SIZEOF_ARRAY(sync_modes);
 		const int mode = sync_modes[mode_index];
 
-		if (stress_sync_allocate(name, fd) < 0)
+		if (stress_sync_allocate(args, fd) < 0)
 			break;
-		for (offset = 0; offset < (off64_t)opt_sync_file_bytes; ) {
+		for (offset = 0; g_keep_stressing_flag &&
+		     (offset < (off64_t)opt_sync_file_bytes); ) {
 			off64_t sz = (mwc32() & 0x1fc00) + KB;
 			ret = shim_sync_file_range(fd, offset, sz, mode);
-			if (ret < 0)
-				pr_fail_err(name, "sync_file_range (forward)");
+			if (ret < 0) {
+				pr_fail_err("sync_file_range (forward)");
+				break;
+			}
 			offset += sz;
 		}
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 
-		if (stress_sync_allocate(name, fd) < 0)
+		if (stress_sync_allocate(args, fd) < 0)
 			break;
-		for (offset = 0; offset < (off64_t)opt_sync_file_bytes; ) {
+		for (offset = 0; g_keep_stressing_flag &&
+		     (offset < (off64_t)opt_sync_file_bytes); ) {
 			off64_t sz = (mwc32() & 0x1fc00) + KB;
 
 			ret = shim_sync_file_range(fd, opt_sync_file_bytes - offset, sz, mode);
-			if (ret < 0)
-				pr_fail_err(name, "sync_file_range (reverse)");
+			if (ret < 0) {
+				pr_fail_err("sync_file_range (reverse)");
+				break;
+			}
 			offset += sz;
 		}
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 
-		if (stress_sync_allocate(name, fd) < 0)
+		if (stress_sync_allocate(args, fd) < 0)
 			break;
-		for (i = 0; i < (off64_t)(opt_sync_file_bytes / (128 * KB)); i++) {
+		for (i = 0; i < g_keep_stressing_flag &&
+		     ((off64_t)(opt_sync_file_bytes / (128 * KB))); i++) {
 			offset = (mwc64() % opt_sync_file_bytes) & ~((128 * KB) - 1);
 			ret = shim_sync_file_range(fd, offset, 128 * KB, mode);
-			if (ret < 0)
-				pr_fail_err(name, "sync_file_range (random)");
+			if (ret < 0) {
+				break;
+				pr_fail_err("sync_file_range (random)");
+			}
 		}
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
 	(void)close(fd);
-	(void)stress_temp_dir_rm(name, pid, instance);
+	(void)stress_temp_dir_rm_args(args);
 
 	return EXIT_SUCCESS;
 }
 #else
-int stress_sync_file(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_sync_file(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
