@@ -39,10 +39,10 @@ static uint64_t opt_timer_freq = DEFAULT_TIMER_FREQ;
  *  stress_set_timer_freq()
  *	set timer frequency from given option
  */
-void stress_set_timer_freq(const char *optarg)
+void stress_set_timer_freq(const char *opt)
 {
 	set_timer_freq = true;
-	opt_timer_freq = get_uint64(optarg);
+	opt_timer_freq = get_uint64(opt);
 	check_range("timer-freq", opt_timer_freq,
 		MIN_TIMER_FREQ, MAX_TIMER_FREQ);
 }
@@ -57,7 +57,7 @@ static void stress_timer_set(struct itimerspec *timer)
 {
 	double rate;
 
-	if (opt_flags & OPT_FLAGS_TIMER_RAND) {
+	if (g_opt_flags & OPT_FLAGS_TIMER_RAND) {
 		/* Mix in some random variation */
 		double r = ((double)(mwc32() % 10000) - 5000.0) / 40000.0;
 		rate = rate_ns + (rate_ns * r);
@@ -93,9 +93,9 @@ static void MLOCKED stress_timer_handler(int sig)
 			goto cancel;
 	/* High freq timer, check periodically for timeout */
 	if ((timer_counter & 65535) == 0)
-		if ((time_now() - start) > (double)opt_timeout)
+		if ((time_now() - start) > (double)g_opt_timeout)
 			goto cancel;
-	if (opt_do_run) {
+	if (g_keep_stressing_flag) {
 		int ret = timer_getoverrun(timerid);
 		if (ret > 0)
 			overruns += ret;
@@ -104,7 +104,7 @@ static void MLOCKED stress_timer_handler(int sig)
 	}
 
 cancel:
-	opt_do_run = false;
+	g_keep_stressing_flag = false;
 	/* Cancel timer if we detect no more runs */
 	memset(&timer, 0, sizeof(timer));
 	(void)timer_settime(timerid, 0, &timer, NULL);
@@ -114,11 +114,7 @@ cancel:
  *  stress_timer
  *	stress timers
  */
-int stress_timer(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_timer(const args_t *args)
 {
 	struct sigevent sev;
 	struct itimerspec timer;
@@ -131,27 +127,27 @@ int stress_timer(
 	start = time_now();
 
 	if (!set_timer_freq) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_timer_freq = MAX_TIMER_FREQ;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_timer_freq = MIN_TIMER_FREQ;
 	}
 	rate_ns = opt_timer_freq ? 1000000000 / opt_timer_freq : 1000000000;
 
-	if (stress_sighandler(name, SIGRTMIN, stress_timer_handler, NULL) < 0)
+	if (stress_sighandler(args->name, SIGRTMIN, stress_timer_handler, NULL) < 0)
 		return EXIT_FAILURE;
 
 	sev.sigev_notify = SIGEV_SIGNAL;
 	sev.sigev_signo = SIGRTMIN;
 	sev.sigev_value.sival_ptr = &timerid;
 	if (timer_create(CLOCK_REALTIME, &sev, &timerid) < 0) {
-		pr_fail_err(name, "timer_create");
+		pr_fail_err("timer_create");
 		return EXIT_FAILURE;
 	}
 
 	stress_timer_set(&timer);
 	if (timer_settime(timerid, 0, &timer, NULL) < 0) {
-		pr_fail_err(name, "timer_settime");
+		pr_fail_err("timer_settime");
 		return EXIT_FAILURE;
 	}
 
@@ -161,25 +157,21 @@ int stress_timer(
 		req.tv_sec = 0;
 		req.tv_nsec = 10000000;
 		(void)nanosleep(&req, NULL);
-		*counter = timer_counter;
-	} while (opt_do_run && (!max_ops || timer_counter < max_ops));
+		*args->counter = timer_counter;
+	} while (keep_stressing());
 
 	if (timer_delete(timerid) < 0) {
-		pr_fail_err(name, "timer_delete");
+		pr_fail_err("timer_delete");
 		return EXIT_FAILURE;
 	}
-	pr_dbg(stderr, "%s: %" PRIu64 " timer overruns (instance %" PRIu32 ")\n",
-		name, overruns, instance);
+	pr_dbg("%s: %" PRIu64 " timer overruns (instance %" PRIu32 ")\n",
+		args->name, overruns, args->instance);
 
 	return EXIT_SUCCESS;
 }
 #else
-int stress_timer(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_timer(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
