@@ -39,10 +39,10 @@ static bool set_timerfd_freq = false;
  *  stress_set_timerfd_freq()
  *	set timer frequency from given option
  */
-void stress_set_timerfd_freq(const char *optarg)
+void stress_set_timerfd_freq(const char *opt)
 {
 	set_timerfd_freq = true;
-	opt_timerfd_freq = get_uint64(optarg);
+	opt_timerfd_freq = get_uint64(opt);
 	check_range("timerfd-freq", opt_timerfd_freq,
 		MIN_TIMERFD_FREQ, MAX_TIMERFD_FREQ);
 }
@@ -57,7 +57,7 @@ static void stress_timerfd_set(struct itimerspec *timer)
 {
 	double rate;
 
-	if (opt_flags & OPT_FLAGS_TIMERFD_RAND) {
+	if (g_opt_flags & OPT_FLAGS_TIMERFD_RAND) {
 		/* Mix in some random variation */
 		double r = ((double)(mwc32() % 10000) - 5000.0) / 40000.0;
 		rate = rate_ns + (rate_ns * r);
@@ -80,33 +80,27 @@ static void stress_timerfd_set(struct itimerspec *timer)
  *  stress_timerfd
  *	stress timerfd
  */
-int stress_timerfd(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_timerfd(const args_t *args)
 {
 	struct itimerspec timer;
 
-	(void)instance;
-
 	if (!set_timerfd_freq) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_timerfd_freq = MAX_TIMERFD_FREQ;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_timerfd_freq = MIN_TIMERFD_FREQ;
 	}
 	rate_ns = opt_timerfd_freq ? 1000000000 / opt_timerfd_freq : 1000000000;
 
 	timerfd = timerfd_create(CLOCK_REALTIME, 0);
 	if (timerfd < 0) {
-		pr_fail_err(name, "timerfd_create");
+		pr_fail_err("timerfd_create");
 		(void)close(timerfd);
 		return EXIT_FAILURE;
 	}
 	stress_timerfd_set(&timer);
 	if (timerfd_settime(timerfd, 0, &timer, NULL) < 0) {
-		pr_fail_err(name, "timer_settime");
+		pr_fail_err("timer_settime");
 		(void)close(timerfd);
 		return EXIT_FAILURE;
 	}
@@ -123,13 +117,13 @@ int stress_timerfd(
 		timeout.tv_sec = 0;
 		timeout.tv_usec = 500000;
 
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 		ret = select(timerfd + 1, &rdfs, NULL, NULL, &timeout);
 		if (ret < 0) {
 			if (errno == EINTR)
 				continue;
-			pr_fail_err(name, "select");
+			pr_fail_err("select");
 			break;
 		}
 		if (ret < 1)
@@ -137,34 +131,30 @@ int stress_timerfd(
 
 		ret = read(timerfd, &exp, sizeof exp);
 		if (ret < 0) {
-			pr_fail_err(name, "timerfd read");
+			pr_fail_err("timerfd read");
 			break;
 		}
 		if (timerfd_gettime(timerfd, &value) < 0) {
-			pr_fail_err(name, "timerfd_gettime");
+			pr_fail_err("timerfd_gettime");
 			break;
 		}
-		if (opt_flags & OPT_FLAGS_TIMERFD_RAND) {
+		if (g_opt_flags & OPT_FLAGS_TIMERFD_RAND) {
 			stress_timerfd_set(&timer);
 			if (timerfd_settime(timerfd, 0, &timer, NULL) < 0) {
-				pr_fail_err(name, "timer_settime");
+				pr_fail_err("timer_settime");
 				break;
 			}
 		}
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || timerfd_counter < max_ops));
+		*args->counter = timerfd_counter;
+	} while (keep_stressing());
 
 	(void)close(timerfd);
 
 	return EXIT_SUCCESS;
 }
 #else
-int stress_timerfd(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_timerfd(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
