@@ -32,10 +32,10 @@ static bool set_tsearch_size = false;
  *  stress_set_tsearch_size()
  *      set tsearch size from given option string
  */
-void stress_set_tsearch_size(const char *optarg)
+void stress_set_tsearch_size(const char *opt)
 {
 	set_tsearch_size = true;
-	opt_tsearch_size = get_uint64_byte(optarg);
+	opt_tsearch_size = get_uint64_byte(opt);
 	check_range("tsearch-size", opt_tsearch_size,
 		MIN_TSEARCH_SIZE, MAX_TSEARCH_SIZE);
 }
@@ -61,28 +61,22 @@ static int cmp(const void *p1, const void *p2)
  *  stress_tsearch()
  *	stress tsearch
  */
-int stress_tsearch(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_tsearch(const args_t *args)
 {
 	int32_t *data;
 	size_t i, n;
 
-	(void)instance;
-
 	if (!set_tsearch_size) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_tsearch_size = MAX_TSEARCH_SIZE;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_tsearch_size = MIN_TSEARCH_SIZE;
 	}
 	n = (size_t)opt_tsearch_size;
 
-	if ((data = malloc(sizeof(int32_t) * n)) == NULL) {
-		pr_fail_dbg(name, "malloc");
-		return EXIT_FAILURE;
+	if ((data = calloc(n, sizeof(int32_t))) == NULL) {
+		pr_fail_dbg("calloc");
+		return EXIT_NO_RESOURCE;
 	}
 
 	do {
@@ -94,31 +88,31 @@ int stress_tsearch(
 			if (tsearch(&data[i], &root, cmp) == NULL) {
 				size_t j;
 
-				pr_err(stderr, "%s: cannot allocate new "
-					"tree node\n", name);
+				pr_err("%s: cannot allocate new "
+					"tree node\n", args->name);
 				for (j = 0; j < i; j++)
 					tdelete(&data[j], &root, cmp);
 				goto abort;
 			}
 		}
 		/* Step #2, find */
-		for (i = 0; opt_do_run && i < n; i++) {
+		for (i = 0; g_keep_stressing_flag && i < n; i++) {
 			void **result;
 
 			result = tfind(&data[i], &root, cmp);
-			if (opt_flags & OPT_FLAGS_VERIFY) {
+			if (g_opt_flags & OPT_FLAGS_VERIFY) {
 				if (result == NULL)
-					pr_fail(stderr, "%s: element %zu "
+					pr_fail("%s: element %zu "
 						"could not be found\n",
-						name, i);
+						args->name, i);
 				else {
 					int32_t *val;
 					val = *result;
 					if (*val != data[i])
-						pr_fail(stderr, "%s: element "
+						pr_fail("%s: element "
 							"%zu found %" PRIu32
 							", expecting %" PRIu32 "\n",
-							name, i, *val, data[i]);
+							args->name, i, *val, data[i]);
 				}
 			}
 		}
@@ -127,12 +121,12 @@ int stress_tsearch(
 			void **result;
 
 			result = tdelete(&data[i], &root, cmp);
-			if ((opt_flags & OPT_FLAGS_VERIFY) && (result == NULL))
-				pr_fail(stderr, "%s: element %zu could not "
-					"be found\n", name, i);
+			if ((g_opt_flags & OPT_FLAGS_VERIFY) && (result == NULL))
+				pr_fail("%s: element %zu could not "
+					"be found\n", args->name, i);
 		}
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
 abort:
 	free(data);
