@@ -47,9 +47,9 @@
 static int opt_udp_domain = AF_INET;
 static int opt_udp_port = DEFAULT_SOCKET_PORT;
 
-void stress_set_udp_port(const char *optarg)
+void stress_set_udp_port(const char *opt)
 {
-	stress_set_net_port("udp-port", optarg,
+	stress_set_net_port("udp-port", opt,
 		MIN_UDP_PORT, MAX_UDP_PORT - STRESS_PROCS_MAX,
 		&opt_udp_port);
 }
@@ -70,23 +70,19 @@ int stress_set_udp_domain(const char *name)
 static void MLOCKED handle_udp_sigalrm(int dummy)
 {
 	(void)dummy;
-	opt_do_run = false;
+	g_keep_stressing_flag = false;
 }
 
 /*
  *  stress_udp
  *	stress by heavy udp ops
  */
-int stress_udp(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_udp(const args_t *args)
 {
 	pid_t pid, ppid = getppid();
 	int rc = EXIT_SUCCESS;
 #if defined(IPPROTO_UDPLITE)
-	int proto = (opt_flags & OPT_FLAGS_UDP_LITE) ?
+	int proto = (g_opt_flags & OPT_FLAGS_UDP_LITE) ?
 		IPPROTO_UDPLITE : IPPROTO_UDP;
 #else
 	int proto = 0;
@@ -96,29 +92,29 @@ int stress_udp(
 	if ((proto == IPPROTO_UDPLITE) &&
 	    (opt_udp_domain == AF_UNIX)) {
 		proto = 0;
-		if (instance == 0) {
-			pr_inf(stdout, "%s: disabling UDP-Lite as it is not "
+		if (args->instance == 0) {
+			pr_inf("%s: disabling UDP-Lite as it is not "
 				"available for UNIX domain UDP\n",
-				name);
+				args->name);
 		}
 	}
 #endif
 
-	pr_dbg(stderr, "%s: process [%d] using udp port %d\n",
-		name, (int)getpid(), opt_udp_port + instance);
+	pr_dbg("%s: process [%d] using udp port %d\n",
+		args->name, (int)args->pid, opt_udp_port + args->instance);
 
 again:
 	pid = fork();
 	if (pid < 0) {
-		if (opt_do_run && (errno == EAGAIN))
+		if (g_keep_stressing_flag && (errno == EAGAIN))
 			goto again;
-		pr_fail_dbg(name, "fork");
+		pr_fail_dbg("fork");
 		return EXIT_FAILURE;
 	} else if (pid == 0) {
 		/* Child, client */
 		struct sockaddr *addr = NULL;
 
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
 
 		do {
@@ -131,19 +127,19 @@ again:
 #endif
 
 			if ((fd = socket(opt_udp_domain, SOCK_DGRAM, proto)) < 0) {
-				pr_fail_dbg(name, "socket");
+				pr_fail_dbg("socket");
 				/* failed, kick parent to finish */
 				(void)kill(getppid(), SIGALRM);
 				exit(EXIT_FAILURE);
 			}
-			stress_set_sockaddr(name, instance, ppid,
+			stress_set_sockaddr(args->name, args->instance, ppid,
 				opt_udp_domain, opt_udp_port,
 				&addr, &len, NET_ADDR_ANY);
 #if defined(IPPROTO_UDPLITE)
 			if (proto == IPPROTO_UDPLITE) {
 				val = 8;	/* Just the 8 byte header */
 				if (setsockopt(fd, SOL_UDPLITE, UDPLITE_SEND_CSCOV, &val, sizeof(int)) < 0) {
-					pr_fail_dbg(name, "setsockopt");
+					pr_fail_dbg("setsockopt");
 					(void)close(fd);
 					(void)kill(getppid(), SIGALRM);
 					exit(EXIT_FAILURE);
@@ -158,13 +154,13 @@ again:
 					ssize_t ret = sendto(fd, buf, i, 0, addr, len);
 					if (ret < 0) {
 						if (errno != EINTR)
-							pr_fail_dbg(name, "sendto");
+							pr_fail_dbg("sendto");
 						break;
 					}
 				}
-			} while (opt_do_run && (!max_ops || *counter < max_ops));
+			} while (keep_stressing());
 			(void)close(fd);
-		} while (opt_do_run && (!max_ops || *counter < max_ops));
+		} while (keep_stressing());
 
 #if defined(AF_UNIX)
 		if ((opt_udp_domain == AF_UNIX) && addr) {
@@ -189,38 +185,38 @@ again:
 		socklen_t addr_len = 0;
 		struct sockaddr *addr = NULL;
 
-		(void)setpgid(pid, pgrp);
+		(void)setpgid(pid, g_pgrp);
 
-		if (stress_sighandler(name, SIGALRM, handle_udp_sigalrm, NULL) < 0) {
+		if (stress_sighandler(args->name, SIGALRM, handle_udp_sigalrm, NULL) < 0) {
 			rc = EXIT_FAILURE;
 			goto die;
 		}
 		if ((fd = socket(opt_udp_domain, SOCK_DGRAM, proto)) < 0) {
-			pr_fail_dbg(name, "socket");
+			pr_fail_dbg("socket");
 			rc = EXIT_FAILURE;
 			goto die;
 		}
-		stress_set_sockaddr(name, instance, ppid,
+		stress_set_sockaddr(args->name, args->instance, ppid,
 			opt_udp_domain, opt_udp_port,
 			&addr, &addr_len, NET_ADDR_ANY);
 #if defined(IPPROTO_UDPLITE)
 		if (proto == IPPROTO_UDPLITE) {
 			val = 8;	/* Just the 8 byte header */
 			if (setsockopt(fd, SOL_UDPLITE, UDPLITE_RECV_CSCOV, &val, sizeof(int)) < 0) {
-				pr_fail_dbg(name, "setsockopt");
+				pr_fail_dbg("setsockopt");
 				rc = EXIT_FAILURE;
 				goto die_close;
 			}
 		}
 #endif
 		if (bind(fd, addr, addr_len) < 0) {
-			pr_fail_dbg(name, "bind");
+			pr_fail_dbg("bind");
 			rc = EXIT_FAILURE;
 			goto die_close;
 		}
 #if !defined(__minix__)
 		if (setsockopt(fd, SOL_SOCKET, SO_REUSEADDR, &so_reuseaddr, sizeof(so_reuseaddr)) < 0) {
-			pr_fail_dbg(name, "setsockopt");
+			pr_fail_dbg("setsockopt");
 			rc = EXIT_FAILURE;
 			goto die_close;
 		}
@@ -233,11 +229,11 @@ again:
 				break;
 			if (n < 0) {
 				if (errno != EINTR)
-					pr_fail_dbg(name, "recvfrom");
+					pr_fail_dbg("recvfrom");
 				break;
 			}
-			(*counter)++;
-		} while (opt_do_run && (!max_ops || *counter < max_ops));
+			inc_counter(args);
+		} while (keep_stressing());
 
 die_close:
 		(void)close(fd);
