@@ -33,10 +33,8 @@
 
 /* Context for clone */
 typedef struct {
+	const args_t *args;
 	uint8_t *data;
-	const char *name;
-	uint64_t *counter;
-	uint64_t max_ops;
 	size_t page_size;
 	size_t sz;
 	pid_t parent;
@@ -47,12 +45,14 @@ typedef struct {
 static size_t opt_userfaultfd_bytes = DEFAULT_MMAP_BYTES;
 static bool set_userfaultfd_bytes = false;
 
-void stress_set_userfaultfd_bytes(const char *optarg)
+void stress_set_userfaultfd_bytes(const char *opt)
 {
 	set_userfaultfd_bytes = true;
-	opt_userfaultfd_bytes = (size_t)get_uint64_byte(optarg);
-	check_range("userfaultfd-bytes", opt_userfaultfd_bytes,
-		MIN_MMAP_BYTES, MAX_MMAP_BYTES);
+	opt_userfaultfd_bytes = (size_t)
+		get_uint64_byte_memory(opt,
+			stressor_instances(STRESS_USERFAULTFD));
+	check_range_bytes("userfaultfd-bytes", opt_userfaultfd_bytes,
+		MIN_MMAP_BYTES, MAX_MEM_LIMIT);
 }
 
 #if defined(__linux__) && defined(__NR_userfaultfd)
@@ -68,7 +68,6 @@ static void MLOCKED stress_child_alarm_handler(int dummy)
 	_exit(0);
 }
 
-
 /*
  *  stress_userfaultfd_child()
  *	generate page faults for parent to handle
@@ -76,25 +75,26 @@ static void MLOCKED stress_child_alarm_handler(int dummy)
 static int stress_userfaultfd_child(void *arg)
 {
 	context_t *c = (context_t *)arg;
+	const args_t *args = c->args;
 
-	(void)setpgid(0, pgrp);
+	(void)setpgid(0, g_pgrp);
 	stress_parent_died_alarm();
-	if (stress_sighandler(c->name, SIGALRM, stress_child_alarm_handler, NULL) < 0)
+	if (stress_sighandler(args->name, SIGALRM, stress_child_alarm_handler, NULL) < 0)
 		return EXIT_NO_RESOURCE;
 
 	do {
 		uint8_t *ptr, *end = c->data + c->sz;
 
 		/* hint we don't need these pages */
-		if (madvise(c->data, c->sz, MADV_DONTNEED) < 0) {
-			pr_fail_err(c->name, "userfaultfd madvise failed");
+		if (shim_madvise(c->data, c->sz, MADV_DONTNEED) < 0) {
+			pr_fail_err("userfaultfd madvise failed");
 			(void)kill(c->parent, SIGALRM);
 			return -1;
 		}
 		/* and trigger some page faults */
 		for (ptr = c->data; ptr < end; ptr += c->page_size)
 			*ptr = 0xff;
-	} while (opt_do_run && (!c->max_ops || *c->counter < c->max_ops));
+	} while (keep_stressing());
 
 	return 0;
 }
@@ -104,7 +104,7 @@ static int stress_userfaultfd_child(void *arg)
  *	handle a write page fault caused by child
  */
 static inline int handle_page_fault(
-	const char *name,
+	const args_t *args,
 	int fd,
 	uint8_t *addr,
 	void *zero_page,
@@ -113,7 +113,7 @@ static inline int handle_page_fault(
 	size_t page_size)
 {
 	if ((addr < data_start) || (addr >= data_end)) {
-		pr_fail_err(name, "userfaultfd page fault address out of range");
+		pr_fail_err("userfaultfd page fault address out of range");
 		return -1;
 	}
 
@@ -127,7 +127,7 @@ static inline int handle_page_fault(
 		copy.len = page_size;
 
 		if (ioctl(fd, UFFDIO_COPY, &copy) < 0) {
-			pr_fail_err(name, "userfaultfd page fault copy ioctl failed");
+			pr_fail_err("userfaultfd page fault copy ioctl failed");
 			return -1;
 		}
 	} else {
@@ -137,7 +137,7 @@ static inline int handle_page_fault(
 		zeropage.range.len = page_size;
 		zeropage.mode = 0;
 		if (ioctl(fd, UFFDIO_ZEROPAGE, &zeropage) < 0) {
-			pr_fail_err(name, "userfaultfd page fault zeropage ioctl failed");
+			pr_fail_err("userfaultfd page fault zeropage ioctl failed");
 			return -1;
 		}
 	}
@@ -150,13 +150,9 @@ static inline int handle_page_fault(
  *	is an OOM-able child process that the
  *	parent can restart
  */
-static int stress_userfaultfd_oomable(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+static int stress_userfaultfd_oomable(const args_t *args)
 {
-	const size_t page_size = stress_get_pagesize();
+	const size_t page_size = args->page_size;
 	size_t sz;
 	uint8_t *data;
 	void *zero_page = NULL;
@@ -175,18 +171,16 @@ static int stress_userfaultfd_oomable(
 		stress_get_stack_direction() * (STACK_SIZE - 64);
 	uint8_t *stack_top = stack + stack_offset;
 
-	(void)instance;
-
 	if (!set_userfaultfd_bytes) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_userfaultfd_bytes = MAX_MMAP_BYTES;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_userfaultfd_bytes = MIN_MMAP_BYTES;
 	}
 	sz = opt_userfaultfd_bytes & ~(page_size - 1);
 
 	if (posix_memalign(&zero_page, page_size, page_size)) {
-		pr_err(stderr, "%s: zero page allocation failed\n", name);
+		pr_err("%s: zero page allocation failed\n", args->name);
 		return EXIT_NO_RESOURCE;
 	}
 
@@ -194,15 +188,15 @@ static int stress_userfaultfd_oomable(
 		MAP_PRIVATE | MAP_ANONYMOUS, -1, 0);
 	if (data == MAP_FAILED) {
 		rc = EXIT_NO_RESOURCE;
-		pr_err(stderr, "%s: mmap failed\n", name);
+		pr_err("%s: mmap failed\n", args->name);
 		goto free_zeropage;
 	}
 
 	/* Get userfault fd */
 	if ((fd = shim_userfaultfd(0)) < 0) {
 		rc = exit_status(errno);
-		pr_err(stderr, "%s: userfaultfd failed, errno = %d (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: userfaultfd failed, errno = %d (%s)\n",
+			args->name, errno, strerror(errno));
 		goto unmap_data;
 	}
 
@@ -214,14 +208,14 @@ static int stress_userfaultfd_oomable(
 	api.api = UFFD_API;
 	api.features = 0;
 	if (ioctl(fd, UFFDIO_API, &api) < 0) {
-		pr_err(stderr, "%s: ioctl UFFDIO_API failed, errno = %d (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: ioctl UFFDIO_API failed, errno = %d (%s)\n",
+			args->name, errno, strerror(errno));
 		rc = EXIT_FAILURE;
 		goto unmap_data;
 	}
 	if (api.api != UFFD_API) {
-		pr_err(stderr, "%s: ioctl UFFDIO_API API check failed\n",
-			name);
+		pr_err("%s: ioctl UFFDIO_API API check failed\n",
+			args->name);
 		rc = EXIT_FAILURE;
 		goto unmap_data;
 	}
@@ -232,34 +226,32 @@ static int stress_userfaultfd_oomable(
 	reg.range.len = sz;
 	reg.mode = UFFDIO_REGISTER_MODE_MISSING;
 	if (ioctl(fd, UFFDIO_REGISTER, &reg) < 0) {
-		pr_err(stderr, "%s: ioctl UFFDIO_REGISTER failed, errno = %d (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: ioctl UFFDIO_REGISTER failed, errno = %d (%s)\n",
+			args->name, errno, strerror(errno));
 		rc = EXIT_FAILURE;
 		goto unmap_data;
 	}
 
 	/* OK, so do we have copy supported? */
 	if ((reg.ioctls & uffdio_copy) != uffdio_copy) {
-		pr_err(stderr, "%s: ioctl UFFDIO_REGISTER did not support _UFFDIO_COPY\n",
-			name);
+		pr_err("%s: ioctl UFFDIO_REGISTER did not support _UFFDIO_COPY\n",
+			args->name);
 		rc = EXIT_FAILURE;
 		goto unmap_data;
 	}
 	/* OK, so do we have zeropage supported? */
 	if ((reg.ioctls & uffdio_zeropage) != uffdio_zeropage) {
-		pr_err(stderr, "%s: ioctl UFFDIO_REGISTER did not support _UFFDIO_ZEROPAGE\n",
-			name);
+		pr_err("%s: ioctl UFFDIO_REGISTER did not support _UFFDIO_ZEROPAGE\n",
+			args->name);
 		rc = EXIT_FAILURE;
 		goto unmap_data;
 	}
 
 	/* Set up context for child */
-	c.name = name;
+	c.args = args;
 	c.data = data;
 	c.sz = sz;
-	c.max_ops = max_ops;
 	c.page_size = page_size;
-	c.counter = counter;
 	c.parent = getpid();
 
 	/*
@@ -269,8 +261,8 @@ static int stress_userfaultfd_oomable(
 	pid = clone(stress_userfaultfd_child, align_stack(stack_top),
 		SIGCHLD | CLONE_FILES | CLONE_FS | CLONE_SIGHAND | CLONE_VM, &c);
 	if (pid < 0) {
-		pr_err(stderr, "%s: fork failed, errno = %d (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: fork failed, errno = %d (%s)\n",
+			args->name, errno, strerror(errno));
 		goto unreg;
 	}
 
@@ -280,7 +272,7 @@ static int stress_userfaultfd_oomable(
 		ssize_t ret;
 
 		/* check we should break out before we block on the read */
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 
 		/*
@@ -302,8 +294,8 @@ static int stress_userfaultfd_oomable(
 				if (errno == EINTR)
 					continue;
 				if (errno != ENOMEM) {
-					pr_fail_err(name, "poll userfaultfd");
-					if (!opt_do_run)
+					pr_fail_err("poll userfaultfd");
+					if (!g_keep_stressing_flag)
 						break;
 				}
 				/*
@@ -322,38 +314,38 @@ do_read:
 		if ((ret = read(fd, &msg, sizeof(msg))) < 0) {
 			if (errno == EINTR)
 				continue;
-			pr_fail_err(name, "read userfaultfd");
-			if (!opt_do_run)
+			pr_fail_err("read userfaultfd");
+			if (!g_keep_stressing_flag)
 				break;
 			continue;
 		}
 		/* We only expect a page fault event */
 		if (msg.event != UFFD_EVENT_PAGEFAULT) {
-			pr_fail_err(name, "userfaultfd msg not pagefault event");
+			pr_fail_err("userfaultfd msg not pagefault event");
 			continue;
 		}
 		/* We only expect a write fault */
 		if (!(msg.arg.pagefault.flags & UFFD_PAGEFAULT_FLAG_WRITE)) {
-			pr_fail_err(name, "userfaultfd msg not write page fault event");
+			pr_fail_err("userfaultfd msg not write page fault event");
 			continue;
 		}
 		/* Go handle the page fault */
-		if (handle_page_fault(name, fd, (uint8_t *)(ptrdiff_t)msg.arg.pagefault.address,
+		if (handle_page_fault(args, fd, (uint8_t *)(ptrdiff_t)msg.arg.pagefault.address,
 				zero_page, data, data + sz, page_size) < 0)
 			break;
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
 	/* Run it over, zap child */
 	(void)kill(pid, SIGKILL);
 	if (waitpid(pid, &status, 0) < 0) {
-		pr_dbg(stderr, "%s: waitpid failed, errno = %d (%s)\n",
-			name, errno, strerror(errno));
+		pr_dbg("%s: waitpid failed, errno = %d (%s)\n",
+			args->name, errno, strerror(errno));
 	}
 unreg:
 	if (ioctl(fd, UFFDIO_UNREGISTER, &reg) < 0) {
-		pr_err(stderr, "%s: ioctl UFFDIO_UNREGISTER failed, errno = %d (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: ioctl UFFDIO_UNREGISTER failed, errno = %d (%s)\n",
+			args->name, errno, strerror(errno));
 		rc = EXIT_FAILURE;
 		goto unmap_data;
 	}
@@ -368,11 +360,7 @@ free_zeropage:
  *  stress_userfaultfd()
  *	stress userfaultfd
  */
-int stress_userfaultfd(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_userfaultfd(const args_t *args)
 {
 	pid_t pid;
 	int rc = EXIT_FAILURE;
@@ -381,32 +369,32 @@ int stress_userfaultfd(
 	if (pid < 0) {
 		if (errno == EAGAIN)
 			return EXIT_NO_RESOURCE;
-		pr_err(stderr, "%s: fork failed: errno=%d: (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: fork failed: errno=%d: (%s)\n",
+			args->name, errno, strerror(errno));
 	} else if (pid > 0) {
 		/* Parent */
 		int status, ret;
 
-		(void)setpgid(pid, pgrp);
+		(void)setpgid(pid, g_pgrp);
 		ret = waitpid(pid, &status, 0);
 		if (ret < 0) {
 			if (errno != EINTR)
-				pr_dbg(stderr, "%s: waitpid(): errno=%d (%s)\n",
-					name, errno, strerror(errno));
+				pr_dbg("%s: waitpid(): errno=%d (%s)\n",
+					args->name, errno, strerror(errno));
 			(void)kill(pid, SIGTERM);
 			(void)kill(pid, SIGKILL);
 			(void)waitpid(pid, &status, 0);
 		} else if (WIFSIGNALED(status)) {
-			pr_dbg(stderr, "%s: child died: %s (instance %d)\n",
-				name, stress_strsignal(WTERMSIG(status)),
-				instance);
+			pr_dbg("%s: child died: %s (instance %d)\n",
+				args->name, stress_strsignal(WTERMSIG(status)),
+				args->instance);
 			/* If we got killed by OOM killer, report this */
 			if (WTERMSIG(status) == SIGKILL) {
 				log_system_mem_info();
-				pr_dbg(stderr, "%s: assuming killed by OOM "
+				pr_dbg("%s: assuming killed by OOM "
 					"killer, aborting "
 					"(instance %d)\n",
-					name, instance);
+					args->name, args->instance);
 				return EXIT_NO_RESOURCE;
 			}
 			return EXIT_FAILURE;
@@ -414,20 +402,16 @@ int stress_userfaultfd(
 		rc = WEXITSTATUS(status);
 	} else if (pid == 0) {
 		/* Child */
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
 
-		_exit(stress_userfaultfd_oomable(counter, instance, max_ops, name));
+		_exit(stress_userfaultfd_oomable(args));
 	}
 	return rc;
 }
 #else
-int stress_userfaultfd(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_userfaultfd(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
