@@ -34,10 +34,7 @@
 #define STACK_SIZE	(64 * 1024)
 
 typedef struct {
-	const char *name;
-	uint64_t *counter;
-	uint64_t max_ops;
-	size_t page_size;
+	const args_t *args;
 	size_t sz;
 	pid_t pid;
 	int pipe_wr[2];
@@ -54,12 +51,14 @@ typedef struct {
 static size_t opt_vm_rw_bytes = DEFAULT_VM_RW_BYTES;
 static bool set_vm_rw_bytes = false;
 
-void stress_set_vm_rw_bytes(const char *optarg)
+void stress_set_vm_rw_bytes(const char *opt)
 {
 	set_vm_rw_bytes = true;
-	opt_vm_rw_bytes = (size_t)get_uint64_byte(optarg);
-	check_range("vm-rw-bytes", opt_vm_rw_bytes,
-		MIN_VM_RW_BYTES, MAX_VM_RW_BYTES);
+	opt_vm_rw_bytes = (size_t)
+		get_uint64_byte_memory(opt,
+			stressor_instances(STRESS_VM_RW));
+	check_range_bytes("vm-rw-bytes", opt_vm_rw_bytes,
+		MIN_VM_RW_BYTES, MAX_MEM_LIMIT);
 }
 
 #if defined(__linux__) &&		\
@@ -70,12 +69,13 @@ void stress_set_vm_rw_bytes(const char *optarg)
 static int stress_vm_child(void *arg)
 {
 	context_t *ctxt = (context_t *)arg;
+	const args_t *args = ctxt->args;
 
 	uint8_t *buf;
 	int ret = EXIT_SUCCESS;
 	addr_msg_t msg_rd, msg_wr;
 
-	(void)setpgid(0, pgrp);
+	(void)setpgid(0, g_pgrp);
 	stress_parent_died_alarm();
 
 	/* Close unwanted ends */
@@ -86,11 +86,11 @@ static int stress_vm_child(void *arg)
 		MAP_ANONYMOUS | MAP_PRIVATE, -1, 0);
 	if (buf == MAP_FAILED) {
 		ret = exit_status(errno);
-		pr_fail_dbg(ctxt->name, "mmap");
+		pr_fail_dbg("mmap");
 		goto cleanup;
 	}
 
-	while (opt_do_run) {
+	while (g_keep_stressing_flag) {
 		uint8_t *ptr, *end = buf + ctxt->sz;
 		int rwret;
 
@@ -105,7 +105,7 @@ redo_wr1:
 			if ((errno == EAGAIN) || (errno == EINTR))
 				goto redo_wr1;
 			if (errno != EBADF)
-				pr_fail_dbg(ctxt->name, "write");
+				pr_fail_dbg("write");
 			break;
 		}
 redo_rd1:
@@ -114,22 +114,22 @@ redo_rd1:
 		if (rwret < 0) {
 			if ((errno == EAGAIN) || (errno == EINTR))
 				goto redo_rd1;
-			pr_fail_dbg(ctxt->name, "read");
+			pr_fail_dbg("read");
 			break;
 		}
 		if (rwret == 0)
 			break;
 		if (rwret != sizeof(msg_rd)) {
-			pr_fail_dbg(ctxt->name, "read");
+			pr_fail_dbg("read");
 			break;
 		}
 
-		if (opt_flags & OPT_FLAGS_VERIFY) {
+		if (g_opt_flags & OPT_FLAGS_VERIFY) {
 			/* Check memory altered by parent is sane */
-			for (ptr = buf; ptr < end; ptr += ctxt->page_size) {
+			for (ptr = buf; ptr < end; ptr += args->page_size) {
 				if (*ptr != msg_rd.val) {
-					pr_fail(stderr, "%s: memory at %p: %d vs %d\n",
-						ctxt->name, ptr, *ptr, msg_rd.val);
+					pr_fail("%s: memory at %p: %d vs %d\n",
+						args->name, ptr, *ptr, msg_rd.val);
 					goto cleanup;
 				}
 				*ptr = 0;
@@ -142,9 +142,9 @@ cleanup:
 	msg_wr.val = 0;
 	if (write(ctxt->pipe_wr[1], &msg_wr, sizeof(msg_wr)) <= 0) {
 		if (errno != EBADF)
-			pr_dbg(stderr, "%s: failed to write termination message "
+			pr_dbg("%s: failed to write termination message "
 				"over pipe: errno=%d (%s)\n",
-				ctxt->name, errno, strerror(errno));
+				args->name, errno, strerror(errno));
 	}
 
 	(void)close(ctxt->pipe_wr[1]);
@@ -160,8 +160,9 @@ static int stress_vm_parent(context_t *ctxt)
 	uint8_t val = 0;
 	uint8_t *localbuf;
 	addr_msg_t msg_rd, msg_wr;
+	const args_t *args = ctxt->args;
 
-	(void)setpgid(ctxt->pid, pgrp);
+	(void)setpgid(ctxt->pid, g_pgrp);
 
 	localbuf = mmap(NULL, ctxt->sz, PROT_READ | PROT_WRITE,
 			MAP_ANONYMOUS | MAP_PRIVATE, -1, 0);
@@ -170,7 +171,7 @@ static int stress_vm_parent(context_t *ctxt)
 		(void)close(ctxt->pipe_wr[1]);
 		(void)close(ctxt->pipe_rd[0]);
 		(void)close(ctxt->pipe_rd[1]);
-		pr_fail_dbg(ctxt->name, "mmap");
+		pr_fail_dbg("mmap");
 		return EXIT_FAILURE;
 	}
 
@@ -185,19 +186,19 @@ static int stress_vm_parent(context_t *ctxt)
 
 		/* Wait for address of child's buffer */
 redo_rd2:
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 		ret = read(ctxt->pipe_wr[0], &msg_rd, sizeof(msg_rd));
 		if (ret < 0) {
 			if ((errno == EAGAIN) || (errno == EINTR))
 				goto redo_rd2;
-			pr_fail_dbg(ctxt->name, "read");
+			pr_fail_dbg("read");
 			break;
 		}
 		if (ret == 0)
 			break;
 		if (ret != sizeof(msg_rd)) {
-			pr_fail_dbg(ctxt->name, "read");
+			pr_fail_dbg("read");
 			break;
 		}
 		/* Child telling us it's terminating? */
@@ -210,22 +211,22 @@ redo_rd2:
 		remote[0].iov_base = msg_rd.addr;
 		remote[0].iov_len = ctxt->sz;
 		if (process_vm_readv(ctxt->pid, local, 1, remote, 1, 0) < 0) {
-			pr_fail_dbg(ctxt->name, "process_vm_readv");
+			pr_fail_dbg("process_vm_readv");
 			break;
 		}
 
-		if (opt_flags & OPT_FLAGS_VERIFY) {
+		if (g_opt_flags & OPT_FLAGS_VERIFY) {
 			/* Check data is sane */
-			for (ptr = localbuf; ptr < end; ptr += ctxt->page_size) {
+			for (ptr = localbuf; ptr < end; ptr += args->page_size) {
 				if (*ptr) {
-					pr_fail(stderr, "%s: memory at %p: %d vs %d\n",
-						ctxt->name, ptr, *ptr, msg_rd.val);
+					pr_fail("%s: memory at %p: %d vs %d\n",
+						args->name, ptr, *ptr, msg_rd.val);
 					goto fail;
 				}
 				*ptr = 0;
 			}
 			/* Set memory */
-			for (ptr = localbuf; ptr < end; ptr += ctxt->page_size)
+			for (ptr = localbuf; ptr < end; ptr += args->page_size)
 				*ptr = val;
 		}
 
@@ -236,13 +237,13 @@ redo_rd2:
 		remote[0].iov_base = msg_rd.addr;
 		remote[0].iov_len = ctxt->sz;
 		if (process_vm_writev(ctxt->pid, local, 1, remote, 1, 0) < 0) {
-			pr_fail_dbg(ctxt->name, "process_vm_writev");
+			pr_fail_dbg("process_vm_writev");
 			break;
 		}
 		msg_wr.val = val;
 		val++;
 redo_wr2:
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 		/* Inform child that memory has been changed */
 		ret = write(ctxt->pipe_rd[1], &msg_wr, sizeof(msg_wr));
@@ -250,21 +251,21 @@ redo_wr2:
 			if ((errno == EAGAIN) || (errno == EINTR))
 				goto redo_wr2;
 			if (errno != EBADF)
-				pr_fail_dbg(ctxt->name, "write");
+				pr_fail_dbg("write");
 			break;
 		}
-		(*ctxt->counter)++;
-	} while (opt_do_run && (!ctxt->max_ops || *ctxt->counter < ctxt->max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 fail:
 	/* Tell child we're done */
 	msg_wr.addr = NULL;
 	msg_wr.val = 0;
 	if (write(ctxt->pipe_wr[0], &msg_wr, sizeof(msg_wr)) < 0) {
 		if (errno != EBADF)
-			pr_dbg(stderr, "%s: failed to write "
+			pr_dbg("%s: failed to write "
 				"termination message "
 				"over pipe: errno=%d (%s)\n",
-				ctxt->name, errno, strerror(errno));
+				args->name, errno, strerror(errno));
 	}
 	(void)close(ctxt->pipe_wr[0]);
 	(void)close(ctxt->pipe_rd[1]);
@@ -279,11 +280,7 @@ fail:
  *  stress_vm_rw
  *	stress vm_read_v/vm_write_v
  */
-int stress_vm_rw(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_vm_rw(const args_t *args)
 {
 	context_t ctxt;
 	uint8_t stack[64*1024];
@@ -291,50 +288,44 @@ int stress_vm_rw(
 		stress_get_stack_direction() * (STACK_SIZE - 64);
 	uint8_t *stack_top = stack + stack_offset;
 
-	(void)instance;
-
 	if (!set_vm_rw_bytes) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_vm_rw_bytes = MAX_VM_RW_BYTES;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_vm_rw_bytes = MIN_VM_RW_BYTES;
 	}
-	ctxt.name = name;
-	ctxt.page_size = stress_get_pagesize();
-	ctxt.sz = opt_vm_rw_bytes & ~(ctxt.page_size - 1);
-	ctxt.counter = counter;
-	ctxt.max_ops = max_ops;
+	ctxt.args = args;
+	ctxt.sz = opt_vm_rw_bytes & ~(args->page_size - 1);
 
 	if (pipe(ctxt.pipe_wr) < 0) {
-		pr_fail_dbg(name, "pipe");
-		return EXIT_FAILURE;
+		pr_fail_dbg("pipe");
+		return EXIT_NO_RESOURCE;
 	}
 	if (pipe(ctxt.pipe_rd) < 0) {
 		(void)close(ctxt.pipe_wr[0]);
 		(void)close(ctxt.pipe_wr[1]);
-		pr_fail_dbg(name, "pipe");
-		return EXIT_FAILURE;
+		pr_fail_dbg("pipe");
+		return EXIT_NO_RESOURCE;
 	}
 
+again:
 	ctxt.pid = clone(stress_vm_child, align_stack(stack_top),
 		SIGCHLD | CLONE_VM, &ctxt);
 	if (ctxt.pid < 0) {
+		if (g_keep_stressing_flag && (errno == EAGAIN))
+			goto again;
 		(void)close(ctxt.pipe_wr[0]);
 		(void)close(ctxt.pipe_wr[1]);
 		(void)close(ctxt.pipe_rd[0]);
 		(void)close(ctxt.pipe_rd[1]);
-		pr_fail_dbg(name, "clone");
-		return EXIT_FAILURE;
+		pr_fail_dbg("clone");
+		return EXIT_NO_RESOURCE;
 	}
 	return stress_vm_parent(&ctxt);
 }
 #else
-int stress_vm_rw(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_vm_rw(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
