@@ -27,12 +27,14 @@
 static size_t opt_vm_splice_bytes = DEFAULT_VM_SPLICE_BYTES;
 static bool set_vm_splice_bytes = false;
 
-void stress_set_vm_splice_bytes(const char *optarg)
+void stress_set_vm_splice_bytes(const char *opt)
 {
 	set_vm_splice_bytes = true;
-	opt_vm_splice_bytes = (size_t)get_uint64_byte(optarg);
-	check_range("vm-splice-bytes", opt_vm_splice_bytes,
-		MIN_VM_SPLICE_BYTES, MAX_VM_SPLICE_BYTES);
+	opt_vm_splice_bytes = (size_t)
+		get_uint64_byte_memory(opt,
+			stressor_instances(STRESS_VM_SPLICE));
+	check_range_bytes("vm-splice-bytes", opt_vm_splice_bytes,
+		MIN_VM_SPLICE_BYTES, MAX_MEM_LIMIT);
 }
 
 #if defined(__linux__) && NEED_GLIBC(2,5,0)
@@ -41,23 +43,17 @@ void stress_set_vm_splice_bytes(const char *optarg)
  *  stress_splice
  *	stress copying of /dev/zero to /dev/null
  */
-int stress_vm_splice(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_vm_splice(const args_t *args)
 {
 	int fd, fds[2];
 	uint8_t *buf;
-	const size_t page_size = stress_get_pagesize();
+	const size_t page_size = args->page_size;
 	size_t sz;
 
-	(void)instance;
-
 	if (!set_vm_splice_bytes) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_vm_splice_bytes = MAX_VM_SPLICE_BYTES;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_vm_splice_bytes = MIN_VM_SPLICE_BYTES;
 	}
 	sz = opt_vm_splice_bytes & ~(page_size - 1);
@@ -67,13 +63,13 @@ int stress_vm_splice(
 	if (buf == MAP_FAILED) {
 		int rc = exit_status(errno);
 
-		pr_fail_dbg(name, "mmap");
+		pr_fail_dbg("mmap");
 		return rc;
 	}
 
 	if (pipe(fds) < 0) {
 		(void)munmap(buf, sz);
-		pr_fail_err(name, "pipe");
+		pr_fail_err("pipe");
 		return EXIT_FAILURE;
 	}
 
@@ -81,7 +77,7 @@ int stress_vm_splice(
 		(void)munmap(buf, sz);
 		(void)close(fds[0]);
 		(void)close(fds[1]);
-		pr_fail_err(name, "open");
+		pr_fail_err("open");
 		return EXIT_FAILURE;
 	}
 
@@ -101,8 +97,8 @@ int stress_vm_splice(
 		if (ret < 0)
 			break;
 
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		inc_counter(args);
+	} while (keep_stressing());
 
 	(void)munmap(buf, sz);
 	(void)close(fd);
@@ -112,12 +108,8 @@ int stress_vm_splice(
 	return EXIT_SUCCESS;
 }
 #else
-int stress_vm_splice(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_vm_splice(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
