@@ -24,6 +24,11 @@
  */
 #include "stress-ng.h"
 
+/*
+ *  For testing, set this to 1 to simulate random memory errors
+ */
+#define INJECT_BIT_ERRORS	(0)
+
 #define VM_BOGO_SHIFT		(12)
 #define VM_ROWHAMMER_LOOPS	(1000000)
 
@@ -48,19 +53,21 @@ static int      opt_vm_flags = 0;                      /* VM mmap flags */
 static const stress_vm_stressor_info_t *opt_vm_stressor;
 static const stress_vm_stressor_info_t vm_methods[];
 
-void stress_set_vm_hang(const char *optarg)
+void stress_set_vm_hang(const char *opt)
 {
-	opt_vm_hang = get_uint64_byte(optarg);
+	opt_vm_hang = get_uint64_byte(opt);
 	check_range("vm-hang", opt_vm_hang,
 		MIN_VM_HANG, MAX_VM_HANG);
 }
 
-void stress_set_vm_bytes(const char *optarg)
+void stress_set_vm_bytes(const char *opt)
 {
 	set_vm_bytes = true;
-	opt_vm_bytes = (size_t)get_uint64_byte(optarg);
-	check_range("vm-bytes", opt_vm_bytes,
-		MIN_VM_BYTES, MAX_VM_BYTES);
+	opt_vm_bytes = (size_t)
+		get_uint64_byte_memory(opt,
+			stressor_instances(STRESS_VM));
+	check_range_bytes("vm-bytes", opt_vm_bytes,
+		MIN_VM_BYTES, MAX_MEM_LIMIT);
 }
 
 void stress_set_vm_flags(const int flag)
@@ -68,11 +75,6 @@ void stress_set_vm_flags(const int flag)
 	opt_vm_flags |= flag;
 }
 
-/*
- *  For testing, set this to 1 to simulate random memory errors
- */
-#define INJECT_BIT_ERRORS	(0)
-
 #define SET_AND_TEST(ptr, val, bit_errors)	\
 {						\
 	*ptr = val;				\
@@ -165,12 +167,12 @@ static inline void inject_random_bit_errors(uint8_t *buf, const size_t sz)
  */
 static void stress_vm_check(const char *name, const size_t bit_errors)
 {
-	if (bit_errors && (opt_flags & OPT_FLAGS_VERIFY))
+	if (bit_errors && (g_opt_flags & OPT_FLAGS_VERIFY))
 #if INJECT_BIT_ERRORS
-		pr_dbg(stderr, "%s: detected %zu memory error%s\n",
+		pr_dbg("%s: detected %zu memory error%s\n",
 			name, bit_errors, bit_errors == 1 ? "" : "s");
 #else
-		pr_fail(stderr, "%s: detected %zu memory error%s\n",
+		pr_fail("%s: detected %zu memory error%s\n",
 			name, bit_errors, bit_errors == 1 ? "" : "s");
 #endif
 }
@@ -226,7 +228,7 @@ static size_t stress_vm_moving_inversion(
 		c++;
 		if (max_ops && c >= max_ops)
 			goto abort;
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			goto abort;
 	}
 
@@ -242,7 +244,7 @@ static size_t stress_vm_moving_inversion(
 		c++;
 		if (max_ops && c >= max_ops)
 			goto abort;
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			goto abort;
 	}
 
@@ -266,7 +268,7 @@ static size_t stress_vm_moving_inversion(
 		c++;
 		if (max_ops && c >= max_ops)
 			goto abort;
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			goto abort;
 	}
 	mwc_seed(w, z);
@@ -274,7 +276,7 @@ static size_t stress_vm_moving_inversion(
 		uint64_t val = mwc64();
 		if (*--ptr != ~val)
 			bit_errors++;
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			goto abort;
 	}
 
@@ -312,7 +314,7 @@ static size_t stress_vm_modulo_x(
 	for (i = 0; i < stride; i++) {
 		for (ptr = buf + i; ptr < buf_end; ptr += stride) {
 			*ptr = pattern;
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				goto abort;
 		}
 		for (ptr = buf; ptr < buf_end; ptr += stride) {
@@ -322,7 +324,7 @@ static size_t stress_vm_modulo_x(
 				if (max_ops && c >= max_ops)
 					goto abort;
 			}
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				goto abort;
 			ptr++;
 			for (j = i + 1; j < stride && ptr < buf_end; j++) {
@@ -331,7 +333,7 @@ static size_t stress_vm_modulo_x(
 				if (max_ops && c >= max_ops)
 					goto abort;
 			}
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				goto abort;
 		}
 		inject_random_bit_errors(buf, sz);
@@ -339,7 +341,7 @@ static size_t stress_vm_modulo_x(
 		for (ptr = buf + i; ptr < buf_end; ptr += stride) {
 			if (*ptr != pattern)
 				bit_errors++;
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				return bit_errors;
 		}
 	}
@@ -379,7 +381,7 @@ static size_t stress_vm_walking_one_data(
 		c++;
 		if (max_ops && c >= max_ops)
 			break;
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 	}
 	stress_vm_check("walking one (data)", bit_errors);
@@ -416,7 +418,7 @@ static size_t stress_vm_walking_zero_data(
 		c++;
 		if (max_ops && c >= max_ops)
 			break;
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 	}
 	stress_vm_check("walking zero (data)", bit_errors);
@@ -466,7 +468,7 @@ static size_t stress_vm_walking_one_addr(
 		c++;
 		if (max_ops && c >= max_ops)
 			break;
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 	}
 	stress_vm_check("walking one (address)", bit_errors);
@@ -520,7 +522,7 @@ static size_t stress_vm_walking_zero_addr(
 		c++;
 		if (max_ops && c >= max_ops)
 			break;
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 	}
 	stress_vm_check("walking zero (address)", bit_errors);
@@ -548,7 +550,7 @@ static size_t stress_vm_gray(
 	uint64_t c = *counter;
 
 	for (v = val, ptr = buf; ptr < buf_end; ptr++, v++) {
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			return 0;
 		*ptr = (v >> 1) ^ v;
 		c++;
@@ -559,7 +561,7 @@ static size_t stress_vm_gray(
 	inject_random_bit_errors(buf, sz);
 
 	for (v = val, ptr = buf; ptr < buf_end; ptr++, v++) {
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 		if (*ptr != ((v >> 1) ^ v))
 			bit_errors++;
@@ -701,7 +703,7 @@ static size_t stress_vm_swap(
 	w1 = mwc64();
 
 	if ((swaps = calloc(chunks, sizeof(size_t))) == NULL) {
-		pr_fail_dbg("stress-vm", "calloc");
+		pr_fail("stress-vm: calloc failed on vm_swap\n");
 		return 0;
 	}
 
@@ -731,7 +733,7 @@ static size_t stress_vm_swap(
 		c++;
 		if (max_ops && c >= max_ops)
 			goto abort;
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			goto abort;
 	}
 	/* Reverse swaps */
@@ -750,7 +752,7 @@ static size_t stress_vm_swap(
 		c++;
 		if (max_ops && c >= max_ops)
 			goto abort;
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			goto abort;
 	}
 
@@ -768,7 +770,7 @@ static size_t stress_vm_swap(
 				bit_errors++;
 			p++;
 		}
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 	}
 abort:
@@ -815,7 +817,7 @@ static size_t stress_vm_rand_set(
 		c++;
 		if (max_ops && c >= max_ops)
 			goto abort;
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			goto abort;
 	}
 
@@ -834,7 +836,7 @@ static size_t stress_vm_rand_set(
 		bit_errors += (*(ptr + 5) != val);
 		bit_errors += (*(ptr + 6) != val);
 		bit_errors += (*(ptr + 7) != val);
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 	}
 abort:
@@ -882,7 +884,7 @@ static size_t stress_vm_ror(
 		c++;
 		if (max_ops && c >= max_ops)
 			goto abort;
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			goto abort;
 	}
 	(void)mincore_touch_pages(buf, sz);
@@ -899,7 +901,7 @@ static size_t stress_vm_ror(
 		c++;
 		if (max_ops && c >= max_ops)
 			goto abort;
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			goto abort;
 	}
 	(void)mincore_touch_pages(buf, sz);
@@ -919,7 +921,7 @@ static size_t stress_vm_ror(
 		bit_errors += (*(ptr + 5) != val);
 		bit_errors += (*(ptr + 6) != val);
 		bit_errors += (*(ptr + 7) != val);
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 	}
 abort:
@@ -974,7 +976,7 @@ static size_t stress_vm_flip(
 		c++;
 		if (max_ops && c >= max_ops)
 			goto abort;
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			goto abort;
 	}
 	(void)mincore_touch_pages(buf, sz);
@@ -993,7 +995,7 @@ static size_t stress_vm_flip(
 			c++;
 			if (max_ops && c >= max_ops)
 				goto abort;
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				goto abort;
 		}
 		(void)mincore_touch_pages(buf, sz);
@@ -1020,7 +1022,7 @@ static size_t stress_vm_flip(
 		bit_errors += (*(ptr + 6) != val);
 		ROR8(val);
 		bit_errors += (*(ptr + 7) != val);
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 	}
 
@@ -1064,7 +1066,7 @@ static size_t stress_vm_zero_one(
 		bit_errors += stress_vm_count_bits(*(ptr + 6));
 		bit_errors += stress_vm_count_bits(*(ptr + 7));
 
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			goto abort;
 	}
 
@@ -1083,7 +1085,7 @@ static size_t stress_vm_zero_one(
 		bit_errors += stress_vm_count_bits(~*(ptr + 6));
 		bit_errors += stress_vm_count_bits(~*(ptr + 7));
 
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 	}
 abort:
@@ -1142,7 +1144,7 @@ static size_t stress_vm_galpat_zero(
 		bits_set += stress_vm_count_bits(*(ptr + 6));
 		bits_set += stress_vm_count_bits(*(ptr + 7));
 
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 	}
 
@@ -1203,7 +1205,7 @@ static size_t stress_vm_galpat_one(
 		bits_set += stress_vm_count_bits(~(*(ptr + 5)));
 		bits_set += stress_vm_count_bits(~(*(ptr + 6)));
 		bits_set += stress_vm_count_bits(~(*(ptr + 7)));
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 	}
 
@@ -1250,7 +1252,7 @@ static size_t stress_vm_inc_nybble(
 		c++;
 		if (max_ops && c >= max_ops)
 			goto abort;
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			goto abort;
 	}
 
@@ -1266,7 +1268,7 @@ static size_t stress_vm_inc_nybble(
 		c++;
 		if (max_ops && c >= max_ops)
 			goto abort;
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			goto abort;
 	}
 	(void)mincore_touch_pages(buf, sz);
@@ -1281,7 +1283,7 @@ static size_t stress_vm_inc_nybble(
 		bit_errors += (*(ptr + 5) != val);
 		bit_errors += (*(ptr + 6) != val);
 		bit_errors += (*(ptr + 7) != val);
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 	}
 
@@ -1326,7 +1328,7 @@ static size_t stress_vm_rand_sum(
 		c++;
 		if (max_ops && c >= max_ops)
 			goto abort;
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			goto abort;
 	}
 
@@ -1343,7 +1345,7 @@ static size_t stress_vm_rand_sum(
 		bit_errors += stress_vm_count_bits(*(ptr + 5) ^ mwc64());
 		bit_errors += stress_vm_count_bits(*(ptr + 6) ^ mwc64());
 		bit_errors += stress_vm_count_bits(*(ptr + 7) ^ mwc64());
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 	}
 abort:
@@ -1392,7 +1394,7 @@ static size_t stress_vm_prime_zero(
 			c++;
 			if (max_ops && c >= max_ops)
 				goto abort;
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				goto abort;
 		}
 	}
@@ -1449,7 +1451,7 @@ static size_t stress_vm_prime_one(
 			c++;
 			if (max_ops && c >= max_ops)
 				goto abort;
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				goto abort;
 		}
 	}
@@ -1458,7 +1460,7 @@ static size_t stress_vm_prime_one(
 
 	for (i = 0; i < sz; i++) {
 		bit_errors += 8 - stress_vm_count_bits(buf[i]);
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 	}
 abort:
@@ -1501,7 +1503,7 @@ static size_t stress_vm_prime_gray_zero(
 		 *  memory and cache stalls
 		 */
 		ptr[j % sz] &= ((i >> 1) ^ i);
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			goto abort;
 		c++;
 		if (max_ops && c >= max_ops)
@@ -1514,7 +1516,7 @@ static size_t stress_vm_prime_gray_zero(
 		 *  memory and cache stalls
 		 */
 		ptr[j % sz] &= ~((i >> 1) ^ i);
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			goto abort;
 		c++;
 		if (max_ops && c >= max_ops)
@@ -1525,7 +1527,7 @@ static size_t stress_vm_prime_gray_zero(
 
 	for (i = 0; i < sz; i++) {
 		bit_errors += stress_vm_count_bits(buf[i]);
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 	}
 abort:
@@ -1568,7 +1570,7 @@ static size_t stress_vm_prime_gray_one(
 		 *  memory and cache stalls
 		 */
 		ptr[j % sz] |= ((i >> 1) ^ i);
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			goto abort;
 		c++;
 		if (max_ops && c >= max_ops)
@@ -1582,7 +1584,7 @@ static size_t stress_vm_prime_gray_one(
 		 *  memory and cache stalls
 		 */
 		ptr[j % sz] |= ~((i >> 1) ^ i);
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			goto abort;
 		c++;
 		if (max_ops && c >= max_ops)
@@ -1593,7 +1595,7 @@ static size_t stress_vm_prime_gray_one(
 
 	for (i = 0; i < sz; i++) {
 		bit_errors += 8 - stress_vm_count_bits(buf[i]);
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 	}
 abort:
@@ -1655,7 +1657,7 @@ static size_t stress_vm_write64(
 		*ptr++ = v;
 		*ptr++ = v;
 		i++;
-		if (!opt_do_run || (max_ops && i >= max_ops))
+		if (!g_keep_stressing_flag || (max_ops && i >= max_ops))
 			break;
 	}
 	*counter += i;
@@ -1715,7 +1717,7 @@ static size_t stress_vm_read64(
 		(void)*(ptr++);
 
 		i++;
-		if (!opt_do_run || (max_ops && i >= max_ops))
+		if (!g_keep_stressing_flag || (max_ops && i >= max_ops))
 			break;
 	}
 	*counter += i;
@@ -1742,7 +1744,7 @@ static size_t stress_vm_rowhammer(
 	(void)max_ops;
 
 	if (!n) {
-		pr_dbg(stderr, "rowhammer: zero uint32_t integers could "
+		pr_dbg("rowhammer: zero uint32_t integers could "
 			"be hammered, aborting\n");
 		return 0;
 	}
@@ -1782,7 +1784,7 @@ static size_t stress_vm_rowhammer(
 			errors++;
 	if (errors) {
 		bit_errors += errors;
-		pr_dbg(stderr, "rowhammer: %zu errors on addresses "
+		pr_dbg("rowhammer: %zu errors on addresses "
 			"%p and %p\n", errors, addr0, addr1);
 	}
 	(*counter) += VM_ROWHAMMER_LOOPS;
@@ -1859,11 +1861,11 @@ int stress_set_vm_method(const char *name)
 		}
 	}
 
-	fprintf(stderr, "vm-method must be one of:");
+	(void)fprintf(stderr, "vm-method must be one of:");
 	for (info = vm_methods; info->func; info++) {
-		fprintf(stderr, " %s", info->name);
+		(void)fprintf(stderr, " %s", info->name);
 	}
-	fprintf(stderr, "\n");
+	(void)fprintf(stderr, "\n");
 
 	return -1;
 }
@@ -1873,60 +1875,80 @@ int stress_set_vm_method(const char *name)
  *  stress_vm()
  *	stress virtual memory
  */
-int stress_vm(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_vm(const args_t *args)
 {
+	uint64_t *bit_error_count = MAP_FAILED;
 	uint32_t restarts = 0, nomems = 0;
 	uint8_t *buf = NULL;
 	pid_t pid;
-	const bool keep = (opt_flags & OPT_FLAGS_VM_KEEP);
+	const bool keep = (g_opt_flags & OPT_FLAGS_VM_KEEP);
 	const stress_vm_func func = opt_vm_stressor->func;
-        const size_t page_size = stress_get_pagesize();
-	size_t buf_sz;
+        const size_t page_size = args->page_size;
+	size_t buf_sz, retries;
+	int err = 0, ret = EXIT_SUCCESS;
 
 	if (!set_vm_bytes) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_vm_bytes = MAX_VM_BYTES;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
+		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_vm_bytes = MIN_VM_BYTES;
 	}
 	buf_sz = opt_vm_bytes & ~(page_size - 1);
 
+	for (retries = 0; (retries < 100) && g_keep_stressing_flag; retries++) {
+		bit_error_count = (uint64_t *)
+			mmap(NULL, page_size, PROT_READ | PROT_WRITE,
+				MAP_SHARED | MAP_ANONYMOUS, -1, 0);
+		err = errno;
+		if (bit_error_count != MAP_FAILED)
+			break;
+		(void)shim_usleep(100);
+	}
+
+	/* Cannot allocate a single page for bit error counter */
+	if (bit_error_count == MAP_FAILED) {
+		if (g_keep_stressing_flag) {
+			pr_err("%s: could not mmap bit error counter: "
+				"retry count=%zu, errno=%d (%s)\n",
+				args->name, retries, err, strerror(err));
+		}
+		return EXIT_NO_RESOURCE;
+	}
+
+	*bit_error_count = 0ULL;
+
 again:
-	if (!opt_do_run)
-		return EXIT_SUCCESS;
+	if (!g_keep_stressing_flag)
+		goto clean_up;
 	pid = fork();
 	if (pid < 0) {
 		if (errno == EAGAIN)
 			goto again;
-		pr_err(stderr, "%s: fork failed: errno=%d: (%s)\n",
-			name, errno, strerror(errno));
+		pr_err("%s: fork failed: errno=%d: (%s)\n",
+			args->name, errno, strerror(errno));
 	} else if (pid > 0) {
-		int status, ret;
+		int status, waitret;
 
 		/* Parent, wait for child */
-		(void)setpgid(pid, pgrp);
-		ret = waitpid(pid, &status, 0);
-		if (ret < 0) {
+		(void)setpgid(pid, g_pgrp);
+		waitret = waitpid(pid, &status, 0);
+		if (waitret < 0) {
 			if (errno != EINTR)
-				pr_dbg(stderr, "%s: waitpid(): errno=%d (%s)\n",
-					name, errno, strerror(errno));
+				pr_dbg("%s: waitpid(): errno=%d (%s)\n",
+					args->name, errno, strerror(errno));
 			(void)kill(pid, SIGTERM);
 			(void)kill(pid, SIGKILL);
 			(void)waitpid(pid, &status, 0);
 		} else if (WIFSIGNALED(status)) {
-			pr_dbg(stderr, "%s: child died: %s (instance %d)\n",
-				name, stress_strsignal(WTERMSIG(status)),
-				instance);
+			pr_dbg("%s: child died: %s (instance %d)\n",
+				args->name, stress_strsignal(WTERMSIG(status)),
+				args->instance);
 			/* If we got killed by OOM killer, re-start */
 			if (WTERMSIG(status) == SIGKILL) {
 				log_system_mem_info();
-				pr_dbg(stderr, "%s: assuming killed by OOM killer, "
+				pr_dbg("%s: assuming killed by OOM killer, "
 					"restarting again (instance %d)\n",
-					name, instance);
+					args->name, args->instance);
 				restarts++;
 				goto again;
 			}
@@ -1934,20 +1956,20 @@ again:
 	} else if (pid == 0) {
 		int no_mem_retries = 0;
 
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
 
 		/* Make sure this is killable by OOM killer */
-		set_oom_adjustment(name, true);
+		set_oom_adjustment(args->name, true);
 
 		do {
 			if (no_mem_retries >= NO_MEM_RETRIES_MAX) {
-				pr_err(stderr, "%s: gave up trying to mmap, no available memory\n",
-					name);
+				pr_err("%s: gave up trying to mmap, no available memory\n",
+					args->name);
 				break;
 			}
 			if (!keep || (buf == NULL)) {
-				if (!opt_do_run)
+				if (!g_keep_stressing_flag)
 					return EXIT_SUCCESS;
 				buf = (uint8_t *)mmap(NULL, buf_sz,
 					PROT_READ | PROT_WRITE,
@@ -1964,7 +1986,8 @@ again:
 
 			no_mem_retries = 0;
 			(void)mincore_touch_pages(buf, buf_sz);
-			(void)func(buf, buf_sz, counter, max_ops << VM_BOGO_SHIFT);
+			*bit_error_count += func(buf, buf_sz, args->counter,
+						args->max_ops << VM_BOGO_SHIFT);
 
 			if (opt_vm_hang == 0) {
 				for (;;) {
@@ -1978,17 +2001,27 @@ again:
 				(void)madvise_random(buf, buf_sz);
 				(void)munmap((void *)buf, buf_sz);
 			}
-		} while (opt_do_run && (!max_ops || *counter < max_ops));
+		} while (keep_stressing());
 
 		if (keep && buf != NULL)
 			(void)munmap((void *)buf, buf_sz);
 	}
-	*counter >>= VM_BOGO_SHIFT;
+clean_up:
+	(void)shim_msync(bit_error_count, page_size, MS_SYNC);
+	if (*bit_error_count > 0) {
+		pr_fail("%s: detected %" PRIu64 " bit errors while "
+			"stressing memory\n",
+			args->name, *bit_error_count);
+		ret = EXIT_FAILURE;
+	}
+	(void)munmap(bit_error_count, page_size);
+
+	*args->counter >>= VM_BOGO_SHIFT;
 
 	if (restarts + nomems > 0)
-		pr_dbg(stderr, "%s: OOM restarts: %" PRIu32
+		pr_dbg("%s: OOM restarts: %" PRIu32
 			", out of memory restarts: %" PRIu32 ".\n",
-			name, restarts, nomems);
+			args->name, restarts, nomems);
 
-	return EXIT_SUCCESS;
+	return ret;
 }
