@@ -33,30 +33,27 @@
  *	spawn a process
  */
 static pid_t spawn(
-	const char *name,
-	void (*func)(const char *name, const pid_t pid,
-		uint64_t *counter, const uint64_t max_ops),
-	pid_t pid_arg,
-	uint64_t *counter,
-	uint64_t max_ops)
+	const args_t *args,
+	void (*func)(const args_t *args, const pid_t pid),
+	pid_t pid_arg)
 {
 	pid_t pid;
 
 again:
 	pid = fork();
 	if (pid < 0) {
-		if (opt_do_run && (errno == EAGAIN))
+		if (g_keep_stressing_flag && (errno == EAGAIN))
 			goto again;
 		return -1;
 	}
 	if (pid == 0) {
-		(void)setpgid(0, pgrp);
+		(void)setpgid(0, g_pgrp);
 		stress_parent_died_alarm();
 
-		func(name, pid_arg, counter, max_ops);
+		func(args, pid_arg);
 		exit(EXIT_SUCCESS);
 	}
-	(void)setpgid(pid, pgrp);
+	(void)setpgid(pid, g_pgrp);
 	return pid;
 }
 
@@ -66,20 +63,18 @@ again:
  *	stopped and continued by the killer process
  */
 static void runner(
-	const char *name,
-	const pid_t pid,
-	uint64_t *counter,
-	const uint64_t max_ops)
+	const args_t *args,
+	const pid_t pid)
 {
 	(void)pid;
 
-	pr_dbg(stderr, "%s: wait: runner started [%d]\n", name, (int)getpid());
+	pr_dbg("%s: wait: runner started [%d]\n", args->name, (int)getpid());
 
 	do {
 		(void)pause();
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (keep_stressing());
 
-	kill(getppid(), SIGALRM);
+	(void)kill(getppid(), SIGALRM);
 	exit(EXIT_SUCCESS);
 }
 
@@ -88,15 +83,13 @@ static void runner(
  *	this continually stops and continues the runner process
  */
 static void killer(
-	const char *name,
-	const pid_t pid,
-	uint64_t *counter,
-	const uint64_t max_ops)
+	const args_t *args,
+	const pid_t pid)
 {
 	double start = time_now();
-	uint64_t last_counter = *counter;
+	uint64_t last_counter = *args->counter;
 
-	pr_dbg(stderr, "%s: wait: killer started [%d]\n", name, (int)getpid());
+	pr_dbg("%s: wait: killer started [%d]\n", args->name, (int)getpid());
 
 	do {
 		(void)kill(pid, SIGSTOP);
@@ -107,19 +100,19 @@ static void killer(
 		 *  so the counter is not being updated.
 		 *  If it is blocked for too long bail out
 		 *  so we don't get stuck in the parent
-		 *  waiter indefintely.
+		 *  waiter indefinitely.
 		 */
-		if (last_counter == *counter) {
+		if (last_counter == *args->counter) {
 			if (time_now() - start > ABORT_TIMEOUT) {
-				pr_dbg(stderr, "%s: waits were blocked, "
-					"aborting\n", name);
+				pr_dbg("%s: waits were blocked, "
+					"aborting\n", args->name);
 				break;
 			}
 		} else {
 			start = time_now();
-			last_counter = *counter;
+			last_counter = *args->counter;
 		}
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (keep_stressing());
 
 	/* forcefully kill runner, wait is in parent */
 	(void)kill(pid, SIGKILL);
@@ -132,29 +125,23 @@ static void killer(
  *  stress_wait
  *	stress wait*() family of calls
  */
-int stress_wait(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_wait(const args_t *args)
 {
 	int status, ret = EXIT_SUCCESS;
 	pid_t pid_r, pid_k;
 
-	(void)instance;
+	pr_dbg("%s: waiter started [%d]\n",
+		args->name, (int)args->pid);
 
-	pr_dbg(stderr, "%s: waiter started [%d]\n",
-		name, (int)getpid());
-
-	pid_r = spawn(name, runner, 0, counter, max_ops);
+	pid_r = spawn(args, runner, 0);
 	if (pid_r < 0) {
-		pr_fail_dbg(name, "fork");
+		pr_fail_dbg("fork");
 		exit(EXIT_FAILURE);
 	}
 
-	pid_k = spawn(name, killer, pid_r, counter, max_ops);
+	pid_k = spawn(args, killer, pid_r);
 	if (pid_k < 0) {
-		pr_fail_dbg(name, "fork");
+		pr_fail_dbg("fork");
 		ret = EXIT_FAILURE;
 		goto tidy;
 	}
@@ -165,13 +152,13 @@ int stress_wait(
 #else
 		(void)waitpid(pid_r, &status, 0);
 #endif
-		if (!opt_do_run)
+		if (!g_keep_stressing_flag)
 			break;
 #if defined(WIFCONINUED)
 		if (WIFCONTINUED(status))
-			(*counter)++;
+			inc_counter(args);
 #else
-		(*counter)++;
+		inc_counter(args);
 #endif
 
 #if _SVID_SOURCE || _XOPEN_SOURCE >= 500 || \
@@ -185,17 +172,17 @@ int stress_wait(
 #else
 			(void)waitid(P_PID, pid_r, &info, 0);
 #endif
-			if (!opt_do_run)
+			if (!g_keep_stressing_flag)
 				break;
 #if defined(WIFCONINUED)
 			if (WIFCONTINUED(status))
-				(*counter)++;
+				inc_counter(args);
 #else
-			(*counter)++;
+			inc_counter(args);
 #endif
 		}
 #endif
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	} while (g_keep_stressing_flag && (!args->max_ops || *args->counter < args->max_ops));
 
 	(void)kill(pid_k, SIGKILL);
 	(void)waitpid(pid_k, &status, 0);
@@ -206,12 +193,8 @@ tidy:
 	return ret;
 }
 #else
-int stress_wait(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_wait(const args_t *args)
 {
-	return stress_not_implemented(counter, instance, max_ops, name);
+	return stress_not_implemented(args);
 }
 #endif
