@@ -86,8 +86,8 @@ static inline void wcschk(
 	const char *msg,
 	bool *failed)
 {
-	if ((opt_flags & OPT_FLAGS_VERIFY) && (!ok)) {
-		pr_fail(stderr, "%s: %s did not return expected result\n",
+	if ((g_opt_flags & OPT_FLAGS_VERIFY) && (!ok)) {
+		pr_fail("%s: %s did not return expected result\n",
 			name, msg);
 		*failed = true;
 	}
@@ -118,7 +118,7 @@ static void stress_wcscasecmp(
 
 	(void)len2;
 
-	for (i = 1; opt_do_run && (i < len1); i++) {
+	for (i = 1; g_keep_stressing_flag && (i < len1); i++) {
 		WCSCHK(name, 0 == __wcscasecmp(str1, str1), failed);
 		WCSCHK(name, 0 == __wcscasecmp(str2, str2), failed);
 
@@ -154,7 +154,7 @@ static void stress_wcsncasecmp(
 
 	(void)len2;
 
-	for (i = 1; opt_do_run && (i < len1); i++) {
+	for (i = 1; g_keep_stressing_flag && (i < len1); i++) {
 		WCSCHK(name, 0 == __wcsncasecmp(str1, str1, len1), failed);
 		WCSCHK(name, 0 == __wcsncasecmp(str2, str2, len2), failed);
 
@@ -192,7 +192,7 @@ static void stress_wcslcpy(
 	const size_t str1_len = wcslen(str1);
 	const size_t str2_len = wcslen(str2);
 
-	for (i = 0; opt_do_run && (i < len1 - 1); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < len1 - 1); i++) {
 		WCSCHK(name, str1_len == __wcslcpy(buf, str1, buf_len), failed);
 		WCSCHK(name, str2_len == __wcslcpy(buf, str2, buf_len), failed);
 	}
@@ -215,7 +215,7 @@ static void stress_wcscpy(
 	wchar_t * (*__wcscpy)(wchar_t *dest, const wchar_t *src) = libc_func;
 	wchar_t buf[len1 + len2 + 1];
 
-	for (i = 0; opt_do_run && (i < len1 - 1); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < len1 - 1); i++) {
 		WCSCHK(name, buf == __wcscpy(buf, str1), failed);
 		WCSCHK(name, buf == __wcscpy(buf, str2), failed);
 	}
@@ -244,7 +244,7 @@ static void stress_wcslcat(
 	const size_t str2_len = wcslen(str2);
 	const size_t str_len = str1_len + str2_len;
 
-	for (i = 0; opt_do_run && (i < len1 - 1); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < len1 - 1); i++) {
 		*buf = L'\0';
 		WCSCHK(name, str1_len == __wcslcat(buf, str1, buf_len), failed);
 		*buf = L'\0';
@@ -275,7 +275,7 @@ static void stress_wcscat(
 	wchar_t * (*__wcscat)(wchar_t *dest, const wchar_t *src) = libc_func;
 	wchar_t buf[len1 + len2 + 1];
 
-	for (i = 0; opt_do_run && (i < len1 - 1); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < len1 - 1); i++) {
 		*buf = L'\0';
 		WCSCHK(name, buf == __wcscat(buf, str1), failed);
 		*buf = L'\0';
@@ -307,7 +307,7 @@ static void stress_wcsncat(
 	wchar_t * (*__wcsncat)(wchar_t *dest, const wchar_t *src, size_t n) = libc_func;
 	wchar_t buf[len1 + len2 + 1];
 
-	for (i = 0; opt_do_run && (i < len1 - 1); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < len1 - 1); i++) {
 		*buf = '\0';
 		WCSCHK(name, buf == __wcsncat(buf, str1, len1), failed);
 		*buf = '\0';
@@ -339,7 +339,7 @@ static void stress_wcschr(
 
 	(void)len2;
 
-	for (i = 0; opt_do_run && (i < len1 - 1); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < len1 - 1); i++) {
 		WCSCHK(name, NULL == __wcschr(str1, '_'), failed);
 		WCSCHK(name, NULL != __wcschr(str1, str1[0]), failed);
 
@@ -366,7 +366,7 @@ static void stress_wcsrchr(
 
 	(void)len2;
 
-	for (i = 0; opt_do_run && (i < len1 - 1); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < len1 - 1); i++) {
 		WCSCHK(name, NULL == __wcsrchr(str1, '_'), failed);
 		WCSCHK(name, NULL != __wcsrchr(str1, str1[0]), failed);
 
@@ -393,7 +393,7 @@ static void stress_wcscmp(
 
 	(void)len2;
 
-	for (i = 1; opt_do_run && (i < len1); i++) {
+	for (i = 1; g_keep_stressing_flag && (i < len1); i++) {
 		WCSCHK(name, 0 == __wcscmp(str1, str1), failed);
 		WCSCHK(name, 0 == __wcscmp(str2, str2), failed);
 
@@ -425,7 +425,7 @@ static void stress_wcsncmp(
 	register size_t i;
 	int (*__wcsncmp)(const wchar_t *s1, const wchar_t *s2, size_t n) = libc_func;
 
-	for (i = 1; opt_do_run && (i < len1); i++) {
+	for (i = 1; g_keep_stressing_flag && (i < len1); i++) {
 		WCSCHK(name, 0 == __wcsncmp(str1, str1, len1), failed);
 		WCSCHK(name, 0 == __wcsncmp(str2, str2, len2), failed);
 
@@ -457,12 +457,12 @@ static void stress_wcslen(
 	register size_t i;
 	size_t (*__wcslen)(const wchar_t *s) = libc_func;
 
-	for (i = 0; opt_do_run && (i < len1 - 1); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < len1 - 1); i++) {
 		WCSCHK(name, len1 - 1 == __wcslen(str1), failed);
 		WCSCHK(name, len1 - 1 - i == __wcslen(str1 + i), failed);
 	}
 
-	for (i = 0; opt_do_run && (i < len2 - 1); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < len2 - 1); i++) {
 		WCSCHK(name, len2 - 1 == __wcslen(str2), failed);
 		WCSCHK(name, len2 - 1 - i == __wcslen(str2 + i), failed);
 	}
@@ -486,7 +486,7 @@ static void stress_wcscoll(
 
 	(void)len2;
 
-	for (i = 1; opt_do_run && (i < len1); i++) {
+	for (i = 1; g_keep_stressing_flag && (i < len1); i++) {
 		WCSCHK(name, 0 == __wcscoll(str1, str1), failed);
 		WCSCHK(name, 0 == __wcscoll(str2, str2), failed);
 
@@ -519,7 +519,7 @@ static void stress_wcsxfrm(
 	size_t (*__wcsxfrm)(wchar_t* destination, const wchar_t* source, size_t num) = libc_func;
 	wchar_t buf[len1 + len2];
 
-	for (i = 0; opt_do_run && (i < len1 - 1); i++) {
+	for (i = 0; g_keep_stressing_flag && (i < len1 - 1); i++) {
 		*buf = '\0';
 		WCSCHK(name, 0 != __wcsxfrm(buf, str1, sizeof(buf)), failed);
 		*buf = '\0';
@@ -606,11 +606,11 @@ int stress_set_wcs_method(const char *name)
 		}
 	}
 
-	fprintf(stderr, "wcs-method must be one of:");
+	(void)fprintf(stderr, "wcs-method must be one of:");
 	for (wcsfunction = wcs_methods; wcsfunction->func; wcsfunction++) {
-		fprintf(stderr, " %s", wcsfunction->name);
+		(void)fprintf(stderr, " %s", wcsfunction->name);
 	}
-	fprintf(stderr, "\n");
+	(void)fprintf(stderr, "\n");
 
 	return -1;
 }
@@ -619,27 +619,21 @@ int stress_set_wcs_method(const char *name)
  *  stress_wcs()
  *	stress CPU by doing wide character string ops
  */
-int stress_wcs(
-	uint64_t *const counter,
-	const uint32_t instance,
-	const uint64_t max_ops,
-	const char *name)
+int stress_wcs(const args_t *args)
 {
 	stress_wcs_func func = opt_wcs_stressor->func;
 	const void *libc_func = opt_wcs_stressor->libc_func;
 	bool failed = false;
 
-	(void)instance;
-
 	do {
 		wchar_t str1[STR1LEN], str2[STR2LEN];
 
 		stress_wcs_fill(str1, STR1LEN);
 		stress_wcs_fill(str2, STR2LEN);
 
-		(void)func(libc_func, name, str1, STR1LEN, str2, STR2LEN, &failed);
-		(*counter)++;
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+		(void)func(libc_func, args->name, str1, STR1LEN, str2, STR2LEN, &failed);
+		inc_counter(args);
+	} while (keep_stressing());
 
 	return failed ? EXIT_FAILURE : EXIT_SUCCESS;
 }
