@@ -28,6 +28,10 @@
 
 static pid_t thrash_pid;
 
+/*
+ *  pagein_proc()
+ *	force pages into memory for a given process
+ */
 static int pagein_proc(const pid_t pid)
 {
 	char path[PATH_MAX];
@@ -37,15 +41,15 @@ static int pagein_proc(const pid_t pid)
 	const size_t page_size = stress_get_pagesize();
 	size_t pages = 0;
 
-	snprintf(path, sizeof(path), "/proc/%d/mem", pid);
+	(void)snprintf(path, sizeof(path), "/proc/%d/mem", pid);
 	fdmem = open(path, O_RDONLY);
 	if (fdmem < 0)
 		return -errno;
 
-	snprintf(path, sizeof(path), "/proc/%d/maps", pid);
+	(void)snprintf(path, sizeof(path), "/proc/%d/maps", pid);
 	fpmap = fopen(path, "r");
 	if (!fpmap) {
-		close(fdmem);
+		(void)close(fdmem);
 		return -errno;
 	}
 
@@ -58,6 +62,15 @@ static int pagein_proc(const pid_t pid)
 		uint8_t byte;
 		if (sscanf(buffer, "%jx-%jx", &begin, &end) != 2)
 			continue;
+		/* Ignore bad range */
+		if (begin >= end)
+			continue;
+		/* Skip huge ranges more than 2GB */
+		if (end - begin > 0x80000000UL)
+			continue;
+		/* Skip bad start */
+		if (end == 0)
+			continue;
 
 		for (off = (off_t)begin; off < (off_t)end; off += page_size, pages++) {
 			if (lseek(fdmem, off, SEEK_SET) == (off_t)-1)
@@ -74,6 +87,10 @@ static int pagein_proc(const pid_t pid)
 	return 0;
 }
 
+/*
+ *  pagein_all_procs()
+ *	force pages into memory for all processes
+ */
 static int pagein_all_procs(void)
 {
 	DIR *dp;
@@ -96,26 +113,30 @@ static int pagein_all_procs(void)
 	return 0;
 }
 
+/*
+ *  thrash_start()
+ *	start paging in thrash process
+ */
 int thrash_start(void)
 {
 	if (geteuid() != 0) {
-		pr_inf(stdout, "not running as root, ignoring --thrash option\n");
+		pr_inf("not running as root, ignoring --thrash option\n");
 		return -1;
 	}
 	if (thrash_pid) {
-		pr_err(stderr, "thrash background process already started\n");
+		pr_err("thrash background process already started\n");
 		return -1;
 	}
 	thrash_pid = fork();
 	if (thrash_pid < 0) {
-		pr_err(stderr, "thrash background process failed to fork: %d (%s)\n",
+		pr_err("thrash background process failed to fork: %d (%s)\n",
 			errno, strerror(errno));
 		return -1;
 	} else if (thrash_pid == 0) {
 #if defined(SCHED_RR)
 		set_sched(SCHED_RR, 10);
 #endif
-		while (opt_do_run) {
+		while (g_keep_stressing_flag) {
 			pagein_all_procs();
 			sleep(1);
 		}
@@ -124,6 +145,10 @@ int thrash_start(void)
 	return 0;
 }
 
+/*
+ *  thrash_stop()
+ *	stop paging in thrash process
+ */
 void thrash_stop(void)
 {
 	int status;
